/*****************************************************************************
  glexthandler.h - Extension handler class
  copyright - 2004, 2005 by Matthaeus G. Chajdas
  -------------------------------------------------------------------------

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights 
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
  copies of the Software, and to permit persons to whom the Software is 
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  SOFTWARE.

  The Original Code is glexthandler.h.

  The Initial Developer of the Original Code is Matthaeus G. Chajdas. Portions 
  created by Matthaeus G. Chajdas are Copyright (C) 2004 Matthaeus G. Chajdas. 
  All Rights Reserved.

*****************************************************************************/

/**
  This file is autogenerated. To create it, first get a up-to-date XML database
  or all OpenGL extensions (use glext2_app.py if you don't have one handy).
  Then, run glext2_app.py and select "Generate .h" to create this file.
*/

#ifdef WIN32
#  define WIN32_LEAN_AND_MEAN	// Less unneeded stuff
#  include <windows.h>
#  include <wingdi.h>

#  include <STDDEF.H>		// ptrdiff_t and friends

  // WGL_* seems to have some deprecated types...
#  define HPBUFFEREXT HANDLE
#  define HPBUFFERARB HANDLE

  // Otherwise MSVC++ doesn't know what's going on
#  define NIV_CALL_TYPE __stdcall
#endif

/// For all kinds of typedefs
#include <gl/gl.h>

/// For assert in the various init functions
#include <assert.h>

/// So GetProcAddress is really cross-platform
#ifdef WIN32
#  define getProcAddress wglGetProcAddress
#else /* GLX */
#  define getProcAddress glXGetProcAddressARB
#endif

/// @TODO: Handle GLU / GLX...
/// For now, just undef them
#undef _GLX
#undef _GLU

/// Helper function to get the proc address in a cross-platform manner
static void* GetProcAddress( const char* name )
{
  return getProcAddress ( name );
}

/// Macro for simpler function inits
/// To init a function, all that needs to be done is to
/// set the function pointer. All function pointers are
/// reset to 0 when the class is constructed, so it is safe
/// to use \code
/// if (ext_loader.glMyEXT) )
///    ext_loader.glMyEXT ( "call the extension" );
/// \endcode
#define INIT_FUNCTION( type, name )                     \
if ( name == 0 )	/* If already loaded, skip */       \
{                                                       \
  type __func##name;                                    \
  __func##name = ( type ) GetProcAddress ( #name );     \
                                                        \
  if (__func##name == NULL)                             \
  {                                                     \
      assert(0);                                        \
      error = true;                                     \
  }                                                     \
                                                        \
  name = __func##name;                                  \
}


#ifndef __INGNORE_MISSING_TYPEDEFS_HANDLE_AND_CHAR_ARB
  // From GL_ARB_shader_objects, but another extension needs them
  // before GL_ARB_shader_objects is defined...
#  ifndef TYPE_GLHANDLEARB_DEFINED
  typedef int GLhandleARB;
#  define TYPE_GLHANDLEARB_DEFINED
#  endif

#  ifndef TYPE_GLCHARB_DEFINED
  typedef char GLcharARB;
#  define TYPE_GLCHARB_DEFINED
#  endif
#endif // __INGNORE_MISSING_TYPEDEFS_HANDLE_AND_CHAR_ARB

// All extensions
// GL_ARB_texture_compression
#ifndef GL_COMPRESSED_RGBA_ARB
#define GL_COMPRESSED_RGBA_ARB 0x84EE
#endif

#ifndef GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB
#define GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB 0x86A0
#endif

#ifndef GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB
#define GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB 0x86A2
#endif

#ifndef GL_COMPRESSED_ALPHA_ARB
#define GL_COMPRESSED_ALPHA_ARB 0x84E9
#endif

#ifndef GL_COMPRESSED_INTENSITY_ARB
#define GL_COMPRESSED_INTENSITY_ARB 0x84EC
#endif

#ifndef GL_COMPRESSED_RGB_ARB
#define GL_COMPRESSED_RGB_ARB 0x84ED
#endif

#ifndef GL_COMPRESSED_TEXTURE_FORMATS_ARB
#define GL_COMPRESSED_TEXTURE_FORMATS_ARB 0x86A3
#endif

#ifndef GL_COMPRESSED_LUMINANCE_ALPHA_ARB
#define GL_COMPRESSED_LUMINANCE_ALPHA_ARB 0x84EB
#endif

#ifndef GL_TEXTURE_COMPRESSED_ARB
#define GL_TEXTURE_COMPRESSED_ARB 0x86A1
#endif

#ifndef GL_TEXTURE_COMPRESSION_HINT_ARB
#define GL_TEXTURE_COMPRESSION_HINT_ARB 0x84EF
#endif

#ifndef GL_COMPRESSED_LUMINANCE_ARB
#define GL_COMPRESSED_LUMINANCE_ARB 0x84EA
#endif

typedef void (NIV_CALL_TYPE * nivenGLCOMPRESSEDTEXIMAGE1DARB) (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void* data);
typedef void (NIV_CALL_TYPE * nivenGLGETCOMPRESSEDTEXIMAGEARB) (GLenum target, GLint lod, void* img);
typedef void (NIV_CALL_TYPE * nivenGLCOMPRESSEDTEXSUBIMAGE1DARB) (GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void* data);
typedef void (NIV_CALL_TYPE * nivenGLCOMPRESSEDTEXIMAGE3DARB) (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void* data);
typedef void (NIV_CALL_TYPE * nivenGLCOMPRESSEDTEXSUBIMAGE2DARB) (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void* data);
typedef void (NIV_CALL_TYPE * nivenGLCOMPRESSEDTEXSUBIMAGE3DARB) (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void* data);
typedef void (NIV_CALL_TYPE * nivenGLCOMPRESSEDTEXIMAGE2DARB) (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void* data);

// GL_SGIX_vertex_preclip
#ifndef GL_VERTEX_PRECLIP_SGIX
#define GL_VERTEX_PRECLIP_SGIX 0x83EE
#endif

#ifndef GL_VERTEX_PRECLIP_HINT_SGIX
#define GL_VERTEX_PRECLIP_HINT_SGIX 0x83EF
#endif


// GL_SGIX_async_pixel
#ifndef GL_MAX_ASYNC_TEX_IMAGE_SGIX
#define GL_MAX_ASYNC_TEX_IMAGE_SGIX 0x835F
#endif

#ifndef GL_ASYNC_DRAW_PIXELS_SGIX
#define GL_ASYNC_DRAW_PIXELS_SGIX 0x835D
#endif

#ifndef GL_ASYNC_TEX_IMAGE_SGIX
#define GL_ASYNC_TEX_IMAGE_SGIX 0x835C
#endif

#ifndef GL_MAX_ASYNC_DRAW_PIXELS_SGIX
#define GL_MAX_ASYNC_DRAW_PIXELS_SGIX 0x8360
#endif

#ifndef GL_MAX_ASYNC_READ_PIXELS_SGIX
#define GL_MAX_ASYNC_READ_PIXELS_SGIX 0x8361
#endif

#ifndef GL_ASYNC_READ_PIXELS_SGIX
#define GL_ASYNC_READ_PIXELS_SGIX 0x835E
#endif


// GL_NV_point_sprite
#ifndef GL_POINT_SPRITE_NV
#define GL_POINT_SPRITE_NV 0x8861
#endif

#ifndef GL_POINT_SPRITE_R_MODE_NV
#define GL_POINT_SPRITE_R_MODE_NV 0x8863
#endif

#ifndef GL_COORD_REPLACE_NV
#define GL_COORD_REPLACE_NV 0x8862
#endif

typedef void (NIV_CALL_TYPE * nivenGLPOINTPARAMETERINV) (GLenum pname, GLint param);
typedef void (NIV_CALL_TYPE * nivenGLPOINTPARAMETERIVNV) (GLenum pname, const GLint* params);

// GL_APPLE_element_array
#ifndef GL_ELEMENT_ARRAY_APPLE
#define GL_ELEMENT_ARRAY_APPLE 0x8768
#endif

#ifndef GL_ELEMENT_ARRAY_TYPE_APPLE
#define GL_ELEMENT_ARRAY_TYPE_APPLE 0x8769
#endif

#ifndef GL_ELEMENT_ARRAY_POINTER_APPLE
#define GL_ELEMENT_ARRAY_POINTER_APPLE 0x876A
#endif

typedef void (NIV_CALL_TYPE * nivenGLMULTIDRAWRANGEELEMENTARRAYAPPLE) (GLenum mode, GLuint start, GLuint end, const GLint* first, const GLsizei* count, GLsizei primcount);
typedef void (NIV_CALL_TYPE * nivenGLELEMENTPOINTERAPPLE) (GLenum type, const void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLDRAWRANGEELEMENTARRAYAPPLE) (GLenum mode, GLuint start, GLuint end, GLint first, GLsizei count);
typedef void (NIV_CALL_TYPE * nivenGLMULTIDRAWELEMENTARRAYAPPLE) (GLenum mode, const GLint* first, const GLsizei* count, GLsizei primcount);
typedef void (NIV_CALL_TYPE * nivenGLDRAWELEMENTARRAYAPPLE) (GLenum mode, GLint first, GLsizei count);

#ifdef _GLX
// GLX_EXT_import_context
#ifndef GLX_SHARE_CONTEXT_EXT
#define GLX_SHARE_CONTEXT_EXT 0x800A
#endif

#ifndef GLX_VISUAL_ID_EXT
#define GLX_VISUAL_ID_EXT 0x800B
#endif

#ifndef GLX_SCREEN_EXT
#define GLX_SCREEN_EXT 0x800C
#endif

#ifndef TYPE_GLXCONTEXTID_DEFINED
typedef XID GLXContextID;
#endif
typedef GLXContext (NIV_CALL_TYPE * nivenGLXIMPORTCONTEXTEXT) (Display* dpy, GLXContextID contextID);
typedef GLXContextID (NIV_CALL_TYPE * nivenGLXGETCONTEXTIDEXT) (const GLXContext context);
typedef void (NIV_CALL_TYPE * nivenGLXFREECONTEXTEXT) (Display* dpy, GLXContext context);
typedef int (NIV_CALL_TYPE * nivenGLXQUERYCONTEXTINFOEXT) (Display* dpy, GLXContext context, int attribute, int* value);
#endif // _GLX
// GL_NV_vertex_array_range2
#ifndef GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV
#define GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV 0x8533
#endif


// GL_EXT_blend_color
#ifndef GL_CONSTANT_ALPHA_EXT
#define GL_CONSTANT_ALPHA_EXT 0x8003
#endif

#ifndef GL_CONSTANT_COLOR_EXT
#define GL_CONSTANT_COLOR_EXT 0x8001
#endif

#ifndef GL_BLEND_COLOR_EXT
#define GL_BLEND_COLOR_EXT 0x8005
#endif

#ifndef GL_ONE_MINUS_CONSTANT_ALPHA_EXT
#define GL_ONE_MINUS_CONSTANT_ALPHA_EXT 0x8004
#endif

#ifndef GL_ONE_MINUS_CONSTANT_COLOR_EXT
#define GL_ONE_MINUS_CONSTANT_COLOR_EXT 0x8002
#endif

typedef void (NIV_CALL_TYPE * nivenGLBLENDCOLOREXT) (GLclampf red, GLclampf green, GLclampf blue, GLclampf alpha);

// GL_EXT_blend_subtract
#ifndef GL_FUNC_REVERSE_SUBTRACT_EXT
#define GL_FUNC_REVERSE_SUBTRACT_EXT 0x800B
#endif

#ifndef GL_FUNC_SUBTRACT_EXT
#define GL_FUNC_SUBTRACT_EXT 0x800A
#endif


// GL_SGIX_tag_sample_buffer
typedef void (NIV_CALL_TYPE * nivenGLTAGSAMPLEBUFFERSGIX) (void );

// GL_EXT_stencil_wrap
#ifndef GL_DECR_WRAP_EXT
#define GL_DECR_WRAP_EXT 0x8508
#endif

#ifndef GL_INCR_WRAP_EXT
#define GL_INCR_WRAP_EXT 0x8507
#endif


// GL_EXT_index_array_formats

// GL_EXT_index_texture

// GL_IBM_texture_mirrored_repeat
#ifndef GL_MIRRORED_REPEAT_IBM
#define GL_MIRRORED_REPEAT_IBM 0x8370
#endif


// GL_NV_half_float
#ifndef GL_HALF_FLOAT_NV
#define GL_HALF_FLOAT_NV 0x140B
#endif

#ifndef TYPE_GLHALF_DEFINED
typedef unsigned short GLhalf;
#endif
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD2HVNV) (GLenum target, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXWEIGHTHNV) (GLhalf weight);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD4HVNV) (const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS3HVNV) (GLuint index, GLsizei n, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS2HVNV) (GLuint index, GLsizei n, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEX4HVNV) (const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3HVNV) (const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLFOGCOORDHVNV) (const GLhalf* fog);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD3HVNV) (const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEX2HNV) (GLhalf x, GLhalf y);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD1HNV) (GLhalf s);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3HVNV) (GLuint index, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1HVNV) (GLuint index, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD1HVNV) (GLenum target, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2HVNV) (const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD4HVNV) (GLenum target, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4HNV) (GLuint index, GLhalf x, GLhalf y, GLhalf z, GLhalf w);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD1HNV) (GLenum target, GLhalf s);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXWEIGHTHVNV) (const GLhalf* weight);
typedef void (NIV_CALL_TYPE * nivenGLNORMAL3HNV) (GLhalf nx, GLhalf ny, GLhalf nz);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD3HNV) (GLhalf s, GLhalf t, GLhalf r);
typedef void (NIV_CALL_TYPE * nivenGLCOLOR4HNV) (GLhalf red, GLhalf green, GLhalf blue, GLhalf alpha);
typedef void (NIV_CALL_TYPE * nivenGLFOGCOORDHNV) (GLhalf fog);
typedef void (NIV_CALL_TYPE * nivenGLVERTEX2HVNV) (const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3HNV) (GLhalf red, GLhalf green, GLhalf blue);
typedef void (NIV_CALL_TYPE * nivenGLNORMAL3HVNV) (const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2HNV) (GLhalf s, GLhalf t);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4HVNV) (GLuint index, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEX3HVNV) (const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEX3HNV) (GLhalf x, GLhalf y, GLhalf z);
typedef void (NIV_CALL_TYPE * nivenGLCOLOR3HVNV) (const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2HVNV) (GLuint index, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLCOLOR3HNV) (GLhalf red, GLhalf green, GLhalf blue);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD4HNV) (GLenum target, GLhalf s, GLhalf t, GLhalf r, GLhalf q);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS4HVNV) (GLuint index, GLsizei n, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1HNV) (GLuint index, GLhalf x);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD3HVNV) (GLenum target, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS1HVNV) (GLuint index, GLsizei n, const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD4HNV) (GLhalf s, GLhalf t, GLhalf r, GLhalf q);
typedef void (NIV_CALL_TYPE * nivenGLVERTEX4HNV) (GLhalf x, GLhalf y, GLhalf z, GLhalf w);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD2HNV) (GLenum target, GLhalf s, GLhalf t);
typedef void (NIV_CALL_TYPE * nivenGLCOLOR4HVNV) (const GLhalf* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2HNV) (GLuint index, GLhalf x, GLhalf y);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD3HNV) (GLenum target, GLhalf s, GLhalf t, GLhalf r);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3HNV) (GLuint index, GLhalf x, GLhalf y, GLhalf z);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD1HVNV) (const GLhalf* v);

// WGL_ARB_extensions_string
#ifdef WIN32
typedef const char* (NIV_CALL_TYPE * nivenWGLGETEXTENSIONSSTRINGARB) (HDC hdc);
#endif
// GL_SGIX_texture_scale_bias
#ifndef GL_POST_TEXTURE_FILTER_BIAS_SGIX
#define GL_POST_TEXTURE_FILTER_BIAS_SGIX 0x8179
#endif

#ifndef GL_POST_TEXTURE_FILTER_SCALE_SGIX
#define GL_POST_TEXTURE_FILTER_SCALE_SGIX 0x817A
#endif

#ifndef GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX
#define GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX 0x817B
#endif

#ifndef GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX
#define GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX 0x817C
#endif


// GL_EXT_texture_compression_s3tc
#ifndef GL_COMPRESSED_RGBA_S3TC_DXT5_EXT
#define GL_COMPRESSED_RGBA_S3TC_DXT5_EXT 0x83F3
#endif

#ifndef GL_COMPRESSED_RGBA_S3TC_DXT3_EXT
#define GL_COMPRESSED_RGBA_S3TC_DXT3_EXT 0x83F2
#endif


// GL_APPLE_transform_hint
#ifndef GL_TRANSFORM_HINT_APPLE
#define GL_TRANSFORM_HINT_APPLE 0x85B1
#endif


// GL_ATI_separate_stencil
#ifndef GL_STENCIL_BACK_FAIL_ATI
#define GL_STENCIL_BACK_FAIL_ATI 0x8801
#endif

#ifndef GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI
#define GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI 0x8802
#endif

#ifndef GL_STENCIL_BACK_FUNC_ATI
#define GL_STENCIL_BACK_FUNC_ATI 0x8800
#endif

#ifndef GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI
#define GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI 0x8803
#endif

typedef void (NIV_CALL_TYPE * nivenGLSTENCILOPSEPARATEATI) (GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass);
typedef void (NIV_CALL_TYPE * nivenGLSTENCILFUNCSEPARATEATI) (GLenum frontfunc, GLenum backfunc, GLint ref, GLuint mask);

// GL_EXT_polygon_offset
#ifndef GL_POLYGON_OFFSET_FACTOR_EXT
#define GL_POLYGON_OFFSET_FACTOR_EXT 0x8038
#endif

#ifndef GL_POLYGON_OFFSET_EXT
#define GL_POLYGON_OFFSET_EXT 0x8037
#endif

#ifndef GL_POLYGON_OFFSET_BIAS_EXT
#define GL_POLYGON_OFFSET_BIAS_EXT 0x8039
#endif

typedef void (NIV_CALL_TYPE * nivenGLPOLYGONOFFSETEXT) (GLfloat factor, GLfloat bias);

// GL_NV_vertex_program2_option

// GL_ARB_depth_texture
#ifndef GL_TEXTURE_DEPTH_SIZE_ARB
#define GL_TEXTURE_DEPTH_SIZE_ARB 0x884A
#endif

#ifndef GL_DEPTH_COMPONENT24_ARB
#define GL_DEPTH_COMPONENT24_ARB 0x81A6
#endif

#ifndef GL_DEPTH_COMPONENT16_ARB
#define GL_DEPTH_COMPONENT16_ARB 0x81A5
#endif

#ifndef GL_DEPTH_COMPONENT32_ARB
#define GL_DEPTH_COMPONENT32_ARB 0x81A7
#endif

#ifndef GL_DEPTH_TEXTURE_MODE_ARB
#define GL_DEPTH_TEXTURE_MODE_ARB 0x884B
#endif


// GL_NV_packed_depth_stencil
#ifndef GL_DEPTH_STENCIL_NV
#define GL_DEPTH_STENCIL_NV 0x84F9
#endif

#ifndef GL_UNSIGNED_INT_24_8_NV
#define GL_UNSIGNED_INT_24_8_NV 0x84FA
#endif


// GL_NV_fragment_program_option

// GL_ARB_vertex_blend
#ifndef GL_MODELVIEW1_ARB
#define GL_MODELVIEW1_ARB 0x850A
#endif

#ifndef GL_WEIGHT_SUM_UNITY_ARB
#define GL_WEIGHT_SUM_UNITY_ARB 0x86A6
#endif

#ifndef GL_MODELVIEW8_ARB
#define GL_MODELVIEW8_ARB 0x8728
#endif

#ifndef GL_MODELVIEW11_ARB
#define GL_MODELVIEW11_ARB 0x872B
#endif

#ifndef GL_WEIGHT_ARRAY_TYPE_ARB
#define GL_WEIGHT_ARRAY_TYPE_ARB 0x86A9
#endif

#ifndef GL_MODELVIEW25_ARB
#define GL_MODELVIEW25_ARB 0x8739
#endif

#ifndef GL_MODELVIEW31_ARB
#define GL_MODELVIEW31_ARB 0x873F
#endif

#ifndef GL_WEIGHT_ARRAY_POINTER_ARB
#define GL_WEIGHT_ARRAY_POINTER_ARB 0x86AC
#endif

#ifndef GL_WEIGHT_ARRAY_ARB
#define GL_WEIGHT_ARRAY_ARB 0x86AD
#endif

#ifndef GL_MODELVIEW22_ARB
#define GL_MODELVIEW22_ARB 0x8736
#endif

#ifndef GL_WEIGHT_ARRAY_STRIDE_ARB
#define GL_WEIGHT_ARRAY_STRIDE_ARB 0x86AA
#endif

#ifndef GL_MODELVIEW20_ARB
#define GL_MODELVIEW20_ARB 0x8734
#endif

#ifndef GL_CURRENT_WEIGHT_ARB
#define GL_CURRENT_WEIGHT_ARB 0x86A8
#endif

#ifndef GL_MODELVIEW30_ARB
#define GL_MODELVIEW30_ARB 0x873E
#endif

#ifndef GL_VERTEX_BLEND_ARB
#define GL_VERTEX_BLEND_ARB 0x86A7
#endif

#ifndef GL_WEIGHT_ARRAY_SIZE_ARB
#define GL_WEIGHT_ARRAY_SIZE_ARB 0x86AB
#endif

#ifndef GL_MODELVIEW23_ARB
#define GL_MODELVIEW23_ARB 0x8737
#endif

#ifndef GL_MODELVIEW26_ARB
#define GL_MODELVIEW26_ARB 0x873A
#endif

#ifndef GL_MODELVIEW3_ARB
#define GL_MODELVIEW3_ARB 0x8723
#endif

#ifndef GL_MODELVIEW4_ARB
#define GL_MODELVIEW4_ARB 0x8724
#endif

#ifndef GL_MODELVIEW14_ARB
#define GL_MODELVIEW14_ARB 0x872E
#endif

#ifndef GL_MODELVIEW28_ARB
#define GL_MODELVIEW28_ARB 0x873C
#endif

#ifndef GL_MODELVIEW18_ARB
#define GL_MODELVIEW18_ARB 0x8732
#endif

#ifndef GL_MODELVIEW24_ARB
#define GL_MODELVIEW24_ARB 0x8738
#endif

#ifndef GL_MODELVIEW5_ARB
#define GL_MODELVIEW5_ARB 0x8725
#endif

#ifndef GL_MODELVIEW29_ARB
#define GL_MODELVIEW29_ARB 0x873D
#endif

#ifndef GL_MODELVIEW21_ARB
#define GL_MODELVIEW21_ARB 0x8735
#endif

#ifndef GL_MODELVIEW16_ARB
#define GL_MODELVIEW16_ARB 0x8730
#endif

#ifndef GL_ACTIVE_VERTEX_UNITS_ARB
#define GL_ACTIVE_VERTEX_UNITS_ARB 0x86A5
#endif

#ifndef GL_MODELVIEW27_ARB
#define GL_MODELVIEW27_ARB 0x873B
#endif

#ifndef GL_MODELVIEW10_ARB
#define GL_MODELVIEW10_ARB 0x872A
#endif

#ifndef GL_MODELVIEW13_ARB
#define GL_MODELVIEW13_ARB 0x872D
#endif

#ifndef GL_MODELVIEW9_ARB
#define GL_MODELVIEW9_ARB 0x8729
#endif

#ifndef GL_MODELVIEW17_ARB
#define GL_MODELVIEW17_ARB 0x8731
#endif

#ifndef GL_MAX_VERTEX_UNITS_ARB
#define GL_MAX_VERTEX_UNITS_ARB 0x86A4
#endif

#ifndef GL_MODELVIEW2_ARB
#define GL_MODELVIEW2_ARB 0x8722
#endif

#ifndef GL_MODELVIEW6_ARB
#define GL_MODELVIEW6_ARB 0x8726
#endif

#ifndef GL_MODELVIEW12_ARB
#define GL_MODELVIEW12_ARB 0x872C
#endif

#ifndef GL_MODELVIEW15_ARB
#define GL_MODELVIEW15_ARB 0x872F
#endif

#ifndef GL_MODELVIEW0_ARB
#define GL_MODELVIEW0_ARB 0x1700
#endif

#ifndef GL_MODELVIEW19_ARB
#define GL_MODELVIEW19_ARB 0x8733
#endif

#ifndef GL_MODELVIEW7_ARB
#define GL_MODELVIEW7_ARB 0x8727
#endif

typedef void (NIV_CALL_TYPE * nivenGLWEIGHTUBVARB) (GLint size, GLubyte* weights);
typedef void (NIV_CALL_TYPE * nivenGLWEIGHTSVARB) (GLint size, GLshort* weights);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXBLENDARB) (GLint count);
typedef void (NIV_CALL_TYPE * nivenGLWEIGHTIVARB) (GLint size, GLint* weights);
typedef void (NIV_CALL_TYPE * nivenGLWEIGHTBVARB) (GLint size, GLbyte* weights);
typedef void (NIV_CALL_TYPE * nivenGLWEIGHTUSVARB) (GLint size, GLushort* weights);
typedef void (NIV_CALL_TYPE * nivenGLWEIGHTPOINTERARB) (GLint size, GLenum type, GLsizei stride, GLvoid* pointer);
typedef void (NIV_CALL_TYPE * nivenGLWEIGHTFVARB) (GLint size, GLfloat* weights);
typedef void (NIV_CALL_TYPE * nivenGLWEIGHTUIVARB) (GLint size, GLuint* weights);
typedef void (NIV_CALL_TYPE * nivenGLWEIGHTDVARB) (GLint size, GLdouble* weights);

// GL_SGIX_ycrcb

// GL_EXT_stencil_two_side
#ifndef GL_STENCIL_TEST_TWO_SIDE_EXT
#define GL_STENCIL_TEST_TWO_SIDE_EXT 0x8910
#endif

#ifndef GL_ACTIVE_STENCIL_FACE_EXT
#define GL_ACTIVE_STENCIL_FACE_EXT 0x8911
#endif

typedef void (NIV_CALL_TYPE * nivenGLACTIVESTENCILFACEEXT) (GLenum face);

// WGL_NV_vertex_array_range
#ifdef WIN32
typedef void (NIV_CALL_TYPE * nivenWGLFREEMEMORYNV) (void* pointer);
typedef void * (NIV_CALL_TYPE * nivenWGLALLOCATEMEMORYNV) (GLsizei size, GLfloat readFrequency, GLfloat writeFrequency, GLfloat priority);
#endif
// GL_EXT_shadow_funcs

// GL_EXT_Cg_shader
#ifndef GL_CG_FRAGMENT_SHADER_EXT
#define GL_CG_FRAGMENT_SHADER_EXT 0x890F
#endif

#ifndef GL_CG_VERTEX_SHADER_EXT
#define GL_CG_VERTEX_SHADER_EXT 0x890E
#endif


#ifdef _GLX
// GLX_SGIS_multisample
#ifndef GLX_SAMPLES_SGIS
#define GLX_SAMPLES_SGIS 100001
#endif

#ifndef GLX_SAMPLE_BUFFERS_SGIS
#define GLX_SAMPLE_BUFFERS_SGIS 100000
#endif

#endif // _GLX
// GL_EXT_convolution
#ifndef GL_POST_CONVOLUTION_BLUE_BIAS_EXT
#define GL_POST_CONVOLUTION_BLUE_BIAS_EXT 0x8022
#endif

#ifndef GL_CONVOLUTION_HEIGHT_EXT
#define GL_CONVOLUTION_HEIGHT_EXT 0x8019
#endif

#ifndef GL_CONVOLUTION_2D_EXT
#define GL_CONVOLUTION_2D_EXT 0x8011
#endif

#ifndef GL_REDUCE_EXT
#define GL_REDUCE_EXT 0x8016
#endif

#ifndef GL_MAX_CONVOLUTION_WIDTH_EXT
#define GL_MAX_CONVOLUTION_WIDTH_EXT 0x801A
#endif

#ifndef GL_POST_CONVOLUTION_ALPHA_BIAS_EXT
#define GL_POST_CONVOLUTION_ALPHA_BIAS_EXT 0x8023
#endif

#ifndef GL_MAX_CONVOLUTION_HEIGHT_EXT
#define GL_MAX_CONVOLUTION_HEIGHT_EXT 0x801B
#endif

#ifndef GL_CONVOLUTION_BORDER_MODE_EXT
#define GL_CONVOLUTION_BORDER_MODE_EXT 0x8013
#endif

#ifndef GL_POST_CONVOLUTION_RED_SCALE_EXT
#define GL_POST_CONVOLUTION_RED_SCALE_EXT 0x801C
#endif

#ifndef GL_CONVOLUTION_FILTER_BIAS_EXT
#define GL_CONVOLUTION_FILTER_BIAS_EXT 0x8015
#endif

#ifndef GL_POST_CONVOLUTION_GREEN_BIAS_EXT
#define GL_POST_CONVOLUTION_GREEN_BIAS_EXT 0x8021
#endif

#ifndef GL_CONVOLUTION_WIDTH_EXT
#define GL_CONVOLUTION_WIDTH_EXT 0x8018
#endif

#ifndef GL_CONVOLUTION_FORMAT_EXT
#define GL_CONVOLUTION_FORMAT_EXT 0x8017
#endif

#ifndef GL_POST_CONVOLUTION_RED_BIAS_EXT
#define GL_POST_CONVOLUTION_RED_BIAS_EXT 0x8020
#endif

#ifndef GL_POST_CONVOLUTION_BLUE_SCALE_EXT
#define GL_POST_CONVOLUTION_BLUE_SCALE_EXT 0x801E
#endif

#ifndef GL_POST_CONVOLUTION_ALPHA_SCALE_EXT
#define GL_POST_CONVOLUTION_ALPHA_SCALE_EXT 0x801F
#endif

#ifndef GL_SEPARABLE_2D_EXT
#define GL_SEPARABLE_2D_EXT 0x8012
#endif

#ifndef GL_CONVOLUTION_1D_EXT
#define GL_CONVOLUTION_1D_EXT 0x8010
#endif

#ifndef GL_POST_CONVOLUTION_GREEN_SCALE_EXT
#define GL_POST_CONVOLUTION_GREEN_SCALE_EXT 0x801D
#endif

#ifndef GL_CONVOLUTION_FILTER_SCALE_EXT
#define GL_CONVOLUTION_FILTER_SCALE_EXT 0x8014
#endif

typedef void (NIV_CALL_TYPE * nivenGLGETCONVOLUTIONPARAMETERIVEXT) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLSEPARABLEFILTER2DEXT) (GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void* row, const void* column);
typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONPARAMETERIEXT) (GLenum target, GLenum pname, GLint param);
typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONPARAMETERIVEXT) (GLenum target, GLenum pname, const GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETCONVOLUTIONPARAMETERFVEXT) (GLenum target, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETSEPARABLEFILTEREXT) (GLenum target, GLenum format, GLenum type, void* row, void* column, void* span);
typedef void (NIV_CALL_TYPE * nivenGLCOPYCONVOLUTIONFILTER2DEXT) (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height);
typedef void (NIV_CALL_TYPE * nivenGLCOPYCONVOLUTIONFILTER1DEXT) (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width);
typedef void (NIV_CALL_TYPE * nivenGLGETCONVOLUTIONFILTEREXT) (GLenum target, GLenum format, GLenum type, void* image);
typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONFILTER1DEXT) (GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void* image);
typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONFILTER2DEXT) (GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void* image);
typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONPARAMETERFEXT) (GLenum target, GLenum pname, GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONPARAMETERFVEXT) (GLenum target, GLenum pname, const GLfloat* params);

// WGL_EXT_pbuffer
#ifdef WIN32
#ifndef WGL_DRAW_TO_PBUFFER_EXT
#define WGL_DRAW_TO_PBUFFER_EXT 0x202D
#endif

#ifndef WGL_OPTIMAL_PBUFFER_HEIGHT_EXT
#define WGL_OPTIMAL_PBUFFER_HEIGHT_EXT 0x2032
#endif

#ifndef WGL_PBUFFER_LARGEST_EXT
#define WGL_PBUFFER_LARGEST_EXT 0x2033
#endif

#ifndef WGL_MAX_PBUFFER_WIDTH_EXT
#define WGL_MAX_PBUFFER_WIDTH_EXT 0x202F
#endif

#ifndef WGL_MAX_PBUFFER_PIXELS_EXT
#define WGL_MAX_PBUFFER_PIXELS_EXT 0x202E
#endif

#ifndef WGL_PBUFFER_HEIGHT_EXT
#define WGL_PBUFFER_HEIGHT_EXT 0x2035
#endif

#ifndef WGL_PBUFFER_WIDTH_EXT
#define WGL_PBUFFER_WIDTH_EXT 0x2034
#endif

#ifndef WGL_MAX_PBUFFER_HEIGHT_EXT
#define WGL_MAX_PBUFFER_HEIGHT_EXT 0x2030
#endif

#ifndef WGL_OPTIMAL_PBUFFER_WIDTH_EXT
#define WGL_OPTIMAL_PBUFFER_WIDTH_EXT 0x2031
#endif

typedef HPBUFFEREXT (NIV_CALL_TYPE * nivenWGLCREATEPBUFFEREXT) (HDC hDC, int iPixelFormat, int iWidth, int iHeight, const int* piAttribList);
typedef BOOL (NIV_CALL_TYPE * nivenWGLQUERYPBUFFEREXT) (HPBUFFEREXT hPbuffer, int iAttribute, int* piValue);
typedef int (NIV_CALL_TYPE * nivenWGLRELEASEPBUFFERDCEXT) (HPBUFFEREXT hPbuffer, HDC hDC);
typedef HDC (NIV_CALL_TYPE * nivenWGLGETPBUFFERDCEXT) (HPBUFFEREXT hPbuffer);
typedef BOOL (NIV_CALL_TYPE * nivenWGLDESTROYPBUFFEREXT) (HPBUFFEREXT hPbuffer);
#endif
// WGL_I3D_genlock
#ifdef WIN32
#ifndef WGL_GENLOCK_SOURCE_MULTIVIEW_I3D
#define WGL_GENLOCK_SOURCE_MULTIVIEW_I3D 0x2044
#endif

#ifndef WGL_GENLOCK_SOURCE_EDGE_BOTH_I3D
#define WGL_GENLOCK_SOURCE_EDGE_BOTH_I3D 0x204C
#endif

#ifndef WGL_GENLOCK_SOURCE_EXTERNAL_SYNC_I3D
#define WGL_GENLOCK_SOURCE_EXTERNAL_SYNC_I3D 0x2045
#endif

#ifndef WGL_GENLOCK_SOURCE_DIGITAL_FIELD_I3D
#define WGL_GENLOCK_SOURCE_DIGITAL_FIELD_I3D 0x2049
#endif

#ifndef WGL_GENLOCK_SOURCE_EDGE_FALLING_I3D
#define WGL_GENLOCK_SOURCE_EDGE_FALLING_I3D 0x204A
#endif

#ifndef WGL_GENLOCK_SOURCE_DIGITAL_SYNC_I3D
#define WGL_GENLOCK_SOURCE_DIGITAL_SYNC_I3D 0x2048
#endif

#ifndef WGL_GENLOCK_SOURCE_EXTERNAL_TTL_I3D
#define WGL_GENLOCK_SOURCE_EXTERNAL_TTL_I3D 0x2047
#endif

#ifndef WGL_GENLOCK_SOURCE_EDGE_RISING_I3D
#define WGL_GENLOCK_SOURCE_EDGE_RISING_I3D 0x204B
#endif

#ifndef WGL_GENLOCK_SOURCE_EXTERNAL_FIELD_I3D
#define WGL_GENLOCK_SOURCE_EXTERNAL_FIELD_I3D 0x2046
#endif

typedef BOOL (NIV_CALL_TYPE * nivenWGLGENLOCKSOURCEEDGEI3D) (HDC hDC, UINT uEdge);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGETGENLOCKSOURCEDELAYI3D) (HDC hDC, UINT* uDelay);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGENLOCKSOURCEDELAYI3D) (HDC hDC, UINT uDelay);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGETGENLOCKSOURCEI3D) (HDC hDC, UINT* uSource);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGENLOCKSAMPLERATEI3D) (HDC hDC, UINT uRate);
typedef BOOL (NIV_CALL_TYPE * nivenWGLISENABLEDGENLOCKI3D) (HDC hDC, BOOL* pFlag);
typedef BOOL (NIV_CALL_TYPE * nivenWGLDISABLEGENLOCKI3D) (HDC hDC);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGETGENLOCKSAMPLERATEI3D) (HDC hDC, UINT* uRate);
typedef BOOL (NIV_CALL_TYPE * nivenWGLQUERYGENLOCKMAXSOURCEDELAYI3D) (HDC hDC, UINT* uMaxLineDelay, UINT* uMaxPixelDelay);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGETGENLOCKSOURCEEDGEI3D) (HDC hDC, UINT* uEdge);
typedef BOOL (NIV_CALL_TYPE * nivenWGLENABLEGENLOCKI3D) (HDC hDC);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGENLOCKSOURCEI3D) (HDC hDC, UINT uSource);
#endif
#ifdef _GLX
// GLX_ATI_pixel_format_float
#ifndef GLX_RGBA_FLOAT_ATI_BIT
#define GLX_RGBA_FLOAT_ATI_BIT 0x00000100
#endif

#endif // _GLX
#ifdef _GLX
// GLX_ARB_multisample
#ifndef GLX_SAMPLES_ARB
#define GLX_SAMPLES_ARB 100001
#endif

#ifndef GLX_SAMPLE_BUFFERS_ARB
#define GLX_SAMPLE_BUFFERS_ARB 100000
#endif

#endif // _GLX
// WGL_ARB_pixel_format
#ifdef WIN32
#ifndef WGL_GREEN_SHIFT_ARB
#define WGL_GREEN_SHIFT_ARB 0x2018
#endif

#ifndef WGL_TRANSPARENT_GREEN_VALUE_ARB
#define WGL_TRANSPARENT_GREEN_VALUE_ARB 0x2038
#endif

#ifndef WGL_SHARE_STENCIL_ARB
#define WGL_SHARE_STENCIL_ARB 0x200D
#endif

#ifndef WGL_ALPHA_SHIFT_ARB
#define WGL_ALPHA_SHIFT_ARB 0x201C
#endif

#ifndef WGL_ACCUM_BITS_ARB
#define WGL_ACCUM_BITS_ARB 0x201D
#endif

#ifndef WGL_TRANSPARENT_RED_VALUE_ARB
#define WGL_TRANSPARENT_RED_VALUE_ARB 0x2037
#endif

#ifndef WGL_ACCUM_ALPHA_BITS_ARB
#define WGL_ACCUM_ALPHA_BITS_ARB 0x2021
#endif

#ifndef WGL_GENERIC_ACCELERATION_ARB
#define WGL_GENERIC_ACCELERATION_ARB 0x2026
#endif

#ifndef WGL_SWAP_COPY_ARB
#define WGL_SWAP_COPY_ARB 0x2029
#endif

#ifndef WGL_DRAW_TO_BITMAP_ARB
#define WGL_DRAW_TO_BITMAP_ARB 0x2002
#endif

#ifndef WGL_SHARE_ACCUM_ARB
#define WGL_SHARE_ACCUM_ARB 0x200E
#endif

#ifndef WGL_NO_ACCELERATION_ARB
#define WGL_NO_ACCELERATION_ARB 0x2025
#endif

#ifndef WGL_BLUE_BITS_ARB
#define WGL_BLUE_BITS_ARB 0x2019
#endif

#ifndef WGL_TYPE_RGBA_ARB
#define WGL_TYPE_RGBA_ARB 0x202B
#endif

#ifndef WGL_COLOR_BITS_ARB
#define WGL_COLOR_BITS_ARB 0x2014
#endif

#ifndef WGL_TRANSPARENT_BLUE_VALUE_ARB
#define WGL_TRANSPARENT_BLUE_VALUE_ARB 0x2039
#endif

#ifndef WGL_SWAP_UNDEFINED_ARB
#define WGL_SWAP_UNDEFINED_ARB 0x202A
#endif

#ifndef WGL_AUX_BUFFERS_ARB
#define WGL_AUX_BUFFERS_ARB 0x2024
#endif

#ifndef WGL_ACCUM_BLUE_BITS_ARB
#define WGL_ACCUM_BLUE_BITS_ARB 0x2020
#endif

#ifndef WGL_NUMBER_OVERLAYS_ARB
#define WGL_NUMBER_OVERLAYS_ARB 0x2008
#endif

#ifndef WGL_TRANSPARENT_ARB
#define WGL_TRANSPARENT_ARB 0x200A
#endif

#ifndef WGL_ACCELERATION_ARB
#define WGL_ACCELERATION_ARB 0x2003
#endif

#ifndef WGL_DOUBLE_BUFFER_ARB
#define WGL_DOUBLE_BUFFER_ARB 0x2011
#endif

#ifndef WGL_GREEN_BITS_ARB
#define WGL_GREEN_BITS_ARB 0x2017
#endif

#ifndef WGL_FULL_ACCELERATION_ARB
#define WGL_FULL_ACCELERATION_ARB 0x2027
#endif

#ifndef WGL_ALPHA_BITS_ARB
#define WGL_ALPHA_BITS_ARB 0x201B
#endif

#ifndef WGL_NEED_PALETTE_ARB
#define WGL_NEED_PALETTE_ARB 0x2004
#endif

#ifndef WGL_STENCIL_BITS_ARB
#define WGL_STENCIL_BITS_ARB 0x2023
#endif

#ifndef WGL_SUPPORT_GDI_ARB
#define WGL_SUPPORT_GDI_ARB 0x200F
#endif

#ifndef WGL_TRANSPARENT_ALPHA_VALUE_ARB
#define WGL_TRANSPARENT_ALPHA_VALUE_ARB 0x203A
#endif

#ifndef WGL_NEED_SYSTEM_PALETTE_ARB
#define WGL_NEED_SYSTEM_PALETTE_ARB 0x2005
#endif

#ifndef WGL_DEPTH_BITS_ARB
#define WGL_DEPTH_BITS_ARB 0x2022
#endif

#ifndef WGL_RED_BITS_ARB
#define WGL_RED_BITS_ARB 0x2015
#endif

#ifndef WGL_SWAP_METHOD_ARB
#define WGL_SWAP_METHOD_ARB 0x2007
#endif

#ifndef WGL_SWAP_EXCHANGE_ARB
#define WGL_SWAP_EXCHANGE_ARB 0x2028
#endif

#ifndef WGL_DRAW_TO_WINDOW_ARB
#define WGL_DRAW_TO_WINDOW_ARB 0x2001
#endif

#ifndef WGL_SHARE_DEPTH_ARB
#define WGL_SHARE_DEPTH_ARB 0x200C
#endif

#ifndef WGL_NUMBER_PIXEL_FORMATS_ARB
#define WGL_NUMBER_PIXEL_FORMATS_ARB 0x2000
#endif

#ifndef WGL_NUMBER_UNDERLAYS_ARB
#define WGL_NUMBER_UNDERLAYS_ARB 0x2009
#endif

#ifndef WGL_RED_SHIFT_ARB
#define WGL_RED_SHIFT_ARB 0x2016
#endif

#ifndef WGL_SWAP_LAYER_BUFFERS_ARB
#define WGL_SWAP_LAYER_BUFFERS_ARB 0x2006
#endif

#ifndef WGL_TRANSPARENT_INDEX_VALUE_ARB
#define WGL_TRANSPARENT_INDEX_VALUE_ARB 0x203B
#endif

#ifndef WGL_SUPPORT_OPENGL_ARB
#define WGL_SUPPORT_OPENGL_ARB 0x2010
#endif

#ifndef WGL_BLUE_SHIFT_ARB
#define WGL_BLUE_SHIFT_ARB 0x201A
#endif

#ifndef WGL_PIXEL_TYPE_ARB
#define WGL_PIXEL_TYPE_ARB 0x2013
#endif

#ifndef WGL_TYPE_COLORINDEX_ARB
#define WGL_TYPE_COLORINDEX_ARB 0x202C
#endif

#ifndef WGL_ACCUM_RED_BITS_ARB
#define WGL_ACCUM_RED_BITS_ARB 0x201E
#endif

#ifndef WGL_ACCUM_GREEN_BITS_ARB
#define WGL_ACCUM_GREEN_BITS_ARB 0x201F
#endif

#ifndef WGL_STEREO_ARB
#define WGL_STEREO_ARB 0x2012
#endif

typedef BOOL (NIV_CALL_TYPE * nivenWGLGETPIXELFORMATATTRIBFVARB) (HDC hdc, int iPixelFormat, int iLayerPlane, UINT nAttributes, const int* piAttributes, FLOAT* pfValues);
typedef BOOL (NIV_CALL_TYPE * nivenWGLCHOOSEPIXELFORMATARB) (HDC hdc, const int* piAttribIList, const FLOAT* pfAttribFList, UINT nMaxFormats, int* piFormats, UINT* nNumFormats);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGETPIXELFORMATATTRIBIVARB) (HDC hdc, int iPixelFormat, int iLayerPlane, UINT nAttributes, const int* piAttributes, int* piValues);
#endif
// WGL_3DFX_multisample
#ifdef WIN32
#ifndef WGL_SAMPLE_BUFFERS_3DFX
#define WGL_SAMPLE_BUFFERS_3DFX 0x2060
#endif

#ifndef WGL_SAMPLES_3DFX
#define WGL_SAMPLES_3DFX 0x2061
#endif

#endif
#ifdef _GLX
// GLX_SGIX_swap_group
typedef void (NIV_CALL_TYPE * nivenGLXJOINSWAPGROUPSGIX) (Display* dpy, GLXDrawable drawable, GLXDrawable member);
#endif // _GLX
// GL_EXT_vertex_shader
#ifndef GL_OUTPUT_TEXTURE_COORD20_EXT
#define GL_OUTPUT_TEXTURE_COORD20_EXT 0x87B1
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD24_EXT
#define GL_OUTPUT_TEXTURE_COORD24_EXT 0x87B5
#endif

#ifndef GL_CURRENT_VERTEX_EXT
#define GL_CURRENT_VERTEX_EXT 0x87E2
#endif

#ifndef GL_VARIANT_ARRAY_STRIDE_EXT
#define GL_VARIANT_ARRAY_STRIDE_EXT 0x87E6
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD22_EXT
#define GL_OUTPUT_TEXTURE_COORD22_EXT 0x87B3
#endif

#ifndef GL_LOCAL_CONSTANT_EXT
#define GL_LOCAL_CONSTANT_EXT 0x87C3
#endif

#ifndef GL_OP_DOT3_EXT
#define GL_OP_DOT3_EXT 0x8784
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD4_EXT
#define GL_OUTPUT_TEXTURE_COORD4_EXT 0x87A1
#endif

#ifndef GL_VERTEX_SHADER_OPTIMIZED_EXT
#define GL_VERTEX_SHADER_OPTIMIZED_EXT 0x87D4
#endif

#ifndef GL_NEGATIVE_Z_EXT
#define GL_NEGATIVE_Z_EXT 0x87DB
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD19_EXT
#define GL_OUTPUT_TEXTURE_COORD19_EXT 0x87B0
#endif

#ifndef GL_OP_SUB_EXT
#define GL_OP_SUB_EXT 0x8796
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD15_EXT
#define GL_OUTPUT_TEXTURE_COORD15_EXT 0x87AC
#endif

#ifndef GL_OP_CLAMP_EXT
#define GL_OP_CLAMP_EXT 0x878E
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD30_EXT
#define GL_OUTPUT_TEXTURE_COORD30_EXT 0x87BB
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD1_EXT
#define GL_OUTPUT_TEXTURE_COORD1_EXT 0x879E
#endif

#ifndef GL_MAX_VERTEX_SHADER_LOCALS_EXT
#define GL_MAX_VERTEX_SHADER_LOCALS_EXT 0x87C9
#endif

#ifndef GL_OP_MUL_EXT
#define GL_OP_MUL_EXT 0x8786
#endif

#ifndef GL_OP_ADD_EXT
#define GL_OP_ADD_EXT 0x8787
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD10_EXT
#define GL_OUTPUT_TEXTURE_COORD10_EXT 0x87A7
#endif

#ifndef GL_OP_SET_LT_EXT
#define GL_OP_SET_LT_EXT 0x878D
#endif

#ifndef GL_LOCAL_EXT
#define GL_LOCAL_EXT 0x87C4
#endif

#ifndef GL_LOCAL_CONSTANT_VALUE_EXT
#define GL_LOCAL_CONSTANT_VALUE_EXT 0x87EC
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD5_EXT
#define GL_OUTPUT_TEXTURE_COORD5_EXT 0x87A2
#endif

#ifndef GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT
#define GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT 0x87CE
#endif

#ifndef GL_OP_LOG_BASE_2_EXT
#define GL_OP_LOG_BASE_2_EXT 0x8792
#endif

#ifndef GL_LOCAL_CONSTANT_DATATYPE_EXT
#define GL_LOCAL_CONSTANT_DATATYPE_EXT 0x87ED
#endif

#ifndef GL_Z_EXT
#define GL_Z_EXT 0x87D7
#endif

#ifndef GL_OP_RECIP_SQRT_EXT
#define GL_OP_RECIP_SQRT_EXT 0x8795
#endif

#ifndef GL_OP_MADD_EXT
#define GL_OP_MADD_EXT 0x8788
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD28_EXT
#define GL_OUTPUT_TEXTURE_COORD28_EXT 0x87B9
#endif

#ifndef GL_OP_ROUND_EXT
#define GL_OP_ROUND_EXT 0x8790
#endif

#ifndef GL_VECTOR_EXT
#define GL_VECTOR_EXT 0x87BF
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD23_EXT
#define GL_OUTPUT_TEXTURE_COORD23_EXT 0x87B4
#endif

#ifndef GL_FULL_RANGE_EXT
#define GL_FULL_RANGE_EXT 0x87E1
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD6_EXT
#define GL_OUTPUT_TEXTURE_COORD6_EXT 0x87A3
#endif

#ifndef GL_OUTPUT_VERTEX_EXT
#define GL_OUTPUT_VERTEX_EXT 0x879A
#endif

#ifndef GL_VARIANT_EXT
#define GL_VARIANT_EXT 0x87C1
#endif

#ifndef GL_NEGATIVE_W_EXT
#define GL_NEGATIVE_W_EXT 0x87DC
#endif

#ifndef GL_NORMALIZED_RANGE_EXT
#define GL_NORMALIZED_RANGE_EXT 0x87E0
#endif

#ifndef GL_OP_FLOOR_EXT
#define GL_OP_FLOOR_EXT 0x878F
#endif

#ifndef GL_OP_POWER_EXT
#define GL_OP_POWER_EXT 0x8793
#endif

#ifndef GL_MVP_MATRIX_EXT
#define GL_MVP_MATRIX_EXT 0x87E3
#endif

#ifndef GL_OP_FRAC_EXT
#define GL_OP_FRAC_EXT 0x8789
#endif

#ifndef GL_OP_EXP_BASE_2_EXT
#define GL_OP_EXP_BASE_2_EXT 0x8791
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD2_EXT
#define GL_OUTPUT_TEXTURE_COORD2_EXT 0x879F
#endif

#ifndef GL_VERTEX_SHADER_LOCALS_EXT
#define GL_VERTEX_SHADER_LOCALS_EXT 0x87D3
#endif

#ifndef GL_VERTEX_SHADER_BINDING_EXT
#define GL_VERTEX_SHADER_BINDING_EXT 0x8781
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD16_EXT
#define GL_OUTPUT_TEXTURE_COORD16_EXT 0x87AD
#endif

#ifndef GL_VERTEX_SHADER_INSTRUCTIONS_EXT
#define GL_VERTEX_SHADER_INSTRUCTIONS_EXT 0x87CF
#endif

#ifndef GL_MAX_VERTEX_SHADER_VARIANTS_EXT
#define GL_MAX_VERTEX_SHADER_VARIANTS_EXT 0x87C6
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD31_EXT
#define GL_OUTPUT_TEXTURE_COORD31_EXT 0x87BC
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD12_EXT
#define GL_OUTPUT_TEXTURE_COORD12_EXT 0x87A9
#endif

#ifndef GL_INVARIANT_VALUE_EXT
#define GL_INVARIANT_VALUE_EXT 0x87EA
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD26_EXT
#define GL_OUTPUT_TEXTURE_COORD26_EXT 0x87B7
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD14_EXT
#define GL_OUTPUT_TEXTURE_COORD14_EXT 0x87AB
#endif

#ifndef GL_MAX_VERTEX_SHADER_INVARIANTS_EXT
#define GL_MAX_VERTEX_SHADER_INVARIANTS_EXT 0x87C7
#endif

#ifndef GL_OP_MULTIPLY_MATRIX_EXT
#define GL_OP_MULTIPLY_MATRIX_EXT 0x8798
#endif

#ifndef GL_INVARIANT_EXT
#define GL_INVARIANT_EXT 0x87C2
#endif

#ifndef GL_SCALAR_EXT
#define GL_SCALAR_EXT 0x87BE
#endif

#ifndef GL_INVARIANT_DATATYPE_EXT
#define GL_INVARIANT_DATATYPE_EXT 0x87EB
#endif

#ifndef GL_W_EXT
#define GL_W_EXT 0x87D8
#endif

#ifndef GL_VARIANT_ARRAY_POINTER_EXT
#define GL_VARIANT_ARRAY_POINTER_EXT 0x87E9
#endif

#ifndef GL_OP_MIN_EXT
#define GL_OP_MIN_EXT 0x878B
#endif

#ifndef GL_OUTPUT_COLOR0_EXT
#define GL_OUTPUT_COLOR0_EXT 0x879B
#endif

#ifndef GL_ZERO_EXT
#define GL_ZERO_EXT 0x87DD
#endif

#ifndef GL_NEGATIVE_ONE_EXT
#define GL_NEGATIVE_ONE_EXT 0x87DF
#endif

#ifndef GL_Y_EXT
#define GL_Y_EXT 0x87D6
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD25_EXT
#define GL_OUTPUT_TEXTURE_COORD25_EXT 0x87B6
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD3_EXT
#define GL_OUTPUT_TEXTURE_COORD3_EXT 0x87A0
#endif

#ifndef GL_OP_RECIP_EXT
#define GL_OP_RECIP_EXT 0x8794
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD13_EXT
#define GL_OUTPUT_TEXTURE_COORD13_EXT 0x87AA
#endif

#ifndef GL_NEGATIVE_Y_EXT
#define GL_NEGATIVE_Y_EXT 0x87DA
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD7_EXT
#define GL_OUTPUT_TEXTURE_COORD7_EXT 0x87A4
#endif

#ifndef GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
#define GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT 0x87C8
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD11_EXT
#define GL_OUTPUT_TEXTURE_COORD11_EXT 0x87A8
#endif

#ifndef GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT
#define GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT 0x87CB
#endif

#ifndef GL_VERTEX_SHADER_VARIANTS_EXT
#define GL_VERTEX_SHADER_VARIANTS_EXT 0x87D0
#endif

#ifndef GL_OP_MOV_EXT
#define GL_OP_MOV_EXT 0x8799
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD17_EXT
#define GL_OUTPUT_TEXTURE_COORD17_EXT 0x87AE
#endif

#ifndef GL_MATRIX_EXT
#define GL_MATRIX_EXT 0x87C0
#endif

#ifndef GL_VERTEX_SHADER_INVARIANTS_EXT
#define GL_VERTEX_SHADER_INVARIANTS_EXT 0x87D1
#endif

#ifndef GL_ONE_EXT
#define GL_ONE_EXT 0x87DE
#endif

#ifndef GL_VARIANT_DATATYPE_EXT
#define GL_VARIANT_DATATYPE_EXT 0x87E5
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD29_EXT
#define GL_OUTPUT_TEXTURE_COORD29_EXT 0x87BA
#endif

#ifndef GL_OP_INDEX_EXT
#define GL_OP_INDEX_EXT 0x8782
#endif

#ifndef GL_VARIANT_ARRAY_EXT
#define GL_VARIANT_ARRAY_EXT 0x87E8
#endif

#ifndef GL_OUTPUT_FOG_EXT
#define GL_OUTPUT_FOG_EXT 0x87BD
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD9_EXT
#define GL_OUTPUT_TEXTURE_COORD9_EXT 0x87A6
#endif

#ifndef GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
#define GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT 0x87D2
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD27_EXT
#define GL_OUTPUT_TEXTURE_COORD27_EXT 0x87B8
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD0_EXT
#define GL_OUTPUT_TEXTURE_COORD0_EXT 0x879D
#endif

#ifndef GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
#define GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT 0x87CD
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD8_EXT
#define GL_OUTPUT_TEXTURE_COORD8_EXT 0x87A5
#endif

#ifndef GL_NEGATIVE_X_EXT
#define GL_NEGATIVE_X_EXT 0x87D9
#endif

#ifndef GL_VERTEX_SHADER_EXT
#define GL_VERTEX_SHADER_EXT 0x8780
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD21_EXT
#define GL_OUTPUT_TEXTURE_COORD21_EXT 0x87B2
#endif

#ifndef GL_X_EXT
#define GL_X_EXT 0x87D5
#endif

#ifndef GL_OP_NEGATE_EXT
#define GL_OP_NEGATE_EXT 0x8783
#endif

#ifndef GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT
#define GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT 0x87CC
#endif

#ifndef GL_OP_DOT4_EXT
#define GL_OP_DOT4_EXT 0x8785
#endif

#ifndef GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT
#define GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT 0x87C5
#endif

#ifndef GL_OP_MAX_EXT
#define GL_OP_MAX_EXT 0x878A
#endif

#ifndef GL_OUTPUT_COLOR1_EXT
#define GL_OUTPUT_COLOR1_EXT 0x879C
#endif

#ifndef GL_OP_SET_GE_EXT
#define GL_OP_SET_GE_EXT 0x878C
#endif

#ifndef GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT
#define GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT 0x87CA
#endif

#ifndef GL_OUTPUT_TEXTURE_COORD18_EXT
#define GL_OUTPUT_TEXTURE_COORD18_EXT 0x87AF
#endif

#ifndef GL_VARIANT_VALUE_EXT
#define GL_VARIANT_VALUE_EXT 0x87E4
#endif

#ifndef GL_VARIANT_ARRAY_TYPE_EXT
#define GL_VARIANT_ARRAY_TYPE_EXT 0x87E7
#endif

#ifndef GL_OP_CROSS_PRODUCT_EXT
#define GL_OP_CROSS_PRODUCT_EXT 0x8797
#endif

typedef void (NIV_CALL_TYPE * nivenGLVARIANTUBVEXT) (GLuint id, GLubyte* addr);
typedef void (NIV_CALL_TYPE * nivenGLSETINVARIANTEXT) (GLuint id, GLenum type, GLvoid* addr);
typedef void (NIV_CALL_TYPE * nivenGLVARIANTSVEXT) (GLuint id, GLshort* addr);
typedef void (NIV_CALL_TYPE * nivenGLGETLOCALCONSTANTINTEGERVEXT) (GLuint id, GLenum value, GLint* data);
typedef void (NIV_CALL_TYPE * nivenGLGETVARIANTINTEGERVEXT) (GLuint id, GLenum value, GLint* data);
typedef void (NIV_CALL_TYPE * nivenGLVARIANTPOINTEREXT) (GLuint id, GLenum type, GLuint stride, GLvoid* addr);
typedef GLuint (NIV_CALL_TYPE * nivenGLGENVERTEXSHADERSEXT) (GLuint range);
typedef void (NIV_CALL_TYPE * nivenGLENDVERTEXSHADEREXT) (void );
typedef void (NIV_CALL_TYPE * nivenGLBINDVERTEXSHADEREXT) (GLuint id);
typedef void (NIV_CALL_TYPE * nivenGLGETVARIANTFLOATVEXT) (GLuint id, GLenum value, GLfloat* data);
typedef void (NIV_CALL_TYPE * nivenGLEXTRACTCOMPONENTEXT) (GLuint res, GLuint src, GLuint num);
typedef void (NIV_CALL_TYPE * nivenGLBEGINVERTEXSHADEREXT) (void );
typedef void (NIV_CALL_TYPE * nivenGLDELETEVERTEXSHADEREXT) (GLuint id);
typedef void (NIV_CALL_TYPE * nivenGLVARIANTDVEXT) (GLuint id, GLdouble* addr);
typedef void (NIV_CALL_TYPE * nivenGLGETLOCALCONSTANTBOOLEANVEXT) (GLuint id, GLenum value, GLboolean* data);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISVARIANTENABLEDEXT) (GLuint id, GLenum cap);
typedef void (NIV_CALL_TYPE * nivenGLVARIANTUIVEXT) (GLuint id, GLuint* addr);
typedef void (NIV_CALL_TYPE * nivenGLWRITEMASKEXT) (GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW);
typedef void (NIV_CALL_TYPE * nivenGLENABLEVARIANTCLIENTSTATEEXT) (GLuint id);
typedef void (NIV_CALL_TYPE * nivenGLVARIANTUSVEXT) (GLuint id, GLushort* addr);
typedef GLuint (NIV_CALL_TYPE * nivenGLGENSYMBOLSEXT) (GLenum dataType, GLenum storageType, GLenum range, GLuint components);
typedef void (NIV_CALL_TYPE * nivenGLGETINVARIANTINTEGERVEXT) (GLuint id, GLenum value, GLint* data);
typedef void (NIV_CALL_TYPE * nivenGLSHADEROP2EXT) (GLenum op, GLuint res, GLuint arg1, GLuint arg2);
typedef GLuint (NIV_CALL_TYPE * nivenGLBINDPARAMETEREXT) (GLenum value);
typedef void (NIV_CALL_TYPE * nivenGLDISABLEVARIANTCLIENTSTATEEXT) (GLuint id);
typedef void (NIV_CALL_TYPE * nivenGLVARIANTIVEXT) (GLuint id, GLint* addr);
typedef void (NIV_CALL_TYPE * nivenGLSWIZZLEEXT) (GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW);
typedef void (NIV_CALL_TYPE * nivenGLGETINVARIANTBOOLEANVEXT) (GLuint id, GLenum value, GLboolean* data);
typedef GLuint (NIV_CALL_TYPE * nivenGLBINDTEXTUREUNITPARAMETEREXT) (GLenum unit, GLenum value);
typedef GLuint (NIV_CALL_TYPE * nivenGLBINDTEXGENPARAMETEREXT) (GLenum unit, GLenum coord, GLenum value);
typedef void (NIV_CALL_TYPE * nivenGLGETINVARIANTFLOATVEXT) (GLuint id, GLenum value, GLfloat* data);
typedef void (NIV_CALL_TYPE * nivenGLGETVARIANTBOOLEANVEXT) (GLuint id, GLenum value, GLboolean* data);
typedef void (NIV_CALL_TYPE * nivenGLGETVARIANTPOINTERVEXT) (GLuint id, GLenum value, GLvoid* *data);
typedef GLuint (NIV_CALL_TYPE * nivenGLBINDLIGHTPARAMETEREXT) (GLenum light, GLenum value);
typedef void (NIV_CALL_TYPE * nivenGLSETLOCALCONSTANTEXT) (GLuint id, GLenum type, GLvoid* addr);
typedef void (NIV_CALL_TYPE * nivenGLGETLOCALCONSTANTFLOATVEXT) (GLuint id, GLenum value, GLfloat* data);
typedef void (NIV_CALL_TYPE * nivenGLSHADEROP1EXT) (GLenum op, GLuint res, GLuint arg1);
typedef GLuint (NIV_CALL_TYPE * nivenGLBINDMATERIALPARAMETEREXT) (GLenum face, GLenum value);
typedef void (NIV_CALL_TYPE * nivenGLINSERTCOMPONENTEXT) (GLuint res, GLuint src, GLuint num);
typedef void (NIV_CALL_TYPE * nivenGLVARIANTFVEXT) (GLuint id, GLfloat* addr);
typedef void (NIV_CALL_TYPE * nivenGLSHADEROP3EXT) (GLenum op, GLuint res, GLuint arg1, GLuint arg2, GLuint arg3);
typedef void (NIV_CALL_TYPE * nivenGLVARIANTBVEXT) (GLuint id, GLbyte* addr);

// GL_APPLE_pixel_buffer
#ifndef GL_MIN_PBUFFER_VIEWPORT_DIMS_APPLE
#define GL_MIN_PBUFFER_VIEWPORT_DIMS_APPLE 0x8A10
#endif


// GL_EXT_misc_attribute

// GL_NV_texture_shader3
#ifndef GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV
#define GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV 0x8851
#endif

#ifndef GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV
#define GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV 0x885A
#endif

#ifndef GL_FORCE_BLUE_TO_ONE_NV
#define GL_FORCE_BLUE_TO_ONE_NV 0x8860
#endif

#ifndef GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV
#define GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV 0x8850
#endif

#ifndef GL_OFFSET_HILO_TEXTURE_2D_NV
#define GL_OFFSET_HILO_TEXTURE_2D_NV 0x8854
#endif

#ifndef GL_DOT_PRODUCT_PASS_THROUGH_NV
#define GL_DOT_PRODUCT_PASS_THROUGH_NV 0x885B
#endif

#ifndef GL_HILO8_NV
#define GL_HILO8_NV 0x885E
#endif

#ifndef GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV
#define GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV 0x8853
#endif

#ifndef GL_DEPENDENT_HILO_TEXTURE_2D_NV
#define GL_DEPENDENT_HILO_TEXTURE_2D_NV 0x8858
#endif

#ifndef GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV
#define GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV 0x8857
#endif

#ifndef GL_SIGNED_HILO8_NV
#define GL_SIGNED_HILO8_NV 0x885F
#endif

#ifndef GL_DOT_PRODUCT_TEXTURE_1D_NV
#define GL_DOT_PRODUCT_TEXTURE_1D_NV 0x885C
#endif

#ifndef GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV
#define GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV 0x8852
#endif

#ifndef GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV
#define GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV 0x885D
#endif

#ifndef GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV
#define GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV 0x8855
#endif

#ifndef GL_DEPENDENT_RGB_TEXTURE_3D_NV
#define GL_DEPENDENT_RGB_TEXTURE_3D_NV 0x8859
#endif

#ifndef GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV
#define GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV 0x8856
#endif


// GL_NV_texture_shader2
#ifndef GL_DOT_PRODUCT_TEXTURE_3D_NV
#define GL_DOT_PRODUCT_TEXTURE_3D_NV 0x86EF
#endif


// GL_EXT_blend_func_separate
#ifndef GL_BLEND_DST_ALPHA_EXT
#define GL_BLEND_DST_ALPHA_EXT 0x80CA
#endif

#ifndef GL_BLEND_SRC_RGB_EXT
#define GL_BLEND_SRC_RGB_EXT 0x80C9
#endif

#ifndef GL_BLEND_DST_RGB_EXT
#define GL_BLEND_DST_RGB_EXT 0x80C8
#endif

#ifndef GL_BLEND_SRC_ALPHA_EXT
#define GL_BLEND_SRC_ALPHA_EXT 0x80CB
#endif

typedef void (NIV_CALL_TYPE * nivenGLBLENDFUNCSEPARATEEXT) (GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha);

// GL_SGIX_pixel_texture_bits

// GL_EXT_texture
#ifndef GL_RGB12_EXT
#define GL_RGB12_EXT 0x8053
#endif

#ifndef GL_RGBA16_EXT
#define GL_RGBA16_EXT 0x805B
#endif

#ifndef GL_INTENSITY12_EXT
#define GL_INTENSITY12_EXT 0x804C
#endif

#ifndef GL_RGB10_A2_EXT
#define GL_RGB10_A2_EXT 0x8059
#endif

#ifndef GL_INTENSITY8_EXT
#define GL_INTENSITY8_EXT 0x804B
#endif

#ifndef GL_LUMINANCE8_EXT
#define GL_LUMINANCE8_EXT 0x8040
#endif

#ifndef GL_INTENSITY16_EXT
#define GL_INTENSITY16_EXT 0x804D
#endif

#ifndef GL_RGB5_A1_EXT
#define GL_RGB5_A1_EXT 0x8057
#endif

#ifndef GL_RGB10_EXT
#define GL_RGB10_EXT 0x8052
#endif

#ifndef GL_ALPHA8_EXT
#define GL_ALPHA8_EXT 0x803C
#endif

#ifndef GL_TEXTURE_BLUE_SIZE_EXT
#define GL_TEXTURE_BLUE_SIZE_EXT 0x805E
#endif

#ifndef GL_ALPHA16_EXT
#define GL_ALPHA16_EXT 0x803E
#endif

#ifndef GL_LUMINANCE6_ALPHA2_EXT
#define GL_LUMINANCE6_ALPHA2_EXT 0x8044
#endif

#ifndef GL_RGB16_EXT
#define GL_RGB16_EXT 0x8054
#endif

#ifndef GL_TEXTURE_ALPHA_SIZE_EXT
#define GL_TEXTURE_ALPHA_SIZE_EXT 0x805F
#endif

#ifndef GL_TEXTURE_GREEN_SIZE_EXT
#define GL_TEXTURE_GREEN_SIZE_EXT 0x805D
#endif

#ifndef GL_PROXY_TEXTURE_1D_EXT
#define GL_PROXY_TEXTURE_1D_EXT 0x8063
#endif

#ifndef GL_RGBA12_EXT
#define GL_RGBA12_EXT 0x805A
#endif

#ifndef GL_RGB4_EXT
#define GL_RGB4_EXT 0x804F
#endif

#ifndef GL_INTENSITY4_EXT
#define GL_INTENSITY4_EXT 0x804A
#endif

#ifndef GL_TEXTURE_INTENSITY_SIZE_EXT
#define GL_TEXTURE_INTENSITY_SIZE_EXT 0x8061
#endif

#ifndef GL_LUMINANCE8_ALPHA8_EXT
#define GL_LUMINANCE8_ALPHA8_EXT 0x8045
#endif

#ifndef GL_PROXY_TEXTURE_2D_EXT
#define GL_PROXY_TEXTURE_2D_EXT 0x8064
#endif

#ifndef GL_LUMINANCE16_EXT
#define GL_LUMINANCE16_EXT 0x8042
#endif

#ifndef GL_RGB5_EXT
#define GL_RGB5_EXT 0x8050
#endif

#ifndef GL_INTENSITY_EXT
#define GL_INTENSITY_EXT 0x8049
#endif

#ifndef GL_LUMINANCE12_EXT
#define GL_LUMINANCE12_EXT 0x8041
#endif

#ifndef GL_TEXTURE_LUMINANCE_SIZE_EXT
#define GL_TEXTURE_LUMINANCE_SIZE_EXT 0x8060
#endif

#ifndef GL_TEXTURE_RED_SIZE_EXT
#define GL_TEXTURE_RED_SIZE_EXT 0x805C
#endif

#ifndef GL_RGBA8_EXT
#define GL_RGBA8_EXT 0x8058
#endif

#ifndef GL_LUMINANCE4_ALPHA4_EXT
#define GL_LUMINANCE4_ALPHA4_EXT 0x8043
#endif

#ifndef GL_REPLACE_EXT
#define GL_REPLACE_EXT 0x8062
#endif

#ifndef GL_LUMINANCE12_ALPHA12_EXT
#define GL_LUMINANCE12_ALPHA12_EXT 0x8047
#endif

#ifndef GL_RGBA4_EXT
#define GL_RGBA4_EXT 0x8056
#endif

#ifndef GL_ALPHA4_EXT
#define GL_ALPHA4_EXT 0x803B
#endif

#ifndef GL_RGBA2_EXT
#define GL_RGBA2_EXT 0x8055
#endif

#ifndef GL_LUMINANCE16_ALPHA16_EXT
#define GL_LUMINANCE16_ALPHA16_EXT 0x8048
#endif

#ifndef GL_RGB2_EXT
#define GL_RGB2_EXT 0x804E
#endif

#ifndef GL_RGB8_EXT
#define GL_RGB8_EXT 0x8051
#endif

#ifndef GL_LUMINANCE12_ALPHA4_EXT
#define GL_LUMINANCE12_ALPHA4_EXT 0x8046
#endif

#ifndef GL_ALPHA12_EXT
#define GL_ALPHA12_EXT 0x803D
#endif

#ifndef GL_LUMINANCE4_EXT
#define GL_LUMINANCE4_EXT 0x803F
#endif


// GL_APPLE_fence
#ifndef GL_FENCE_APPLE
#define GL_FENCE_APPLE 0x8A0B
#endif

#ifndef GL_DRAW_PIXELS_APPLE
#define GL_DRAW_PIXELS_APPLE 0x8A0A
#endif

typedef void (NIV_CALL_TYPE * nivenGLDELETEFENCESAPPLE) (GLsizei n, const GLuint* fences);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISFENCEAPPLE) (GLuint fence);
typedef void (NIV_CALL_TYPE * nivenGLFINISHOBJECTAPPLE) (GLenum object, GLint name);
typedef GLboolean (NIV_CALL_TYPE * nivenGLTESTOBJECTAPPLE) (GLenum object, GLuint name);
typedef GLboolean (NIV_CALL_TYPE * nivenGLTESTFENCEAPPLE) (GLuint fence);
typedef void (NIV_CALL_TYPE * nivenGLFINISHFENCEAPPLE) (GLuint fence);
typedef void (NIV_CALL_TYPE * nivenGLGENFENCESAPPLE) (GLsizei n, GLuint* fences);
typedef void (NIV_CALL_TYPE * nivenGLSETFENCEAPPLE) (GLuint fence);

// GL_EXT_multisample
#ifndef GL_SAMPLE_MASK_INVERT_EXT
#define GL_SAMPLE_MASK_INVERT_EXT 0x80AB
#endif

#ifndef GL_SAMPLE_MASK_EXT
#define GL_SAMPLE_MASK_EXT 0x80A0
#endif

#ifndef GL_4PASS_1_EXT
#define GL_4PASS_1_EXT 0x80A5
#endif

#ifndef GL_2PASS_0_EXT
#define GL_2PASS_0_EXT 0x80A2
#endif

#ifndef GL_2PASS_1_EXT
#define GL_2PASS_1_EXT 0x80A3
#endif

#ifndef GL_MULTISAMPLE_BIT_EXT
#define GL_MULTISAMPLE_BIT_EXT 0x20000000
#endif

#ifndef GL_SAMPLE_ALPHA_TO_ONE_EXT
#define GL_SAMPLE_ALPHA_TO_ONE_EXT 0x809F
#endif

#ifndef GL_SAMPLE_PATTERN_EXT
#define GL_SAMPLE_PATTERN_EXT 0x80AC
#endif

#ifndef GL_4PASS_2_EXT
#define GL_4PASS_2_EXT 0x80A6
#endif

#ifndef GL_4PASS_3_EXT
#define GL_4PASS_3_EXT 0x80A7
#endif

#ifndef GL_4PASS_0_EXT
#define GL_4PASS_0_EXT 0x80A4
#endif

#ifndef GL_SAMPLE_MASK_VALUE_EXT
#define GL_SAMPLE_MASK_VALUE_EXT 0x80AA
#endif

#ifndef GL_MULTISAMPLE_EXT
#define GL_MULTISAMPLE_EXT 0x809D
#endif

#ifndef GL_1PASS_EXT
#define GL_1PASS_EXT 0x80A1
#endif

#ifndef GL_SAMPLE_ALPHA_TO_MASK_EXT
#define GL_SAMPLE_ALPHA_TO_MASK_EXT 0x809E
#endif

#ifndef GL_SAMPLES_EXT
#define GL_SAMPLES_EXT 0x80A9
#endif

#ifndef GL_SAMPLE_BUFFERS_EXT
#define GL_SAMPLE_BUFFERS_EXT 0x80A8
#endif

typedef void (NIV_CALL_TYPE * nivenGLSAMPLEMASKEXT) (GLclampf value, GLboolean invert);
typedef void (NIV_CALL_TYPE * nivenGLSAMPLEPATTERNEXT) (GLenum pattern);

// GL_EXT_texture_cube_map
#ifndef GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT
#define GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT 0x8518
#endif

#ifndef GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT
#define GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT 0x8516
#endif

#ifndef GL_TEXTURE_CUBE_MAP_EXT
#define GL_TEXTURE_CUBE_MAP_EXT 0x8513
#endif

#ifndef GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT
#define GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT 0x8519
#endif

#ifndef GL_TEXTURE_BINDING_CUBE_MAP_EXT
#define GL_TEXTURE_BINDING_CUBE_MAP_EXT 0x8514
#endif

#ifndef GL_REFLECTION_MAP_EXT
#define GL_REFLECTION_MAP_EXT 0x8512
#endif

#ifndef GL_NORMAL_MAP_EXT
#define GL_NORMAL_MAP_EXT 0x8511
#endif

#ifndef GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT
#define GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT 0x8517
#endif

#ifndef GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT
#define GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT 0x8515
#endif

#ifndef GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT
#define GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT 0x851C
#endif

#ifndef GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT
#define GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT 0x851A
#endif

#ifndef GL_PROXY_TEXTURE_CUBE_MAP_EXT
#define GL_PROXY_TEXTURE_CUBE_MAP_EXT 0x851B
#endif


// GL_ARB_occlusion_query
#ifndef GL_QUERY_RESULT_AVAILABLE_ARB
#define GL_QUERY_RESULT_AVAILABLE_ARB 0x8867
#endif

#ifndef GL_CURRENT_QUERY_ARB
#define GL_CURRENT_QUERY_ARB 0x8865
#endif

#ifndef GL_QUERY_COUNTER_BITS_ARB
#define GL_QUERY_COUNTER_BITS_ARB 0x8864
#endif

#ifndef GL_SAMPLES_PASSED_ARB
#define GL_SAMPLES_PASSED_ARB 0x8914
#endif

#ifndef GL_QUERY_RESULT_ARB
#define GL_QUERY_RESULT_ARB 0x8866
#endif

typedef void (NIV_CALL_TYPE * nivenGLGETQUERYOBJECTUIVARB) (GLuint id, GLenum pname, GLuint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETQUERYIVARB) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGENQUERIESARB) (GLsizei n, GLuint* ids);
typedef void (NIV_CALL_TYPE * nivenGLGETQUERYOBJECTIVARB) (GLuint id, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLENDQUERYARB) (GLenum target);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISQUERYARB) (GLuint id);
typedef void (NIV_CALL_TYPE * nivenGLBEGINQUERYARB) (GLenum target, GLuint id);
typedef void (NIV_CALL_TYPE * nivenGLDELETEQUERIESARB) (GLsizei n, const GLuint* ids);

// GL_INGR_color_clamp
#ifndef GL_BLUE_MIN_CLAMP_INGR
#define GL_BLUE_MIN_CLAMP_INGR 0x8562
#endif

#ifndef GL_GREEN_MAX_CLAMP_INGR
#define GL_GREEN_MAX_CLAMP_INGR 0x8565
#endif

#ifndef GL_ALPHA_MIN_CLAMP_INGR
#define GL_ALPHA_MIN_CLAMP_INGR 0x8563
#endif

#ifndef GL_GREEN_MIN_CLAMP_INGR
#define GL_GREEN_MIN_CLAMP_INGR 0x8561
#endif

#ifndef GL_RED_MIN_CLAMP_INGR
#define GL_RED_MIN_CLAMP_INGR 0x8560
#endif

#ifndef GL_RED_MAX_CLAMP_INGR
#define GL_RED_MAX_CLAMP_INGR 0x8564
#endif

#ifndef GL_ALPHA_MAX_CLAMP_INGR
#define GL_ALPHA_MAX_CLAMP_INGR 0x8567
#endif

#ifndef GL_BLUE_MAX_CLAMP_INGR
#define GL_BLUE_MAX_CLAMP_INGR 0x8566
#endif


// GL_EXT_422_pixels
#ifndef GL_422_REV_AVERAGE_EXT
#define GL_422_REV_AVERAGE_EXT 0x80CF
#endif

#ifndef GL_422_EXT
#define GL_422_EXT 0x80CC
#endif

#ifndef GL_422_REV_EXT
#define GL_422_REV_EXT 0x80CD
#endif

#ifndef GL_422_AVERAGE_EXT
#define GL_422_AVERAGE_EXT 0x80CE
#endif


// GL_EXT_index_func
typedef void (NIV_CALL_TYPE * nivenGLINDEXFUNCEXT) (GLenum func, GLfloat ref);

#ifdef _GLX
// GLX_MESA_set_3dfx_mode
#ifndef GLX_3DFX_FULLSCREEN_MODE_MESA
#define GLX_3DFX_FULLSCREEN_MODE_MESA 0x2
#endif

#ifndef GLX_3DFX_WINDOW_MODE_MESA
#define GLX_3DFX_WINDOW_MODE_MESA 0x1
#endif

typedef GLboolean (NIV_CALL_TYPE * nivenGLXSET3DFXMODEMESA) (GLint mode);
#endif // _GLX
// WGL_NV_float_buffer
#ifdef WIN32
#ifndef WGL_FLOAT_COMPONENTS_NV
#define WGL_FLOAT_COMPONENTS_NV 0x20B0
#endif

#ifndef WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RG_NV
#define WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RG_NV 0x20B2
#endif

#ifndef WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGBA_NV
#define WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGBA_NV 0x20B4
#endif

#ifndef WGL_TEXTURE_FLOAT_R_NV
#define WGL_TEXTURE_FLOAT_R_NV 0x20B5
#endif

#ifndef WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGB_NV
#define WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGB_NV 0x20B3
#endif

#ifndef WGL_TEXTURE_FLOAT_RGBA_NV
#define WGL_TEXTURE_FLOAT_RGBA_NV 0x20B8
#endif

#ifndef WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_R_NV
#define WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_R_NV 0x20B1
#endif

#ifndef WGL_TEXTURE_FLOAT_RG_NV
#define WGL_TEXTURE_FLOAT_RG_NV 0x20B6
#endif

#ifndef WGL_TEXTURE_FLOAT_RGB_NV
#define WGL_TEXTURE_FLOAT_RGB_NV 0x20B7
#endif

#endif
// GL_SUN_read_video_pixels
typedef void (NIV_CALL_TYPE * nivenGLREADVIDEOPIXELSSUN) (GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLvoid* pixels);

// GL_ARB_transpose_matrix
#ifndef GL_TRANSPOSE_MODELVIEW_MATRIX_ARB
#define GL_TRANSPOSE_MODELVIEW_MATRIX_ARB 0x84E3
#endif

#ifndef GL_TRANSPOSE_COLOR_MATRIX_ARB
#define GL_TRANSPOSE_COLOR_MATRIX_ARB 0x84E6
#endif

#ifndef GL_TRANSPOSE_PROJECTION_MATRIX_ARB
#define GL_TRANSPOSE_PROJECTION_MATRIX_ARB 0x84E4
#endif

#ifndef GL_TRANSPOSE_TEXTURE_MATRIX_ARB
#define GL_TRANSPOSE_TEXTURE_MATRIX_ARB 0x84E5
#endif

typedef void (NIV_CALL_TYPE * nivenGLMULTTRANSPOSEMATRIXDARB) (GLdouble m[16]);
typedef void (NIV_CALL_TYPE * nivenGLLOADTRANSPOSEMATRIXDARB) (GLdouble m[16]);
typedef void (NIV_CALL_TYPE * nivenGLLOADTRANSPOSEMATRIXFARB) (GLfloat m[16]);
typedef void (NIV_CALL_TYPE * nivenGLMULTTRANSPOSEMATRIXFARB) (GLfloat m[16]);

// WGL_EXT_extensions_string
#ifdef WIN32
typedef const char* (NIV_CALL_TYPE * nivenWGLGETEXTENSIONSSTRINGEXT) (void );
#endif
// WGL_ATI_pixel_format_float
#ifdef WIN32
#ifndef GL_RGBA_FLOAT_MODE_ATI
#define GL_RGBA_FLOAT_MODE_ATI 0x8820
#endif

#ifndef GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI
#define GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI 0x8835
#endif

#ifndef WGL_TYPE_RGBA_FLOAT_ATI
#define WGL_TYPE_RGBA_FLOAT_ATI 0x21A0
#endif

#endif
// WGL_I3D_image_buffer
#ifdef WIN32
#ifndef WGL_IMAGE_BUFFER_LOCK_I3D
#define WGL_IMAGE_BUFFER_LOCK_I3D 0x00000002
#endif

#ifndef WGL_IMAGE_BUFFER_MIN_ACCESS_I3D
#define WGL_IMAGE_BUFFER_MIN_ACCESS_I3D 0x00000001
#endif

typedef BOOL (NIV_CALL_TYPE * nivenWGLASSOCIATEIMAGEBUFFEREVENTSI3D) (HDC hdc, HANDLE* pEvent, LPVOID* pAddress, DWORD* pSize, UINT count);
typedef BOOL (NIV_CALL_TYPE * nivenWGLDESTROYIMAGEBUFFERI3D) (HDC hDC, LPVOID pAddress);
typedef BOOL (NIV_CALL_TYPE * nivenWGLRELEASEIMAGEBUFFEREVENTSI3D) (HDC hdc, LPVOID* pAddress, UINT count);
typedef LPVOID (NIV_CALL_TYPE * nivenWGLCREATEIMAGEBUFFERI3D) (HDC hDC, DWORD dwSize, UINT uFlags);
#endif
// GL_NV_fence
#ifndef GL_ALL_COMPLETED_NV
#define GL_ALL_COMPLETED_NV 0x84F2
#endif

#ifndef GL_FENCE_STATUS_NV
#define GL_FENCE_STATUS_NV 0x84F3
#endif

#ifndef GL_FENCE_CONDITION_NV
#define GL_FENCE_CONDITION_NV 0x84F4
#endif

typedef void (NIV_CALL_TYPE * nivenGLDELETEFENCESNV) (GLsizei n, const GLuint* fences);
typedef GLboolean (NIV_CALL_TYPE * nivenGLTESTFENCENV) (GLuint fence);
typedef void (NIV_CALL_TYPE * nivenGLGENFENCESNV) (GLsizei n, GLuint* fences);
typedef void (NIV_CALL_TYPE * nivenGLGETFENCEIVNV) (GLuint fence, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLFINISHFENCENV) (GLuint fence);
typedef void (NIV_CALL_TYPE * nivenGLSETFENCENV) (GLuint fence, GLenum condition);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISFENCENV) (GLuint fence);

// WGL_ATI_render_texture_rectangle
#ifdef WIN32
#ifndef WGL_TEXTURE_RECTANGLE_ATI
#define WGL_TEXTURE_RECTANGLE_ATI 0x21A5
#endif

#endif
// GL_ARB_texture_border_clamp
#ifndef GL_CLAMP_TO_BORDER_ARB
#define GL_CLAMP_TO_BORDER_ARB 0x812D
#endif


// GL_EXT_fog_coord
#ifndef GL_FOG_COORDINATE_ARRAY_TYPE_EXT
#define GL_FOG_COORDINATE_ARRAY_TYPE_EXT 0x8454
#endif

#ifndef GL_CURRENT_FOG_COORDINATE_EXT
#define GL_CURRENT_FOG_COORDINATE_EXT 0x8453
#endif

#ifndef GL_FOG_COORDINATE_ARRAY_EXT
#define GL_FOG_COORDINATE_ARRAY_EXT 0x8457
#endif

#ifndef GL_FOG_COORDINATE_ARRAY_POINTER_EXT
#define GL_FOG_COORDINATE_ARRAY_POINTER_EXT 0x8456
#endif

#ifndef GL_FRAGMENT_DEPTH_EXT
#define GL_FRAGMENT_DEPTH_EXT 0x8452
#endif

#ifndef GL_FOG_COORDINATE_SOURCE_EXT
#define GL_FOG_COORDINATE_SOURCE_EXT 0x8450
#endif

#ifndef GL_FOG_COORDINATE_EXT
#define GL_FOG_COORDINATE_EXT 0x8451
#endif

#ifndef GL_FOG_COORDINATE_ARRAY_STRIDE_EXT
#define GL_FOG_COORDINATE_ARRAY_STRIDE_EXT 0x8455
#endif

typedef void (NIV_CALL_TYPE * nivenGLFOGCOORDDEXT) (GLdouble coord);
typedef void (NIV_CALL_TYPE * nivenGLFOGCOORDPOINTEREXT) (GLenum type, GLsizei stride, const GLvoid* pointer);
typedef void (NIV_CALL_TYPE * nivenGLFOGCOORDFVEXT) (const GLfloat* coord);
typedef void (NIV_CALL_TYPE * nivenGLFOGCOORDDVEXT) (const GLdouble* coord);
typedef void (NIV_CALL_TYPE * nivenGLFOGCOORDFEXT) (GLfloat coord);

// GL_NV_depth_clamp
#ifndef GL_DEPTH_CLAMP_NV
#define GL_DEPTH_CLAMP_NV 0x864F
#endif


// WGL_I3D_digital_video_control
#ifdef WIN32
#ifndef WGL_DIGITAL_VIDEO_CURSOR_ALPHA_FRAMEBUFFER_I3D
#define WGL_DIGITAL_VIDEO_CURSOR_ALPHA_FRAMEBUFFER_I3D 0x2050
#endif

#ifndef WGL_DIGITAL_VIDEO_GAMMA_CORRECTED_I3D
#define WGL_DIGITAL_VIDEO_GAMMA_CORRECTED_I3D 0x2053
#endif

#ifndef WGL_DIGITAL_VIDEO_CURSOR_ALPHA_VALUE_I3D
#define WGL_DIGITAL_VIDEO_CURSOR_ALPHA_VALUE_I3D 0x2051
#endif

#ifndef WGL_DIGITAL_VIDEO_CURSOR_INCLUDED_I3D
#define WGL_DIGITAL_VIDEO_CURSOR_INCLUDED_I3D 0x2052
#endif

typedef BOOL (NIV_CALL_TYPE * nivenWGLSETDIGITALVIDEOPARAMETERSI3D) (HDC hDC, int iAttribute, const int* piValue);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGETDIGITALVIDEOPARAMETERSI3D) (HDC hDC, int iAttribute, int* piValue);
#endif
// GL_ARB_texture_cube_map
#ifndef GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB
#define GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB 0x8515
#endif

#ifndef GL_TEXTURE_CUBE_MAP_ARB
#define GL_TEXTURE_CUBE_MAP_ARB 0x8513
#endif

#ifndef GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB
#define GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB 0x8518
#endif

#ifndef GL_TEXTURE_BINDING_CUBE_MAP_ARB
#define GL_TEXTURE_BINDING_CUBE_MAP_ARB 0x8514
#endif

#ifndef GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB
#define GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB 0x851A
#endif

#ifndef GL_MAX_CUBE_MAP_TEXTURE_SIZE_ARB
#define GL_MAX_CUBE_MAP_TEXTURE_SIZE_ARB 0x851C
#endif

#ifndef GL_REFLECTION_MAP_ARB
#define GL_REFLECTION_MAP_ARB 0x8512
#endif

#ifndef GL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB
#define GL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB 0x8516
#endif

#ifndef GL_NORMAL_MAP_ARB
#define GL_NORMAL_MAP_ARB 0x8511
#endif

#ifndef GL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB
#define GL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB 0x8517
#endif

#ifndef GL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB
#define GL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB 0x8519
#endif

#ifndef GL_PROXY_TEXTURE_CUBE_MAP_ARB
#define GL_PROXY_TEXTURE_CUBE_MAP_ARB 0x851B
#endif


// GL_EXT_color_subtable
typedef void (NIV_CALL_TYPE * nivenGLCOPYCOLORSUBTABLEEXT) (GLenum target, GLsizei start, GLint x, GLint y, GLsizei width);
typedef void (NIV_CALL_TYPE * nivenGLCOLORSUBTABLEEXT) (GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const void* data);

// GL_EXT_blend_equation_separate
#ifndef GL_BLEND_EQUATION_ALPHA_EXT
#define GL_BLEND_EQUATION_ALPHA_EXT 0x883D
#endif

#ifndef GL_BLEND_EQUATION_RGB_EXT
#define GL_BLEND_EQUATION_RGB_EXT 0x8009
#endif

typedef void (NIV_CALL_TYPE * nivenGLBLENDEQUATIONSEPARATEEXT) (GLenum modeRGB, GLenum modeAlpha);

// WGL_I3D_swap_frame_lock
#ifdef WIN32
typedef BOOL (NIV_CALL_TYPE * nivenWGLENABLEFRAMELOCKI3D) (VOID );
typedef BOOL (NIV_CALL_TYPE * nivenWGLQUERYFRAMELOCKMASTERI3D) (BOOL* pFlag);
typedef BOOL (NIV_CALL_TYPE * nivenWGLDISABLEFRAMELOCKI3D) (VOID );
typedef BOOL (NIV_CALL_TYPE * nivenWGLISENABLEDFRAMELOCKI3D) (BOOL* pFlag);
#endif
// GL_SUN_mesh_array
#ifndef GL_TRIANGLE_MESH_SUN
#define GL_TRIANGLE_MESH_SUN 0x8615
#endif

#ifndef GL_QUAD_MESH_SUN
#define GL_QUAD_MESH_SUN 0x8614
#endif


// GL_SUNX_constant_data
#ifndef GL_UNPACK_CONSTANT_DATA_SUNX
#define GL_UNPACK_CONSTANT_DATA_SUNX 0x81D5
#endif

#ifndef GL_TEXTURE_CONSTANT_DATA_SUNX
#define GL_TEXTURE_CONSTANT_DATA_SUNX 0x81D6
#endif

typedef void (NIV_CALL_TYPE * nivenGLFINISHTEXTURESUNX) (void );

// GL_ARB_point_parameters
#ifndef GL_POINT_SIZE_MAX_ARB
#define GL_POINT_SIZE_MAX_ARB 0x8127
#endif

#ifndef GL_POINT_FADE_THRESHOLD_SIZE_ARB
#define GL_POINT_FADE_THRESHOLD_SIZE_ARB 0x8128
#endif

#ifndef GL_POINT_SIZE_MIN_ARB
#define GL_POINT_SIZE_MIN_ARB 0x8126
#endif

#ifndef GL_POINT_DISTANCE_ATTENUATION_ARB
#define GL_POINT_DISTANCE_ATTENUATION_ARB 0x8129
#endif

typedef void (NIV_CALL_TYPE * nivenGLPOINTPARAMETERFARB) (GLenum pname, GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLPOINTPARAMETERFVARB) (GLenum pname, GLfloat* params);

// GL_EXT_texture_env_dot3
#ifndef GL_DOT3_RGBA_EXT
#define GL_DOT3_RGBA_EXT 0x8741
#endif

#ifndef GL_DOT3_RGB_EXT
#define GL_DOT3_RGB_EXT 0x8740
#endif


// WGL_ARB_buffer_region
#ifdef WIN32
#ifndef WGL_BACK_COLOR_BUFFER_BIT_ARB
#define WGL_BACK_COLOR_BUFFER_BIT_ARB 0x00000002
#endif

#ifndef WGL_FRONT_COLOR_BUFFER_BIT_ARB
#define WGL_FRONT_COLOR_BUFFER_BIT_ARB 0x00000001
#endif

#ifndef WGL_DEPTH_BUFFER_BIT_ARB
#define WGL_DEPTH_BUFFER_BIT_ARB 0x00000004
#endif

#ifndef WGL_STENCIL_BUFFER_BIT_ARB
#define WGL_STENCIL_BUFFER_BIT_ARB 0x00000008
#endif

typedef BOOL (NIV_CALL_TYPE * nivenWGLSAVEBUFFERREGIONARB) (HANDLE hRegion, int x, int y, int width, int height);
typedef HANDLE (NIV_CALL_TYPE * nivenWGLCREATEBUFFERREGIONARB) (HDC hDC, int iLayerPlane, UINT uType);
typedef VOID (NIV_CALL_TYPE * nivenWGLDELETEBUFFERREGIONARB) (HANDLE hRegion);
typedef BOOL (NIV_CALL_TYPE * nivenWGLRESTOREBUFFERREGIONARB) (HANDLE hRegion, int x, int y, int width, int height, int xSrc, int ySrc);
#endif
// GL_ATI_texture_env_combine3
#ifndef GL_MODULATE_SUBTRACT_ATI
#define GL_MODULATE_SUBTRACT_ATI 0x8746
#endif

#ifndef GL_MODULATE_SIGNED_ADD_ATI
#define GL_MODULATE_SIGNED_ADD_ATI 0x8745
#endif

#ifndef GL_MODULATE_ADD_ATI
#define GL_MODULATE_ADD_ATI 0x8744
#endif


// GL_SGIX_shadow_ambient
#ifndef GL_SHADOW_AMBIENT_SGIX
#define GL_SHADOW_AMBIENT_SGIX 0x80BF
#endif


// GL_EXT_multi_draw_arrays
typedef void (NIV_CALL_TYPE * nivenGLMULTIDRAWELEMENTSEXT) (GLenum mode, GLsizei* count, GLenum type, const GLvoid* *indices, GLsizei primcount);
typedef void (NIV_CALL_TYPE * nivenGLMULTIDRAWARRAYSEXT) (GLenum mode, GLint* first, GLsizei* count, GLsizei primcount);

// GL_SGIX_depth_texture
#ifndef GL_DEPTH_COMPONENT24_SGIX
#define GL_DEPTH_COMPONENT24_SGIX 0x81A6
#endif

#ifndef GL_DEPTH_COMPONENT16_SGIX
#define GL_DEPTH_COMPONENT16_SGIX 0x81A5
#endif

#ifndef GL_DEPTH_COMPONENT32_SGIX
#define GL_DEPTH_COMPONENT32_SGIX 0x81A7
#endif


// GL_EXT_texture_compression_dxt1
#ifndef GL_COMPRESSED_RGB_S3TC_DXT1_EXT
#define GL_COMPRESSED_RGB_S3TC_DXT1_EXT 0x83F0
#endif

#ifndef GL_COMPRESSED_RGBA_S3TC_DXT1_EXT
#define GL_COMPRESSED_RGBA_S3TC_DXT1_EXT 0x83F1
#endif


// GL_NV_texgen_emboss
#ifndef GL_EMBOSS_CONSTANT_NV
#define GL_EMBOSS_CONSTANT_NV 0x855E
#endif

#ifndef GL_EMBOSS_LIGHT_NV
#define GL_EMBOSS_LIGHT_NV 0x855D
#endif

#ifndef GL_EMBOSS_MAP_NV
#define GL_EMBOSS_MAP_NV 0x855F
#endif


// GL_HP_occlusion_test
#ifndef GL_OCCLUSION_TEST_HP
#define GL_OCCLUSION_TEST_HP 0x8165
#endif

#ifndef GL_OCCLUSION_TEST_RESULT_HP
#define GL_OCCLUSION_TEST_RESULT_HP 0x8166
#endif


// GL_WIN_phong_shading
#ifndef GL_PHONG_HINT_WIN
#define GL_PHONG_HINT_WIN 0x80EB
#endif

#ifndef GL_PHONG_WIN
#define GL_PHONG_WIN 0x80EA
#endif


#ifdef _GLX
// GLX_SGIS_shared_multisample
#ifndef GLX_MULTISAMPLE_SUB_RECT_HEIGHT_SGIS
#define GLX_MULTISAMPLE_SUB_RECT_HEIGHT_SGIS 0x8027
#endif

#ifndef GLX_MULTISAMPLE_SUB_RECT_WIDTH_SGIS
#define GLX_MULTISAMPLE_SUB_RECT_WIDTH_SGIS 0x8026
#endif

#endif // _GLX
// GL_ATIX_texture_env_combine3
#ifndef GL_MODULATE_ADD_ATIX
#define GL_MODULATE_ADD_ATIX 0x8744
#endif

#ifndef GL_MODULATE_SIGNED_ADD_ATIX
#define GL_MODULATE_SIGNED_ADD_ATIX 0x8745
#endif

#ifndef GL_MODULATE_SUBTRACT_ATIX
#define GL_MODULATE_SUBTRACT_ATIX 0x8746
#endif


// GL_EXT_texture_filter_anisotropic
#ifndef GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT
#define GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT 0x84FF
#endif

#ifndef GL_TEXTURE_MAX_ANISOTROPY_EXT
#define GL_TEXTURE_MAX_ANISOTROPY_EXT 0x84FE
#endif


// GL_EXT_texture_perturb_normal
#ifndef GL_TEXTURE_NORMAL_EXT
#define GL_TEXTURE_NORMAL_EXT 0x85AF
#endif

#ifndef GL_PERTURB_EXT
#define GL_PERTURB_EXT 0x85AE
#endif

typedef void (NIV_CALL_TYPE * nivenGLTEXTURENORMALEXT) (GLenum mode);

// GL_NV_fog_distance
#ifndef GL_EYE_RADIAL_NV
#define GL_EYE_RADIAL_NV 0x855B
#endif

#ifndef GL_FOG_DISTANCE_MODE_NV
#define GL_FOG_DISTANCE_MODE_NV 0x855A
#endif

#ifndef GL_EYE_PLANE_ABSOLUTE_NV
#define GL_EYE_PLANE_ABSOLUTE_NV 0x855C
#endif


// GL_ATIX_vertex_shader_output_point_size
#ifndef GL_OUTPUT_POINT_SIZE_ATIX
#define GL_OUTPUT_POINT_SIZE_ATIX 0x610E
#endif


// GL_SUN_global_alpha
#ifndef GL_GLOBAL_ALPHA_SUN
#define GL_GLOBAL_ALPHA_SUN 0x81D9
#endif

#ifndef GL_GLOBAL_ALPHA_FACTOR_SUN
#define GL_GLOBAL_ALPHA_FACTOR_SUN 0x81DA
#endif

typedef void (NIV_CALL_TYPE * nivenGLGLOBALALPHAFACTORDSUN) (GLdouble factor);
typedef void (NIV_CALL_TYPE * nivenGLGLOBALALPHAFACTORSSUN) (GLshort factor);
typedef void (NIV_CALL_TYPE * nivenGLGLOBALALPHAFACTORISUN) (GLint factor);
typedef void (NIV_CALL_TYPE * nivenGLGLOBALALPHAFACTORUSSUN) (GLushort factor);
typedef void (NIV_CALL_TYPE * nivenGLGLOBALALPHAFACTORFSUN) (GLfloat factor);
typedef void (NIV_CALL_TYPE * nivenGLGLOBALALPHAFACTORBSUN) (GLbyte factor);
typedef void (NIV_CALL_TYPE * nivenGLGLOBALALPHAFACTORUISUN) (GLuint factor);
typedef void (NIV_CALL_TYPE * nivenGLGLOBALALPHAFACTORUBSUN) (GLubyte factor);

// WGL_EXT_pixel_format
#ifdef WIN32
#ifndef WGL_SWAP_LAYER_BUFFERS_EXT
#define WGL_SWAP_LAYER_BUFFERS_EXT 0x2006
#endif

#ifndef WGL_RED_SHIFT_EXT
#define WGL_RED_SHIFT_EXT 0x2016
#endif

#ifndef WGL_GENERIC_ACCELERATION_EXT
#define WGL_GENERIC_ACCELERATION_EXT 0x2026
#endif

#ifndef WGL_SHARE_STENCIL_EXT
#define WGL_SHARE_STENCIL_EXT 0x200D
#endif

#ifndef WGL_ACCUM_BLUE_BITS_EXT
#define WGL_ACCUM_BLUE_BITS_EXT 0x2020
#endif

#ifndef WGL_NEED_PALETTE_EXT
#define WGL_NEED_PALETTE_EXT 0x2004
#endif

#ifndef WGL_ACCUM_BITS_EXT
#define WGL_ACCUM_BITS_EXT 0x201D
#endif

#ifndef WGL_TYPE_RGBA_EXT
#define WGL_TYPE_RGBA_EXT 0x202B
#endif

#ifndef WGL_NUMBER_PIXEL_FORMATS_EXT
#define WGL_NUMBER_PIXEL_FORMATS_EXT 0x2000
#endif

#ifndef WGL_SUPPORT_OPENGL_EXT
#define WGL_SUPPORT_OPENGL_EXT 0x2010
#endif

#ifndef WGL_NUMBER_UNDERLAYS_EXT
#define WGL_NUMBER_UNDERLAYS_EXT 0x2009
#endif

#ifndef WGL_STEREO_EXT
#define WGL_STEREO_EXT 0x2012
#endif

#ifndef WGL_PIXEL_TYPE_EXT
#define WGL_PIXEL_TYPE_EXT 0x2013
#endif

#ifndef WGL_SWAP_EXCHANGE_EXT
#define WGL_SWAP_EXCHANGE_EXT 0x2028
#endif

#ifndef WGL_DRAW_TO_WINDOW_EXT
#define WGL_DRAW_TO_WINDOW_EXT 0x2001
#endif

#ifndef WGL_GREEN_BITS_EXT
#define WGL_GREEN_BITS_EXT 0x2017
#endif

#ifndef WGL_SHARE_ACCUM_EXT
#define WGL_SHARE_ACCUM_EXT 0x200E
#endif

#ifndef WGL_TRANSPARENT_EXT
#define WGL_TRANSPARENT_EXT 0x200A
#endif

#ifndef WGL_GREEN_SHIFT_EXT
#define WGL_GREEN_SHIFT_EXT 0x2018
#endif

#ifndef WGL_ACCELERATION_EXT
#define WGL_ACCELERATION_EXT 0x2003
#endif

#ifndef WGL_DOUBLE_BUFFER_EXT
#define WGL_DOUBLE_BUFFER_EXT 0x2011
#endif

#ifndef WGL_COLOR_BITS_EXT
#define WGL_COLOR_BITS_EXT 0x2014
#endif

#ifndef WGL_FULL_ACCELERATION_EXT
#define WGL_FULL_ACCELERATION_EXT 0x2027
#endif

#ifndef WGL_DRAW_TO_BITMAP_EXT
#define WGL_DRAW_TO_BITMAP_EXT 0x2002
#endif

#ifndef WGL_SHARE_DEPTH_EXT
#define WGL_SHARE_DEPTH_EXT 0x200C
#endif

#ifndef WGL_RED_BITS_EXT
#define WGL_RED_BITS_EXT 0x2015
#endif

#ifndef WGL_ALPHA_BITS_EXT
#define WGL_ALPHA_BITS_EXT 0x201B
#endif

#ifndef WGL_SWAP_METHOD_EXT
#define WGL_SWAP_METHOD_EXT 0x2007
#endif

#ifndef WGL_DEPTH_BITS_EXT
#define WGL_DEPTH_BITS_EXT 0x2022
#endif

#ifndef WGL_NO_ACCELERATION_EXT
#define WGL_NO_ACCELERATION_EXT 0x2025
#endif

#ifndef WGL_BLUE_BITS_EXT
#define WGL_BLUE_BITS_EXT 0x2019
#endif

#ifndef WGL_SUPPORT_GDI_EXT
#define WGL_SUPPORT_GDI_EXT 0x200F
#endif

#ifndef WGL_ACCUM_GREEN_BITS_EXT
#define WGL_ACCUM_GREEN_BITS_EXT 0x201F
#endif

#ifndef WGL_AUX_BUFFERS_EXT
#define WGL_AUX_BUFFERS_EXT 0x2024
#endif

#ifndef WGL_SWAP_UNDEFINED_EXT
#define WGL_SWAP_UNDEFINED_EXT 0x202A
#endif

#ifndef WGL_ACCUM_ALPHA_BITS_EXT
#define WGL_ACCUM_ALPHA_BITS_EXT 0x2021
#endif

#ifndef WGL_BLUE_SHIFT_EXT
#define WGL_BLUE_SHIFT_EXT 0x201A
#endif

#ifndef WGL_NUMBER_OVERLAYS_EXT
#define WGL_NUMBER_OVERLAYS_EXT 0x2008
#endif

#ifndef WGL_TRANSPARENT_VALUE_EXT
#define WGL_TRANSPARENT_VALUE_EXT 0x200B
#endif

#ifndef WGL_TYPE_COLORINDEX_EXT
#define WGL_TYPE_COLORINDEX_EXT 0x202C
#endif

#ifndef WGL_ACCUM_RED_BITS_EXT
#define WGL_ACCUM_RED_BITS_EXT 0x201E
#endif

#ifndef WGL_ALPHA_SHIFT_EXT
#define WGL_ALPHA_SHIFT_EXT 0x201C
#endif

#ifndef WGL_STENCIL_BITS_EXT
#define WGL_STENCIL_BITS_EXT 0x2023
#endif

#ifndef WGL_NEED_SYSTEM_PALETTE_EXT
#define WGL_NEED_SYSTEM_PALETTE_EXT 0x2005
#endif

#ifndef WGL_SWAP_COPY_EXT
#define WGL_SWAP_COPY_EXT 0x2029
#endif

typedef BOOL (NIV_CALL_TYPE * nivenWGLGETPIXELFORMATATTRIBFVEXT) (HDC hdc, int iPixelFormat, int iLayerPlane, UINT nAttributes, int* piAttributes, FLOAT* pfValues);
typedef BOOL (NIV_CALL_TYPE * nivenWGLCHOOSEPIXELFORMATEXT) (HDC hdc, const int* piAttribIList, const FLOAT* pfAttribFList, UINT nMaxFormats, int* piFormats, UINT* nNumFormats);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGETPIXELFORMATATTRIBIVEXT) (HDC hdc, int iPixelFormat, int iLayerPlane, UINT nAttributes, int* piAttributes, int* piValues);
#endif
// GL_SGIX_async_histogram
#ifndef GL_ASYNC_HISTOGRAM_SGIX
#define GL_ASYNC_HISTOGRAM_SGIX 0x832C
#endif

#ifndef GL_MAX_ASYNC_HISTOGRAM_SGIX
#define GL_MAX_ASYNC_HISTOGRAM_SGIX 0x832D
#endif


// GL_ARB_vertex_program
#ifndef GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB
#define GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB 0x8624
#endif

#ifndef GL_MATRIX21_ARB
#define GL_MATRIX21_ARB 0x88D5
#endif

#ifndef GL_PROGRAM_BINDING_ARB
#define GL_PROGRAM_BINDING_ARB 0x8677
#endif

#ifndef GL_MATRIX12_ARB
#define GL_MATRIX12_ARB 0x88CC
#endif

#ifndef GL_MATRIX24_ARB
#define GL_MATRIX24_ARB 0x88D8
#endif

#ifndef GL_VERTEX_PROGRAM_POINT_SIZE_ARB
#define GL_VERTEX_PROGRAM_POINT_SIZE_ARB 0x8642
#endif

#ifndef GL_MATRIX30_ARB
#define GL_MATRIX30_ARB 0x88DE
#endif

#ifndef GL_MATRIX9_ARB
#define GL_MATRIX9_ARB 0x88C9
#endif

#ifndef GL_MAX_PROGRAM_ENV_PARAMETERS_ARB
#define GL_MAX_PROGRAM_ENV_PARAMETERS_ARB 0x88B5
#endif

#ifndef GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB
#define GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB 0x88B6
#endif

#ifndef GL_MATRIX15_ARB
#define GL_MATRIX15_ARB 0x88CF
#endif

#ifndef GL_MATRIX0_ARB
#define GL_MATRIX0_ARB 0x88C0
#endif

#ifndef GL_MATRIX23_ARB
#define GL_MATRIX23_ARB 0x88D7
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB
#define GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB 0x8622
#endif

#ifndef GL_MATRIX17_ARB
#define GL_MATRIX17_ARB 0x88D1
#endif

#ifndef GL_MAX_PROGRAM_INSTRUCTIONS_ARB
#define GL_MAX_PROGRAM_INSTRUCTIONS_ARB 0x88A1
#endif

#ifndef GL_MATRIX28_ARB
#define GL_MATRIX28_ARB 0x88DC
#endif

#ifndef GL_PROGRAM_NATIVE_PARAMETERS_ARB
#define GL_PROGRAM_NATIVE_PARAMETERS_ARB 0x88AA
#endif

#ifndef GL_MAX_PROGRAM_MATRICES_ARB
#define GL_MAX_PROGRAM_MATRICES_ARB 0x862F
#endif

#ifndef GL_PROGRAM_PARAMETERS_ARB
#define GL_PROGRAM_PARAMETERS_ARB 0x88A8
#endif

#ifndef GL_PROGRAM_ADDRESS_REGISTERS_ARB
#define GL_PROGRAM_ADDRESS_REGISTERS_ARB 0x88B0
#endif

#ifndef GL_MATRIX5_ARB
#define GL_MATRIX5_ARB 0x88C5
#endif

#ifndef GL_PROGRAM_INSTRUCTIONS_ARB
#define GL_PROGRAM_INSTRUCTIONS_ARB 0x88A0
#endif

#ifndef GL_VERTEX_PROGRAM_TWO_SIDE_ARB
#define GL_VERTEX_PROGRAM_TWO_SIDE_ARB 0x8643
#endif

#ifndef GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB
#define GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB 0x88B3
#endif

#ifndef GL_MATRIX31_ARB
#define GL_MATRIX31_ARB 0x88DF
#endif

#ifndef GL_TRANSPOSE_CURRENT_MATRIX_ARB
#define GL_TRANSPOSE_CURRENT_MATRIX_ARB 0x88B7
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB
#define GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB 0x8645
#endif

#ifndef GL_MATRIX1_ARB
#define GL_MATRIX1_ARB 0x88C1
#endif

#ifndef GL_PROGRAM_NATIVE_TEMPORARIES_ARB
#define GL_PROGRAM_NATIVE_TEMPORARIES_ARB 0x88A6
#endif

#ifndef GL_MAX_PROGRAM_ATTRIBS_ARB
#define GL_MAX_PROGRAM_ATTRIBS_ARB 0x88AD
#endif

#ifndef GL_MATRIX3_ARB
#define GL_MATRIX3_ARB 0x88C3
#endif

#ifndef GL_PROGRAM_STRING_ARB
#define GL_PROGRAM_STRING_ARB 0x8628
#endif

#ifndef GL_MATRIX6_ARB
#define GL_MATRIX6_ARB 0x88C6
#endif

#ifndef GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB
#define GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB 0x88A2
#endif

#ifndef GL_PROGRAM_ERROR_POSITION_ARB
#define GL_PROGRAM_ERROR_POSITION_ARB 0x864B
#endif

#ifndef GL_MATRIX8_ARB
#define GL_MATRIX8_ARB 0x88C8
#endif

#ifndef GL_PROGRAM_ATTRIBS_ARB
#define GL_PROGRAM_ATTRIBS_ARB 0x88AC
#endif

#ifndef GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB
#define GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB 0x88B4
#endif

#ifndef GL_MATRIX10_ARB
#define GL_MATRIX10_ARB 0x88CA
#endif

#ifndef GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB
#define GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB 0x88AF
#endif

#ifndef GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB
#define GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB 0x88AB
#endif

#ifndef GL_MATRIX19_ARB
#define GL_MATRIX19_ARB 0x88D3
#endif

#ifndef GL_MATRIX22_ARB
#define GL_MATRIX22_ARB 0x88D6
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB
#define GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB 0x8623
#endif

#ifndef GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB
#define GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB 0x88A3
#endif

#ifndef GL_MATRIX16_ARB
#define GL_MATRIX16_ARB 0x88D0
#endif

#ifndef GL_MATRIX27_ARB
#define GL_MATRIX27_ARB 0x88DB
#endif

#ifndef GL_PROGRAM_LENGTH_ARB
#define GL_PROGRAM_LENGTH_ARB 0x8627
#endif

#ifndef GL_MATRIX4_ARB
#define GL_MATRIX4_ARB 0x88C4
#endif

#ifndef GL_PROGRAM_NATIVE_ATTRIBS_ARB
#define GL_PROGRAM_NATIVE_ATTRIBS_ARB 0x88AE
#endif

#ifndef GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB
#define GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB 0x88A7
#endif

#ifndef GL_MATRIX14_ARB
#define GL_MATRIX14_ARB 0x88CE
#endif

#ifndef GL_MATRIX13_ARB
#define GL_MATRIX13_ARB 0x88CD
#endif

#ifndef GL_PROGRAM_TEMPORARIES_ARB
#define GL_PROGRAM_TEMPORARIES_ARB 0x88A4
#endif

#ifndef GL_MATRIX20_ARB
#define GL_MATRIX20_ARB 0x88D4
#endif

#ifndef GL_CURRENT_VERTEX_ATTRIB_ARB
#define GL_CURRENT_VERTEX_ATTRIB_ARB 0x8626
#endif

#ifndef GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB
#define GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB 0x88B1
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB
#define GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB 0x886A
#endif

#ifndef GL_VERTEX_PROGRAM_ARB
#define GL_VERTEX_PROGRAM_ARB 0x8620
#endif

#ifndef GL_MATRIX18_ARB
#define GL_MATRIX18_ARB 0x88D2
#endif

#ifndef GL_MATRIX2_ARB
#define GL_MATRIX2_ARB 0x88C2
#endif

#ifndef GL_MATRIX29_ARB
#define GL_MATRIX29_ARB 0x88DD
#endif

#ifndef GL_MATRIX11_ARB
#define GL_MATRIX11_ARB 0x88CB
#endif

#ifndef GL_MAX_PROGRAM_PARAMETERS_ARB
#define GL_MAX_PROGRAM_PARAMETERS_ARB 0x88A9
#endif

#ifndef GL_MATRIX7_ARB
#define GL_MATRIX7_ARB 0x88C7
#endif

#ifndef GL_MAX_PROGRAM_TEMPORARIES_ARB
#define GL_MAX_PROGRAM_TEMPORARIES_ARB 0x88A5
#endif

#ifndef GL_PROGRAM_FORMAT_ARB
#define GL_PROGRAM_FORMAT_ARB 0x8876
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB
#define GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB 0x8625
#endif

#ifndef GL_PROGRAM_ERROR_STRING_ARB
#define GL_PROGRAM_ERROR_STRING_ARB 0x8874
#endif

#ifndef GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB
#define GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB 0x88B2
#endif

#ifndef GL_CURRENT_MATRIX_ARB
#define GL_CURRENT_MATRIX_ARB 0x8641
#endif

#ifndef GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB
#define GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB 0x862E
#endif

#ifndef GL_MAX_VERTEX_ATTRIBS_ARB
#define GL_MAX_VERTEX_ATTRIBS_ARB 0x8869
#endif

#ifndef GL_COLOR_SUM_ARB
#define GL_COLOR_SUM_ARB 0x8458
#endif

#ifndef GL_CURRENT_MATRIX_STACK_DEPTH_ARB
#define GL_CURRENT_MATRIX_STACK_DEPTH_ARB 0x8640
#endif

#ifndef GL_MATRIX26_ARB
#define GL_MATRIX26_ARB 0x88DA
#endif

#ifndef GL_PROGRAM_FORMAT_ASCII_ARB
#define GL_PROGRAM_FORMAT_ASCII_ARB 0x8875
#endif

#ifndef GL_MATRIX25_ARB
#define GL_MATRIX25_ARB 0x88D9
#endif

typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4UBVARB) (GLuint index, const GLubyte* v);
typedef void (NIV_CALL_TYPE * nivenGLDISABLEVERTEXATTRIBARRAYARB) (GLuint index);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4NSVARB) (GLuint index, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMLOCALPARAMETERFVARB) (GLenum target, GLuint index, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2DVARB) (GLuint index, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMENVPARAMETER4FVARB) (GLenum target, GLuint index, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4NIVARB) (GLuint index, const GLint* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1SARB) (GLuint index, GLshort x);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4UIVARB) (GLuint index, const GLuint* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4NUBARB) (GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMLOCALPARAMETER4DARB) (GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3FVARB) (GLuint index, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1FVARB) (GLuint index, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMSTRINGARB) (GLenum target, GLenum pname, void* string);
typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMLOCALPARAMETERDVARB) (GLenum target, GLuint index, GLdouble* params);
typedef void (NIV_CALL_TYPE * nivenGLENABLEVERTEXATTRIBARRAYARB) (GLuint index);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2FVARB) (GLuint index, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3DVARB) (GLuint index, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMENVPARAMETER4FARB) (GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
typedef void (NIV_CALL_TYPE * nivenGLGETVERTEXATTRIBIVARB) (GLuint index, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4SVARB) (GLuint index, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4FARB) (GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3DARB) (GLuint index, GLdouble x, GLdouble y, GLdouble z);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISPROGRAMARB) (GLuint program);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMLOCALPARAMETER4DVARB) (GLenum target, GLuint index, const GLdouble* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2SVARB) (GLuint index, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1DARB) (GLuint index, GLdouble x);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1FARB) (GLuint index, GLfloat x);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMLOCALPARAMETER4FVARB) (GLenum target, GLuint index, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2FARB) (GLuint index, GLfloat x, GLfloat y);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMENVPARAMETER4DARB) (GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2DARB) (GLuint index, GLdouble x, GLdouble y);
typedef void (NIV_CALL_TYPE * nivenGLGETVERTEXATTRIBFVARB) (GLuint index, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4NUSVARB) (GLuint index, const GLushort* v);
typedef void (NIV_CALL_TYPE * nivenGLGETVERTEXATTRIBPOINTERVARB) (GLuint index, GLenum pname, GLvoid* *pointer);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3FARB) (GLuint index, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMENVPARAMETERDVARB) (GLenum target, GLuint index, GLdouble* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4NUBVARB) (GLuint index, const GLubyte* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3SARB) (GLuint index, GLshort x, GLshort y, GLshort z);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4IVARB) (GLuint index, const GLint* v);
typedef void (NIV_CALL_TYPE * nivenGLDELETEPROGRAMSARB) (GLsizei n, const GLuint* programs);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4NBVARB) (GLuint index, const GLbyte* v);
typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMIVARB) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMENVPARAMETER4DVARB) (GLenum target, GLuint index, const GLdouble* params);
typedef void (NIV_CALL_TYPE * nivenGLGETVERTEXATTRIBDVARB) (GLuint index, GLenum pname, GLdouble* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4USVARB) (GLuint index, const GLushort* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1SVARB) (GLuint index, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4SARB) (GLuint index, GLshort x, GLshort y, GLshort z, GLshort w);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4DVARB) (GLuint index, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4BVARB) (GLuint index, const GLbyte* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBPOINTERARB) (GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3SVARB) (GLuint index, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLBINDPROGRAMARB) (GLenum target, GLuint program);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMSTRINGARB) (GLenum target, GLenum format, GLsizei len, const void* string);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMLOCALPARAMETER4FARB) (GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4FVARB) (GLuint index, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4DARB) (GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMENVPARAMETERFVARB) (GLenum target, GLuint index, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1DVARB) (GLuint index, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2SARB) (GLuint index, GLshort x, GLshort y);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4NUIVARB) (GLuint index, const GLuint* v);
typedef void (NIV_CALL_TYPE * nivenGLGENPROGRAMSARB) (GLsizei n, GLuint* programs);

// GL_MESA_resize_buffers
typedef void (NIV_CALL_TYPE * nivenGLRESIZEBUFFERSMESA) (void );

// GL_3DFX_multisample
#ifndef GL_SAMPLE_BUFFERS_3DFX
#define GL_SAMPLE_BUFFERS_3DFX 0x86B3
#endif

#ifndef GL_SAMPLES_3DFX
#define GL_SAMPLES_3DFX 0x86B4
#endif

#ifndef GL_MULTISAMPLE_BIT_3DFX
#define GL_MULTISAMPLE_BIT_3DFX 0x20000000
#endif

#ifndef GL_MULTISAMPLE_3DFX
#define GL_MULTISAMPLE_3DFX 0x86B2
#endif


// WGL_NV_render_texture_rectangle
#ifdef WIN32
#ifndef WGL_TEXTURE_RECTANGLE_NV
#define WGL_TEXTURE_RECTANGLE_NV 0x20A2
#endif

#ifndef WGL_BIND_TO_TEXTURE_RECTANGLE_RGBA_NV
#define WGL_BIND_TO_TEXTURE_RECTANGLE_RGBA_NV 0x20A1
#endif

#ifndef WGL_BIND_TO_TEXTURE_RECTANGLE_RGB_NV
#define WGL_BIND_TO_TEXTURE_RECTANGLE_RGB_NV 0x20A0
#endif

#endif
// GL_ARB_texture_env_dot3
#ifndef GL_DOT3_RGBA_ARB
#define GL_DOT3_RGBA_ARB 0x86AF
#endif

#ifndef GL_DOT3_RGB_ARB
#define GL_DOT3_RGB_ARB 0x86AE
#endif


// GL_EXT_bgra
#ifndef GL_BGR_EXT
#define GL_BGR_EXT 0x80E0
#endif

#ifndef GL_BGRA_EXT
#define GL_BGRA_EXT 0x80E1
#endif


// GL_NV_float_buffer
#ifndef GL_FLOAT_R16_NV
#define GL_FLOAT_R16_NV 0x8884
#endif

#ifndef GL_FLOAT_RGBA32_NV
#define GL_FLOAT_RGBA32_NV 0x888B
#endif

#ifndef GL_TEXTURE_FLOAT_COMPONENTS_NV
#define GL_TEXTURE_FLOAT_COMPONENTS_NV 0x888C
#endif

#ifndef GL_FLOAT_RG16_NV
#define GL_FLOAT_RG16_NV 0x8886
#endif

#ifndef GL_FLOAT_RGB_NV
#define GL_FLOAT_RGB_NV 0x8882
#endif

#ifndef GL_FLOAT_RG32_NV
#define GL_FLOAT_RG32_NV 0x8887
#endif

#ifndef GL_FLOAT_RGB32_NV
#define GL_FLOAT_RGB32_NV 0x8889
#endif

#ifndef GL_FLOAT_CLEAR_COLOR_VALUE_NV
#define GL_FLOAT_CLEAR_COLOR_VALUE_NV 0x888D
#endif

#ifndef GL_FLOAT_R_NV
#define GL_FLOAT_R_NV 0x8880
#endif

#ifndef GL_FLOAT_R32_NV
#define GL_FLOAT_R32_NV 0x8885
#endif

#ifndef GL_FLOAT_RGB16_NV
#define GL_FLOAT_RGB16_NV 0x8888
#endif

#ifndef GL_FLOAT_RGBA_NV
#define GL_FLOAT_RGBA_NV 0x8883
#endif

#ifndef GL_FLOAT_RGBA_MODE_NV
#define GL_FLOAT_RGBA_MODE_NV 0x888E
#endif

#ifndef GL_FLOAT_RG_NV
#define GL_FLOAT_RG_NV 0x8881
#endif

#ifndef GL_FLOAT_RGBA16_NV
#define GL_FLOAT_RGBA16_NV 0x888A
#endif


// GL_INGR_interlace_read
#ifndef GL_INTERLACE_READ_INGR
#define GL_INTERLACE_READ_INGR 0x8568
#endif


// GL_NV_texture_env_combine4
#ifndef GL_OPERAND3_ALPHA_NV
#define GL_OPERAND3_ALPHA_NV 0x859B
#endif

#ifndef GL_SOURCE3_RGB_NV
#define GL_SOURCE3_RGB_NV 0x8583
#endif

#ifndef GL_SOURCE3_ALPHA_NV
#define GL_SOURCE3_ALPHA_NV 0x858B
#endif

#ifndef GL_COMBINE4_NV
#define GL_COMBINE4_NV 0x8503
#endif

#ifndef GL_OPERAND3_RGB_NV
#define GL_OPERAND3_RGB_NV 0x8593
#endif


// GL_OML_interlace
#ifndef GL_INTERLACE_READ_OML
#define GL_INTERLACE_READ_OML 0x8981
#endif

#ifndef GL_INTERLACE_OML
#define GL_INTERLACE_OML 0x8980
#endif


#ifdef _GLX
// GLX_SGI_swap_control
typedef int (NIV_CALL_TYPE * nivenGLXSWAPINTERVALSGI) (int interval);
#endif // _GLX
// WGL_EXT_depth_float
#ifdef WIN32
#ifndef WGL_DEPTH_FLOAT_EXT
#define WGL_DEPTH_FLOAT_EXT 0x2040
#endif

#endif
// WGL_ARB_multisample
#ifdef WIN32
#ifndef WGL_SAMPLE_BUFFERS_ARB
#define WGL_SAMPLE_BUFFERS_ARB 0x2041
#endif

#ifndef WGL_SAMPLES_ARB
#define WGL_SAMPLES_ARB 0x2042
#endif

#endif
// GL_ATI_fragment_shader
#ifndef GL_CON_0_ATI
#define GL_CON_0_ATI 0x8941
#endif

#ifndef GL_SWIZZLE_STRQ_ATI
#define GL_SWIZZLE_STRQ_ATI 0x897A
#endif

#ifndef GL_NEGATE_BIT_ATI
#define GL_NEGATE_BIT_ATI 0x00000004
#endif

#ifndef GL_DOT3_ATI
#define GL_DOT3_ATI 0x8966
#endif

#ifndef GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI
#define GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI 0x8973
#endif

#ifndef GL_REG_2_ATI
#define GL_REG_2_ATI 0x8923
#endif

#ifndef GL_SWIZZLE_STR_ATI
#define GL_SWIZZLE_STR_ATI 0x8976
#endif

#ifndef GL_COLOR_ALPHA_PAIRING_ATI
#define GL_COLOR_ALPHA_PAIRING_ATI 0x8975
#endif

#ifndef GL_RED_BIT_ATI
#define GL_RED_BIT_ATI 0x00000001
#endif

#ifndef GL_4X_BIT_ATI
#define GL_4X_BIT_ATI 0x00000002
#endif

#ifndef GL_BIAS_BIT_ATI
#define GL_BIAS_BIT_ATI 0x00000008
#endif

#ifndef GL_HALF_BIT_ATI
#define GL_HALF_BIT_ATI 0x00000008
#endif

#ifndef GL_REG_0_ATI
#define GL_REG_0_ATI 0x8921
#endif

#ifndef GL_GREEN_BIT_ATI
#define GL_GREEN_BIT_ATI 0x00000002
#endif

#ifndef GL_DOT4_ATI
#define GL_DOT4_ATI 0x8967
#endif

#ifndef GL_2X_BIT_ATI
#define GL_2X_BIT_ATI 0x00000001
#endif

#ifndef GL_REG_1_ATI
#define GL_REG_1_ATI 0x8922
#endif

#ifndef GL_SWIZZLE_STQ_DQ_ATI
#define GL_SWIZZLE_STQ_DQ_ATI 0x8979
#endif

#ifndef GL_DOT2_ADD_ATI
#define GL_DOT2_ADD_ATI 0x896C
#endif

#ifndef GL_CON_4_ATI
#define GL_CON_4_ATI 0x8945
#endif

#ifndef GL_SUB_ATI
#define GL_SUB_ATI 0x8965
#endif

#ifndef GL_CON_2_ATI
#define GL_CON_2_ATI 0x8943
#endif

#ifndef GL_MUL_ATI
#define GL_MUL_ATI 0x8964
#endif

#ifndef GL_BLUE_BIT_ATI
#define GL_BLUE_BIT_ATI 0x00000004
#endif

#ifndef GL_NUM_PASSES_ATI
#define GL_NUM_PASSES_ATI 0x8970
#endif

#ifndef GL_CON_6_ATI
#define GL_CON_6_ATI 0x8947
#endif

#ifndef GL_COMP_BIT_ATI
#define GL_COMP_BIT_ATI 0x00000002
#endif

#ifndef GL_REG_5_ATI
#define GL_REG_5_ATI 0x8926
#endif

#ifndef GL_8X_BIT_ATI
#define GL_8X_BIT_ATI 0x00000004
#endif

#ifndef GL_CON_7_ATI
#define GL_CON_7_ATI 0x8948
#endif

#ifndef GL_SATURATE_BIT_ATI
#define GL_SATURATE_BIT_ATI 0x00000040
#endif

#ifndef GL_MAD_ATI
#define GL_MAD_ATI 0x8968
#endif

#ifndef GL_CND_ATI
#define GL_CND_ATI 0x896A
#endif

#ifndef GL_REG_3_ATI
#define GL_REG_3_ATI 0x8924
#endif

#ifndef GL_SWIZZLE_STRQ_DQ_ATI
#define GL_SWIZZLE_STRQ_DQ_ATI 0x897B
#endif

#ifndef GL_MOV_ATI
#define GL_MOV_ATI 0x8961
#endif

#ifndef GL_ADD_ATI
#define GL_ADD_ATI 0x8963
#endif

#ifndef GL_EIGHTH_BIT_ATI
#define GL_EIGHTH_BIT_ATI 0x00000020
#endif

#ifndef GL_NUM_FRAGMENT_CONSTANTS_ATI
#define GL_NUM_FRAGMENT_CONSTANTS_ATI 0x896F
#endif

#ifndef GL_CON_1_ATI
#define GL_CON_1_ATI 0x8942
#endif

#ifndef GL_NUM_FRAGMENT_REGISTERS_ATI
#define GL_NUM_FRAGMENT_REGISTERS_ATI 0x896E
#endif

#ifndef GL_CON_3_ATI
#define GL_CON_3_ATI 0x8944
#endif

#ifndef GL_LERP_ATI
#define GL_LERP_ATI 0x8969
#endif

#ifndef GL_SWIZZLE_STQ_ATI
#define GL_SWIZZLE_STQ_ATI 0x8977
#endif

#ifndef GL_NUM_INSTRUCTIONS_TOTAL_ATI
#define GL_NUM_INSTRUCTIONS_TOTAL_ATI 0x8972
#endif

#ifndef GL_REG_4_ATI
#define GL_REG_4_ATI 0x8925
#endif

#ifndef GL_SWIZZLE_STR_DR_ATI
#define GL_SWIZZLE_STR_DR_ATI 0x8978
#endif

#ifndef GL_QUARTER_BIT_ATI
#define GL_QUARTER_BIT_ATI 0x00000010
#endif

#ifndef GL_CON_5_ATI
#define GL_CON_5_ATI 0x8946
#endif

#ifndef GL_NUM_LOOPBACK_COMPONENTS_ATI
#define GL_NUM_LOOPBACK_COMPONENTS_ATI 0x8974
#endif

#ifndef GL_CND0_ATI
#define GL_CND0_ATI 0x896B
#endif

#ifndef GL_SECONDARY_INTERPOLATOR_ATI
#define GL_SECONDARY_INTERPOLATOR_ATI 0x896D
#endif

#ifndef GL_FRAGMENT_SHADER_ATI
#define GL_FRAGMENT_SHADER_ATI 0x8920
#endif

#ifndef GL_NUM_INSTRUCTIONS_PER_PASS_ATI
#define GL_NUM_INSTRUCTIONS_PER_PASS_ATI 0x8971
#endif

typedef void (NIV_CALL_TYPE * nivenGLBEGINFRAGMENTSHADERATI) (void );
typedef void (NIV_CALL_TYPE * nivenGLALPHAFRAGMENTOP3ATI) (GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod);
typedef void (NIV_CALL_TYPE * nivenGLCOLORFRAGMENTOP3ATI) (GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod);
typedef void (NIV_CALL_TYPE * nivenGLDELETEFRAGMENTSHADERATI) (GLuint id);
typedef void (NIV_CALL_TYPE * nivenGLSAMPLEMAPATI) (GLuint dst, GLuint interp, GLenum swizzle);
typedef GLuint (NIV_CALL_TYPE * nivenGLGENFRAGMENTSHADERSATI) (GLuint range);
typedef void (NIV_CALL_TYPE * nivenGLSETFRAGMENTSHADERCONSTANTATI) (GLuint dst, const GLfloat* value);
typedef void (NIV_CALL_TYPE * nivenGLCOLORFRAGMENTOP2ATI) (GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod);
typedef void (NIV_CALL_TYPE * nivenGLCOLORFRAGMENTOP1ATI) (GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod);
typedef void (NIV_CALL_TYPE * nivenGLALPHAFRAGMENTOP1ATI) (GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod);
typedef void (NIV_CALL_TYPE * nivenGLALPHAFRAGMENTOP2ATI) (GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod);
typedef void (NIV_CALL_TYPE * nivenGLBINDFRAGMENTSHADERATI) (GLuint id);
typedef void (NIV_CALL_TYPE * nivenGLENDFRAGMENTSHADERATI) (void );
typedef void (NIV_CALL_TYPE * nivenGLPASSTEXCOORDATI) (GLuint dst, GLuint coord, GLenum swizzle);

// GL_ARB_texture_env_combine
#ifndef GL_OPERAND2_ALPHA_ARB
#define GL_OPERAND2_ALPHA_ARB 0x859A
#endif

#ifndef GL_COMBINE_RGB_ARB
#define GL_COMBINE_RGB_ARB 0x8571
#endif

#ifndef GL_SOURCE2_ALPHA_ARB
#define GL_SOURCE2_ALPHA_ARB 0x858A
#endif

#ifndef GL_COMBINE_ARB
#define GL_COMBINE_ARB 0x8570
#endif

#ifndef GL_INTERPOLATE_ARB
#define GL_INTERPOLATE_ARB 0x8575
#endif

#ifndef GL_SOURCE0_ALPHA_ARB
#define GL_SOURCE0_ALPHA_ARB 0x8588
#endif

#ifndef GL_COMBINE_ALPHA_ARB
#define GL_COMBINE_ALPHA_ARB 0x8572
#endif

#ifndef GL_ADD_SIGNED_ARB
#define GL_ADD_SIGNED_ARB 0x8574
#endif

#ifndef GL_SOURCE2_RGB_ARB
#define GL_SOURCE2_RGB_ARB 0x8582
#endif

#ifndef GL_CONSTANT_ARB
#define GL_CONSTANT_ARB 0x8576
#endif

#ifndef GL_OPERAND1_ALPHA_ARB
#define GL_OPERAND1_ALPHA_ARB 0x8599
#endif

#ifndef GL_RGB_SCALE_ARB
#define GL_RGB_SCALE_ARB 0x8573
#endif

#ifndef GL_SOURCE1_ALPHA_ARB
#define GL_SOURCE1_ALPHA_ARB 0x8589
#endif

#ifndef GL_OPERAND2_RGB_ARB
#define GL_OPERAND2_RGB_ARB 0x8592
#endif

#ifndef GL_SOURCE0_RGB_ARB
#define GL_SOURCE0_RGB_ARB 0x8580
#endif

#ifndef GL_PREVIOUS_ARB
#define GL_PREVIOUS_ARB 0x8578
#endif

#ifndef GL_OPERAND1_RGB_ARB
#define GL_OPERAND1_RGB_ARB 0x8591
#endif

#ifndef GL_PRIMARY_COLOR_ARB
#define GL_PRIMARY_COLOR_ARB 0x8577
#endif

#ifndef GL_OPERAND0_ALPHA_ARB
#define GL_OPERAND0_ALPHA_ARB 0x8598
#endif

#ifndef GL_SOURCE1_RGB_ARB
#define GL_SOURCE1_RGB_ARB 0x8581
#endif

#ifndef GL_SUBTRACT_ARB
#define GL_SUBTRACT_ARB 0x84E7
#endif

#ifndef GL_OPERAND0_RGB_ARB
#define GL_OPERAND0_RGB_ARB 0x8590
#endif


// GL_ARB_vertex_buffer_object
#ifndef GL_STATIC_COPY_ARB
#define GL_STATIC_COPY_ARB 0x88E6
#endif

#ifndef GL_BUFFER_MAP_POINTER_ARB
#define GL_BUFFER_MAP_POINTER_ARB 0x88BD
#endif

#ifndef GL_NORMAL_ARRAY_BUFFER_BINDING_ARB
#define GL_NORMAL_ARRAY_BUFFER_BINDING_ARB 0x8897
#endif

#ifndef GL_DYNAMIC_READ_ARB
#define GL_DYNAMIC_READ_ARB 0x88E9
#endif

#ifndef GL_DYNAMIC_DRAW_ARB
#define GL_DYNAMIC_DRAW_ARB 0x88E8
#endif

#ifndef GL_ELEMENT_ARRAY_BUFFER_ARB
#define GL_ELEMENT_ARRAY_BUFFER_ARB 0x8893
#endif

#ifndef GL_BUFFER_MAPPED_ARB
#define GL_BUFFER_MAPPED_ARB 0x88BC
#endif

#ifndef GL_READ_ONLY_ARB
#define GL_READ_ONLY_ARB 0x88B8
#endif

#ifndef GL_READ_WRITE_ARB
#define GL_READ_WRITE_ARB 0x88BA
#endif

#ifndef GL_STREAM_DRAW_ARB
#define GL_STREAM_DRAW_ARB 0x88E0
#endif

#ifndef GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB
#define GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB 0x889A
#endif

#ifndef GL_ARRAY_BUFFER_ARB
#define GL_ARRAY_BUFFER_ARB 0x8892
#endif

#ifndef GL_BUFFER_USAGE_ARB
#define GL_BUFFER_USAGE_ARB 0x8765
#endif

#ifndef GL_STATIC_DRAW_ARB
#define GL_STATIC_DRAW_ARB 0x88E4
#endif

#ifndef GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB
#define GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB 0x889C
#endif

#ifndef GL_BUFFER_SIZE_ARB
#define GL_BUFFER_SIZE_ARB 0x8764
#endif

#ifndef GL_VERTEX_ARRAY_BUFFER_BINDING_ARB
#define GL_VERTEX_ARRAY_BUFFER_BINDING_ARB 0x8896
#endif

#ifndef GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB
#define GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB 0x889E
#endif

#ifndef GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB
#define GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB 0x889D
#endif

#ifndef GL_STREAM_COPY_ARB
#define GL_STREAM_COPY_ARB 0x88E2
#endif

#ifndef GL_BUFFER_ACCESS_ARB
#define GL_BUFFER_ACCESS_ARB 0x88BB
#endif

#ifndef GL_ARRAY_BUFFER_BINDING_ARB
#define GL_ARRAY_BUFFER_BINDING_ARB 0x8894
#endif

#ifndef GL_DYNAMIC_COPY_ARB
#define GL_DYNAMIC_COPY_ARB 0x88EA
#endif

#ifndef GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB
#define GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB 0x889B
#endif

#ifndef GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB
#define GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB 0x8895
#endif

#ifndef GL_WRITE_ONLY_ARB
#define GL_WRITE_ONLY_ARB 0x88B9
#endif

#ifndef GL_STATIC_READ_ARB
#define GL_STATIC_READ_ARB 0x88E5
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB
#define GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB 0x889F
#endif

#ifndef GL_INDEX_ARRAY_BUFFER_BINDING_ARB
#define GL_INDEX_ARRAY_BUFFER_BINDING_ARB 0x8899
#endif

#ifndef GL_STREAM_READ_ARB
#define GL_STREAM_READ_ARB 0x88E1
#endif

#ifndef GL_COLOR_ARRAY_BUFFER_BINDING_ARB
#define GL_COLOR_ARRAY_BUFFER_BINDING_ARB 0x8898
#endif

#ifndef TYPE_GLINTPTRARB_DEFINED
typedef ptrdiff_t GLintptrARB;
#endif
#ifndef TYPE_GLSIZEIPTRARB_DEFINED
typedef ptrdiff_t GLsizeiptrARB;
#endif
typedef void (NIV_CALL_TYPE * nivenGLGENBUFFERSARB) (GLsizei n, GLuint* buffers);
typedef void (NIV_CALL_TYPE * nivenGLBUFFERSUBDATAARB) (GLenum target, GLintptrARB offset, GLsizeiptrARB size, const GLvoid* data);
typedef void (NIV_CALL_TYPE * nivenGLDELETEBUFFERSARB) (GLsizei n, const GLuint* buffers);
typedef GLboolean (NIV_CALL_TYPE * nivenGLUNMAPBUFFERARB) (GLenum target);
typedef void (NIV_CALL_TYPE * nivenGLBINDBUFFERARB) (GLenum target, GLuint buffer);
typedef void (NIV_CALL_TYPE * nivenGLGETBUFFERPARAMETERIVARB) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETBUFFERPOINTERVARB) (GLenum target, GLenum pname, GLvoid* *params);
typedef void (NIV_CALL_TYPE * nivenGLGETBUFFERSUBDATAARB) (GLenum target, GLintptrARB offset, GLsizeiptrARB size, GLvoid* data);
typedef GLvoid * (NIV_CALL_TYPE * nivenGLMAPBUFFERARB) (GLenum target, GLenum access);
typedef void (NIV_CALL_TYPE * nivenGLBUFFERDATAARB) (GLenum target, GLsizeiptrARB size, const GLvoid* data, GLenum usage);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISBUFFERARB) (GLuint buffer);

// GL_SUN_triangle_list
#ifndef GL_REPLACE_OLDEST_SUN
#define GL_REPLACE_OLDEST_SUN 0x03
#endif

#ifndef GL_REPLACEMENT_CODE_SUN
#define GL_REPLACEMENT_CODE_SUN 0x81D8
#endif

#ifndef GL_R1UI_C4UB_V3F_SUN
#define GL_R1UI_C4UB_V3F_SUN 0x85C5
#endif

#ifndef GL_R1UI_C4F_N3F_V3F_SUN
#define GL_R1UI_C4F_N3F_V3F_SUN 0x85C8
#endif

#ifndef GL_R1UI_T2F_C4F_N3F_V3F_SUN
#define GL_R1UI_T2F_C4F_N3F_V3F_SUN 0x85CB
#endif

#ifndef GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN
#define GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN 0x85C1
#endif

#ifndef GL_RESTART_SUN
#define GL_RESTART_SUN 0x01
#endif

#ifndef GL_TRIANGLE_LIST_SUN
#define GL_TRIANGLE_LIST_SUN 0x81D7
#endif

#ifndef GL_R1UI_N3F_V3F_SUN
#define GL_R1UI_N3F_V3F_SUN 0x85C7
#endif

#ifndef GL_REPLACEMENT_CODE_ARRAY_SUN
#define GL_REPLACEMENT_CODE_ARRAY_SUN 0x85C0
#endif

#ifndef GL_R1UI_V3F_SUN
#define GL_R1UI_V3F_SUN 0x85C4
#endif

#ifndef GL_R1UI_C3F_V3F_SUN
#define GL_R1UI_C3F_V3F_SUN 0x85C6
#endif

#ifndef GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN
#define GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN 0x85C2
#endif

#ifndef GL_REPLACE_MIDDLE_SUN
#define GL_REPLACE_MIDDLE_SUN 0x02
#endif

#ifndef GL_R1UI_T2F_V3F_SUN
#define GL_R1UI_T2F_V3F_SUN 0x85C9
#endif

#ifndef GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN
#define GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN 0x85C3
#endif

#ifndef GL_R1UI_T2F_N3F_V3F_SUN
#define GL_R1UI_T2F_N3F_V3F_SUN 0x85CA
#endif

typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUBVSUN) (const GLubyte* code);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUISUN) (GLuint code);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUIVSUN) (const GLuint* code);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEPOINTERSUN) (GLenum type, GLsizei stride, const void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUSVSUN) (const GLushort* code);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUSSUN) (GLushort code);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUBSUN) (GLubyte code);

// WGL_EXT_swap_control
#ifdef WIN32
typedef int (NIV_CALL_TYPE * nivenWGLGETSWAPINTERVALEXT) (void );
typedef BOOL (NIV_CALL_TYPE * nivenWGLSWAPINTERVALEXT) (int interval);
#endif
#ifdef _GLX
// GLX_EXT_scene_marker
#endif // _GLX
// GL_ATI_text_fragment_shader
#ifndef GL_TEXT_FRAGMENT_SHADER_ATI
#define GL_TEXT_FRAGMENT_SHADER_ATI 0x8200
#endif


// GL_EXT_histogram
#ifndef GL_HISTOGRAM_BLUE_SIZE_EXT
#define GL_HISTOGRAM_BLUE_SIZE_EXT 0x802A
#endif

#ifndef GL_HISTOGRAM_EXT
#define GL_HISTOGRAM_EXT 0x8024
#endif

#ifndef GL_MINMAX_FORMAT_EXT
#define GL_MINMAX_FORMAT_EXT 0x802F
#endif

#ifndef GL_HISTOGRAM_WIDTH_EXT
#define GL_HISTOGRAM_WIDTH_EXT 0x8026
#endif

#ifndef GL_HISTOGRAM_GREEN_SIZE_EXT
#define GL_HISTOGRAM_GREEN_SIZE_EXT 0x8029
#endif

#ifndef GL_MINMAX_EXT
#define GL_MINMAX_EXT 0x802E
#endif

#ifndef GL_HISTOGRAM_LUMINANCE_SIZE_EXT
#define GL_HISTOGRAM_LUMINANCE_SIZE_EXT 0x802C
#endif

#ifndef GL_MINMAX_SINK_EXT
#define GL_MINMAX_SINK_EXT 0x8030
#endif

#ifndef GL_HISTOGRAM_FORMAT_EXT
#define GL_HISTOGRAM_FORMAT_EXT 0x8027
#endif

#ifndef GL_PROXY_HISTOGRAM_EXT
#define GL_PROXY_HISTOGRAM_EXT 0x8025
#endif

#ifndef GL_HISTOGRAM_ALPHA_SIZE_EXT
#define GL_HISTOGRAM_ALPHA_SIZE_EXT 0x802B
#endif

#ifndef GL_HISTOGRAM_RED_SIZE_EXT
#define GL_HISTOGRAM_RED_SIZE_EXT 0x8028
#endif

#ifndef GL_HISTOGRAM_SINK_EXT
#define GL_HISTOGRAM_SINK_EXT 0x802D
#endif

typedef void (NIV_CALL_TYPE * nivenGLGETMINMAXPARAMETERFVEXT) (GLenum target, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLMINMAXEXT) (GLenum target, GLenum internalformat, GLboolean sink);
typedef void (NIV_CALL_TYPE * nivenGLGETHISTOGRAMPARAMETERIVEXT) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETMINMAXPARAMETERIVEXT) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLRESETHISTOGRAMEXT) (GLenum target);
typedef void (NIV_CALL_TYPE * nivenGLRESETMINMAXEXT) (GLenum target);
typedef void (NIV_CALL_TYPE * nivenGLGETMINMAXEXT) (GLenum target, GLboolean reset, GLenum format, GLenum type, void* values);
typedef void (NIV_CALL_TYPE * nivenGLGETHISTOGRAMEXT) (GLenum target, GLboolean reset, GLenum format, GLenum type, void* values);
typedef void (NIV_CALL_TYPE * nivenGLHISTOGRAMEXT) (GLenum target, GLsizei width, GLenum internalformat, GLboolean sink);
typedef void (NIV_CALL_TYPE * nivenGLGETHISTOGRAMPARAMETERFVEXT) (GLenum target, GLenum pname, GLfloat* params);

// GL_NV_vertex_program3
#ifndef MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB
#define MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB 0x8B4C
#endif


// GL_NV_vertex_array_range
#ifndef GL_VERTEX_ARRAY_RANGE_NV
#define GL_VERTEX_ARRAY_RANGE_NV 0x851D
#endif

#ifndef GL_VERTEX_ARRAY_RANGE_VALID_NV
#define GL_VERTEX_ARRAY_RANGE_VALID_NV 0x851F
#endif

#ifndef GL_VERTEX_ARRAY_RANGE_POINTER_NV
#define GL_VERTEX_ARRAY_RANGE_POINTER_NV 0x8521
#endif

#ifndef GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV
#define GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV 0x8520
#endif

#ifndef GL_VERTEX_ARRAY_RANGE_LENGTH_NV
#define GL_VERTEX_ARRAY_RANGE_LENGTH_NV 0x851E
#endif

typedef void (NIV_CALL_TYPE * nivenGLFLUSHVERTEXARRAYRANGENV) (void );
typedef void (NIV_CALL_TYPE * nivenGLVERTEXARRAYRANGENV) (GLsizei length, void* pointer);

// GL_HP_texture_lighting

// WGL_EXT_display_color_table
#ifdef WIN32
typedef void (NIV_CALL_TYPE * nivenWGLDESTROYDISPLAYCOLORTABLEEXT) (GLushort id);
typedef GLboolean (NIV_CALL_TYPE * nivenWGLCREATEDISPLAYCOLORTABLEEXT) (GLushort id);
typedef GLboolean (NIV_CALL_TYPE * nivenWGLBINDDISPLAYCOLORTABLEEXT) (GLushort id);
typedef GLboolean (NIV_CALL_TYPE * nivenWGLLOADDISPLAYCOLORTABLEEXT) (GLushort* table, GLuint length);
#endif
// GL_NV_texture_expand_normal
#ifndef GL_TEXTURE_UNSIGNED_REMAP_MODE_NV
#define GL_TEXTURE_UNSIGNED_REMAP_MODE_NV 0x888F
#endif


// GL_EXT_separate_specular_color
#ifndef GL_LIGHT_MODEL_COLOR_CONTROL_EXT
#define GL_LIGHT_MODEL_COLOR_CONTROL_EXT 0x81F8
#endif

#ifndef GL_SEPARATE_SPECULAR_COLOR_EXT
#define GL_SEPARATE_SPECULAR_COLOR_EXT 0x81FA
#endif

#ifndef GL_SINGLE_COLOR_EXT
#define GL_SINGLE_COLOR_EXT 0x81F9
#endif


// GL_EXT_paletted_texture
#ifndef GL_COLOR_TABLE_GREEN_SIZE_EXT
#define GL_COLOR_TABLE_GREEN_SIZE_EXT 0x80DB
#endif

#ifndef GL_PROXY_TEXTURE_2D
#define GL_PROXY_TEXTURE_2D 0x8064
#endif

#ifndef GL_COLOR_INDEX4_EXT
#define GL_COLOR_INDEX4_EXT 0x80E4
#endif

#ifndef GL_COLOR_TABLE_WIDTH_EXT
#define GL_COLOR_TABLE_WIDTH_EXT 0x80D9
#endif

#ifndef GL_COLOR_INDEX16_EXT
#define GL_COLOR_INDEX16_EXT 0x80E7
#endif

#ifndef GL_COLOR_INDEX1_EXT
#define GL_COLOR_INDEX1_EXT 0x80E2
#endif

#ifndef GL_COLOR_TABLE_RED_SIZE_EXT
#define GL_COLOR_TABLE_RED_SIZE_EXT 0x80DA
#endif

#ifndef GL_PROXY_TEXTURE_3D_EXT
#define GL_PROXY_TEXTURE_3D_EXT 0x8070
#endif

#ifndef GL_COLOR_TABLE_FORMAT_EXT
#define GL_COLOR_TABLE_FORMAT_EXT 0x80D8
#endif

#ifndef GL_COLOR_TABLE_ALPHA_SIZE_EXT
#define GL_COLOR_TABLE_ALPHA_SIZE_EXT 0x80DD
#endif

#ifndef GL_TEXTURE_3D_EXT
#define GL_TEXTURE_3D_EXT 0x806F
#endif

#ifndef GL_COLOR_INDEX2_EXT
#define GL_COLOR_INDEX2_EXT 0x80E3
#endif

#ifndef GL_TEXTURE_1D
#define GL_TEXTURE_1D 0x0DE0
#endif

#ifndef GL_COLOR_TABLE_INTENSITY_SIZE_EXT
#define GL_COLOR_TABLE_INTENSITY_SIZE_EXT 0x80DF
#endif

#ifndef GL_COLOR_TABLE_BLUE_SIZE_EXT
#define GL_COLOR_TABLE_BLUE_SIZE_EXT 0x80DC
#endif

#ifndef GL_TEXTURE_2D
#define GL_TEXTURE_2D 0x0DE1
#endif

#ifndef GL_COLOR_TABLE_LUMINANCE_SIZE_EXT
#define GL_COLOR_TABLE_LUMINANCE_SIZE_EXT 0x80DE
#endif

#ifndef GL_PROXY_TEXTURE_1D
#define GL_PROXY_TEXTURE_1D 0x8063
#endif

#ifndef GL_TEXTURE_INDEX_SIZE_EXT
#define GL_TEXTURE_INDEX_SIZE_EXT 0x80ED
#endif

#ifndef GL_COLOR_INDEX12_EXT
#define GL_COLOR_INDEX12_EXT 0x80E6
#endif

#ifndef GL_COLOR_INDEX8_EXT
#define GL_COLOR_INDEX8_EXT 0x80E5
#endif

typedef void (NIV_CALL_TYPE * nivenGLCOLORTABLEEXT) (GLenum target, GLenum internalFormat, GLsizei width, GLenum format, GLenum type, const void* data);
typedef void (NIV_CALL_TYPE * nivenGLGETCOLORTABLEPARAMETERFVEXT) (GLenum target, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETCOLORTABLEPARAMETERIVEXT) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETCOLORTABLEEXT) (GLenum target, GLenum format, GLenum type, void* data);

// GL_ATI_texture_float
#ifndef GL_INTENSITY_FLOAT16_ATI
#define GL_INTENSITY_FLOAT16_ATI 0x881D
#endif

#ifndef GL_RGB_FLOAT32_ATI
#define GL_RGB_FLOAT32_ATI 0x8815
#endif

#ifndef GL_ALPHA_FLOAT16_ATI
#define GL_ALPHA_FLOAT16_ATI 0x881C
#endif

#ifndef GL_ALPHA_FLOAT32_ATI
#define GL_ALPHA_FLOAT32_ATI 0x8816
#endif

#ifndef GL_LUMINANCE_ALPHA_FLOAT32_ATI
#define GL_LUMINANCE_ALPHA_FLOAT32_ATI 0x8819
#endif

#ifndef GL_RGBA_FLOAT16_ATI
#define GL_RGBA_FLOAT16_ATI 0x881A
#endif

#ifndef GL_LUMINANCE_FLOAT32_ATI
#define GL_LUMINANCE_FLOAT32_ATI 0x8818
#endif

#ifndef GL_RGB_FLOAT16_ATI
#define GL_RGB_FLOAT16_ATI 0x881B
#endif

#ifndef GL_LUMINANCE_FLOAT16_ATI
#define GL_LUMINANCE_FLOAT16_ATI 0x881E
#endif

#ifndef GL_INTENSITY_FLOAT32_ATI
#define GL_INTENSITY_FLOAT32_ATI 0x8817
#endif

#ifndef GL_LUMINANCE_ALPHA_FLOAT16_ATI
#define GL_LUMINANCE_ALPHA_FLOAT16_ATI 0x881F
#endif

#ifndef GL_RGBA_FLOAT32_ATI
#define GL_RGBA_FLOAT32_ATI 0x8814
#endif


// GL_EXT_texture_env_add

// GL_EXT_texture_mirror_clamp
#ifndef GL_MIRROR_CLAMP_TO_BORDER_EXT
#define GL_MIRROR_CLAMP_TO_BORDER_EXT 0x8912
#endif

#ifndef GL_MIRROR_CLAMP_EXT
#define GL_MIRROR_CLAMP_EXT 0x8742
#endif

#ifndef GL_MIRROR_CLAMP_TO_EDGE_EXT
#define GL_MIRROR_CLAMP_TO_EDGE_EXT 0x8743
#endif


// GL_ATI_pn_triangles
#ifndef GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI
#define GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI 0x87F8
#endif

#ifndef GL_PN_TRIANGLES_POINT_MODE_ATI
#define GL_PN_TRIANGLES_POINT_MODE_ATI 0x87F2
#endif

#ifndef GL_PN_TRIANGLES_ATI
#define GL_PN_TRIANGLES_ATI 0x87F0
#endif

#ifndef GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI
#define GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI 0x87F6
#endif

#ifndef GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI
#define GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI 0x87F4
#endif

#ifndef GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI
#define GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI 0x87F1
#endif

#ifndef GL_PN_TRIANGLES_NORMAL_MODE_ATI
#define GL_PN_TRIANGLES_NORMAL_MODE_ATI 0x87F3
#endif

#ifndef GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI
#define GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI 0x87F5
#endif

#ifndef GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI
#define GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI 0x87F7
#endif

typedef void (NIV_CALL_TYPE * nivenGLPNTRIANGLESFATI) (GLenum pname, GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLPNTRIANGLESIATI) (GLenum pname, GLint param);

// GL_NV_texture_rectangle
#ifndef GL_TEXTURE_RECTANGLE_NV
#define GL_TEXTURE_RECTANGLE_NV 0x84F5
#endif

#ifndef GL_MAX_RECTANGLE_TEXTURE_SIZE_NV
#define GL_MAX_RECTANGLE_TEXTURE_SIZE_NV 0x84F8
#endif

#ifndef GL_PROXY_TEXTURE_RECTANGLE_NV
#define GL_PROXY_TEXTURE_RECTANGLE_NV 0x84F7
#endif

#ifndef GL_TEXTURE_BINDING_RECTANGLE_NV
#define GL_TEXTURE_BINDING_RECTANGLE_NV 0x84F6
#endif


// WGL_OML_sync_control
#ifdef WIN32
typedef BOOL (NIV_CALL_TYPE * nivenWGLGETSYNCVALUESOML) (HDC hdc, INT64* ust, INT64* msc, INT64* sbc);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGETMSCRATEOML) (HDC hdc, INT32* numerator, INT32* denominator);
typedef INT64 (NIV_CALL_TYPE * nivenWGLSWAPBUFFERSMSCOML) (HDC hdc, INT64 target_msc, INT64 divisor, INT64 remainder);
typedef INT64 (NIV_CALL_TYPE * nivenWGLSWAPLAYERBUFFERSMSCOML) (HDC hdc, INT fuPlanes, INT64 target_msc, INT64 divisor, INT64 remainder);
typedef BOOL (NIV_CALL_TYPE * nivenWGLWAITFORSBCOML) (HDC hdc, INT64 target_sbc, INT64* ust, INT64* msc, INT64* sbc);
typedef BOOL (NIV_CALL_TYPE * nivenWGLWAITFORMSCOML) (HDC hdc, INT64 target_msc, INT64 divisor, INT64 remainder, INT64* ust, INT64* msc, INT64* sbc);
#endif
// GL_NV_multisample_filter_hint
#ifndef GL_MULTISAMPLE_FILTER_HINT_NV
#define GL_MULTISAMPLE_FILTER_HINT_NV 0x8534
#endif


// GL_APPLE_float_pixels
#ifndef GL_LUMINANCE_ALPHA_FLOAT16_APPLE
#define GL_LUMINANCE_ALPHA_FLOAT16_APPLE 0x881F
#endif

#ifndef GL_ALPHA_FLOAT32_APPLE
#define GL_ALPHA_FLOAT32_APPLE 0x8816
#endif

#ifndef GL_RGB_FLOAT32_APPLE
#define GL_RGB_FLOAT32_APPLE 0x8815
#endif

#ifndef GL_LUMINANCE_ALPHA_FLOAT32_APPLE
#define GL_LUMINANCE_ALPHA_FLOAT32_APPLE 0x8819
#endif

#ifndef GL_LUMINANCE_FLOAT16_APPLE
#define GL_LUMINANCE_FLOAT16_APPLE 0x881E
#endif

#ifndef GL_INTENSITY_FLOAT32_APPLE
#define GL_INTENSITY_FLOAT32_APPLE 0x8817
#endif

#ifndef GL_RGBA_FLOAT32_APPLE
#define GL_RGBA_FLOAT32_APPLE 0x8814
#endif

#ifndef GL_RGBA_FLOAT16_APPLE
#define GL_RGBA_FLOAT16_APPLE 0x881A
#endif

#ifndef GL_HALF_APPLE
#define GL_HALF_APPLE 0x140B
#endif

#ifndef GL_ALPHA_FLOAT16_APPLE
#define GL_ALPHA_FLOAT16_APPLE 0x881C
#endif

#ifndef GL_COLOR_FLOAT_APPLE
#define GL_COLOR_FLOAT_APPLE 0x8A0F
#endif

#ifndef GL_LUMINANCE_FLOAT32_APPLE
#define GL_LUMINANCE_FLOAT32_APPLE 0x8818
#endif

#ifndef GL_RGB_FLOAT16_APPLE
#define GL_RGB_FLOAT16_APPLE 0x881B
#endif

#ifndef GL_INTENSITY_FLOAT16_APPLE
#define GL_INTENSITY_FLOAT16_APPLE 0x881D
#endif


// GL_SGIS_texture_border_clamp
#ifndef GL_CLAMP_TO_BORDER_SGIS
#define GL_CLAMP_TO_BORDER_SGIS 0x812D
#endif


// GL_ATI_vertex_attrib_array_object
typedef void (NIV_CALL_TYPE * nivenGLGETVERTEXATTRIBARRAYOBJECTIVATI) (GLuint index, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETVERTEXATTRIBARRAYOBJECTFVATI) (GLuint index, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBARRAYOBJECTATI) (GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLuint buffer, GLuint offset);

// GL_SGIX_clipmap

// GL_HP_image_transform
typedef void (NIV_CALL_TYPE * nivenGLIMAGETRANSFORMPARAMETERFHP) (GLenum target, GLenum pname, const GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLGETIMAGETRANSFORMPARAMETERIVHP) (GLenum target, GLenum pname, const GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLIMAGETRANSFORMPARAMETERIVHP) (GLenum target, GLenum pname, const GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETIMAGETRANSFORMPARAMETERFVHP) (GLenum target, GLenum pname, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLIMAGETRANSFORMPARAMETERFVHP) (GLenum target, GLenum pname, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLIMAGETRANSFORMPARAMETERIHP) (GLenum target, GLenum pname, const GLint param);

// GL_SGIX_flush_raster
typedef void (NIV_CALL_TYPE * nivenGLFLUSHRASTERSGIX) (void );

// GL_EXT_light_texture
#ifndef GL_FRAGMENT_MATERIAL_EXT
#define GL_FRAGMENT_MATERIAL_EXT 0x8349
#endif

#ifndef GL_SHADOW_ATTENUATION_EXT
#define GL_SHADOW_ATTENUATION_EXT 0x834E
#endif

#ifndef GL_ATTENUATION_EXT
#define GL_ATTENUATION_EXT 0x834D
#endif

#ifndef GL_TEXTURE_MATERIAL_FACE_EXT
#define GL_TEXTURE_MATERIAL_FACE_EXT 0x8351
#endif

#ifndef GL_FRAGMENT_NORMAL_EXT
#define GL_FRAGMENT_NORMAL_EXT 0x834A
#endif

#ifndef GL_FRAGMENT_COLOR_EXT
#define GL_FRAGMENT_COLOR_EXT 0x834C
#endif

#ifndef GL_TEXTURE_MATERIAL_PARAMETER_EXT
#define GL_TEXTURE_MATERIAL_PARAMETER_EXT 0x8352
#endif

#ifndef GL_TEXTURE_APPLICATION_MODE_EXT
#define GL_TEXTURE_APPLICATION_MODE_EXT 0x834F
#endif

#ifndef GL_TEXTURE_LIGHT_EXT
#define GL_TEXTURE_LIGHT_EXT 0x8350
#endif

typedef void (NIV_CALL_TYPE * nivenGLTEXTUREMATERIALEXT) (GLenum face, GLenum mode);
typedef void (NIV_CALL_TYPE * nivenGLAPPLYTEXTUREEXT) (GLenum mode);
typedef void (NIV_CALL_TYPE * nivenGLTEXTURELIGHTEXT) (GLenum pname);

// GL_ARB_point_sprite
#ifndef GL_POINT_SPRITE_ARB
#define GL_POINT_SPRITE_ARB 0x8861
#endif

#ifndef GL_COORD_REPLACE_ARB
#define GL_COORD_REPLACE_ARB 0x8862
#endif


// GL_MESA_ycbcr_texture
#ifndef GL_UNSIGNED_SHORT_8_8_MESA
#define GL_UNSIGNED_SHORT_8_8_MESA 0x85BA
#endif

#ifndef GL_YCBCR_MESA
#define GL_YCBCR_MESA 0x8757
#endif

#ifndef GL_UNSIGNED_SHORT_8_8_REV_MESA
#define GL_UNSIGNED_SHORT_8_8_REV_MESA 0x85BB
#endif


// GL_ARB_shading_language_100
#ifndef GL_SHADING_LANGUAGE_VERSION_ARB
#define GL_SHADING_LANGUAGE_VERSION_ARB 0x8B8C
#endif


// GL_SGIS_texture_select

// GL_NV_vertex_program2

#ifdef _GLX
// GLX_SGI_make_current_read
typedef GLXDrawable (NIV_CALL_TYPE * nivenGLXGETCURRENTREADDRAWABLESGI) (void );
typedef Bool (NIV_CALL_TYPE * nivenGLXMAKECURRENTREADSGI) (Display* dpy, GLXDrawable draw, GLXDrawable read, GLXContext ctx);
#endif // _GLX
// GL_ARB_half_float_pixel
#ifndef GL_HALF_FLOAT_ARB
#define GL_HALF_FLOAT_ARB 0x140B
#endif


// GL_KTX_buffer_region
#ifndef GL_KTX_BACK_REGION
#define GL_KTX_BACK_REGION 0x1
#endif

#ifndef GL_KTX_Z_REGION
#define GL_KTX_Z_REGION 0x2
#endif

#ifndef GL_KTX_STENCIL_REGION
#define GL_KTX_STENCIL_REGION 0x3
#endif

#ifndef GL_KTX_FRONT_REGION
#define GL_KTX_FRONT_REGION 0x0
#endif

typedef void (NIV_CALL_TYPE * nivenGLDELETEBUFFERREGIONEXT) (GLenum region);
typedef void (NIV_CALL_TYPE * nivenGLREADBUFFERREGIONEXT) (GLuint region, GLint x, GLint y, GLsizei width, GLsizei height);
typedef GLuint (NIV_CALL_TYPE * nivenGLBUFFERREGIONENABLEDEXT) (void );
typedef GLuint (NIV_CALL_TYPE * nivenGLNEWBUFFERREGIONEXT) (GLenum region);
typedef void (NIV_CALL_TYPE * nivenGLDRAWBUFFERREGIONEXT) (GLuint region, GLint x, GLint y, GLsizei width, GLsizei height, GLint xDest, GLint yDest);

// GL_EXT_vertex_weighting
#ifndef GL_VERTEX_WEIGHTING_EXT
#define GL_VERTEX_WEIGHTING_EXT 0x8509
#endif

#ifndef GL_MODELVIEW1_EXT
#define GL_MODELVIEW1_EXT 0x850A
#endif

#ifndef GL_VERTEX_WEIGHT_ARRAY_EXT
#define GL_VERTEX_WEIGHT_ARRAY_EXT 0x850C
#endif

#ifndef GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT
#define GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT 0x850F
#endif

#ifndef GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT
#define GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT 0x850D
#endif

#ifndef GL_MODELVIEW1_MATRIX_EXT
#define GL_MODELVIEW1_MATRIX_EXT 0x8506
#endif

#ifndef GL_MODELVIEW0_STACK_DEPTH_EXT
#define GL_MODELVIEW0_STACK_DEPTH_EXT 0x0BA3
#endif

#ifndef GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT
#define GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT 0x8510
#endif

#ifndef GL_MODELVIEW0_EXT
#define GL_MODELVIEW0_EXT 0x1700
#endif

#ifndef GL_CURRENT_VERTEX_WEIGHT_EXT
#define GL_CURRENT_VERTEX_WEIGHT_EXT 0x850B
#endif

#ifndef GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT
#define GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT 0x850E
#endif

#ifndef GL_MODELVIEW1_STACK_DEPTH_EXT
#define GL_MODELVIEW1_STACK_DEPTH_EXT 0x8502
#endif

#ifndef GL_MODELVIEW0_MATRIX_EXT
#define GL_MODELVIEW0_MATRIX_EXT 0x0BA6
#endif

typedef void (NIV_CALL_TYPE * nivenGLVERTEXWEIGHTFVEXT) (GLfloat* weight);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXWEIGHTFEXT) (GLfloat weight);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXWEIGHTPOINTEREXT) (GLint size, GLenum type, GLsizei stride, void* pointer);

// GL_ATIX_point_sprites
#ifndef GL_POINT_SPRITE_CULL_CENTER_ATIX
#define GL_POINT_SPRITE_CULL_CENTER_ATIX 0x60b4
#endif

#ifndef GL_POINT_SPRITE_CULL_CLIP_ATIX
#define GL_POINT_SPRITE_CULL_CLIP_ATIX 0x60b5
#endif

#ifndef GL_POINT_SPRITE_CULL_MODE_ATIX
#define GL_POINT_SPRITE_CULL_MODE_ATIX 0x60b3
#endif

#ifndef GL_TEXTURE_POINT_ONE_COORD_ATIX
#define GL_TEXTURE_POINT_ONE_COORD_ATIX 0x60b1
#endif

#ifndef GL_TEXTURE_POINT_MODE_ATIX
#define GL_TEXTURE_POINT_MODE_ATIX 0x60b0
#endif

#ifndef GL_TEXTURE_POINT_SPRITE_ATIX
#define GL_TEXTURE_POINT_SPRITE_ATIX 0x60b2
#endif


// GL_APPLE_vertex_array_range
#ifndef GL_VERTEX_ARRAY_RANGE_APPLE
#define GL_VERTEX_ARRAY_RANGE_APPLE 0x851D
#endif

#ifndef GL_VERTEX_ARRAY_STORAGE_HINT_APPLE
#define GL_VERTEX_ARRAY_STORAGE_HINT_APPLE 0x851F
#endif

#ifndef GL_VERTEX_ARRAY_RANGE_POINTER_APPLE
#define GL_VERTEX_ARRAY_RANGE_POINTER_APPLE 0x8521
#endif

#ifndef GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_APPLE
#define GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_APPLE 0x8520
#endif

#ifndef GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE
#define GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE 0x851E
#endif

typedef void (NIV_CALL_TYPE * nivenGLVERTEXARRAYRANGEAPPLE) (GLsizei length, void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLFLUSHVERTEXARRAYRANGEAPPLE) (GLsizei length, void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXARRAYPARAMETERIAPPLE) (GLenum pname, GLint param);

#ifdef _GLX
// GLX_NV_float_buffer
#ifndef GLX_FLOAT_COMPONENTS_NV
#define GLX_FLOAT_COMPONENTS_NV 0x20B0
#endif

#endif // _GLX
// GL_SGIS_detail_texture
typedef void (NIV_CALL_TYPE * nivenGLDETAILTEXFUNCSGIS) (GLenum target, GLsizei n, const GLfloat* points);
typedef void (NIV_CALL_TYPE * nivenGLGETDETAILTEXFUNCSGIS) (GLenum target, GLfloat* points);

// GL_SGIX_sprite
typedef void (NIV_CALL_TYPE * nivenGLSPRITEPARAMETERFSGIX) (GLenum pname, GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLSPRITEPARAMETERISGIX) (GLenum pname, GLint param);
typedef void (NIV_CALL_TYPE * nivenGLSPRITEPARAMETERIVSGIX) (GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLSPRITEPARAMETERFVSGIX) (GLenum pname, GLfloat* params);

// GL_NV_register_combiners
#ifndef GL_COLOR_SUM_CLAMP_NV
#define GL_COLOR_SUM_CLAMP_NV 0x854F
#endif

#ifndef GL_COMBINER_MUX_SUM_NV
#define GL_COMBINER_MUX_SUM_NV 0x8547
#endif

#ifndef GL_VARIABLE_F_NV
#define GL_VARIABLE_F_NV 0x8528
#endif

#ifndef GL_EXPAND_NEGATE_NV
#define GL_EXPAND_NEGATE_NV 0x8539
#endif

#ifndef GL_EXPAND_NORMAL_NV
#define GL_EXPAND_NORMAL_NV 0x8538
#endif

#ifndef GL_SCALE_BY_ONE_HALF_NV
#define GL_SCALE_BY_ONE_HALF_NV 0x8540
#endif

#ifndef GL_VARIABLE_G_NV
#define GL_VARIABLE_G_NV 0x8529
#endif

#ifndef GL_UNSIGNED_IDENTITY_NV
#define GL_UNSIGNED_IDENTITY_NV 0x8536
#endif

#ifndef GL_COMBINER_CD_DOT_PRODUCT_NV
#define GL_COMBINER_CD_DOT_PRODUCT_NV 0x8546
#endif

#ifndef GL_COMBINER_MAPPING_NV
#define GL_COMBINER_MAPPING_NV 0x8543
#endif

#ifndef GL_COMBINER1_NV
#define GL_COMBINER1_NV 0x8551
#endif

#ifndef GL_VARIABLE_C_NV
#define GL_VARIABLE_C_NV 0x8525
#endif

#ifndef GL_UNSIGNED_INVERT_NV
#define GL_UNSIGNED_INVERT_NV 0x8537
#endif

#ifndef GL_SCALE_BY_FOUR_NV
#define GL_SCALE_BY_FOUR_NV 0x853F
#endif

#ifndef GL_COMBINER_COMPONENT_USAGE_NV
#define GL_COMBINER_COMPONENT_USAGE_NV 0x8544
#endif

#ifndef GL_COMBINER3_NV
#define GL_COMBINER3_NV 0x8553
#endif

#ifndef GL_COMBINER_SCALE_NV
#define GL_COMBINER_SCALE_NV 0x8548
#endif

#ifndef GL_COMBINER0_NV
#define GL_COMBINER0_NV 0x8550
#endif

#ifndef GL_MAX_GENERAL_COMBINERS_NV
#define GL_MAX_GENERAL_COMBINERS_NV 0x854D
#endif

#ifndef GL_VARIABLE_B_NV
#define GL_VARIABLE_B_NV 0x8524
#endif

#ifndef GL_COMBINER7_NV
#define GL_COMBINER7_NV 0x8557
#endif

#ifndef GL_HALF_BIAS_NEGATE_NV
#define GL_HALF_BIAS_NEGATE_NV 0x853B
#endif

#ifndef GL_SECONDARY_COLOR_NV
#define GL_SECONDARY_COLOR_NV 0x852D
#endif

#ifndef GL_SPARE0_NV
#define GL_SPARE0_NV 0x852E
#endif

#ifndef GL_COMBINER6_NV
#define GL_COMBINER6_NV 0x8556
#endif

#ifndef GL_SCALE_BY_TWO_NV
#define GL_SCALE_BY_TWO_NV 0x853E
#endif

#ifndef GL_REGISTER_COMBINERS_NV
#define GL_REGISTER_COMBINERS_NV 0x8522
#endif

#ifndef GL_COMBINER_INPUT_NV
#define GL_COMBINER_INPUT_NV 0x8542
#endif

#ifndef GL_COMBINER_BIAS_NV
#define GL_COMBINER_BIAS_NV 0x8549
#endif

#ifndef GL_CONSTANT_COLOR1_NV
#define GL_CONSTANT_COLOR1_NV 0x852B
#endif

#ifndef GL_SPARE1_NV
#define GL_SPARE1_NV 0x852F
#endif

#ifndef GL_COMBINER_AB_DOT_PRODUCT_NV
#define GL_COMBINER_AB_DOT_PRODUCT_NV 0x8545
#endif

#ifndef GL_VARIABLE_D_NV
#define GL_VARIABLE_D_NV 0x8526
#endif

#ifndef GL_VARIABLE_A_NV
#define GL_VARIABLE_A_NV 0x8523
#endif

#ifndef GL_COMBINER_SUM_OUTPUT_NV
#define GL_COMBINER_SUM_OUTPUT_NV 0x854C
#endif

#ifndef GL_CONSTANT_COLOR0_NV
#define GL_CONSTANT_COLOR0_NV 0x852A
#endif

#ifndef GL_SIGNED_IDENTITY_NV
#define GL_SIGNED_IDENTITY_NV 0x853C
#endif

#ifndef GL_COMBINER4_NV
#define GL_COMBINER4_NV 0x8554
#endif

#ifndef GL_DISCARD_NV
#define GL_DISCARD_NV 0x8530
#endif

#ifndef GL_COMBINER2_NV
#define GL_COMBINER2_NV 0x8552
#endif

#ifndef GL_HALF_BIAS_NORMAL_NV
#define GL_HALF_BIAS_NORMAL_NV 0x853A
#endif

#ifndef GL_NUM_GENERAL_COMBINERS_NV
#define GL_NUM_GENERAL_COMBINERS_NV 0x854E
#endif

#ifndef GL_E_TIMES_F_NV
#define GL_E_TIMES_F_NV 0x8531
#endif

#ifndef GL_PRIMARY_COLOR_NV
#define GL_PRIMARY_COLOR_NV 0x852C
#endif

#ifndef GL_VARIABLE_E_NV
#define GL_VARIABLE_E_NV 0x8527
#endif

#ifndef GL_BIAS_BY_NEGATIVE_ONE_HALF_NV
#define GL_BIAS_BY_NEGATIVE_ONE_HALF_NV 0x8541
#endif

#ifndef GL_COMBINER5_NV
#define GL_COMBINER5_NV 0x8555
#endif

#ifndef GL_COMBINER_CD_OUTPUT_NV
#define GL_COMBINER_CD_OUTPUT_NV 0x854B
#endif

#ifndef GL_SPARE0_PLUS_SECONDARY_COLOR_NV
#define GL_SPARE0_PLUS_SECONDARY_COLOR_NV 0x8532
#endif

#ifndef GL_SIGNED_NEGATE_NV
#define GL_SIGNED_NEGATE_NV 0x853D
#endif

#ifndef GL_COMBINER_AB_OUTPUT_NV
#define GL_COMBINER_AB_OUTPUT_NV 0x854A
#endif

typedef void (NIV_CALL_TYPE * nivenGLCOMBINERPARAMETERFVNV) (GLenum pname, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLCOMBINERPARAMETERIVNV) (GLenum pname, const GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETFINALCOMBINERINPUTPARAMETERIVNV) (GLenum variable, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLCOMBINERPARAMETERINV) (GLenum pname, GLint param);
typedef void (NIV_CALL_TYPE * nivenGLCOMBINERINPUTNV) (GLenum stage, GLenum portion, GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage);
typedef void (NIV_CALL_TYPE * nivenGLCOMBINEROUTPUTNV) (GLenum stage, GLenum portion, GLenum abOutput, GLenum cdOutput, GLenum sumOutput, GLenum scale, GLenum bias, GLboolean abDotProduct, GLboolean cdDotProduct, GLboolean muxSum);
typedef void (NIV_CALL_TYPE * nivenGLGETCOMBINEROUTPUTPARAMETERFVNV) (GLenum stage, GLenum portion, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLCOMBINERPARAMETERFNV) (GLenum pname, GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLFINALCOMBINERINPUTNV) (GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage);
typedef void (NIV_CALL_TYPE * nivenGLGETFINALCOMBINERINPUTPARAMETERFVNV) (GLenum variable, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETCOMBINERINPUTPARAMETERFVNV) (GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETCOMBINERINPUTPARAMETERIVNV) (GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETCOMBINEROUTPUTPARAMETERIVNV) (GLenum stage, GLenum portion, GLenum pname, GLint* params);

// GL_ARB_draw_buffers
#ifndef GL_DRAW_BUFFER14_ARB
#define GL_DRAW_BUFFER14_ARB 0x8833
#endif

#ifndef GL_DRAW_BUFFER9_ARB
#define GL_DRAW_BUFFER9_ARB 0x882E
#endif

#ifndef GL_MAX_DRAW_BUFFERS_ARB
#define GL_MAX_DRAW_BUFFERS_ARB 0x8824
#endif

#ifndef GL_DRAW_BUFFER7_ARB
#define GL_DRAW_BUFFER7_ARB 0x882C
#endif

#ifndef GL_DRAW_BUFFER4_ARB
#define GL_DRAW_BUFFER4_ARB 0x8829
#endif

#ifndef GL_DRAW_BUFFER3_ARB
#define GL_DRAW_BUFFER3_ARB 0x8828
#endif

#ifndef GL_DRAW_BUFFER0_ARB
#define GL_DRAW_BUFFER0_ARB 0x8825
#endif

#ifndef GL_DRAW_BUFFER15_ARB
#define GL_DRAW_BUFFER15_ARB 0x8834
#endif

#ifndef GL_DRAW_BUFFER12_ARB
#define GL_DRAW_BUFFER12_ARB 0x8831
#endif

#ifndef GL_DRAW_BUFFER6_ARB
#define GL_DRAW_BUFFER6_ARB 0x882B
#endif

#ifndef GL_DRAW_BUFFER8_ARB
#define GL_DRAW_BUFFER8_ARB 0x882D
#endif

#ifndef GL_DRAW_BUFFER5_ARB
#define GL_DRAW_BUFFER5_ARB 0x882A
#endif

#ifndef GL_DRAW_BUFFER2_ARB
#define GL_DRAW_BUFFER2_ARB 0x8827
#endif

#ifndef GL_DRAW_BUFFER1_ARB
#define GL_DRAW_BUFFER1_ARB 0x8826
#endif

#ifndef GL_DRAW_BUFFER10_ARB
#define GL_DRAW_BUFFER10_ARB 0x882F
#endif

#ifndef GL_DRAW_BUFFER11_ARB
#define GL_DRAW_BUFFER11_ARB 0x8830
#endif

#ifndef GL_DRAW_BUFFER13_ARB
#define GL_DRAW_BUFFER13_ARB 0x8832
#endif

typedef void (NIV_CALL_TYPE * nivenGLDRAWBUFFERSARB) (GLsizei n, const GLenum* bufs);

// GL_ARB_fragment_program_shadow

// WGL_EXT_make_current_read
#ifdef WIN32
typedef HDC (NIV_CALL_TYPE * nivenWGLGETCURRENTREADDCEXT) (VOID );
typedef BOOL (NIV_CALL_TYPE * nivenWGLMAKECONTEXTCURRENTEXT) (HDC hDrawDC, HDC hReadDC, HGLRC hglrc);
#endif
// GL_EXT_shared_texture_palette
#ifndef GL_SHARED_TEXTURE_PALETTE_EXT
#define GL_SHARED_TEXTURE_PALETTE_EXT 0x81FB
#endif


// GL_ATI_element_array
#ifndef GL_ELEMENT_ARRAY_POINTER_ATI
#define GL_ELEMENT_ARRAY_POINTER_ATI 0x876A
#endif

#ifndef GL_ELEMENT_ARRAY_TYPE_ATI
#define GL_ELEMENT_ARRAY_TYPE_ATI 0x8769
#endif

#ifndef GL_ELEMENT_ARRAY_ATI
#define GL_ELEMENT_ARRAY_ATI 0x8768
#endif

typedef void (NIV_CALL_TYPE * nivenGLDRAWELEMENTARRAYATI) (GLenum mode, GLsizei count);
typedef void (NIV_CALL_TYPE * nivenGLELEMENTPOINTERATI) (GLenum type, const void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLDRAWRANGEELEMENTARRAYATI) (GLenum mode, GLuint start, GLuint end, GLsizei count);

#ifdef _GLX
// GLX_ARB_get_proc_address
#endif // _GLX
// GL_OML_resample
#ifndef GL_RESAMPLE_AVERAGE_OML
#define GL_RESAMPLE_AVERAGE_OML 0x8988
#endif

#ifndef GL_RESAMPLE_DECIMATE_OML
#define GL_RESAMPLE_DECIMATE_OML 0x8989
#endif

#ifndef GL_PACK_RESAMPLE_OML
#define GL_PACK_RESAMPLE_OML 0x8984
#endif

#ifndef GL_RESAMPLE_REPLICATE_OML
#define GL_RESAMPLE_REPLICATE_OML 0x8986
#endif

#ifndef GL_RESAMPLE_ZERO_FILL_OML
#define GL_RESAMPLE_ZERO_FILL_OML 0x8987
#endif

#ifndef GL_UNPACK_RESAMPLE_OML
#define GL_UNPACK_RESAMPLE_OML 0x8985
#endif


// GL_EXT_coordinate_frame
#ifndef GL_BINORMAL_ARRAY_EXT
#define GL_BINORMAL_ARRAY_EXT 0x843A
#endif

#ifndef GL_CURRENT_TANGENT_EXT
#define GL_CURRENT_TANGENT_EXT 0x843B
#endif

#ifndef GL_BINORMAL_ARRAY_TYPE_EXT
#define GL_BINORMAL_ARRAY_TYPE_EXT 0x8440
#endif

#ifndef GL_TANGENT_ARRAY_POINTER_EXT
#define GL_TANGENT_ARRAY_POINTER_EXT 0x8442
#endif

#ifndef GL_BINORMAL_ARRAY_STRIDE_EXT
#define GL_BINORMAL_ARRAY_STRIDE_EXT 0x8441
#endif

#ifndef GL_MAP1_BINORMAL_EXT
#define GL_MAP1_BINORMAL_EXT 0x8446
#endif

#ifndef GL_MAP2_BINORMAL_EXT
#define GL_MAP2_BINORMAL_EXT 0x8447
#endif

#ifndef GL_BINORMAL_ARRAY_POINTER_EXT
#define GL_BINORMAL_ARRAY_POINTER_EXT 0x8443
#endif

#ifndef GL_TANGENT_ARRAY_STRIDE_EXT
#define GL_TANGENT_ARRAY_STRIDE_EXT 0x843F
#endif

#ifndef GL_TANGENT_ARRAY_TYPE_EXT
#define GL_TANGENT_ARRAY_TYPE_EXT 0x843E
#endif

#ifndef GL_MAP1_TANGENT_EXT
#define GL_MAP1_TANGENT_EXT 0x8444
#endif

#ifndef GL_MAP2_TANGENT_EXT
#define GL_MAP2_TANGENT_EXT 0x8445
#endif

#ifndef GL_CURRENT_BINORMAL_EXT
#define GL_CURRENT_BINORMAL_EXT 0x843C
#endif

#ifndef GL_TANGENT_ARRAY_EXT
#define GL_TANGENT_ARRAY_EXT 0x8439
#endif

typedef void (NIV_CALL_TYPE * nivenGLTANGENTPOINTEREXT) (GLenum type, GLsizei stride, void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLBINORMALPOINTEREXT) (GLenum type, GLsizei stride, void* pointer);

// GL_ATI_texture_mirror_once
#ifndef GL_MIRROR_CLAMP_TO_EDGE_ATI
#define GL_MIRROR_CLAMP_TO_EDGE_ATI 0x8743
#endif

#ifndef GL_MIRROR_CLAMP_ATI
#define GL_MIRROR_CLAMP_ATI 0x8742
#endif


// WGL_ARB_pbuffer
#ifdef WIN32
#ifndef WGL_MAX_PBUFFER_HEIGHT_ARB
#define WGL_MAX_PBUFFER_HEIGHT_ARB 0x2030
#endif

#ifndef WGL_MAX_PBUFFER_WIDTH_ARB
#define WGL_MAX_PBUFFER_WIDTH_ARB 0x202F
#endif

#ifndef WGL_PBUFFER_WIDTH_ARB
#define WGL_PBUFFER_WIDTH_ARB 0x2034
#endif

#ifndef WGL_PBUFFER_HEIGHT_ARB
#define WGL_PBUFFER_HEIGHT_ARB 0x2035
#endif

#ifndef WGL_MAX_PBUFFER_PIXELS_ARB
#define WGL_MAX_PBUFFER_PIXELS_ARB 0x202E
#endif

#ifndef WGL_DRAW_TO_PBUFFER_ARB
#define WGL_DRAW_TO_PBUFFER_ARB 0x202D
#endif

#ifndef WGL_PBUFFER_LOST_ARB
#define WGL_PBUFFER_LOST_ARB 0x2036
#endif

#ifndef WGL_PBUFFER_LARGEST_ARB
#define WGL_PBUFFER_LARGEST_ARB 0x2033
#endif

typedef int (NIV_CALL_TYPE * nivenWGLRELEASEPBUFFERDCARB) (HPBUFFERARB hPbuffer, HDC hDC);
typedef HPBUFFERARB (NIV_CALL_TYPE * nivenWGLCREATEPBUFFERARB) (HDC hDC, int iPixelFormat, int iWidth, int iHeight, const int* piAttribList);
typedef BOOL (NIV_CALL_TYPE * nivenWGLQUERYPBUFFERARB) (HPBUFFERARB hPbuffer, int iAttribute, int* piValue);
typedef HDC (NIV_CALL_TYPE * nivenWGLGETPBUFFERDCARB) (HPBUFFERARB hPbuffer);
typedef BOOL (NIV_CALL_TYPE * nivenWGLDESTROYPBUFFERARB) (HPBUFFERARB hPbuffer);
#endif
// GL_EXT_cull_vertex
typedef void (NIV_CALL_TYPE * nivenGLCULLPARAMETERDVEXT) (GLenum pname, GLdouble* params);
typedef void (NIV_CALL_TYPE * nivenGLCULLPARAMETERFVEXT) (GLenum pname, GLfloat* params);

// GL_IBM_rasterpos_clip
#ifndef GL_RASTER_POSITION_UNCLIPPED_IBM
#define GL_RASTER_POSITION_UNCLIPPED_IBM 103010
#endif


// GL_SGIX_reference_plane
typedef void (NIV_CALL_TYPE * nivenGLREFERENCEPLANESGIX) (const GLdouble* equation);

// GL_APPLE_texture_range
#ifndef GL_STORAGE_CACHED_APPLE
#define GL_STORAGE_CACHED_APPLE 0x85BE
#endif

#ifndef GL_TEXTURE_STORAGE_HINT_APPLE
#define GL_TEXTURE_STORAGE_HINT_APPLE 0x85BC
#endif

#ifndef GL_TEXTURE_RANGE_LENGTH_APPLE
#define GL_TEXTURE_RANGE_LENGTH_APPLE 0x85B7
#endif

#ifndef GL_STORAGE_SHARED_APPLE
#define GL_STORAGE_SHARED_APPLE 0x85BF
#endif

#ifndef GL_STORAGE_PRIVATE_APPLE
#define GL_STORAGE_PRIVATE_APPLE 0x85BD
#endif

#ifndef GL_TEXTURE_RANGE_POINTER_APPLE
#define GL_TEXTURE_RANGE_POINTER_APPLE 0x85B8
#endif

typedef void (NIV_CALL_TYPE * nivenGLTEXTURERANGEAPPLE) (GLenum target, GLsizei length, GLvoid* pointer);
typedef void (NIV_CALL_TYPE * nivenGLGETTEXPARAMETERPOINTERVAPPLE) (GLenum target, GLenum pname, GLvoid* *params);

// GL_SGIX_shadow
#ifndef GL_TEXTURE_COMPARE_OPERATOR_SGIX
#define GL_TEXTURE_COMPARE_OPERATOR_SGIX 0x819B
#endif

#ifndef GL_TEXTURE_GEQUAL_R_SGIX
#define GL_TEXTURE_GEQUAL_R_SGIX 0x819D
#endif

#ifndef GL_TEXTURE_COMPARE_SGIX
#define GL_TEXTURE_COMPARE_SGIX 0x819A
#endif

#ifndef GL_TEXTURE_LEQUAL_R_SGIX
#define GL_TEXTURE_LEQUAL_R_SGIX 0x819C
#endif


// GL_SGIX_texture_lod_bias

#ifdef _GLX
// GLX_SGIX_pbuffer
#ifndef GLX_HEIGHT_SGIX
#define GLX_HEIGHT_SGIX 0x801E
#endif

#ifndef GLX_MAX_PBUFFER_HEIGHT_SGIX
#define GLX_MAX_PBUFFER_HEIGHT_SGIX 0x8017
#endif

#ifndef GLX_MAX_PBUFFER_PIXELS_SGIX
#define GLX_MAX_PBUFFER_PIXELS_SGIX 0x8018
#endif

#ifndef GLX_LARGEST_PBUFFER_SGIX
#define GLX_LARGEST_PBUFFER_SGIX 0x801C
#endif

#ifndef GLX_PBUFFER_BIT_SGIX
#define GLX_PBUFFER_BIT_SGIX 0x00000004
#endif

#ifndef GLX_BACK_LEFT_BUFFER_BIT_SGIX
#define GLX_BACK_LEFT_BUFFER_BIT_SGIX 0x00000004
#endif

#ifndef GLX_PRESERVED_CONTENTS_SGIX
#define GLX_PRESERVED_CONTENTS_SGIX 0x801B
#endif

#ifndef GLX_EVENT_MASK_SGIX
#define GLX_EVENT_MASK_SGIX 0x801F
#endif

#ifndef GLX_ACCUM_BUFFER_BIT_SGIX
#define GLX_ACCUM_BUFFER_BIT_SGIX 0x00000080
#endif

#ifndef GLX_OPTIMAL_PBUFFER_WIDTH_SGIX
#define GLX_OPTIMAL_PBUFFER_WIDTH_SGIX 0x8019
#endif

#ifndef GLX_FRONT_LEFT_BUFFER_BIT_SGIX
#define GLX_FRONT_LEFT_BUFFER_BIT_SGIX 0x00000001
#endif

#ifndef GLX_DAMAGED_SGIX
#define GLX_DAMAGED_SGIX 0x8020
#endif

#ifndef GLX_STENCIL_BUFFER_BIT_SGIX
#define GLX_STENCIL_BUFFER_BIT_SGIX 0x00000040
#endif

#ifndef GLX_BACK_RIGHT_BUFFER_BIT_SGIX
#define GLX_BACK_RIGHT_BUFFER_BIT_SGIX 0x00000008
#endif

#ifndef GLX_FRONT_RIGHT_BUFFER_BIT_SGIX
#define GLX_FRONT_RIGHT_BUFFER_BIT_SGIX 0x00000002
#endif

#ifndef GLX_SAVED_SGIX
#define GLX_SAVED_SGIX 0x8021
#endif

#ifndef GLX_WINDOW_SGIX
#define GLX_WINDOW_SGIX 0x8022
#endif

#ifndef GLX_MAX_PBUFFER_WIDTH_SGIX
#define GLX_MAX_PBUFFER_WIDTH_SGIX 0x8016
#endif

#ifndef GLX_PBUFFER_SGIX
#define GLX_PBUFFER_SGIX 0x8023
#endif

#ifndef GLX_OPTIMAL_PBUFFER_HEIGHT_SGIX
#define GLX_OPTIMAL_PBUFFER_HEIGHT_SGIX 0x801A
#endif

#ifndef GLX_SAMPLE_BUFFERS_BIT_SGIX
#define GLX_SAMPLE_BUFFERS_BIT_SGIX 0x00000100
#endif

#ifndef GLX_BUFFER_CLOBBER_MASK_SGIX
#define GLX_BUFFER_CLOBBER_MASK_SGIX 0x08000000
#endif

#ifndef GLX_DEPTH_BUFFER_BIT_SGIX
#define GLX_DEPTH_BUFFER_BIT_SGIX 0x00000020
#endif

#ifndef GLX_WIDTH_SGIX
#define GLX_WIDTH_SGIX 0x801D
#endif

#ifndef GLX_AUX_BUFFERS_BIT_SGIX
#define GLX_AUX_BUFFERS_BIT_SGIX 0x00000010
#endif

#ifndef TYPE_GLXPBUFFERSGIX_DEFINED
typedef XID GLXPbufferSGIX;
#endif
#ifndef TYPE_GLXBUFFERCLOBBEREVENTSGIX_DEFINED
typedef struct { int type; unsigned long serial; Bool send_event; Display *display; GLXDrawable drawable; int event_type; int draw_type; unsigned int mask; int x, y; int width, height; int count; } GLXBufferClobberEventSGIX;
#endif
typedef GLXPbuffer (NIV_CALL_TYPE * nivenGLXCREATEGLXPBUFFERSGIX) (Display* dpy, GLXFBConfig config, unsigned int width, unsigned int height, int* attrib_list);
typedef void (NIV_CALL_TYPE * nivenGLXGETSELECTEDEVENTSGIX) (Display* dpy, GLXDrawable drawable, unsigned long* mask);
typedef void (NIV_CALL_TYPE * nivenGLXDESTROYGLXPBUFFERSGIX) (Display* dpy, GLXPbuffer pbuf);
typedef void (NIV_CALL_TYPE * nivenGLXSELECTEVENTSGIX) (Display* dpy, GLXDrawable drawable, unsigned long mask);
typedef void (NIV_CALL_TYPE * nivenGLXQUERYGLXPBUFFERSGIX) (Display* dpy, GLXPbuffer pbuf, int attribute, unsigned int* value);
#endif // _GLX
// GL_NV_texgen_reflection
#ifndef GL_NORMAL_MAP_NV
#define GL_NORMAL_MAP_NV 0x8511
#endif

#ifndef GL_REFLECTION_MAP_NV
#define GL_REFLECTION_MAP_NV 0x8512
#endif


// GL_SUN_slice_accum
#ifndef GL_SLICE_ACCUM_SUN
#define GL_SLICE_ACCUM_SUN 0x85CC
#endif


// GL_IBM_multimode_draw_arrays
typedef void (NIV_CALL_TYPE * nivenGLMULTIMODEDRAWELEMENTSIBM) (const GLenum* mode, const GLsizei* count, GLenum type, const GLvoid* const *indices, GLsizei primcount, GLint modestride);
typedef void (NIV_CALL_TYPE * nivenGLMULTIMODEDRAWARRAYSIBM) (const GLenum* mode, const GLint* first, const GLsizei* count, GLsizei primcount, GLint modestride);

// GL_IBM_static_data
#ifndef GL_STATIC_VERTEX_ARRAY_IBM
#define GL_STATIC_VERTEX_ARRAY_IBM 103061
#endif

#ifndef GL_ALL_STATIC_DATA_IBM
#define GL_ALL_STATIC_DATA_IBM 103060
#endif


#ifdef _GLX
// GLX_EXT_visual_info
#ifndef GLX_STATIC_COLOR_EXT
#define GLX_STATIC_COLOR_EXT 0x8005
#endif

#ifndef GLX_PSEUDO_COLOR_EXT
#define GLX_PSEUDO_COLOR_EXT 0x8004
#endif

#ifndef GLX_TRUE_COLOR_EXT
#define GLX_TRUE_COLOR_EXT 0x8002
#endif

#ifndef GLX_TRANSPARENT_RGB_EXT
#define GLX_TRANSPARENT_RGB_EXT 0x8008
#endif

#ifndef GLX_TRANSPARENT_INDEX_EXT
#define GLX_TRANSPARENT_INDEX_EXT 0x8009
#endif

#ifndef GLX_X_VISUAL_TYPE_EXT
#define GLX_X_VISUAL_TYPE_EXT 0x22
#endif

#ifndef GLX_TRANSPARENT_TYPE_EXT
#define GLX_TRANSPARENT_TYPE_EXT 0x23
#endif

#ifndef GLX_NONE_EXT
#define GLX_NONE_EXT 0x8000
#endif

#ifndef GLX_TRANSPARENT_GREEN_VALUE_EXT
#define GLX_TRANSPARENT_GREEN_VALUE_EXT 0x26
#endif

#ifndef GLX_TRANSPARENT_ALPHA_VALUE_EXT
#define GLX_TRANSPARENT_ALPHA_VALUE_EXT 0x28
#endif

#ifndef GLX_TRANSPARENT_RED_VALUE_EXT
#define GLX_TRANSPARENT_RED_VALUE_EXT 0x25
#endif

#ifndef GLX_GRAY_SCALE_EXT
#define GLX_GRAY_SCALE_EXT 0x8006
#endif

#ifndef GLX_DIRECT_COLOR_EXT
#define GLX_DIRECT_COLOR_EXT 0x8003
#endif

#ifndef GLX_TRANSPARENT_BLUE_VALUE_EXT
#define GLX_TRANSPARENT_BLUE_VALUE_EXT 0x27
#endif

#ifndef GLX_TRANSPARENT_INDEX_VALUE_EXT
#define GLX_TRANSPARENT_INDEX_VALUE_EXT 0x24
#endif

#ifndef GLX_STATIC_GRAY_EXT
#define GLX_STATIC_GRAY_EXT 0x8007
#endif

#endif // _GLX
// GL_EXT_clip_volume_hint
#ifndef GL_CLIP_VOLUME_CLIPPING_HINT_EXT
#define GL_CLIP_VOLUME_CLIPPING_HINT_EXT 0x80F0
#endif


// GL_EXT_cmyka
#ifndef GL_CMYKA_EXT
#define GL_CMYKA_EXT 0x800D
#endif

#ifndef GL_PACK_CMYK_HINT_EXT
#define GL_PACK_CMYK_HINT_EXT 0x800E
#endif

#ifndef GL_UNPACK_CMYK_HINT_EXT
#define GL_UNPACK_CMYK_HINT_EXT 0x800F
#endif

#ifndef GL_CMYK_EXT
#define GL_CMYK_EXT 0x800C
#endif


// GL_EXT_compiled_vertex_array
typedef void (NIV_CALL_TYPE * nivenGLLOCKARRAYSEXT) (GLint first, GLsizei count);
typedef void (NIV_CALL_TYPE * nivenGLUNLOCKARRAYSEXT) (void );

// GL_3DFX_tbuffer
typedef void (NIV_CALL_TYPE * nivenGLTBUFFERMASK3DFX) (GLuint mask);

// GL_EXT_point_parameters
#ifndef GL_POINT_SIZE_MAX_EXT
#define GL_POINT_SIZE_MAX_EXT 0x8127
#endif

#ifndef GL_POINT_FADE_THRESHOLD_SIZE_EXT
#define GL_POINT_FADE_THRESHOLD_SIZE_EXT 0x8128
#endif

#ifndef GL_POINT_SIZE_MIN_EXT
#define GL_POINT_SIZE_MIN_EXT 0x8126
#endif

#ifndef GL_DISTANCE_ATTENUATION_EXT
#define GL_DISTANCE_ATTENUATION_EXT 0x8129
#endif

typedef void (NIV_CALL_TYPE * nivenGLPOINTPARAMETERFEXT) (GLenum pname, GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLPOINTPARAMETERFVEXT) (GLenum pname, GLfloat* params);

// GL_APPLE_vertex_array_object
#ifndef GL_VERTEX_ARRAY_BINDING_APPLE
#define GL_VERTEX_ARRAY_BINDING_APPLE 0x85B5
#endif

typedef void (NIV_CALL_TYPE * nivenGLGENVERTEXARRAYSAPPLE) (GLsizei n, const GLuint* arrays);
typedef void (NIV_CALL_TYPE * nivenGLBINDVERTEXARRAYAPPLE) (GLuint array);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISVERTEXARRAYAPPLE) (GLuint array);
typedef void (NIV_CALL_TYPE * nivenGLDELETEVERTEXARRAYSAPPLE) (GLsizei n, const GLuint* arrays);

// GL_3DFX_texture_compression_FXT1
#ifndef GL_COMPRESSED_RGB_FXT1_3DFX
#define GL_COMPRESSED_RGB_FXT1_3DFX 0x86B0
#endif

#ifndef GL_COMPRESSED_RGBA_FXT1_3DFX
#define GL_COMPRESSED_RGBA_FXT1_3DFX 0x86B1
#endif


// GL_NV_occlusion_query
#ifndef GL_CURRENT_OCCLUSION_QUERY_ID_NV
#define GL_CURRENT_OCCLUSION_QUERY_ID_NV 0x8865
#endif

#ifndef GL_PIXEL_COUNT_AVAILABLE_NV
#define GL_PIXEL_COUNT_AVAILABLE_NV 0x8867
#endif

#ifndef GL_PIXEL_COUNT_NV
#define GL_PIXEL_COUNT_NV 0x8866
#endif

#ifndef GL_PIXEL_COUNTER_BITS_NV
#define GL_PIXEL_COUNTER_BITS_NV 0x8864
#endif

typedef void (NIV_CALL_TYPE * nivenGLENDOCCLUSIONQUERYNV) (void );
typedef void (NIV_CALL_TYPE * nivenGLDELETEOCCLUSIONQUERIESNV) (GLsizei n, const GLuint* ids);
typedef void (NIV_CALL_TYPE * nivenGLGETOCCLUSIONQUERYUIVNV) (GLuint id, GLenum pname, GLuint* params);
typedef void (NIV_CALL_TYPE * nivenGLGENOCCLUSIONQUERIESNV) (GLsizei n, GLuint* ids);
typedef void (NIV_CALL_TYPE * nivenGLGETOCCLUSIONQUERYIVNV) (GLuint id, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLBEGINOCCLUSIONQUERYNV) (GLuint id);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISOCCLUSIONQUERYNV) (GLuint id);

#ifdef _GLX
// GLX_OML_sync_control
typedef Bool (NIV_CALL_TYPE * nivenGLXGETSYNCVALUESOML) (Display* dpy, GLXDrawable drawable, int64_t* ust, int64_t* msc, int64_t* sbc);
typedef Bool (NIV_CALL_TYPE * nivenGLXGETMSCRATEOML) (Display* dpy, GLXDrawable drawable, int32_t* numerator, int32_t* denominator);
typedef Bool (NIV_CALL_TYPE * nivenGLXWAITFORSBCOML) (Display* dpy, GLXDrawable drawable, int64_t target_sbc, int64_t* ust, int64_t* msc, int64_t* sbc);
typedef Bool (NIV_CALL_TYPE * nivenGLXWAITFORMSCOML) (Display* dpy, GLXDrawable drawable, int64_t target_msc, int64_t divisor, int64_t remainder, int64_t* ust, int64_t* msc, int64_t* sbc);
typedef int64_t (NIV_CALL_TYPE * nivenGLXSWAPBUFFERSMSCOML) (Display* dpy, GLXDrawable drawable, int64_t target_msc, int64_t divisor, int64_t remainder);
#endif // _GLX
// WGL_ARB_render_texture
#ifdef WIN32
#ifndef WGL_TEXTURE_FORMAT_ARB
#define WGL_TEXTURE_FORMAT_ARB 0x2072
#endif

#ifndef WGL_AUX3_ARB
#define WGL_AUX3_ARB 0x208A
#endif

#ifndef WGL_BIND_TO_TEXTURE_RGBA_ARB
#define WGL_BIND_TO_TEXTURE_RGBA_ARB 0x2071
#endif

#ifndef WGL_BACK_LEFT_ARB
#define WGL_BACK_LEFT_ARB 0x2085
#endif

#ifndef WGL_MIPMAP_LEVEL_ARB
#define WGL_MIPMAP_LEVEL_ARB 0x207B
#endif

#ifndef WGL_AUX2_ARB
#define WGL_AUX2_ARB 0x2089
#endif

#ifndef WGL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB
#define WGL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB 0x2081
#endif

#ifndef WGL_AUX4_ARB
#define WGL_AUX4_ARB 0x208B
#endif

#ifndef WGL_AUX6_ARB
#define WGL_AUX6_ARB 0x208D
#endif

#ifndef WGL_TEXTURE_CUBE_MAP_ARB
#define WGL_TEXTURE_CUBE_MAP_ARB 0x2078
#endif

#ifndef WGL_FRONT_LEFT_ARB
#define WGL_FRONT_LEFT_ARB 0x2083
#endif

#ifndef WGL_MIPMAP_TEXTURE_ARB
#define WGL_MIPMAP_TEXTURE_ARB 0x2074
#endif

#ifndef WGL_TEXTURE_RGBA_ARB
#define WGL_TEXTURE_RGBA_ARB 0x2076
#endif

#ifndef WGL_TEXTURE_2D_ARB
#define WGL_TEXTURE_2D_ARB 0x207A
#endif

#ifndef WGL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB
#define WGL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB 0x207F
#endif

#ifndef WGL_TEXTURE_RGB_ARB
#define WGL_TEXTURE_RGB_ARB 0x2075
#endif

#ifndef WGL_AUX9_ARB
#define WGL_AUX9_ARB 0x2090
#endif

#ifndef WGL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB
#define WGL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB 0x207D
#endif

#ifndef WGL_FRONT_RIGHT_ARB
#define WGL_FRONT_RIGHT_ARB 0x2084
#endif

#ifndef WGL_BACK_RIGHT_ARB
#define WGL_BACK_RIGHT_ARB 0x2086
#endif

#ifndef WGL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB
#define WGL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB 0x2082
#endif

#ifndef WGL_TEXTURE_1D_ARB
#define WGL_TEXTURE_1D_ARB 0x2079
#endif

#ifndef WGL_NO_TEXTURE_ARB
#define WGL_NO_TEXTURE_ARB 0x2077
#endif

#ifndef WGL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB
#define WGL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB 0x207E
#endif

#ifndef WGL_AUX0_ARB
#define WGL_AUX0_ARB 0x2087
#endif

#ifndef WGL_AUX7_ARB
#define WGL_AUX7_ARB 0x208E
#endif

#ifndef WGL_CUBE_MAP_FACE_ARB
#define WGL_CUBE_MAP_FACE_ARB 0x207C
#endif

#ifndef WGL_BIND_TO_TEXTURE_RGB_ARB
#define WGL_BIND_TO_TEXTURE_RGB_ARB 0x2070
#endif

#ifndef WGL_AUX5_ARB
#define WGL_AUX5_ARB 0x208C
#endif

#ifndef WGL_AUX8_ARB
#define WGL_AUX8_ARB 0x208F
#endif

#ifndef WGL_AUX1_ARB
#define WGL_AUX1_ARB 0x2088
#endif

#ifndef WGL_TEXTURE_TARGET_ARB
#define WGL_TEXTURE_TARGET_ARB 0x2073
#endif

#ifndef WGL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB
#define WGL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB 0x2080
#endif

typedef BOOL (NIV_CALL_TYPE * nivenWGLRELEASETEXIMAGEARB) (HPBUFFERARB hPbuffer, int iBuffer);
typedef BOOL (NIV_CALL_TYPE * nivenWGLBINDTEXIMAGEARB) (HPBUFFERARB hPbuffer, int iBuffer);
typedef BOOL (NIV_CALL_TYPE * nivenWGLSETPBUFFERATTRIBARB) (HPBUFFERARB hPbuffer, const int* piAttribList);
#endif
// GL_SGIS_multisample
#ifndef GL_4PASS_3_SGIS
#define GL_4PASS_3_SGIS 0x80A7
#endif

#ifndef GL_SAMPLES_SGIS
#define GL_SAMPLES_SGIS 0x80A9
#endif

#ifndef GL_4PASS_0_SGIS
#define GL_4PASS_0_SGIS 0x80A4
#endif

#ifndef GL_SAMPLE_BUFFERS_SGIS
#define GL_SAMPLE_BUFFERS_SGIS 0x80A8
#endif

#ifndef GL_SAMPLE_MASK_INVERT_SGIS
#define GL_SAMPLE_MASK_INVERT_SGIS 0x80AB
#endif

#ifndef GL_2PASS_1_SGIS
#define GL_2PASS_1_SGIS 0x80A3
#endif

#ifndef GL_2PASS_0_SGIS
#define GL_2PASS_0_SGIS 0x80A2
#endif

#ifndef GL_4PASS_2_SGIS
#define GL_4PASS_2_SGIS 0x80A6
#endif

#ifndef GL_MULTISAMPLE_SGIS
#define GL_MULTISAMPLE_SGIS 0x809D
#endif

#ifndef GL_SAMPLE_PATTERN_SGIS
#define GL_SAMPLE_PATTERN_SGIS 0x80AC
#endif

#ifndef GL_SAMPLE_ALPHA_TO_ONE_SGIS
#define GL_SAMPLE_ALPHA_TO_ONE_SGIS 0x809F
#endif

#ifndef GL_SAMPLE_MASK_SGIS
#define GL_SAMPLE_MASK_SGIS 0x80A0
#endif

#ifndef GL_SAMPLE_ALPHA_TO_MASK_SGIS
#define GL_SAMPLE_ALPHA_TO_MASK_SGIS 0x809E
#endif

#ifndef GL_4PASS_1_SGIS
#define GL_4PASS_1_SGIS 0x80A5
#endif

#ifndef GL_SAMPLE_MASK_VALUE_SGIS
#define GL_SAMPLE_MASK_VALUE_SGIS 0x80AA
#endif

#ifndef GL_1PASS_SGIS
#define GL_1PASS_SGIS 0x80A1
#endif

typedef void (NIV_CALL_TYPE * nivenGLSAMPLEMASKSGIS) (GLclampf value, GLboolean invert);
typedef void (NIV_CALL_TYPE * nivenGLSAMPLEPATTERNSGIS) (GLenum pattern);

// GL_ARB_vertex_shader
#ifndef GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB
#define GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB 0x8B4C
#endif

#ifndef GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB
#define GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB 0x8B4D
#endif

#ifndef GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB
#define GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB 0x8B8A
#endif

#ifndef GL_OBJECT_ACTIVE_ATTRIBUTES_ARB
#define GL_OBJECT_ACTIVE_ATTRIBUTES_ARB 0x8B89
#endif

#ifndef GL_MAX_VARYING_FLOATS_ARB
#define GL_MAX_VARYING_FLOATS_ARB 0x8B4B
#endif

#ifndef GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB
#define GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB 0x8B4A
#endif

#ifndef GL_VERTEX_SHADER_ARB
#define GL_VERTEX_SHADER_ARB 0x8B31
#endif

typedef void (NIV_CALL_TYPE * nivenGLGETACTIVEATTRIBARB) (GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei* length, GLint* size, GLenum* type, GLcharARB* name);
typedef void (NIV_CALL_TYPE * nivenGLBINDATTRIBLOCATIONARB) (GLhandleARB programObj, GLuint index, const GLcharARB* name);
typedef GLint (NIV_CALL_TYPE * nivenGLGETATTRIBLOCATIONARB) (GLhandleARB programObj, const GLcharARB* name);

// WGL_NV_render_depth_texture
#ifdef WIN32
#ifndef WGL_BIND_TO_TEXTURE_RECTANGLE_DEPTH_NV
#define WGL_BIND_TO_TEXTURE_RECTANGLE_DEPTH_NV 0x20A4
#endif

#ifndef WGL_DEPTH_COMPONENT_NV
#define WGL_DEPTH_COMPONENT_NV 0x20A7
#endif

#ifndef WGL_BIND_TO_TEXTURE_DEPTH_NV
#define WGL_BIND_TO_TEXTURE_DEPTH_NV 0x20A3
#endif

#ifndef WGL_DEPTH_TEXTURE_FORMAT_NV
#define WGL_DEPTH_TEXTURE_FORMAT_NV 0x20A5
#endif

#ifndef WGL_TEXTURE_DEPTH_COMPONENT_NV
#define WGL_TEXTURE_DEPTH_COMPONENT_NV 0x20A6
#endif

#endif
// GL_EXT_texture_env
#ifndef GL_ENV_BLEND_EXT
#define GL_ENV_BLEND_EXT 0
#endif

#ifndef GL_ENV_MODULATE_EXT
#define GL_ENV_MODULATE_EXT 0
#endif

#ifndef GL_ENV_REVERSE_SUBTRACT_EXT
#define GL_ENV_REVERSE_SUBTRACT_EXT 0
#endif

#ifndef GL_ENV_SUBTRACT_EXT
#define GL_ENV_SUBTRACT_EXT 0
#endif

#ifndef GL_TEXTURE_ENV_SHIFT_EXT
#define GL_TEXTURE_ENV_SHIFT_EXT 0
#endif

#ifndef GL_ENV_REVERSE_BLEND_EXT
#define GL_ENV_REVERSE_BLEND_EXT 0
#endif

#ifndef GL_ENV_COPY_EXT
#define GL_ENV_COPY_EXT 0
#endif

#ifndef GL_ENV_ADD_EXT
#define GL_ENV_ADD_EXT 0
#endif

#ifndef GL_TEXTURE_ENV_MODE_ALPHA_EXT
#define GL_TEXTURE_ENV_MODE_ALPHA_EXT 0
#endif

#ifndef GL_ENV_REPLACE_EXT
#define GL_ENV_REPLACE_EXT 0
#endif

#ifndef GL_TEXTURE_ENV0_EXT
#define GL_TEXTURE_ENV0_EXT 0
#endif


// GL_SGIX_fragment_specular_lighting
typedef void (NIV_CALL_TYPE * nivenGLGETFRAGMENTLIGHTFVSGIX) (GLenum light, GLenum value, GLfloat* data);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTMATERIALISGIX) (GLenum face, GLenum pname, const GLint param);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTCOLORMATERIALSGIX) (GLenum face, GLenum mode);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTMATERIALFVSGIX) (GLenum face, GLenum pname, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTISGIX) (GLenum light, GLenum pname, GLint param);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTMODELIVSGIX) (GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTFSGIX) (GLenum light, GLenum pname, GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTFVSGIX) (GLenum light, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTMODELFSGIX) (GLenum pname, GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTIVSGIX) (GLenum light, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTMODELFVSGIX) (GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTMATERIALIVSGIX) (GLenum face, GLenum pname, const GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETFRAGMENTMATERIALIVSGIX) (GLenum face, GLenum pname, const GLint* data);
typedef void (NIV_CALL_TYPE * nivenGLGETFRAGMENTMATERIALFVSGIX) (GLenum face, GLenum pname, const GLfloat* data);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTMODELISGIX) (GLenum pname, GLint param);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTMATERIALFSGIX) (GLenum face, GLenum pname, const GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLGETFRAGMENTLIGHTIVSGIX) (GLenum light, GLenum value, GLint* data);

#ifdef _GLX
// GLX_3DFX_multisample
#ifndef GLX_SAMPLES_3DFX
#define GLX_SAMPLES_3DFX 0x8051
#endif

#ifndef GLX_SAMPLE_BUFFERS_3DFX
#define GLX_SAMPLE_BUFFERS_3DFX 0x8050
#endif

#endif // _GLX
// GL_ARB_fragment_shader
#ifndef GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB
#define GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB 0x8B8B
#endif

#ifndef GL_FRAGMENT_SHADER_ARB
#define GL_FRAGMENT_SHADER_ARB 0x8B30
#endif

#ifndef GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB
#define GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB 0x8B49
#endif


#ifdef _GLX
// GLX_SGI_video_sync
typedef int (NIV_CALL_TYPE * nivenGLXWAITVIDEOSYNCSGI) (int divisor, int remainder, unsigned int* count);
typedef int (NIV_CALL_TYPE * nivenGLXGETVIDEOSYNCSGI) (uint* count);
#endif // _GLX
// GL_NV_texture_shader
#ifndef GL_DSDT_NV
#define GL_DSDT_NV 0x86F5
#endif

#ifndef GL_SIGNED_LUMINANCE_NV
#define GL_SIGNED_LUMINANCE_NV 0x8701
#endif

#ifndef GL_TEXTURE_SHADER_NV
#define GL_TEXTURE_SHADER_NV 0x86DE
#endif

#ifndef GL_HILO_NV
#define GL_HILO_NV 0x86F4
#endif

#ifndef GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV
#define GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV 0x86F3
#endif

#ifndef GL_SIGNED_ALPHA8_NV
#define GL_SIGNED_ALPHA8_NV 0x8706
#endif

#ifndef GL_SIGNED_ALPHA_NV
#define GL_SIGNED_ALPHA_NV 0x8705
#endif

#ifndef GL_HI_SCALE_NV
#define GL_HI_SCALE_NV 0x870E
#endif

#ifndef GL_VIBRANCE_SCALE_NV
#define GL_VIBRANCE_SCALE_NV 0x8713
#endif

#ifndef GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV
#define GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV 0x870D
#endif

#ifndef GL_PREVIOUS_TEXTURE_INPUT_NV
#define GL_PREVIOUS_TEXTURE_INPUT_NV 0x86E4
#endif

#ifndef GL_OFFSET_TEXTURE_SCALE_NV
#define GL_OFFSET_TEXTURE_SCALE_NV 0x86E2
#endif

#ifndef GL_SIGNED_HILO16_NV
#define GL_SIGNED_HILO16_NV 0x86FA
#endif

#ifndef GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV
#define GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV 0x864E
#endif

#ifndef GL_SIGNED_LUMINANCE8_NV
#define GL_SIGNED_LUMINANCE8_NV 0x8702
#endif

#ifndef GL_DSDT_MAG_NV
#define GL_DSDT_MAG_NV 0x86F6
#endif

#ifndef GL_OFFSET_TEXTURE_MATRIX_NV
#define GL_OFFSET_TEXTURE_MATRIX_NV 0x86E1
#endif

#ifndef GL_DOT_PRODUCT_DEPTH_REPLACE_NV
#define GL_DOT_PRODUCT_DEPTH_REPLACE_NV 0x86ED
#endif

#ifndef GL_SIGNED_RGB_NV
#define GL_SIGNED_RGB_NV 0x86FE
#endif

#ifndef GL_DT_SCALE_NV
#define GL_DT_SCALE_NV 0x8711
#endif

#ifndef GL_TEXTURE_DS_SIZE_NV
#define GL_TEXTURE_DS_SIZE_NV 0x871D
#endif

#ifndef GL_OFFSET_TEXTURE_BIAS_NV
#define GL_OFFSET_TEXTURE_BIAS_NV 0x86E3
#endif

#ifndef GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV
#define GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV 0x86F0
#endif

#ifndef GL_SIGNED_RGB8_NV
#define GL_SIGNED_RGB8_NV 0x86FF
#endif

#ifndef GL_DOT_PRODUCT_NV
#define GL_DOT_PRODUCT_NV 0x86EC
#endif

#ifndef GL_HILO16_NV
#define GL_HILO16_NV 0x86F8
#endif

#ifndef GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV
#define GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV 0x86F2
#endif

#ifndef GL_LO_BIAS_NV
#define GL_LO_BIAS_NV 0x8715
#endif

#ifndef GL_SIGNED_LUMINANCE_ALPHA_NV
#define GL_SIGNED_LUMINANCE_ALPHA_NV 0x8703
#endif

#ifndef GL_MAGNITUDE_SCALE_NV
#define GL_MAGNITUDE_SCALE_NV 0x8712
#endif

#ifndef GL_DSDT8_MAG8_NV
#define GL_DSDT8_MAG8_NV 0x870A
#endif

#ifndef GL_SIGNED_INTENSITY_NV
#define GL_SIGNED_INTENSITY_NV 0x8707
#endif

#ifndef GL_DOT_PRODUCT_TEXTURE_2D_NV
#define GL_DOT_PRODUCT_TEXTURE_2D_NV 0x86EE
#endif

#ifndef GL_DEPENDENT_GB_TEXTURE_2D_NV
#define GL_DEPENDENT_GB_TEXTURE_2D_NV 0x86EA
#endif

#ifndef GL_LO_SCALE_NV
#define GL_LO_SCALE_NV 0x870F
#endif

#ifndef GL_SIGNED_RGBA8_NV
#define GL_SIGNED_RGBA8_NV 0x86FC
#endif

#ifndef GL_SIGNED_RGBA_NV
#define GL_SIGNED_RGBA_NV 0x86FB
#endif

#ifndef GL_UNSIGNED_INT_S8_S8_8_8_NV
#define GL_UNSIGNED_INT_S8_S8_8_8_NV 0x86DA
#endif

#ifndef GL_DSDT8_NV
#define GL_DSDT8_NV 0x8709
#endif

#ifndef GL_UNSIGNED_INT_8_8_S8_S8_REV_NV
#define GL_UNSIGNED_INT_8_8_S8_S8_REV_NV 0x86DB
#endif

#ifndef GL_TEXTURE_LO_SIZE_NV
#define GL_TEXTURE_LO_SIZE_NV 0x871C
#endif

#ifndef GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV
#define GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV 0x86F1
#endif

#ifndef GL_SIGNED_HILO_NV
#define GL_SIGNED_HILO_NV 0x86F9
#endif

#ifndef GL_SIGNED_INTENSITY8_NV
#define GL_SIGNED_INTENSITY8_NV 0x8708
#endif

#ifndef GL_SIGNED_LUMINANCE8_ALPHA8_NV
#define GL_SIGNED_LUMINANCE8_ALPHA8_NV 0x8704
#endif

#ifndef GL_TEXTURE_DT_SIZE_NV
#define GL_TEXTURE_DT_SIZE_NV 0x871E
#endif

#ifndef GL_DS_SCALE_NV
#define GL_DS_SCALE_NV 0x8710
#endif

#ifndef GL_DT_BIAS_NV
#define GL_DT_BIAS_NV 0x8717
#endif

#ifndef GL_OFFSET_TEXTURE_RECTANGLE_NV
#define GL_OFFSET_TEXTURE_RECTANGLE_NV 0x864C
#endif

#ifndef GL_SHADER_OPERATION_NV
#define GL_SHADER_OPERATION_NV 0x86DF
#endif

#ifndef GL_CONST_EYE_NV
#define GL_CONST_EYE_NV 0x86E5
#endif

#ifndef GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV
#define GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV 0x86D9
#endif

#ifndef GL_SHADER_CONSISTENT_NV
#define GL_SHADER_CONSISTENT_NV 0x86DD
#endif

#ifndef GL_CULL_FRAGMENT_NV
#define GL_CULL_FRAGMENT_NV 0x86E7
#endif

#ifndef GL_CULL_MODES_NV
#define GL_CULL_MODES_NV 0x86E0
#endif

#ifndef GL_DS_BIAS_NV
#define GL_DS_BIAS_NV 0x8716
#endif

#ifndef GL_HI_BIAS_NV
#define GL_HI_BIAS_NV 0x8714
#endif

#ifndef GL_TEXTURE_MAG_SIZE_NV
#define GL_TEXTURE_MAG_SIZE_NV 0x871F
#endif

#ifndef GL_VIBRANCE_BIAS_NV
#define GL_VIBRANCE_BIAS_NV 0x8719
#endif

#ifndef GL_TEXTURE_BORDER_VALUES_NV
#define GL_TEXTURE_BORDER_VALUES_NV 0x871A
#endif

#ifndef GL_DSDT_MAG_INTENSITY_NV
#define GL_DSDT_MAG_INTENSITY_NV 0x86DC
#endif

#ifndef GL_DSDT8_MAG8_INTENSITY8_NV
#define GL_DSDT8_MAG8_INTENSITY8_NV 0x870B
#endif

#ifndef GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV
#define GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV 0x864D
#endif

#ifndef GL_MAGNITUDE_BIAS_NV
#define GL_MAGNITUDE_BIAS_NV 0x8718
#endif

#ifndef GL_PASS_THROUGH_NV
#define GL_PASS_THROUGH_NV 0x86E6
#endif

#ifndef GL_SIGNED_RGB_UNSIGNED_ALPHA_NV
#define GL_SIGNED_RGB_UNSIGNED_ALPHA_NV 0x870C
#endif

#ifndef GL_TEXTURE_HI_SIZE_NV
#define GL_TEXTURE_HI_SIZE_NV 0x871B
#endif

#ifndef GL_DSDT_MAG_VIB_NV
#define GL_DSDT_MAG_VIB_NV 0x86F7
#endif

#ifndef GL_OFFSET_TEXTURE_2D_NV
#define GL_OFFSET_TEXTURE_2D_NV 0x86E8
#endif

#ifndef GL_DEPENDENT_AR_TEXTURE_2D_NV
#define GL_DEPENDENT_AR_TEXTURE_2D_NV 0x86E9
#endif


// GL_NV_pixel_data_range
#ifndef GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV
#define GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV 0x887A
#endif

#ifndef GL_READ_PIXEL_DATA_RANGE_LENGTH_NV
#define GL_READ_PIXEL_DATA_RANGE_LENGTH_NV 0x887B
#endif

#ifndef GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV
#define GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV 0x887C
#endif

#ifndef GL_WRITE_PIXEL_DATA_RANGE_NV
#define GL_WRITE_PIXEL_DATA_RANGE_NV 0x8878
#endif

#ifndef GL_READ_PIXEL_DATA_RANGE_NV
#define GL_READ_PIXEL_DATA_RANGE_NV 0x8879
#endif

#ifndef GL_READ_PIXEL_DATA_RANGE_POINTER_NV
#define GL_READ_PIXEL_DATA_RANGE_POINTER_NV 0x887D
#endif

typedef void (NIV_CALL_TYPE * nivenGLPIXELDATARANGENV) (GLenum target, GLsizei length, void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLFLUSHPIXELDATARANGENV) (GLenum target);

// WGL_EXT_multisample
#ifdef WIN32
#ifndef WGL_SAMPLE_BUFFERS_EXT
#define WGL_SAMPLE_BUFFERS_EXT 0x2041
#endif

#ifndef WGL_SAMPLES_EXT
#define WGL_SAMPLES_EXT 0x2042
#endif

#endif
// GL_SGIS_texture_edge_clamp
#ifndef GL_CLAMP_TO_EDGE_SGIS
#define GL_CLAMP_TO_EDGE_SGIS 0x812F
#endif


// GL_ARB_imaging
#ifndef GL_COLOR_MATRIX
#define GL_COLOR_MATRIX 0x80B1
#endif

#ifndef GL_SEPARABLE_2D
#define GL_SEPARABLE_2D 0x8012
#endif

#ifndef GL_COLOR_TABLE_GREEN_SIZE
#define GL_COLOR_TABLE_GREEN_SIZE 0x80DB
#endif

#ifndef GL_CONVOLUTION_FORMAT
#define GL_CONVOLUTION_FORMAT 0x8017
#endif

#ifndef GL_COLOR_TABLE_RED_SIZE
#define GL_COLOR_TABLE_RED_SIZE 0x80DA
#endif

#ifndef GL_POST_COLOR_MATRIX_ALPHA_BIAS
#define GL_POST_COLOR_MATRIX_ALPHA_BIAS 0x80BB
#endif

#ifndef GL_CONVOLUTION_FILTER_BIAS
#define GL_CONVOLUTION_FILTER_BIAS 0x8015
#endif

#ifndef GL_ONE_MINUS_CONSTANT_COLOR
#define GL_ONE_MINUS_CONSTANT_COLOR 0x8002
#endif

#ifndef GL_MAX_CONVOLUTION_HEIGHT
#define GL_MAX_CONVOLUTION_HEIGHT 0x801B
#endif

#ifndef GL_MAX_CONVOLUTION_WIDTH
#define GL_MAX_CONVOLUTION_WIDTH 0x801A
#endif

#ifndef GL_POST_CONVOLUTION_BLUE_SCALE
#define GL_POST_CONVOLUTION_BLUE_SCALE 0x801E
#endif

#ifndef GL_REDUCE
#define GL_REDUCE 0x8016
#endif

#ifndef GL_CONSTANT_ALPHA
#define GL_CONSTANT_ALPHA 0x8003
#endif

#ifndef GL_POST_CONVOLUTION_GREEN_BIAS
#define GL_POST_CONVOLUTION_GREEN_BIAS 0x8021
#endif

#ifndef GL_HISTOGRAM_ALPHA_SIZE
#define GL_HISTOGRAM_ALPHA_SIZE 0x802B
#endif

#ifndef GL_POST_CONVOLUTION_COLOR_TABLE
#define GL_POST_CONVOLUTION_COLOR_TABLE 0x80D1
#endif

#ifndef GL_HISTOGRAM_BLUE_SIZE
#define GL_HISTOGRAM_BLUE_SIZE 0x802A
#endif

#ifndef GL_HISTOGRAM
#define GL_HISTOGRAM 0x8024
#endif

#ifndef GL_POST_CONVOLUTION_RED_BIAS
#define GL_POST_CONVOLUTION_RED_BIAS 0x8020
#endif

#ifndef GL_POST_COLOR_MATRIX_GREEN_BIAS
#define GL_POST_COLOR_MATRIX_GREEN_BIAS 0x80B9
#endif

#ifndef GL_BLEND_COLOR
#define GL_BLEND_COLOR 0x8005
#endif

#ifndef GL_FUNC_ADD
#define GL_FUNC_ADD 0x8006
#endif

#ifndef GL_COLOR_MATRIX_STACK_DEPTH
#define GL_COLOR_MATRIX_STACK_DEPTH 0x80B2
#endif

#ifndef GL_MAX
#define GL_MAX 0x8008
#endif

#ifndef GL_PROXY_POST_CONVOLUTION_COLOR_TABLE
#define GL_PROXY_POST_CONVOLUTION_COLOR_TABLE 0x80D4
#endif

#ifndef GL_MAX_COLOR_MATRIX_STACK_DEPTH
#define GL_MAX_COLOR_MATRIX_STACK_DEPTH 0x80B3
#endif

#ifndef GL_PROXY_HISTOGRAM
#define GL_PROXY_HISTOGRAM 0x8025
#endif

#ifndef GL_ONE_MINUS_CONSTANT_ALPHA
#define GL_ONE_MINUS_CONSTANT_ALPHA 0x8004
#endif

#ifndef GL_COLOR_TABLE_INTENSITY_SIZE
#define GL_COLOR_TABLE_INTENSITY_SIZE 0x80DF
#endif

#ifndef GL_POST_COLOR_MATRIX_RED_BIAS
#define GL_POST_COLOR_MATRIX_RED_BIAS 0x80B8
#endif

#ifndef GL_POST_CONVOLUTION_ALPHA_SCALE
#define GL_POST_CONVOLUTION_ALPHA_SCALE 0x801F
#endif

#ifndef GL_PROXY_COLOR_TABLE
#define GL_PROXY_COLOR_TABLE 0x80D3
#endif

#ifndef GL_COLOR_TABLE
#define GL_COLOR_TABLE 0x80D0
#endif

#ifndef GL_POST_CONVOLUTION_GREEN_SCALE
#define GL_POST_CONVOLUTION_GREEN_SCALE 0x801D
#endif

#ifndef GL_FUNC_REVERSE_SUBTRACT
#define GL_FUNC_REVERSE_SUBTRACT 0x800B
#endif

#ifndef GL_CONSTANT_COLOR
#define GL_CONSTANT_COLOR 0x8001
#endif

#ifndef GL_CONVOLUTION_1D
#define GL_CONVOLUTION_1D 0x8010
#endif

#ifndef GL_POST_COLOR_MATRIX_BLUE_BIAS
#define GL_POST_COLOR_MATRIX_BLUE_BIAS 0x80BA
#endif

#ifndef GL_COLOR_TABLE_WIDTH
#define GL_COLOR_TABLE_WIDTH 0x80D9
#endif

#ifndef GL_POST_CONVOLUTION_ALPHA_BIAS
#define GL_POST_CONVOLUTION_ALPHA_BIAS 0x8023
#endif

#ifndef GL_POST_COLOR_MATRIX_BLUE_SCALE
#define GL_POST_COLOR_MATRIX_BLUE_SCALE 0x80B6
#endif

#ifndef GL_MIN
#define GL_MIN 0x8007
#endif

#ifndef GL_CONVOLUTION_BORDER_COLOR
#define GL_CONVOLUTION_BORDER_COLOR 0x8154
#endif

#ifndef GL_FUNC_SUBTRACT
#define GL_FUNC_SUBTRACT 0x800A
#endif

#ifndef GL_MINMAX_SINK
#define GL_MINMAX_SINK 0x8030
#endif

#ifndef GL_POST_COLOR_MATRIX_RED_SCALE
#define GL_POST_COLOR_MATRIX_RED_SCALE 0x80B4
#endif

#ifndef GL_COLOR_TABLE_LUMINANCE_SIZE
#define GL_COLOR_TABLE_LUMINANCE_SIZE 0x80DE
#endif

#ifndef GL_HISTOGRAM_SINK
#define GL_HISTOGRAM_SINK 0x802D
#endif

#ifndef GL_POST_COLOR_MATRIX_ALPHA_SCALE
#define GL_POST_COLOR_MATRIX_ALPHA_SCALE 0x80B7
#endif

#ifndef GL_IGNORE_BORDER
#define GL_IGNORE_BORDER 0x8150
#endif

#ifndef GL_MINMAX
#define GL_MINMAX 0x802E
#endif

#ifndef GL_COLOR_TABLE_BLUE_SIZE
#define GL_COLOR_TABLE_BLUE_SIZE 0x80DC
#endif

#ifndef GL_HISTOGRAM_RED_SIZE
#define GL_HISTOGRAM_RED_SIZE 0x8028
#endif

#ifndef GL_HISTOGRAM_LUMINANCE_SIZE
#define GL_HISTOGRAM_LUMINANCE_SIZE 0x802C
#endif

#ifndef GL_CONVOLUTION_HEIGHT
#define GL_CONVOLUTION_HEIGHT 0x8019
#endif

#ifndef GL_CONVOLUTION_WIDTH
#define GL_CONVOLUTION_WIDTH 0x8018
#endif

#ifndef GL_POST_COLOR_MATRIX_COLOR_TABLE
#define GL_POST_COLOR_MATRIX_COLOR_TABLE 0x80D2
#endif

#ifndef GL_TABLE_TOO_LARGE
#define GL_TABLE_TOO_LARGE 0x8031
#endif

#ifndef GL_COLOR_TABLE_BIAS
#define GL_COLOR_TABLE_BIAS 0x80D7
#endif

#ifndef GL_REPLICATE_BORDER
#define GL_REPLICATE_BORDER 0x8153
#endif

#ifndef GL_POST_CONVOLUTION_BLUE_BIAS
#define GL_POST_CONVOLUTION_BLUE_BIAS 0x8022
#endif

#ifndef GL_WRAP_BORDER
#define GL_WRAP_BORDER 0x8152
#endif

#ifndef GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE
#define GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE 0x80D5
#endif

#ifndef GL_HISTOGRAM_GREEN_SIZE
#define GL_HISTOGRAM_GREEN_SIZE 0x8029
#endif

#ifndef GL_POST_CONVOLUTION_RED_SCALE
#define GL_POST_CONVOLUTION_RED_SCALE 0x801C
#endif

#ifndef GL_HISTOGRAM_WIDTH
#define GL_HISTOGRAM_WIDTH 0x8026
#endif

#ifndef GL_COLOR_TABLE_SCALE
#define GL_COLOR_TABLE_SCALE 0x80D6
#endif

#ifndef GL_COLOR_TABLE_ALPHA_SIZE
#define GL_COLOR_TABLE_ALPHA_SIZE 0x80DD
#endif

#ifndef GL_CONVOLUTION_FILTER_SCALE
#define GL_CONVOLUTION_FILTER_SCALE 0x8014
#endif

#ifndef GL_BLEND_EQUATION
#define GL_BLEND_EQUATION 0x8009
#endif

#ifndef GL_MINMAX_FORMAT
#define GL_MINMAX_FORMAT 0x802F
#endif

#ifndef GL_CONVOLUTION_BORDER_MODE
#define GL_CONVOLUTION_BORDER_MODE 0x8013
#endif

#ifndef GL_COLOR_TABLE_FORMAT
#define GL_COLOR_TABLE_FORMAT 0x80D8
#endif

#ifndef GL_POST_COLOR_MATRIX_GREEN_SCALE
#define GL_POST_COLOR_MATRIX_GREEN_SCALE 0x80B5
#endif

#ifndef GL_CONSTANT_BORDER
#define GL_CONSTANT_BORDER 0x8151
#endif

#ifndef GL_CONVOLUTION_2D
#define GL_CONVOLUTION_2D 0x8011
#endif

#ifndef GL_HISTOGRAM_FORMAT
#define GL_HISTOGRAM_FORMAT 0x8027
#endif

typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONPARAMETERI) (GLenum target, GLenum pname, GLint params);
typedef void (NIV_CALL_TYPE * nivenGLGETCONVOLUTIONPARAMETERIV) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETMINMAXPARAMETERFV) (GLenum target, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONPARAMETERF) (GLenum target, GLenum pname, GLfloat params);
typedef void (NIV_CALL_TYPE * nivenGLCOLORTABLEPARAMETERIV) (GLenum target, GLenum pname, const GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLCOLORTABLE) (GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const GLvoid* table);
typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONPARAMETERIV) (GLenum target, GLenum pname, const GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETMINMAX) (GLenum target, GLboolean reset, GLenum format, GLenum types, GLvoid* values);
typedef void (NIV_CALL_TYPE * nivenGLMINMAX) (GLenum target, GLenum internalformat, GLboolean sink);
typedef void (NIV_CALL_TYPE * nivenGLCOPYCOLORSUBTABLE) (GLenum target, GLsizei start, GLint x, GLint y, GLsizei width);
typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONFILTER2D) (GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const GLvoid* image);
typedef void (NIV_CALL_TYPE * nivenGLGETSEPARABLEFILTER) (GLenum target, GLenum format, GLenum type, GLvoid* row, GLvoid* column, GLvoid* span);
typedef void (NIV_CALL_TYPE * nivenGLGETCOLORTABLEPARAMETERIV) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLCOPYCOLORTABLE) (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width);
typedef void (NIV_CALL_TYPE * nivenGLSEPARABLEFILTER2D) (GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const GLvoid* row, const GLvoid* column);
typedef void (NIV_CALL_TYPE * nivenGLCOPYCONVOLUTIONFILTER1D) (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width);
typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONPARAMETERFV) (GLenum target, GLenum pname, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETCONVOLUTIONFILTER) (GLenum target, GLenum format, GLenum type, GLvoid* image);
typedef void (NIV_CALL_TYPE * nivenGLCOLORTABLEPARAMETERFV) (GLenum target, GLenum pname, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLRESETMINMAX) (GLenum target);
typedef void (NIV_CALL_TYPE * nivenGLCOPYCONVOLUTIONFILTER2D) (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height);
typedef void (NIV_CALL_TYPE * nivenGLHISTOGRAM) (GLenum target, GLsizei width, GLenum internalformat, GLboolean sink);
typedef void (NIV_CALL_TYPE * nivenGLGETMINMAXPARAMETERIV) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETHISTOGRAMPARAMETERFV) (GLenum target, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETCOLORTABLE) (GLenum target, GLenum format, GLenum type, GLvoid* table);
typedef void (NIV_CALL_TYPE * nivenGLGETCONVOLUTIONPARAMETERFV) (GLenum target, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLRESETHISTOGRAM) (GLenum target);
typedef void (NIV_CALL_TYPE * nivenGLCONVOLUTIONFILTER1D) (GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const GLvoid* image);
typedef void (NIV_CALL_TYPE * nivenGLGETCOLORTABLEPARAMETERFV) (GLenum target, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETHISTOGRAM) (GLenum target, GLboolean reset, GLenum format, GLenum type, GLvoid* values);
typedef void (NIV_CALL_TYPE * nivenGLGETHISTOGRAMPARAMETERIV) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLCOLORSUBTABLE) (GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const GLvoid* data);

// GL_WIN_specular_fog
#ifndef GL_FOG_SPECULAR_TEXTURE_WIN
#define GL_FOG_SPECULAR_TEXTURE_WIN 0x80EC
#endif


// GL_APPLE_client_storage
#ifndef GL_UNPACK_CLIENT_STORAGE_APPLE
#define GL_UNPACK_CLIENT_STORAGE_APPLE 0x85B2
#endif


// GL_IBM_vertex_array_lists
#ifndef GL_VERTEX_ARRAY_LIST_IBM
#define GL_VERTEX_ARRAY_LIST_IBM 103070
#endif

#ifndef GL_INDEX_ARRAY_LIST_STRIDE_IBM
#define GL_INDEX_ARRAY_LIST_STRIDE_IBM 103083
#endif

#ifndef GL_TEXTURE_COORD_ARRAY_LIST_IBM
#define GL_TEXTURE_COORD_ARRAY_LIST_IBM 103074
#endif

#ifndef GL_EDGE_FLAG_ARRAY_LIST_IBM
#define GL_EDGE_FLAG_ARRAY_LIST_IBM 103075
#endif

#ifndef GL_TEXTURE_COORD_ARRAY_LIST_STRIDE_IBM
#define GL_TEXTURE_COORD_ARRAY_LIST_STRIDE_IBM 103084
#endif

#ifndef GL_SECONDARY_COLOR_ARRAY_LIST_STRIDE_IBM
#define GL_SECONDARY_COLOR_ARRAY_LIST_STRIDE_IBM 103087
#endif

#ifndef GL_FOG_COORDINATE_ARRAY_LIST_STRIDE_IBM
#define GL_FOG_COORDINATE_ARRAY_LIST_STRIDE_IBM 103086
#endif

#ifndef GL_COLOR_ARRAY_LIST_IBM
#define GL_COLOR_ARRAY_LIST_IBM 103072
#endif

#ifndef GL_VERTEX_ARRAY_LIST_STRIDE_IBM
#define GL_VERTEX_ARRAY_LIST_STRIDE_IBM 103080
#endif

#ifndef GL_EDGE_FLAG_ARRAY_LIST_STRIDE_IBM
#define GL_EDGE_FLAG_ARRAY_LIST_STRIDE_IBM 103085
#endif

#ifndef GL_INDEX_ARRAY_LIST_IBM
#define GL_INDEX_ARRAY_LIST_IBM 103073
#endif

#ifndef GL_SECONDARY_COLOR_ARRAY_LIST_IBM
#define GL_SECONDARY_COLOR_ARRAY_LIST_IBM 103077
#endif

#ifndef GL_NORMAL_ARRAY_LIST_STRIDE_IBM
#define GL_NORMAL_ARRAY_LIST_STRIDE_IBM 103081
#endif

#ifndef GL_COLOR_ARRAY_LIST_STRIDE_IBM
#define GL_COLOR_ARRAY_LIST_STRIDE_IBM 103082
#endif

#ifndef GL_NORMAL_ARRAY_LIST_IBM
#define GL_NORMAL_ARRAY_LIST_IBM 103071
#endif

#ifndef GL_FOG_COORDINATE_ARRAY_LIST_IBM
#define GL_FOG_COORDINATE_ARRAY_LIST_IBM 103076
#endif

typedef void (NIV_CALL_TYPE * nivenGLTEXCOORDPOINTERLISTIBM) (GLint size, GLenum type, GLint stride, const GLvoid* *pointer, GLint ptrstride);
typedef void (NIV_CALL_TYPE * nivenGLEDGEFLAGPOINTERLISTIBM) (GLint stride, const GLboolean* *pointer, GLint ptrstride);
typedef void (NIV_CALL_TYPE * nivenGLNORMALPOINTERLISTIBM) (GLenum type, GLint stride, const GLvoid* *pointer, GLint ptrstride);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLORPOINTERLISTIBM) (GLint size, GLenum type, GLint stride, const GLvoid* *pointer, GLint ptrstride);
typedef void (NIV_CALL_TYPE * nivenGLINDEXPOINTERLISTIBM) (GLenum type, GLint stride, const GLvoid* *pointer, GLint ptrstride);
typedef void (NIV_CALL_TYPE * nivenGLCOLORPOINTERLISTIBM) (GLint size, GLenum type, GLint stride, const GLvoid* *pointer, GLint ptrstride);
typedef void (NIV_CALL_TYPE * nivenGLFOGCOORDPOINTERLISTIBM) (GLenum type, GLint stride, const GLvoid* *pointer, GLint ptrstride);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXPOINTERLISTIBM) (GLint size, GLenum type, GLint stride, const GLvoid* *pointer, GLint ptrstride);

// GL_ARB_fragment_program
#ifndef GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB
#define GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB 0x880C
#endif

#ifndef GL_PROGRAM_TEX_INSTRUCTIONS_ARB
#define GL_PROGRAM_TEX_INSTRUCTIONS_ARB 0x8806
#endif

#ifndef GL_MAX_TEXTURE_IMAGE_UNITS_ARB
#define GL_MAX_TEXTURE_IMAGE_UNITS_ARB 0x8872
#endif

#ifndef GL_FRAGMENT_PROGRAM_ARB
#define GL_FRAGMENT_PROGRAM_ARB 0x8804
#endif

#ifndef GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB
#define GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB 0x880E
#endif

#ifndef GL_PROGRAM_ALU_INSTRUCTIONS_ARB
#define GL_PROGRAM_ALU_INSTRUCTIONS_ARB 0x8805
#endif

#ifndef GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB
#define GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB 0x8810
#endif

#ifndef GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB
#define GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB 0x8809
#endif

#ifndef GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB
#define GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB 0x880A
#endif

#ifndef GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB
#define GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB 0x8808
#endif

#ifndef GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB
#define GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB 0x880B
#endif

#ifndef GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB
#define GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB 0x880D
#endif

#ifndef GL_PROGRAM_TEX_INDIRECTIONS_ARB
#define GL_PROGRAM_TEX_INDIRECTIONS_ARB 0x8807
#endif

#ifndef GL_MAX_TEXTURE_COORDS_ARB
#define GL_MAX_TEXTURE_COORDS_ARB 0x8871
#endif

#ifndef GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB
#define GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB 0x880F
#endif


// GL_ARB_shader_objects
#ifndef GL_OBJECT_LINK_STATUS_ARB
#define GL_OBJECT_LINK_STATUS_ARB 0x8B82
#endif

#ifndef GL_SAMPLER_2D_RECT_SHADOW_ARB
#define GL_SAMPLER_2D_RECT_SHADOW_ARB 0x8B64
#endif

#ifndef GL_FLOAT_MAT4_ARB
#define GL_FLOAT_MAT4_ARB 0x8B5C
#endif

#ifndef GL_BOOL_VEC2_ARB
#define GL_BOOL_VEC2_ARB 0x8B57
#endif

#ifndef GL_SAMPLER_2D_SHADOW_ARB
#define GL_SAMPLER_2D_SHADOW_ARB 0x8B62
#endif

#ifndef GL_OBJECT_VALIDATE_STATUS_ARB
#define GL_OBJECT_VALIDATE_STATUS_ARB 0x8B83
#endif

#ifndef GL_SAMPLER_3D_ARB
#define GL_SAMPLER_3D_ARB 0x8B5F
#endif

#ifndef GL_FLOAT_VEC3_ARB
#define GL_FLOAT_VEC3_ARB 0x8B51
#endif

#ifndef GL_SAMPLER_2D_ARB
#define GL_SAMPLER_2D_ARB 0x8B5E
#endif

#ifndef GL_OBJECT_DELETE_STATUS_ARB
#define GL_OBJECT_DELETE_STATUS_ARB 0x8B80
#endif

#ifndef GL_OBJECT_INFO_LOG_LENGTH_ARB
#define GL_OBJECT_INFO_LOG_LENGTH_ARB 0x8B84
#endif

#ifndef GL_FLOAT_MAT3_ARB
#define GL_FLOAT_MAT3_ARB 0x8B5B
#endif

#ifndef GL_SAMPLER_1D_SHADOW_ARB
#define GL_SAMPLER_1D_SHADOW_ARB 0x8B61
#endif

#ifndef GL_PROGRAM_OBJECT_ARB
#define GL_PROGRAM_OBJECT_ARB 0x8B40
#endif

#ifndef GL_INT_VEC2_ARB
#define GL_INT_VEC2_ARB 0x8B53
#endif

#ifndef GL_BOOL_ARB
#define GL_BOOL_ARB 0x8B56
#endif

#ifndef GL_OBJECT_COMPILE_STATUS_ARB
#define GL_OBJECT_COMPILE_STATUS_ARB 0x8B81
#endif

#ifndef GL_OBJECT_ATTACHED_OBJECTS_ARB
#define GL_OBJECT_ATTACHED_OBJECTS_ARB 0x8B85
#endif

#ifndef GL_OBJECT_TYPE_ARB
#define GL_OBJECT_TYPE_ARB 0x8B4E
#endif

#ifndef GL_SAMPLER_2D_RECT_ARB
#define GL_SAMPLER_2D_RECT_ARB 0x8B63
#endif

#ifndef GL_OBJECT_SUBTYPE_ARB
#define GL_OBJECT_SUBTYPE_ARB 0x8B4F
#endif

#ifndef GL_FLOAT_VEC4_ARB
#define GL_FLOAT_VEC4_ARB 0x8B52
#endif

#ifndef GL_INT_VEC4_ARB
#define GL_INT_VEC4_ARB 0x8B55
#endif

#ifndef GL_INT_VEC3_ARB
#define GL_INT_VEC3_ARB 0x8B54
#endif

#ifndef GL_OBJECT_ACTIVE_UNIFORMS_ARB
#define GL_OBJECT_ACTIVE_UNIFORMS_ARB 0x8B86
#endif

#ifndef GL_FLOAT_VEC2_ARB
#define GL_FLOAT_VEC2_ARB 0x8B50
#endif

#ifndef GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB
#define GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB 0x8B87
#endif

#ifndef GL_OBJECT_SHADER_SOURCE_LENGTH_ARB
#define GL_OBJECT_SHADER_SOURCE_LENGTH_ARB 0x8B88
#endif

#ifndef GL_SAMPLER_1D_ARB
#define GL_SAMPLER_1D_ARB 0x8B5D
#endif

#ifndef GL_SAMPLER_CUBE_ARB
#define GL_SAMPLER_CUBE_ARB 0x8B60
#endif

#ifndef GL_FLOAT_MAT2_ARB
#define GL_FLOAT_MAT2_ARB 0x8B5A
#endif

#ifndef GL_BOOL_VEC4_ARB
#define GL_BOOL_VEC4_ARB 0x8B59
#endif

#ifndef GL_SHADER_OBJECT_ARB
#define GL_SHADER_OBJECT_ARB 0x8B48
#endif

#ifndef GL_BOOL_VEC3_ARB
#define GL_BOOL_VEC3_ARB 0x8B58
#endif

#ifndef TYPE_GLHANDLEARB_DEFINED
typedef unsigned int GLhandleARB;
#endif
#ifndef TYPE_GLCHARARB_DEFINED
typedef char GLcharARB;
#endif
typedef GLhandleARB (NIV_CALL_TYPE * nivenGLGETHANDLEARB) (GLenum pname);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM3FVARB) (GLint location, GLsizei count, const GLfloat* value);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM4IARB) (GLint location, GLint v0, GLint v1, GLint v2, GLint v3);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM2FARB) (GLint location, GLfloat v0, GLfloat v1);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM3FARB) (GLint location, GLfloat v0, GLfloat v1, GLfloat v2);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM1IARB) (GLint location, GLint v0);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM1FVARB) (GLint location, GLsizei count, const GLfloat* value);
typedef void (NIV_CALL_TYPE * nivenGLVALIDATEPROGRAMARB) (GLhandleARB programObj);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM3IARB) (GLint location, GLint v0, GLint v1, GLint v2);
typedef void (NIV_CALL_TYPE * nivenGLDELETEOBJECTARB) (GLhandleARB obj);
typedef void (NIV_CALL_TYPE * nivenGLCOMPILESHADERARB) (GLhandleARB shaderObj);
typedef void (NIV_CALL_TYPE * nivenGLGETOBJECTPARAMETERFVARB) (GLhandleARB obj, GLenum pname, GLfloat* params);
typedef GLint (NIV_CALL_TYPE * nivenGLGETUNIFORMLOCATIONARB) (GLhandleARB programObj, const GLcharARB* name);
typedef GLhandleARB (NIV_CALL_TYPE * nivenGLCREATEPROGRAMOBJECTARB) (void );
typedef void (NIV_CALL_TYPE * nivenGLGETSHADERSOURCEARB) (GLhandleARB obj, GLsizei maxLength, GLsizei* length, GLcharARB* source);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM2IVARB) (GLint location, GLsizei count, const GLint* value);
typedef void (NIV_CALL_TYPE * nivenGLUSEPROGRAMOBJECTARB) (GLhandleARB programObj);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORMMATRIX2FVARB) (GLint location, GLsizei count, GLboolean transpose, const GLfloat* value);
typedef void (NIV_CALL_TYPE * nivenGLLINKPROGRAMARB) (GLhandleARB programObj);
typedef void (NIV_CALL_TYPE * nivenGLGETUNIFORMFVARB) (GLhandleARB programObj, GLint location, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM1IVARB) (GLint location, GLsizei count, const GLint* value);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM2IARB) (GLint location, GLint v0, GLint v1);
typedef void (NIV_CALL_TYPE * nivenGLATTACHOBJECTARB) (GLhandleARB containerObj, GLhandleARB obj);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORMMATRIX3FVARB) (GLint location, GLsizei count, GLboolean transpose, const GLfloat* value);
typedef GLhandleARB (NIV_CALL_TYPE * nivenGLCREATESHADEROBJECTARB) (GLenum shaderType);
typedef void (NIV_CALL_TYPE * nivenGLGETATTACHEDOBJECTSARB) (GLhandleARB containerObj, GLsizei maxCount, GLsizei* count, GLhandleARB* obj);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM4FARB) (GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM4IVARB) (GLint location, GLsizei count, const GLint* value);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM3IVARB) (GLint location, GLsizei count, const GLint* value);
typedef void (NIV_CALL_TYPE * nivenGLGETUNIFORMIVARB) (GLhandleARB programObj, GLint location, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETACTIVEUNIFORMARB) (GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei* length, GLint* size, GLenum* type, GLcharARB* name);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORMMATRIX4FVARB) (GLint location, GLsizei count, GLboolean transpose, const GLfloat* value);
typedef void (NIV_CALL_TYPE * nivenGLGETOBJECTPARAMETERIVARB) (GLhandleARB obj, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM1FARB) (GLint location, GLfloat v0);
typedef void (NIV_CALL_TYPE * nivenGLDETACHOBJECTARB) (GLhandleARB containerObj, GLhandleARB attachedObj);
typedef void (NIV_CALL_TYPE * nivenGLSHADERSOURCEARB) (GLhandleARB shaderObj, GLsizei count, const GLcharARB* *string, const GLint* length);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM4FVARB) (GLint location, GLsizei count, const GLfloat* value);
typedef void (NIV_CALL_TYPE * nivenGLGETINFOLOGARB) (GLhandleARB obj, GLsizei maxLength, GLsizei* length, GLcharARB* infoLog);
typedef void (NIV_CALL_TYPE * nivenGLUNIFORM2FVARB) (GLint location, GLsizei count, const GLfloat* value);

// GL_EXT_framebuffer_object
#ifndef GL_FRAMEBUFFER_BINDING_EXT
#define GL_FRAMEBUFFER_BINDING_EXT 0x8CA6
#endif

#ifndef GL_RENDERBUFFER_HEIGHT_EXT
#define GL_RENDERBUFFER_HEIGHT_EXT 0x8D43
#endif

#ifndef GL_INVALID_FRAMEBUFFER_OPERATION_EXT
#define GL_INVALID_FRAMEBUFFER_OPERATION_EXT 0x0506
#endif

#ifndef GL_COLOR_ATTACHMENT8_EXT
#define GL_COLOR_ATTACHMENT8_EXT 0x8CE8
#endif

#ifndef GL_FRAMEBUFFER_STATUS_ERROR_EXT
#define GL_FRAMEBUFFER_STATUS_ERROR_EXT 0x8CDE
#endif

#ifndef GL_STENCIL_INDEX1_EXT
#define GL_STENCIL_INDEX1_EXT 0x8D46
#endif

#ifndef GL_COLOR_ATTACHMENT5_EXT
#define GL_COLOR_ATTACHMENT5_EXT 0x8CE5
#endif

#ifndef GL_STENCIL_INDEX4_EXT
#define GL_STENCIL_INDEX4_EXT 0x8D47
#endif

#ifndef GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT
#define GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT 0x8CD1
#endif

#ifndef GL_STENCIL_ATTACHMENT_EXT
#define GL_STENCIL_ATTACHMENT_EXT 0x8D20
#endif

#ifndef GL_RENDERBUFFER_EXT
#define GL_RENDERBUFFER_EXT 0x8D41
#endif

#ifndef GL_STENCIL_INDEX16_EXT
#define GL_STENCIL_INDEX16_EXT 0x8D49
#endif

#ifndef GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT
#define GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT 0x8CDA
#endif

#ifndef GL_COLOR_ATTACHMENT4_EXT
#define GL_COLOR_ATTACHMENT4_EXT 0x8CE4
#endif

#ifndef GL_COLOR_ATTACHMENT13_EXT
#define GL_COLOR_ATTACHMENT13_EXT 0x8CED
#endif

#ifndef GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT
#define GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT 0x8CD2
#endif

#ifndef GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT
#define GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT 0x8CD7
#endif

#ifndef GL_COLOR_ATTACHMENT10_EXT
#define GL_COLOR_ATTACHMENT10_EXT 0x8CEA
#endif

#ifndef GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT
#define GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT 0x8CDC
#endif

#ifndef GL_COLOR_ATTACHMENT1_EXT
#define GL_COLOR_ATTACHMENT1_EXT 0x8CE1
#endif

#ifndef GL_RENDERBUFFER_INTERNAL_FORMAT_EXT
#define GL_RENDERBUFFER_INTERNAL_FORMAT_EXT 0x8D44
#endif

#ifndef GL_STENCIL_INDEX_EXT
#define GL_STENCIL_INDEX_EXT 0x8D45
#endif

#ifndef GL_FRAMEBUFFER_EXT
#define GL_FRAMEBUFFER_EXT 0x8D40
#endif

#ifndef GL_COLOR_ATTACHMENT15_EXT
#define GL_COLOR_ATTACHMENT15_EXT 0x8CEF
#endif

#ifndef GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT
#define GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT 0x8CD4
#endif

#ifndef GL_COLOR_ATTACHMENT12_EXT
#define GL_COLOR_ATTACHMENT12_EXT 0x8CEC
#endif

#ifndef GL_COLOR_ATTACHMENT0_EXT
#define GL_COLOR_ATTACHMENT0_EXT 0x8CE0
#endif

#ifndef GL_FRAMEBUFFER_COMPLETE_EXT
#define GL_FRAMEBUFFER_COMPLETE_EXT 0x8CD5
#endif

#ifndef GL_FRAMEBUFFER_INCOMPLETE_DUPLICATE_ATTACHMENT_EXT
#define GL_FRAMEBUFFER_INCOMPLETE_DUPLICATE_ATTACHMENT_EXT 0x8CD8
#endif

#ifndef GL_DEPTH_ATTACHMENT_EXT
#define GL_DEPTH_ATTACHMENT_EXT 0x8D00
#endif

#ifndef GL_COLOR_ATTACHMENT6_EXT
#define GL_COLOR_ATTACHMENT6_EXT 0x8CE6
#endif

#ifndef GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT
#define GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT 0x8CD6
#endif

#ifndef GL_COLOR_ATTACHMENT3_EXT
#define GL_COLOR_ATTACHMENT3_EXT 0x8CE3
#endif

#ifndef GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT
#define GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT 0x8CD3
#endif

#ifndef GL_STENCIL_INDEX8_EXT
#define GL_STENCIL_INDEX8_EXT 0x8D48
#endif

#ifndef GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT
#define GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT 0x8CD9
#endif

#ifndef GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT
#define GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT 0x8CD0
#endif

#ifndef GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT
#define GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT 0x8CDB
#endif

#ifndef GL_COLOR_ATTACHMENT2_EXT
#define GL_COLOR_ATTACHMENT2_EXT 0x8CE2
#endif

#ifndef GL_COLOR_ATTACHMENT14_EXT
#define GL_COLOR_ATTACHMENT14_EXT 0x8CEE
#endif

#ifndef GL_RENDERBUFFER_WIDTH_EXT
#define GL_RENDERBUFFER_WIDTH_EXT 0x8D42
#endif

#ifndef GL_MAX_RENDERBUFFER_SIZE_EXT
#define GL_MAX_RENDERBUFFER_SIZE_EXT 0x84E8
#endif

#ifndef GL_RENDERBUFFER_BINDING_EXT
#define GL_RENDERBUFFER_BINDING_EXT 0x8CA7
#endif

#ifndef GL_COLOR_ATTACHMENT9_EXT
#define GL_COLOR_ATTACHMENT9_EXT 0x8CE9
#endif

#ifndef GL_MAX_COLOR_ATTACHMENTS_EXT
#define GL_MAX_COLOR_ATTACHMENTS_EXT 0x8CDF
#endif

#ifndef GL_COLOR_ATTACHMENT7_EXT
#define GL_COLOR_ATTACHMENT7_EXT 0x8CE7
#endif

#ifndef GL_COLOR_ATTACHMENT11_EXT
#define GL_COLOR_ATTACHMENT11_EXT 0x8CEB
#endif

#ifndef GL_FRAMEBUFFER_UNSUPPORTED_EXT
#define GL_FRAMEBUFFER_UNSUPPORTED_EXT 0x8CDD
#endif

typedef GLenum (NIV_CALL_TYPE * nivenGLCHECKFRAMEBUFFERSTATUSEXT) (GLenum target);
typedef void (NIV_CALL_TYPE * nivenGLDELETERENDERBUFFERSEXT) (GLsizei n, const GLuint* renderbuffers);
typedef void (NIV_CALL_TYPE * nivenGLFRAMEBUFFERTEXTURE1DEXT) (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
typedef void (NIV_CALL_TYPE * nivenGLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXT) (GLenum target, GLenum attachment, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAMEBUFFERTEXTURE2DEXT) (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
typedef void (NIV_CALL_TYPE * nivenGLGENRENDERBUFFERSEXT) (GLsizei n, GLuint* renderbuffers);
typedef void (NIV_CALL_TYPE * nivenGLGENFRAMEBUFFERSEXT) (GLsizei n, GLuint* framebuffers);
typedef void (NIV_CALL_TYPE * nivenGLDELETEFRAMEBUFFERSEXT) (GLsizei n, const GLuint* framebuffers);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISFRAMEBUFFEREXT) (GLuint framebuffer);
typedef void (NIV_CALL_TYPE * nivenGLFRAMEBUFFERTEXTURE3DEXT) (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISRENDERBUFFEREXT) (GLuint renderbuffer);
typedef void (NIV_CALL_TYPE * nivenGLFRAMEBUFFERRENDERBUFFEREXT) (GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
typedef void (NIV_CALL_TYPE * nivenGLGENERATEMIPMAPEXT) (GLenum target);
typedef void (NIV_CALL_TYPE * nivenGLBINDFRAMEBUFFEREXT) (GLenum target, GLuint framebuffer);
typedef void (NIV_CALL_TYPE * nivenGLGETRENDERBUFFERPARAMETERIVEXT) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLBINDRENDERBUFFEREXT) (GLenum target, GLuint renderbuffer);
typedef void (NIV_CALL_TYPE * nivenGLRENDERBUFFERSTORAGEEXT) (GLenum target, GLenum internalformat, GLsizei width, GLsizei height);

// WGL_I3D_gamma
#ifdef WIN32
#ifndef WGL_GAMMA_TABLE_SIZE_I3D
#define WGL_GAMMA_TABLE_SIZE_I3D 0x204E
#endif

#ifndef WGL_GAMMA_EXCLUDE_DESKTOP_I3D
#define WGL_GAMMA_EXCLUDE_DESKTOP_I3D 0x204F
#endif

typedef BOOL (NIV_CALL_TYPE * nivenWGLGETGAMMATABLEPARAMETERSI3D) (HDC hDC, int iAttribute, int* piValue);
typedef BOOL (NIV_CALL_TYPE * nivenWGLGETGAMMATABLEI3D) (HDC hDC, int iEntries, USHORT* puRed, USHORT* puGreen, USHORT* puBlue);
typedef BOOL (NIV_CALL_TYPE * nivenWGLSETGAMMATABLEPARAMETERSI3D) (HDC hDC, int iAttribute, const int* piValue);
typedef BOOL (NIV_CALL_TYPE * nivenWGLSETGAMMATABLEI3D) (HDC hDC, int iEntries, const USHORT* puRed, const USHORT* puGreen, const USHORT* puBlue);
#endif
// GL_ATI_vertex_streams
#ifndef GL_VERTEX_STREAM7_ATI
#define GL_VERTEX_STREAM7_ATI 0x8774
#endif

#ifndef GL_VERTEX_STREAM6_ATI
#define GL_VERTEX_STREAM6_ATI 0x8773
#endif

#ifndef GL_VERTEX_STREAM2_ATI
#define GL_VERTEX_STREAM2_ATI 0x876F
#endif

#ifndef GL_VERTEX_STREAM5_ATI
#define GL_VERTEX_STREAM5_ATI 0x8772
#endif

#ifndef GL_VERTEX_SOURCE_ATI
#define GL_VERTEX_SOURCE_ATI 0x876C
#endif

#ifndef GL_VERTEX_STREAM0_ATI
#define GL_VERTEX_STREAM0_ATI 0x876D
#endif

#ifndef GL_VERTEX_STREAM3_ATI
#define GL_VERTEX_STREAM3_ATI 0x8770
#endif

#ifndef GL_MAX_VERTEX_STREAMS_ATI
#define GL_MAX_VERTEX_STREAMS_ATI 0x876B
#endif

#ifndef GL_VERTEX_STREAM4_ATI
#define GL_VERTEX_STREAM4_ATI 0x8771
#endif

#ifndef GL_VERTEX_STREAM1_ATI
#define GL_VERTEX_STREAM1_ATI 0x876E
#endif

typedef void (NIV_CALL_TYPE * nivenGLNORMALSTREAM3BVATI) (GLenum stream, const GLbyte* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM2DATI) (GLenum stream, GLdouble x, GLdouble y);
typedef void (NIV_CALL_TYPE * nivenGLNORMALSTREAM3SATI) (GLenum stream, GLshort x, GLshort y, GLshort z);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM2IVATI) (GLenum stream, const GLint* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM3DVATI) (GLenum stream, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM3SVATI) (GLenum stream, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM3SATI) (GLenum stream, GLshort x, GLshort y, GLshort z);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM4IATI) (GLenum stream, GLint x, GLint y, GLint z, GLint w);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM3FATI) (GLenum stream, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM2SVATI) (GLenum stream, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLNORMALSTREAM3DVATI) (GLenum stream, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM2SATI) (GLenum stream, GLshort x, GLshort y);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM4IVATI) (GLenum stream, const GLint* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM3IVATI) (GLenum stream, const GLint* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM3IATI) (GLenum stream, GLint x, GLint y, GLint z);
typedef void (NIV_CALL_TYPE * nivenGLNORMALSTREAM3BATI) (GLenum stream, GLbyte x, GLbyte y, GLbyte z);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM3FVATI) (GLenum stream, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM2DVATI) (GLenum stream, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM2FVATI) (GLenum stream, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLNORMALSTREAM3IATI) (GLenum stream, GLint x, GLint y, GLint z);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM3DATI) (GLenum stream, GLdouble x, GLdouble y, GLdouble z);
typedef void (NIV_CALL_TYPE * nivenGLNORMALSTREAM3FATI) (GLenum stream, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM4FVATI) (GLenum stream, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLNORMALSTREAM3FVATI) (GLenum stream, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXBLENDENVFATI) (GLenum pname, GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLNORMALSTREAM3DATI) (GLenum stream, GLdouble x, GLdouble y, GLdouble z);
typedef void (NIV_CALL_TYPE * nivenGLNORMALSTREAM3IVATI) (GLenum stream, const GLint* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM4FATI) (GLenum stream, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXBLENDENVIATI) (GLenum pname, GLint param);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM4DVATI) (GLenum stream, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM4SVATI) (GLenum stream, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM2IATI) (GLenum stream, GLint x, GLint y);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM2FATI) (GLenum stream, GLfloat x, GLfloat y);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM4SATI) (GLenum stream, GLshort x, GLshort y, GLshort z, GLshort w);
typedef void (NIV_CALL_TYPE * nivenGLNORMALSTREAM3SVATI) (GLenum stream, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXSTREAM4DATI) (GLenum stream, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
typedef void (NIV_CALL_TYPE * nivenGLCLIENTACTIVEVERTEXSTREAMATI) (GLenum stream);

// GL_APPLE_ycbcr_422
#ifndef GL_UNSIGNED_SHORT_8_8_APPLE
#define GL_UNSIGNED_SHORT_8_8_APPLE 0x85BA
#endif

#ifndef GL_YCBCR_422_APPLE
#define GL_YCBCR_422_APPLE 0x85B9
#endif

#ifndef GL_UNSIGNED_SHORT_8_8_REV_APPLE
#define GL_UNSIGNED_SHORT_8_8_REV_APPLE 0x85BB
#endif


// GL_NV_blend_square

// GL_MESA_window_pos
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS4IMESA) (GLint x, GLint y, GLint z, GLint w);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3IMESA) (GLint x, GLint y, GLint z);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2IVMESA) (const GLint* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2DMESA) (GLdouble x, GLdouble y);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3DMESA) (GLdouble x, GLdouble y, GLdouble z);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3IVMESA) (const GLint* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS4DMESA) (GLdouble x, GLdouble y, GLdouble z, GLdouble );
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3FVMESA) (const GLfloat* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2FVMESA) (const GLfloat* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3SMESA) (GLshort x, GLshort y, GLshort z);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2SMESA) (GLshort x, GLshort y);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3FMESA) (GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3SVMESA) (const GLshort* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS4IVMESA) (const GLint* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS4SVMESA) (const GLshort* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3DVMESA) (const GLdouble* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS4FMESA) (GLfloat x, GLfloat y, GLfloat z, GLfloat w);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS4DVMESA) (const GLdouble* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2FMESA) (GLfloat x, GLfloat y);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS4SMESA) (GLshort x, GLshort y, GLshort z, GLshort w);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2SVMESA) (const GLshort* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2IMESA) (GLint x, GLint y);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS4FVMESA) (const GLfloat* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2DVMESA) (const GLdouble* p);

// GL_ATI_envmap_bumpmap
#ifndef GL_BUMP_ROT_MATRIX_SIZE_ATI
#define GL_BUMP_ROT_MATRIX_SIZE_ATI 0x8776
#endif

#ifndef GL_BUMP_TEX_UNITS_ATI
#define GL_BUMP_TEX_UNITS_ATI 0x8778
#endif

#ifndef GL_DU8DV8_ATI
#define GL_DU8DV8_ATI 0x877A
#endif

#ifndef GL_BUMP_ENVMAP_ATI
#define GL_BUMP_ENVMAP_ATI 0x877B
#endif

#ifndef GL_BUMP_TARGET_ATI
#define GL_BUMP_TARGET_ATI 0x877C
#endif

#ifndef GL_DUDV_ATI
#define GL_DUDV_ATI 0x8779
#endif

#ifndef GL_BUMP_NUM_TEX_UNITS_ATI
#define GL_BUMP_NUM_TEX_UNITS_ATI 0x8777
#endif

#ifndef GL_BUMP_ROT_MATRIX_ATI
#define GL_BUMP_ROT_MATRIX_ATI 0x8775
#endif

typedef void (NIV_CALL_TYPE * nivenGLTEXBUMPPARAMETERFVATI) (GLenum pname, GLfloat* param);
typedef void (NIV_CALL_TYPE * nivenGLTEXBUMPPARAMETERIVATI) (GLenum pname, GLint* param);
typedef void (NIV_CALL_TYPE * nivenGLGETTEXBUMPPARAMETERIVATI) (GLenum pname, GLint* param);
typedef void (NIV_CALL_TYPE * nivenGLGETTEXBUMPPARAMETERFVATI) (GLenum pname, GLfloat* param);

// GL_ARB_texture_non_power_of_two

// GL_EXT_texture_env_combine
#ifndef GL_OPERAND0_RGB_EXT
#define GL_OPERAND0_RGB_EXT 0x8590
#endif

#ifndef GL_OPERAND1_ALPHA_EXT
#define GL_OPERAND1_ALPHA_EXT 0x8599
#endif

#ifndef GL_SOURCE1_RGB_EXT
#define GL_SOURCE1_RGB_EXT 0x8581
#endif

#ifndef GL_OPERAND2_ALPHA_EXT
#define GL_OPERAND2_ALPHA_EXT 0x859A
#endif

#ifndef GL_PREVIOUS_EXT
#define GL_PREVIOUS_EXT 0x8578
#endif

#ifndef GL_ADD_SIGNED_EXT
#define GL_ADD_SIGNED_EXT 0x8574
#endif

#ifndef GL_COMBINE_EXT
#define GL_COMBINE_EXT 0x8570
#endif

#ifndef GL_OPERAND1_RGB_EXT
#define GL_OPERAND1_RGB_EXT 0x8591
#endif

#ifndef GL_OPERAND2_RGB_EXT
#define GL_OPERAND2_RGB_EXT 0x8592
#endif

#ifndef GL_RGB_SCALE_EXT
#define GL_RGB_SCALE_EXT 0x8573
#endif

#ifndef GL_SOURCE0_ALPHA_EXT
#define GL_SOURCE0_ALPHA_EXT 0x8588
#endif

#ifndef GL_COMBINE_RGB_EXT
#define GL_COMBINE_RGB_EXT 0x8571
#endif

#ifndef GL_CONSTANT_EXT
#define GL_CONSTANT_EXT 0x8576
#endif

#ifndef GL_SOURCE2_RGB_EXT
#define GL_SOURCE2_RGB_EXT 0x8582
#endif

#ifndef GL_PRIMARY_COLOR_EXT
#define GL_PRIMARY_COLOR_EXT 0x8577
#endif

#ifndef GL_SOURCE1_ALPHA_EXT
#define GL_SOURCE1_ALPHA_EXT 0x8589
#endif

#ifndef GL_OPERAND0_ALPHA_EXT
#define GL_OPERAND0_ALPHA_EXT 0x8598
#endif

#ifndef GL_SOURCE0_RGB_EXT
#define GL_SOURCE0_RGB_EXT 0x8580
#endif

#ifndef GL_SOURCE2_ALPHA_EXT
#define GL_SOURCE2_ALPHA_EXT 0x858A
#endif

#ifndef GL_COMBINE_ALPHA_EXT
#define GL_COMBINE_ALPHA_EXT 0x8572
#endif

#ifndef GL_INTERPOLATE_EXT
#define GL_INTERPOLATE_EXT 0x8575
#endif


// GL_EXT_texture_object
#ifndef GL_TEXTURE_RESIDENT_EXT
#define GL_TEXTURE_RESIDENT_EXT 0x8067
#endif

#ifndef GL_TEXTURE_2D_BINDING_EXT
#define GL_TEXTURE_2D_BINDING_EXT 0x8069
#endif

#ifndef GL_TEXTURE_3D_BINDING_EXT
#define GL_TEXTURE_3D_BINDING_EXT 0x806A
#endif

#ifndef GL_TEXTURE_PRIORITY_EXT
#define GL_TEXTURE_PRIORITY_EXT 0x8066
#endif

#ifndef GL_TEXTURE_1D_BINDING_EXT
#define GL_TEXTURE_1D_BINDING_EXT 0x8068
#endif

typedef void (NIV_CALL_TYPE * nivenGLBINDTEXTUREEXT) (GLenum target, GLuint texture);
typedef void (NIV_CALL_TYPE * nivenGLPRIORITIZETEXTURESEXT) (GLsizei n, const GLuint* textures, const GLclampf* priorities);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISTEXTUREEXT) (GLuint texture);
typedef void (NIV_CALL_TYPE * nivenGLDELETETEXTURESEXT) (GLsizei n, const GLuint* textures);
typedef void (NIV_CALL_TYPE * nivenGLGENTEXTURESEXT) (GLsizei n, GLuint* textures);
typedef GLboolean (NIV_CALL_TYPE * nivenGLARETEXTURESRESIDENTEXT) (GLsizei n, const GLuint* textures, GLboolean* residences);

// GL_ATI_texture_compression_3dc
#ifndef GL_COMPRESSED_RGB_3DC_ATI
#define GL_COMPRESSED_RGB_3DC_ATI 0x8837
#endif


// GL_OML_subsample
#ifndef GL_FORMAT_SUBSAMPLE_244_244_OML
#define GL_FORMAT_SUBSAMPLE_244_244_OML 0x8983
#endif

#ifndef GL_FORMAT_SUBSAMPLE_24_24_OML
#define GL_FORMAT_SUBSAMPLE_24_24_OML 0x8982
#endif


// GL_EXT_texture_lod_bias
#ifndef GL_TEXTURE_LOD_BIAS_EXT
#define GL_TEXTURE_LOD_BIAS_EXT 0x8501
#endif

#ifndef GL_TEXTURE_FILTER_CONTROL_EXT
#define GL_TEXTURE_FILTER_CONTROL_EXT 0x8500
#endif

#ifndef GL_MAX_TEXTURE_LOD_BIAS_EXT
#define GL_MAX_TEXTURE_LOD_BIAS_EXT 0x84FD
#endif


// WGL_ARB_pixel_format_float
#ifdef WIN32
#ifndef WGL_TYPE_RGBA_FLOAT_ARB
#define WGL_TYPE_RGBA_FLOAT_ARB 0x21A0
#endif

#endif
// GL_EXT_scene_marker
typedef void (NIV_CALL_TYPE * nivenGLBEGINSCENEEXT) (void );
typedef void (NIV_CALL_TYPE * nivenGLENDSCENEEXT) (void );

// GL_NV_primitive_restart
#ifndef GL_PRIMITIVE_RESTART_INDEX_NV
#define GL_PRIMITIVE_RESTART_INDEX_NV 0x8559
#endif

#ifndef GL_PRIMITIVE_RESTART_NV
#define GL_PRIMITIVE_RESTART_NV 0x8558
#endif

typedef void (NIV_CALL_TYPE * nivenGLPRIMITIVERESTARTINDEXNV) (GLuint index);
typedef void (NIV_CALL_TYPE * nivenGLPRIMITIVERESTARTNV) (void );

// GL_ARB_shadow_ambient
#ifndef GL_TEXTURE_COMPARE_FAIL_VALUE_ARB
#define GL_TEXTURE_COMPARE_FAIL_VALUE_ARB 0x80BF
#endif


// GL_SGIX_vertex_preclip_hint

#ifdef _GLX
// GLX_MESA_pixmap_colormap
typedef GLXPixmap (NIV_CALL_TYPE * nivenGLXCREATEGLXPIXMAPMESA) (Display* dpy, XVisualInfo* visual, Pixmap pixmap, Colormap cmap);
#endif // _GLX
// GL_EXT_pixel_buffer_object
#ifndef GL_PIXEL_PACK_BUFFER_EXT
#define GL_PIXEL_PACK_BUFFER_EXT 0x88EB
#endif

#ifndef GL_PIXEL_PACK_BUFFER_BINDING_EXT
#define GL_PIXEL_PACK_BUFFER_BINDING_EXT 0x88ED
#endif

#ifndef GL_PIXEL_UNPACK_BUFFER_EXT
#define GL_PIXEL_UNPACK_BUFFER_EXT 0x88EC
#endif

#ifndef GL_PIXEL_UNPACK_BUFFER_BINDING_EXT
#define GL_PIXEL_UNPACK_BUFFER_BINDING_EXT 0x88EF
#endif


// GL_EXT_abgr
#ifndef GL_ABGR_EXT
#define GL_ABGR_EXT 0x8000
#endif


// GL_NV_vertex_program
#ifndef GL_MAP2_VERTEX_ATTRIB9_4_NV
#define GL_MAP2_VERTEX_ATTRIB9_4_NV 0x8679
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB12_4_NV
#define GL_MAP1_VERTEX_ATTRIB12_4_NV 0x866C
#endif

#ifndef GL_CURRENT_MATRIX_STACK_DEPTH_NV
#define GL_CURRENT_MATRIX_STACK_DEPTH_NV 0x8640
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB2_4_NV
#define GL_MAP1_VERTEX_ATTRIB2_4_NV 0x8662
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB5_4_NV
#define GL_MAP2_VERTEX_ATTRIB5_4_NV 0x8675
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB8_4_NV
#define GL_MAP1_VERTEX_ATTRIB8_4_NV 0x8668
#endif

#ifndef GL_ATTRIB_ARRAY_SIZE_NV
#define GL_ATTRIB_ARRAY_SIZE_NV 0x8623
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB1_4_NV
#define GL_MAP1_VERTEX_ATTRIB1_4_NV 0x8661
#endif

#ifndef GL_ATTRIB_ARRAY_STRIDE_NV
#define GL_ATTRIB_ARRAY_STRIDE_NV 0x8624
#endif

#ifndef GL_VERTEX_STATE_PROGRAM_NV
#define GL_VERTEX_STATE_PROGRAM_NV 0x8621
#endif

#ifndef GL_PROGRAM_TARGET_NV
#define GL_PROGRAM_TARGET_NV 0x8646
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY9_NV
#define GL_VERTEX_ATTRIB_ARRAY9_NV 0x8659
#endif

#ifndef GL_CURRENT_MATRIX_NV
#define GL_CURRENT_MATRIX_NV 0x8641
#endif

#ifndef GL_MATRIX0_NV
#define GL_MATRIX0_NV 0x8630
#endif

#ifndef GL_PROGRAM_RESIDENT_NV
#define GL_PROGRAM_RESIDENT_NV 0x8647
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY14_NV
#define GL_VERTEX_ATTRIB_ARRAY14_NV 0x865E
#endif

#ifndef GL_PROGRAM_LENGTH_NV
#define GL_PROGRAM_LENGTH_NV 0x8627
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB11_4_NV
#define GL_MAP1_VERTEX_ATTRIB11_4_NV 0x866B
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY6_NV
#define GL_VERTEX_ATTRIB_ARRAY6_NV 0x8656
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB7_4_NV
#define GL_MAP2_VERTEX_ATTRIB7_4_NV 0x8677
#endif

#ifndef GL_IDENTITY_NV
#define GL_IDENTITY_NV 0x862A
#endif

#ifndef GL_MAX_TRACK_MATRICES_NV
#define GL_MAX_TRACK_MATRICES_NV 0x862F
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB14_4_NV
#define GL_MAP2_VERTEX_ATTRIB14_4_NV 0x867E
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY11_NV
#define GL_VERTEX_ATTRIB_ARRAY11_NV 0x865B
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB4_4_NV
#define GL_MAP2_VERTEX_ATTRIB4_4_NV 0x8674
#endif

#ifndef GL_VERTEX_PROGRAM_TWO_SIDE_NV
#define GL_VERTEX_PROGRAM_TWO_SIDE_NV 0x8643
#endif

#ifndef GL_ATTRIB_ARRAY_POINTER_NV
#define GL_ATTRIB_ARRAY_POINTER_NV 0x8645
#endif

#ifndef GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV
#define GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV 0x862E
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY12_NV
#define GL_VERTEX_ATTRIB_ARRAY12_NV 0x865C
#endif

#ifndef GL_INVERSE_TRANSPOSE_NV
#define GL_INVERSE_TRANSPOSE_NV 0x862D
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB14_4_NV
#define GL_MAP1_VERTEX_ATTRIB14_4_NV 0x866E
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB15_4_NV
#define GL_MAP1_VERTEX_ATTRIB15_4_NV 0x866F
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB0_4_NV
#define GL_MAP1_VERTEX_ATTRIB0_4_NV 0x8660
#endif

#ifndef GL_CURRENT_ATTRIB_NV
#define GL_CURRENT_ATTRIB_NV 0x8626
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB8_4_NV
#define GL_MAP2_VERTEX_ATTRIB8_4_NV 0x8678
#endif

#ifndef GL_VERTEX_PROGRAM_POINT_SIZE_NV
#define GL_VERTEX_PROGRAM_POINT_SIZE_NV 0x8642
#endif

#ifndef GL_PROGRAM_ERROR_POSITION_NV
#define GL_PROGRAM_ERROR_POSITION_NV 0x864B
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB5_4_NV
#define GL_MAP1_VERTEX_ATTRIB5_4_NV 0x8665
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB10_4_NV
#define GL_MAP1_VERTEX_ATTRIB10_4_NV 0x866A
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB3_4_NV
#define GL_MAP2_VERTEX_ATTRIB3_4_NV 0x8673
#endif

#ifndef GL_MATRIX1_NV
#define GL_MATRIX1_NV 0x8631
#endif

#ifndef GL_MATRIX6_NV
#define GL_MATRIX6_NV 0x8636
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB9_4_NV
#define GL_MAP1_VERTEX_ATTRIB9_4_NV 0x8669
#endif

#ifndef GL_TRANSPOSE_NV
#define GL_TRANSPOSE_NV 0x862C
#endif

#ifndef GL_PROGRAM_STRING_NV
#define GL_PROGRAM_STRING_NV 0x8628
#endif

#ifndef GL_ATTRIB_ARRAY_TYPE_NV
#define GL_ATTRIB_ARRAY_TYPE_NV 0x8625
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB4_4_NV
#define GL_MAP1_VERTEX_ATTRIB4_4_NV 0x8664
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB0_4_NV
#define GL_MAP2_VERTEX_ATTRIB0_4_NV 0x8670
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY3_NV
#define GL_VERTEX_ATTRIB_ARRAY3_NV 0x8653
#endif

#ifndef GL_INVERSE_NV
#define GL_INVERSE_NV 0x862B
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY5_NV
#define GL_VERTEX_ATTRIB_ARRAY5_NV 0x8655
#endif

#ifndef GL_MATRIX7_NV
#define GL_MATRIX7_NV 0x8637
#endif

#ifndef GL_MATRIX4_NV
#define GL_MATRIX4_NV 0x8634
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB2_4_NV
#define GL_MAP2_VERTEX_ATTRIB2_4_NV 0x8672
#endif

#ifndef GL_PROGRAM_PARAMETER_NV
#define GL_PROGRAM_PARAMETER_NV 0x8644
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB7_4_NV
#define GL_MAP1_VERTEX_ATTRIB7_4_NV 0x8667
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB15_4_NV
#define GL_MAP2_VERTEX_ATTRIB15_4_NV 0x867F
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY10_NV
#define GL_VERTEX_ATTRIB_ARRAY10_NV 0x865A
#endif

#ifndef GL_TRACK_MATRIX_TRANSFORM_NV
#define GL_TRACK_MATRIX_TRANSFORM_NV 0x8649
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY4_NV
#define GL_VERTEX_ATTRIB_ARRAY4_NV 0x8654
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY7_NV
#define GL_VERTEX_ATTRIB_ARRAY7_NV 0x8657
#endif

#ifndef GL_MATRIX3_NV
#define GL_MATRIX3_NV 0x8633
#endif

#ifndef GL_MODELVIEW_PROJECTION_NV
#define GL_MODELVIEW_PROJECTION_NV 0x8629
#endif

#ifndef GL_MATRIX5_NV
#define GL_MATRIX5_NV 0x8635
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB10_4_NV
#define GL_MAP2_VERTEX_ATTRIB10_4_NV 0x867A
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB13_4_NV
#define GL_MAP2_VERTEX_ATTRIB13_4_NV 0x867D
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB11_4_NV
#define GL_MAP2_VERTEX_ATTRIB11_4_NV 0x867B
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY13_NV
#define GL_VERTEX_ATTRIB_ARRAY13_NV 0x865D
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB1_4_NV
#define GL_MAP2_VERTEX_ATTRIB1_4_NV 0x8671
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY0_NV
#define GL_VERTEX_ATTRIB_ARRAY0_NV 0x8650
#endif

#ifndef GL_MATRIX2_NV
#define GL_MATRIX2_NV 0x8632
#endif

#ifndef GL_TRACK_MATRIX_NV
#define GL_TRACK_MATRIX_NV 0x8648
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY2_NV
#define GL_VERTEX_ATTRIB_ARRAY2_NV 0x8652
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB13_4_NV
#define GL_MAP1_VERTEX_ATTRIB13_4_NV 0x866D
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB6_4_NV
#define GL_MAP1_VERTEX_ATTRIB6_4_NV 0x8666
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB6_4_NV
#define GL_MAP2_VERTEX_ATTRIB6_4_NV 0x8676
#endif

#ifndef GL_MAP2_VERTEX_ATTRIB12_4_NV
#define GL_MAP2_VERTEX_ATTRIB12_4_NV 0x867C
#endif

#ifndef GL_VERTEX_PROGRAM_BINDING_NV
#define GL_VERTEX_PROGRAM_BINDING_NV 0x864A
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY8_NV
#define GL_VERTEX_ATTRIB_ARRAY8_NV 0x8658
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY15_NV
#define GL_VERTEX_ATTRIB_ARRAY15_NV 0x865F
#endif

#ifndef GL_VERTEX_ATTRIB_ARRAY1_NV
#define GL_VERTEX_ATTRIB_ARRAY1_NV 0x8651
#endif

#ifndef GL_VERTEX_PROGRAM_NV
#define GL_VERTEX_PROGRAM_NV 0x8620
#endif

#ifndef GL_MAP1_VERTEX_ATTRIB3_4_NV
#define GL_MAP1_VERTEX_ATTRIB3_4_NV 0x8663
#endif

typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS2FVNV) (GLuint index, GLsizei n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLTRACKMATRIXNV) (GLenum target, GLuint address, GLenum matrix, GLenum transform);
typedef void (NIV_CALL_TYPE * nivenGLBINDPROGRAMNV) (GLenum target, GLuint id);
typedef void (NIV_CALL_TYPE * nivenGLGETVERTEXATTRIBFVNV) (GLuint index, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3SNV) (GLuint index, GLshort x, GLshort y, GLshort z);
typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMPARAMETERDVNV) (GLenum target, GLuint index, GLenum pname, GLdouble* params);
typedef void (NIV_CALL_TYPE * nivenGLGETTRACKMATRIXIVNV) (GLenum target, GLuint address, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4FNV) (GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
typedef GLboolean (NIV_CALL_TYPE * nivenGLAREPROGRAMSRESIDENTNV) (GLsizei n, const GLuint* ids, GLboolean* residences);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1DNV) (GLuint index, GLdouble x);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS3DVNV) (GLuint index, GLsizei n, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLDELETEPROGRAMSNV) (GLsizei n, const GLuint* ids);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBPOINTERNV) (GLuint index, GLint size, GLenum type, GLsizei stride, const void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS1SVNV) (GLuint index, GLsizei n, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2DNV) (GLuint index, GLdouble x, GLdouble y);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3DNV) (GLuint index, GLdouble x, GLdouble y, GLdouble z);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1SVNV) (GLuint index, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS3SVNV) (GLuint index, GLsizei n, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS1DVNV) (GLuint index, GLsizei n, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS4FVNV) (GLuint index, GLsizei n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMPARAMETER4FNV) (GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMPARAMETERS4DVNV) (GLenum target, GLuint index, GLuint num, const GLdouble* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4UBNV) (GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w);
typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMIVNV) (GLuint id, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4SVNV) (GLuint index, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4FVNV) (GLuint index, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS4SVNV) (GLuint index, GLsizei n, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLLOADPROGRAMNV) (GLenum target, GLuint id, GLsizei len, const GLubyte* program);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1FVNV) (GLuint index, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLEXECUTEPROGRAMNV) (GLenum target, GLuint id, const GLfloat* params);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISPROGRAMNV) (GLuint id);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4DVNV) (GLuint index, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMPARAMETER4DNV) (GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2FNV) (GLuint index, GLfloat x, GLfloat y);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3FNV) (GLuint index, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1DVNV) (GLuint index, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1FNV) (GLuint index, GLfloat x);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2DVNV) (GLuint index, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS1FVNV) (GLuint index, GLsizei n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS2DVNV) (GLuint index, GLsizei n, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS2SVNV) (GLuint index, GLsizei n, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMPARAMETERFVNV) (GLenum target, GLuint index, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMSTRINGNV) (GLuint id, GLenum pname, GLubyte* program);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS3FVNV) (GLuint index, GLsizei n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4DNV) (GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4UBVNV) (GLuint index, const GLubyte* v);
typedef void (NIV_CALL_TYPE * nivenGLGENPROGRAMSNV) (GLsizei n, GLuint* ids);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB4SNV) (GLuint index, GLshort x, GLshort y, GLshort z, GLshort w);
typedef void (NIV_CALL_TYPE * nivenGLREQUESTRESIDENTPROGRAMSNV) (GLsizei n, GLuint* ids);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3FVNV) (GLuint index, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB1SNV) (GLuint index, GLshort x);
typedef void (NIV_CALL_TYPE * nivenGLGETVERTEXATTRIBIVNV) (GLuint index, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3SVNV) (GLuint index, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMPARAMETER4FVNV) (GLenum target, GLuint index, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS4UBVNV) (GLuint index, GLsizei n, const GLubyte* v);
typedef void (NIV_CALL_TYPE * nivenGLGETVERTEXATTRIBDVNV) (GLuint index, GLenum pname, GLdouble* params);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB3DVNV) (GLuint index, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2FVNV) (GLuint index, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2SNV) (GLuint index, GLshort x, GLshort y);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMPARAMETERS4FVNV) (GLenum target, GLuint index, GLuint num, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETVERTEXATTRIBPOINTERVNV) (GLuint index, GLenum pname, GLvoid* *pointer);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIBS4DVNV) (GLuint index, GLsizei n, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLVERTEXATTRIB2SVNV) (GLuint index, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMPARAMETER4DVNV) (GLenum target, GLuint index, const GLdouble* params);

// GL_SGIX_texture_multi_buffer
#ifndef GL_TEXTURE_MULTI_BUFFER_HINT_SGIX
#define GL_TEXTURE_MULTI_BUFFER_HINT_SGIX 0x812E
#endif


#ifdef _GLX
// GLX_SGIS_blended_overlay
#ifndef GLX_BLENDED_RGBA_SGIS
#define GLX_BLENDED_RGBA_SGIS 0x8025
#endif

#endif // _GLX
// GL_ARB_texture_rectangle
#ifndef GL_PROXY_TEXTURE_RECTANGLE_ARB
#define GL_PROXY_TEXTURE_RECTANGLE_ARB 0x84F7
#endif

#ifndef GL_TEXTURE_BINDING_RECTANGLE_ARB
#define GL_TEXTURE_BINDING_RECTANGLE_ARB 0x84F6
#endif

#ifndef GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB
#define GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB 0x84F8
#endif

#ifndef GL_TEXTURE_RECTANGLE_ARB
#define GL_TEXTURE_RECTANGLE_ARB 0x84F5
#endif


// GL_SGI_texture_color_table
#ifndef GL_TEXTURE_COLOR_TABLE_SGI
#define GL_TEXTURE_COLOR_TABLE_SGI 0x80BC
#endif

#ifndef GL_PROXY_TEXTURE_COLOR_TABLE_SGI
#define GL_PROXY_TEXTURE_COLOR_TABLE_SGI 0x80BD
#endif


#ifdef _GLX
// GLX_SGIX_visual_select_group
#ifndef GLX_VISUAL_SELECT_GROUP_SGIX
#define GLX_VISUAL_SELECT_GROUP_SGIX 0x8028
#endif

#endif // _GLX
// GL_SGIS_pixel_texture

// GL_ARB_multisample
#ifndef GL_SAMPLE_COVERAGE_ARB
#define GL_SAMPLE_COVERAGE_ARB 0x80A0
#endif

#ifndef GL_SAMPLE_COVERAGE_INVERT_ARB
#define GL_SAMPLE_COVERAGE_INVERT_ARB 0x80AB
#endif

#ifndef GL_MULTISAMPLE_ARB
#define GL_MULTISAMPLE_ARB 0x809D
#endif

#ifndef GL_SAMPLE_ALPHA_TO_COVERAGE_ARB
#define GL_SAMPLE_ALPHA_TO_COVERAGE_ARB 0x809E
#endif

#ifndef GL_SAMPLE_BUFFERS_ARB
#define GL_SAMPLE_BUFFERS_ARB 0x80A8
#endif

#ifndef GL_SAMPLE_COVERAGE_VALUE_ARB
#define GL_SAMPLE_COVERAGE_VALUE_ARB 0x80AA
#endif

#ifndef GL_MULTISAMPLE_BIT_ARB
#define GL_MULTISAMPLE_BIT_ARB 0x20000000
#endif

#ifndef GL_SAMPLE_ALPHA_TO_ONE_ARB
#define GL_SAMPLE_ALPHA_TO_ONE_ARB 0x809F
#endif

#ifndef GL_SAMPLES_ARB
#define GL_SAMPLES_ARB 0x80A9
#endif

typedef void (NIV_CALL_TYPE * nivenGLSAMPLECOVERAGEARB) (GLclampf value, GLboolean invert);

// GL_SGIS_generate_mipmap
#ifndef GL_GENERATE_MIPMAP_HINT_SGIS
#define GL_GENERATE_MIPMAP_HINT_SGIS 0x8192
#endif

#ifndef GL_GENERATE_MIPMAP_SGIS
#define GL_GENERATE_MIPMAP_SGIS 0x8191
#endif


#ifdef _GLX
// GLX_EXT_visual_rating
#ifndef GLX_VISUAL_CAVEAT_EXT
#define GLX_VISUAL_CAVEAT_EXT 0x20
#endif

#ifndef GLX_NON_CONFORMANT_VISUAL_EXT
#define GLX_NON_CONFORMANT_VISUAL_EXT 0x800D
#endif

#ifndef GLX_SLOW_VISUAL_EXT
#define GLX_SLOW_VISUAL_EXT 0x8001
#endif

#endif // _GLX
// GL_ATI_map_object_buffer
typedef void* (NIV_CALL_TYPE * nivenGLMAPOBJECTBUFFERATI) (GLuint buffer);
typedef void (NIV_CALL_TYPE * nivenGLUNMAPOBJECTBUFFERATI) (GLuint buffer);

// GL_EXT_texture_edge_clamp
#ifndef GL_CLAMP_TO_EDGE_EXT
#define GL_CLAMP_TO_EDGE_EXT 0x812F
#endif


#ifdef _GLX
// GLX_MESA_agp_offset
typedef unsigned int (NIV_CALL_TYPE * nivenGLXGETAGPOFFSETMESA) (const void* pointer);
#endif // _GLX
// GL_NV_light_max_exponent
#ifndef GL_MAX_SPOT_EXPONENT_NV
#define GL_MAX_SPOT_EXPONENT_NV 0x8505
#endif

#ifndef GL_MAX_SHININESS_NV
#define GL_MAX_SHININESS_NV 0x8504
#endif


// GL_EXT_blend_minmax
#ifndef GL_FUNC_ADD_EXT
#define GL_FUNC_ADD_EXT 0x8006
#endif

#ifndef GL_MAX_EXT
#define GL_MAX_EXT 0x8008
#endif

#ifndef GL_MIN_EXT
#define GL_MIN_EXT 0x8007
#endif

#ifndef GL_BLEND_EQUATION_EXT
#define GL_BLEND_EQUATION_EXT 0x8009
#endif

typedef void (NIV_CALL_TYPE * nivenGLBLENDEQUATIONEXT) (GLenum mode);

// GL_ARB_texture_float
#ifndef GL_ALPHA32F_ARB
#define GL_ALPHA32F_ARB 0x8816
#endif

#ifndef GL_TEXTURE_INTENSITY_TYPE_ARB
#define GL_TEXTURE_INTENSITY_TYPE_ARB 0x8C15
#endif

#ifndef GL_LUMINANCE32F_ARB
#define GL_LUMINANCE32F_ARB 0x8818
#endif

#ifndef GL_TEXTURE_BLUE_TYPE_ARB
#define GL_TEXTURE_BLUE_TYPE_ARB 0x8C12
#endif

#ifndef GL_UNSIGNED_NORMALIZED_ARB
#define GL_UNSIGNED_NORMALIZED_ARB 0x8C17
#endif

#ifndef GL_LUMINANCE16F_ARB
#define GL_LUMINANCE16F_ARB 0x881E
#endif

#ifndef GL_INTENSITY32F_ARB
#define GL_INTENSITY32F_ARB 0x8817
#endif

#ifndef GL_RGB16F_ARB
#define GL_RGB16F_ARB 0x881B
#endif

#ifndef GL_TEXTURE_DEPTH_TYPE_ARB
#define GL_TEXTURE_DEPTH_TYPE_ARB 0x8C16
#endif

#ifndef GL_RGBA16F_ARB
#define GL_RGBA16F_ARB 0x881A
#endif

#ifndef GL_LUMINANCE_ALPHA32F_ARB
#define GL_LUMINANCE_ALPHA32F_ARB 0x8819
#endif

#ifndef GL_RGB32F_ARB
#define GL_RGB32F_ARB 0x8815
#endif

#ifndef GL_ALPHA16F_ARB
#define GL_ALPHA16F_ARB 0x881C
#endif

#ifndef GL_INTENSITY16F_ARB
#define GL_INTENSITY16F_ARB 0x881D
#endif

#ifndef GL_LUMINANCE_ALPHA16F_ARB
#define GL_LUMINANCE_ALPHA16F_ARB 0x881F
#endif

#ifndef GL_RGBA32F_ARB
#define GL_RGBA32F_ARB 0x8814
#endif

#ifndef GL_TEXTURE_LUMINANCE_TYPE_ARB
#define GL_TEXTURE_LUMINANCE_TYPE_ARB 0x8C14
#endif

#ifndef GL_TEXTURE_ALPHA_TYPE_ARB
#define GL_TEXTURE_ALPHA_TYPE_ARB 0x8C13
#endif

#ifndef GL_TEXTURE_RED_TYPE_ARB
#define GL_TEXTURE_RED_TYPE_ARB 0x8C10
#endif

#ifndef GL_TEXTURE_GREEN_TYPE_ARB
#define GL_TEXTURE_GREEN_TYPE_ARB 0x8C11
#endif


// GL_SUN_vertex
typedef void (NIV_CALL_TYPE * nivenGLCOLOR3FVERTEX3FVSUN) (const GLfloat* c, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUN) (const GLuint* rc, const GLfloat* tc, const GLfloat* c, const GLfloat* n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUIVERTEX3FSUN) (GLuint rc, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FVSUN) (const GLuint* rc, const GLfloat* c, const GLfloat* n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD4FVERTEX4FVSUN) (const GLfloat* tc, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2FCOLOR3FVERTEX3FSUN) (GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FSUN) (GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUINORMAL3FVERTEX3FSUN) (GLuint rc, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUN) (const GLfloat* tc, const GLfloat* c, const GLfloat* n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2FNORMAL3FVERTEX3FSUN) (GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FSUN) (GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2FCOLOR3FVERTEX3FVSUN) (const GLfloat* tc, const GLfloat* c, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FSUN) (GLuint rc, GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLNORMAL3FVERTEX3FVSUN) (const GLfloat* n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLCOLOR4FNORMAL3FVERTEX3FSUN) (GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUICOLOR3FVERTEX3FSUN) (GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLNORMAL3FVERTEX3FSUN) (GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUICOLOR4UBVERTEX3FSUN) (GLuint rc, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUICOLOR4UBVERTEX3FVSUN) (const GLuint* rc, const GLubyte* c, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FVSUN) (const GLfloat* tc, const GLfloat* c, const GLfloat* n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2FCOLOR4UBVERTEX3FVSUN) (const GLfloat* tc, const GLubyte* c, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2FCOLOR4UBVERTEX3FSUN) (GLfloat s, GLfloat t, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD4FVERTEX4FSUN) (GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
typedef void (NIV_CALL_TYPE * nivenGLCOLOR4UBVERTEX2FSUN) (GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y);
typedef void (NIV_CALL_TYPE * nivenGLCOLOR3FVERTEX3FSUN) (GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUIVERTEX3FVSUN) (const GLuint* rc, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FSUN) (GLuint rc, GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FVSUN) (const GLuint* rc, const GLfloat* tc, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2FVERTEX3FVSUN) (const GLfloat* tc, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUINORMAL3FVERTEX3FVSUN) (const GLuint* rc, const GLfloat* n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLCOLOR4UBVERTEX2FVSUN) (const GLubyte* c, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLCOLOR4UBVERTEX3FVSUN) (const GLubyte* c, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUN) (GLuint rc, GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2FNORMAL3FVERTEX3FVSUN) (const GLfloat* tc, const GLfloat* n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLCOLOR4FNORMAL3FVERTEX3FVSUN) (const GLfloat* c, const GLfloat* n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FVSUN) (const GLuint* rc, const GLfloat* tc, const GLfloat* n, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLREPLACEMENTCODEUICOLOR3FVERTEX3FVSUN) (const GLuint* rc, const GLfloat* c, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLCOLOR4UBVERTEX3FSUN) (GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2FVERTEX3FSUN) (GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUN) (GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);

// GL_ARB_texture_env_crossbar

// GL_SGIS_texture_lod
#ifndef GL_TEXTURE_MAX_LOD_SGIS
#define GL_TEXTURE_MAX_LOD_SGIS 0x813B
#endif

#ifndef GL_TEXTURE_MIN_LOD_SGIS
#define GL_TEXTURE_MIN_LOD_SGIS 0x813A
#endif

#ifndef GL_TEXTURE_MAX_LEVEL_SGIS
#define GL_TEXTURE_MAX_LEVEL_SGIS 0x813D
#endif

#ifndef GL_TEXTURE_BASE_LEVEL_SGIS
#define GL_TEXTURE_BASE_LEVEL_SGIS 0x813C
#endif


// GL_MESA_pack_invert
#ifndef GL_PACK_INVERT_MESA
#define GL_PACK_INVERT_MESA 0x8758
#endif


// GL_ATIX_texture_env_route
#ifndef GL_TEXTURE_OUTPUT_RGB_ATIX
#define GL_TEXTURE_OUTPUT_RGB_ATIX 0x8748
#endif

#ifndef GL_TEXTURE_OUTPUT_ALPHA_ATIX
#define GL_TEXTURE_OUTPUT_ALPHA_ATIX 0x8749
#endif

#ifndef GL_SECONDARY_COLOR_ATIX
#define GL_SECONDARY_COLOR_ATIX 0x8747
#endif


#ifdef _GLX
// GLX_MESA_release_buffers
typedef Bool (NIV_CALL_TYPE * nivenGLXRELEASEBUFFERSMESA) (Display* dpy, GLXDrawable d);
#endif // _GLX
// GL_SGIS_sharpen_texture
typedef void (NIV_CALL_TYPE * nivenGLGETSHARPENTEXFUNCSGIS) (GLenum target, GLfloat* points);
typedef void (NIV_CALL_TYPE * nivenGLSHARPENTEXFUNCSGIS) (GLenum target, GLsizei n, const GLfloat* points);

// GL_SGIX_texture_range
#ifndef GL_RGB16_SIGNED_SGIX
#define GL_RGB16_SIGNED_SGIX 0x85E6
#endif

#ifndef GL_MAX_INTENSITY_SGIS
#define GL_MAX_INTENSITY_SGIS 0x85FB
#endif

#ifndef GL_LUMINANCE_EXTENDED_RANGE_SGIX
#define GL_LUMINANCE_EXTENDED_RANGE_SGIX 0x85EF
#endif

#ifndef GL_RGB16_EXTENDED_RANGE_SGIX
#define GL_RGB16_EXTENDED_RANGE_SGIX 0x85F2
#endif

#ifndef GL_ALPHA16_EXTENDED_RANGE_SGIX
#define GL_ALPHA16_EXTENDED_RANGE_SGIX 0x85F4
#endif

#ifndef GL_ALPHA_EXTENDED_RANGE_SGIX
#define GL_ALPHA_EXTENDED_RANGE_SGIX 0x85EE
#endif

#ifndef GL_ALPHA_SIGNED_SGIX
#define GL_ALPHA_SIGNED_SGIX 0x85E2
#endif

#ifndef GL_RGB_SIGNED_SGIX
#define GL_RGB_SIGNED_SGIX 0x85E0
#endif

#ifndef GL_RGBA16_EXTENDED_RANGE_SGIX
#define GL_RGBA16_EXTENDED_RANGE_SGIX 0x85F3
#endif

#ifndef GL_RGBA16_SIGNED_SGIX
#define GL_RGBA16_SIGNED_SGIX 0x85E7
#endif

#ifndef GL_MIN_INTENSITY_SGIS
#define GL_MIN_INTENSITY_SGIS 0x85FA
#endif

#ifndef GL_RGBA_EXTENDED_RANGE_SGIX
#define GL_RGBA_EXTENDED_RANGE_SGIX 0x85ED
#endif

#ifndef GL_LUMINANCE_ALPHA_SIGNED_SGIX
#define GL_LUMINANCE_ALPHA_SIGNED_SGIX 0x85E5
#endif

#ifndef GL_MAX_LUMINANCE_SGIS
#define GL_MAX_LUMINANCE_SGIS 0x85F9
#endif

#ifndef GL_INTENSITY16_SIGNED_SGIX
#define GL_INTENSITY16_SIGNED_SGIX 0x85EA
#endif

#ifndef GL_LUMINANCE16_ALPHA16_SIGNED_SGIX
#define GL_LUMINANCE16_ALPHA16_SIGNED_SGIX 0x85EB
#endif

#ifndef GL_LUMINANCE16_ALPHA16_EXTENDED_RANGE_SGIX
#define GL_LUMINANCE16_ALPHA16_EXTENDED_RANGE_SGIX 0x85F7
#endif

#ifndef GL_RGB_EXTENDED_RANGE_SGIX
#define GL_RGB_EXTENDED_RANGE_SGIX 0x85EC
#endif

#ifndef GL_INTENSITY16_EXTENDED_RANGE_SGIX
#define GL_INTENSITY16_EXTENDED_RANGE_SGIX 0x85F6
#endif

#ifndef GL_LUMINANCE_SIGNED_SGIX
#define GL_LUMINANCE_SIGNED_SGIX 0x85E3
#endif

#ifndef GL_LUMINANCE_ALPHA_EXTENDED_RANGE_SGIX
#define GL_LUMINANCE_ALPHA_EXTENDED_RANGE_SGIX 0x85F1
#endif

#ifndef GL_INTENSITY_SIGNED_SGIX
#define GL_INTENSITY_SIGNED_SGIX 0x85E4
#endif

#ifndef GL_MIN_LUMINANCE_SGIS
#define GL_MIN_LUMINANCE_SGIS 0x85F8
#endif

#ifndef GL_LUMINANCE16_SIGNED_SGIX
#define GL_LUMINANCE16_SIGNED_SGIX 0x85E9
#endif

#ifndef GL_ALPHA16_SIGNED_SGIX
#define GL_ALPHA16_SIGNED_SGIX 0x85E8
#endif

#ifndef GL_LUMINANCE16_EXTENDED_RANGE_SGIX
#define GL_LUMINANCE16_EXTENDED_RANGE_SGIX 0x85F5
#endif

#ifndef GL_RGBA_SIGNED_SGIX
#define GL_RGBA_SIGNED_SGIX 0x85E1
#endif

#ifndef GL_INTENSITY_EXTENDED_RANGE_SGIX
#define GL_INTENSITY_EXTENDED_RANGE_SGIX 0x85F0
#endif


// GL_EXT_texture_rectangle
#ifndef GL_MAX_RECTANGLE_TEXTURE_SIZE_EXT
#define GL_MAX_RECTANGLE_TEXTURE_SIZE_EXT 0x84F8
#endif

#ifndef GL_PROXY_TEXTURE_RECTANGLE_EXT
#define GL_PROXY_TEXTURE_RECTANGLE_EXT 0x84F7
#endif

#ifndef GL_TEXTURE_BINDING_RECTANGLE_EXT
#define GL_TEXTURE_BINDING_RECTANGLE_EXT 0x84F6
#endif

#ifndef GL_TEXTURE_RECTANGLE_EXT
#define GL_TEXTURE_RECTANGLE_EXT 0x84F5
#endif


// GL_EXT_blend_logic_op

// GL_SGIS_fog_function
typedef void (NIV_CALL_TYPE * nivenGLGETFOGFUNCSGIS) (GLfloat* points);
typedef void (NIV_CALL_TYPE * nivenGLFOGFUNCSGIS) (GLsizei n, const GLfloat* points);

#ifdef _GLX
// GLX_SUN_video_resize
#ifndef GL_VIDEO_RESIZE_COMPENSATION_SUN
#define GL_VIDEO_RESIZE_COMPENSATION_SUN 0x85CD
#endif

#ifndef GLX_VIDEO_RESIZE_SUN
#define GLX_VIDEO_RESIZE_SUN 0x8171
#endif

typedef int (NIV_CALL_TYPE * nivenGLXGETVIDEORESIZESUN) (Display* display, GLXDrawable window, float* factor);
typedef int (NIV_CALL_TYPE * nivenGLXVIDEORESIZESUN) (Display* display, GLXDrawable window, float factor);
#endif // _GLX
// GL_IBM_cull_vertex
#ifndef GL_CULL_VERTEX_IBM
#define GL_CULL_VERTEX_IBM 103050
#endif


// GL_PGI_vertex_hints
#ifndef GL_TEXCOORD2_BIT_PGI
#define GL_TEXCOORD2_BIT_PGI 0x20000000
#endif

#ifndef GL_MAX_VERTEX_HINT_PGI
#define GL_MAX_VERTEX_HINT_PGI 107053
#endif

#ifndef GL_COLOR4_BIT_PGI
#define GL_COLOR4_BIT_PGI 0x00020000
#endif

#ifndef GL_MAT_AMBIENT_BIT_PGI
#define GL_MAT_AMBIENT_BIT_PGI 0x00100000
#endif

#ifndef GL_TEXCOORD3_BIT_PGI
#define GL_TEXCOORD3_BIT_PGI 0x40000000
#endif

#ifndef GL_MATERIAL_SIDE_HINT_PGI
#define GL_MATERIAL_SIDE_HINT_PGI 107052
#endif

#ifndef GL_MAT_SHININESS_BIT_PGI
#define GL_MAT_SHININESS_BIT_PGI 0x02000000
#endif

#ifndef GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI
#define GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI 0x00200000
#endif

#ifndef GL_MAT_EMISSION_BIT_PGI
#define GL_MAT_EMISSION_BIT_PGI 0x00800000
#endif

#ifndef GL_VERTEX_CONSISTENT_HINT_PGI
#define GL_VERTEX_CONSISTENT_HINT_PGI 107051
#endif

#ifndef GL_VERTEX23_BIT_PGI
#define GL_VERTEX23_BIT_PGI 0x00000004
#endif

#ifndef GL_TEXCOORD4_BIT_PGI
#define GL_TEXCOORD4_BIT_PGI 0x80000000
#endif

#ifndef GL_MAT_SPECULAR_BIT_PGI
#define GL_MAT_SPECULAR_BIT_PGI 0x04000000
#endif

#ifndef GL_TEXCOORD1_BIT_PGI
#define GL_TEXCOORD1_BIT_PGI 0x10000000
#endif

#ifndef GL_VERTEX4_BIT_PGI
#define GL_VERTEX4_BIT_PGI 0x00000008
#endif

#ifndef GL_INDEX_BIT_PGI
#define GL_INDEX_BIT_PGI 0x00080000
#endif

#ifndef GL_COLOR3_BIT_PGI
#define GL_COLOR3_BIT_PGI 0x00010000
#endif

#ifndef GL_MAT_DIFFUSE_BIT_PGI
#define GL_MAT_DIFFUSE_BIT_PGI 0x00400000
#endif

#ifndef GL_EDGEFLAG_BIT_PGI
#define GL_EDGEFLAG_BIT_PGI 0x00040000
#endif

#ifndef GL_NORMAL_BIT_PGI
#define GL_NORMAL_BIT_PGI 0x08000000
#endif

#ifndef GL_MAT_COLOR_INDEXES_BIT_PGI
#define GL_MAT_COLOR_INDEXES_BIT_PGI 0x01000000
#endif

#ifndef GL_VERTEX_DATA_HINT_PGI
#define GL_VERTEX_DATA_HINT_PGI 107050
#endif


// GL_GREMEDY_string_marker
typedef void (NIV_CALL_TYPE * nivenGLSTRINGMARKERGREMEDY) (GLsizei len, const void* string);

#ifdef _GLX
// GLX_SGIS_color_range
#ifndef GLX_MAX_ALPHA_SGIS
#define GLX_MAX_ALPHA_SGIS 0
#endif

#ifndef GLX_MIN_GREEN_SGIS
#define GLX_MIN_GREEN_SGIS 0
#endif

#ifndef GLX_MIN_ALPHA_SGIS
#define GLX_MIN_ALPHA_SGIS 0
#endif

#ifndef GLX_MAX_GREEN_SGIS
#define GLX_MAX_GREEN_SGIS 0
#endif

#ifndef GLX_MAX_BLUE_SGIS
#define GLX_MAX_BLUE_SGIS 0
#endif

#ifndef GLX_MAX_RED_SGIS
#define GLX_MAX_RED_SGIS 0
#endif

#ifndef GLX_MIN_BLUE_SGIS
#define GLX_MIN_BLUE_SGIS 0
#endif

#ifndef GLX_MIN_RED_SGIS
#define GLX_MIN_RED_SGIS 0
#endif

#ifndef GLX_EXTENDED_RANGE_SGIS
#define GLX_EXTENDED_RANGE_SGIS 0
#endif

#endif // _GLX
// GL_EXT_subtexture
typedef void (NIV_CALL_TYPE * nivenGLTEXSUBIMAGE1DEXT) (GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void* pixels);
typedef void (NIV_CALL_TYPE * nivenGLTEXSUBIMAGE2DEXT) (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void* pixels);
typedef void (NIV_CALL_TYPE * nivenGLTEXSUBIMAGE3DEXT) (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void* pixels);

// GL_WIN_swap_hint
typedef void (NIV_CALL_TYPE * nivenGLADDSWAPHINTRECTWIN) (GLint x, GLint y, GLsizei width, GLsizei height);

// GL_ARB_color_buffer_float
#ifndef GL_CLAMP_FRAGMENT_COLOR_ARB
#define GL_CLAMP_FRAGMENT_COLOR_ARB 0x891B
#endif

#ifndef GL_CLAMP_READ_COLOR_ARB
#define GL_CLAMP_READ_COLOR_ARB 0x891C
#endif

#ifndef GL_CLAMP_VERTEX_COLOR_ARB
#define GL_CLAMP_VERTEX_COLOR_ARB 0x891A
#endif

#ifndef GL_FIXED_ONLY_ARB
#define GL_FIXED_ONLY_ARB 0x891D
#endif

#ifndef GL_RGBA_FLOAT_MODE_ARB
#define GL_RGBA_FLOAT_MODE_ARB 0x8820
#endif

typedef void (NIV_CALL_TYPE * nivenGLCLAMPCOLORARB) (GLenum target, GLenum clamp);

// GL_EXT_pixel_transform_color_table

#ifdef _GLX
// GLX_ARB_fbconfig_float
#ifndef GLX_RGBA_FLOAT_BIT
#define GLX_RGBA_FLOAT_BIT 0x00000004
#endif

#ifndef GLX_RGBA_FLOAT_TYPE
#define GLX_RGBA_FLOAT_TYPE 0x20B9
#endif

#endif // _GLX
// GL_ARB_window_pos
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2SARB) (GLshort x, GLshort y);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2SVARB) (const GLshort* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3FARB) (GLfloat x, GLfloat y, GLfloat z);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2FVARB) (const GLfloat* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2DARB) (GLdouble x, GLdouble y);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2FARB) (GLfloat x, GLfloat y);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3DARB) (GLdouble x, GLdouble y, GLdouble z);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3SARB) (GLshort x, GLshort y, GLshort z);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3SVARB) (const GLshort* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2IARB) (GLint x, GLint y);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2IVARB) (const GLint* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3IVARB) (const GLint* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3IARB) (GLint x, GLint y, GLint z);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3FVARB) (const GLfloat* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS2DVARB) (const GLdouble* p);
typedef void (NIV_CALL_TYPE * nivenGLWINDOWPOS3DVARB) (const GLdouble* p);

// GL_NV_fragment_program2
#ifndef GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV
#define GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV 0x88F4
#endif

#ifndef GL_MAX_PROGRAM_LOOP_COUNT_NV
#define GL_MAX_PROGRAM_LOOP_COUNT_NV 0x88F8
#endif

#ifndef GL_MAX_PROGRAM_LOOP_DEPTH_NV
#define GL_MAX_PROGRAM_LOOP_DEPTH_NV 0x88F7
#endif

#ifndef GL_MAX_PROGRAM_IF_DEPTH_NV
#define GL_MAX_PROGRAM_IF_DEPTH_NV 0x88F6
#endif

#ifndef GL_MAX_PROGRAM_CALL_DEPTH_NV
#define GL_MAX_PROGRAM_CALL_DEPTH_NV 0x88F5
#endif


// GL_ARB_shadow
#ifndef GL_TEXTURE_COMPARE_FUNC_ARB
#define GL_TEXTURE_COMPARE_FUNC_ARB 0x884D
#endif

#ifndef GL_TEXTURE_COMPARE_MODE_ARB
#define GL_TEXTURE_COMPARE_MODE_ARB 0x884C
#endif

#ifndef GL_COMPARE_R_TO_TEXTURE_ARB
#define GL_COMPARE_R_TO_TEXTURE_ARB 0x884E
#endif


// GL_ARB_texture_mirrored_repeat
#ifndef GL_MIRRORED_REPEAT_ARB
#define GL_MIRRORED_REPEAT_ARB 0x8370
#endif


#ifdef _GLX
// GLX_SGIX_video_resize
#ifndef GLX_SYNC_SWAP_SGIX
#define GLX_SYNC_SWAP_SGIX 0x00000001
#endif

#ifndef GLX_SYNC_FRAME_SGIX
#define GLX_SYNC_FRAME_SGIX 0x00000000
#endif

typedef int (NIV_CALL_TYPE * nivenGLXCHANNELRECTSGIX) (Display* display, int screen, int channel, int x, int y, int w, int h);
typedef int (NIV_CALL_TYPE * nivenGLXQUERYCHANNELRECTSGIX) (Display* display, int screen, int channel, int* dx, int* dy, int* dw, int* dh);
typedef int (NIV_CALL_TYPE * nivenGLXBINDCHANNELTOWINDOWSGIX) (Display* display, int screen, int channel, Window window);
typedef int (NIV_CALL_TYPE * nivenGLXCHANNELRECTSYNCSGIX) (Display* display, int screen, int channel, GLenum synctype);
typedef int (NIV_CALL_TYPE * nivenGLXQUERYCHANNELDELTASSGIX) (Display* display, int screen, int channel, int* x, int* y, int* w, int* h);
#endif // _GLX
// WGL_I3D_swap_frame_usage
#ifdef WIN32
typedef BOOL (NIV_CALL_TYPE * nivenWGLGETFRAMEUSAGEI3D) (float* pUsage);
typedef BOOL (NIV_CALL_TYPE * nivenWGLENDFRAMETRACKINGI3D) (void );
typedef BOOL (NIV_CALL_TYPE * nivenWGLBEGINFRAMETRACKINGI3D) (void );
typedef BOOL (NIV_CALL_TYPE * nivenWGLQUERYFRAMETRACKINGI3D) (DWORD* pFrameCount, DWORD* pMissedFrames, float* pLastMissedUsage);
#endif
// GL_PGI_misc_hints
#ifndef GL_ALWAYS_SOFT_HINT_PGI
#define GL_ALWAYS_SOFT_HINT_PGI 107021
#endif

#ifndef GL_NATIVE_GRAPHICS_END_HINT_PGI
#define GL_NATIVE_GRAPHICS_END_HINT_PGI 107012
#endif

#ifndef GL_FULL_STIPPLE_HINT_PGI
#define GL_FULL_STIPPLE_HINT_PGI 107033
#endif

#ifndef GL_CLIP_FAR_HINT_PGI
#define GL_CLIP_FAR_HINT_PGI 107041
#endif

#ifndef GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI
#define GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI 107011
#endif

#ifndef GL_CONSERVE_MEMORY_HINT_PGI
#define GL_CONSERVE_MEMORY_HINT_PGI 107005
#endif

#ifndef GL_PREFER_DOUBLEBUFFER_HINT_PGI
#define GL_PREFER_DOUBLEBUFFER_HINT_PGI 107000
#endif

#ifndef GL_NATIVE_GRAPHICS_HANDLE_PGI
#define GL_NATIVE_GRAPHICS_HANDLE_PGI 107010
#endif

#ifndef GL_ALLOW_DRAW_MEM_HINT_PGI
#define GL_ALLOW_DRAW_MEM_HINT_PGI 107025
#endif

#ifndef GL_WIDE_LINE_HINT_PGI
#define GL_WIDE_LINE_HINT_PGI 107042
#endif

#ifndef GL_STRICT_DEPTHFUNC_HINT_PGI
#define GL_STRICT_DEPTHFUNC_HINT_PGI 107030
#endif

#ifndef GL_ALLOW_DRAW_OBJ_HINT_PGI
#define GL_ALLOW_DRAW_OBJ_HINT_PGI 107022
#endif

#ifndef GL_CLIP_NEAR_HINT_PGI
#define GL_CLIP_NEAR_HINT_PGI 107040
#endif

#ifndef GL_STRICT_SCISSOR_HINT_PGI
#define GL_STRICT_SCISSOR_HINT_PGI 107032
#endif

#ifndef GL_RECLAIM_MEMORY_HINT_PGI
#define GL_RECLAIM_MEMORY_HINT_PGI 107006
#endif

#ifndef GL_BACK_NORMALS_HINT_PGI
#define GL_BACK_NORMALS_HINT_PGI 107043
#endif

#ifndef GL_ALWAYS_FAST_HINT_PGI
#define GL_ALWAYS_FAST_HINT_PGI 107020
#endif

#ifndef GL_ALLOW_DRAW_FRG_HINT_PGI
#define GL_ALLOW_DRAW_FRG_HINT_PGI 107024
#endif

#ifndef GL_STRICT_LIGHTING_HINT_PGI
#define GL_STRICT_LIGHTING_HINT_PGI 107031
#endif

#ifndef GL_ALLOW_DRAW_WIN_HINT_PGI
#define GL_ALLOW_DRAW_WIN_HINT_PGI 107023
#endif


// GL_NV_evaluators
#ifndef GL_MAP_ATTRIB_U_ORDER_NV
#define GL_MAP_ATTRIB_U_ORDER_NV 0x86C3
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB9_NV
#define GL_EVAL_VERTEX_ATTRIB9_NV 0x86CF
#endif

#ifndef GL_MAP_ATTRIB_V_ORDER_NV
#define GL_MAP_ATTRIB_V_ORDER_NV 0x86C4
#endif

#ifndef GL_MAX_MAP_TESSELLATION_NV
#define GL_MAX_MAP_TESSELLATION_NV 0x86D6
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB15_NV
#define GL_EVAL_VERTEX_ATTRIB15_NV 0x86D5
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB10_NV
#define GL_EVAL_VERTEX_ATTRIB10_NV 0x86D0
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB13_NV
#define GL_EVAL_VERTEX_ATTRIB13_NV 0x86D3
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB12_NV
#define GL_EVAL_VERTEX_ATTRIB12_NV 0x86D2
#endif

#ifndef GL_EVAL_FRACTIONAL_TESSELLATION_NV
#define GL_EVAL_FRACTIONAL_TESSELLATION_NV 0x86C5
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB2_NV
#define GL_EVAL_VERTEX_ATTRIB2_NV 0x86C8
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB5_NV
#define GL_EVAL_VERTEX_ATTRIB5_NV 0x86CB
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB8_NV
#define GL_EVAL_VERTEX_ATTRIB8_NV 0x86CE
#endif

#ifndef GL_MAX_RATIONAL_EVAL_ORDER_NV
#define GL_MAX_RATIONAL_EVAL_ORDER_NV 0x86D7
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB4_NV
#define GL_EVAL_VERTEX_ATTRIB4_NV 0x86CA
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB7_NV
#define GL_EVAL_VERTEX_ATTRIB7_NV 0x86CD
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB11_NV
#define GL_EVAL_VERTEX_ATTRIB11_NV 0x86D1
#endif

#ifndef GL_EVAL_TRIANGULAR_2D_NV
#define GL_EVAL_TRIANGULAR_2D_NV 0x86C1
#endif

#ifndef GL_EVAL_2D_NV
#define GL_EVAL_2D_NV 0x86C0
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB14_NV
#define GL_EVAL_VERTEX_ATTRIB14_NV 0x86D4
#endif

#ifndef GL_MAP_TESSELLATION_NV
#define GL_MAP_TESSELLATION_NV 0x86C2
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB0_NV
#define GL_EVAL_VERTEX_ATTRIB0_NV 0x86C6
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB3_NV
#define GL_EVAL_VERTEX_ATTRIB3_NV 0x86C9
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB6_NV
#define GL_EVAL_VERTEX_ATTRIB6_NV 0x86CC
#endif

#ifndef GL_EVAL_VERTEX_ATTRIB1_NV
#define GL_EVAL_VERTEX_ATTRIB1_NV 0x86C7
#endif

typedef void (NIV_CALL_TYPE * nivenGLGETMAPPARAMETERIVNV) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLMAPCONTROLPOINTSNV) (GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLint uorder, GLint vorder, GLboolean packed, const void* points);
typedef void (NIV_CALL_TYPE * nivenGLGETMAPATTRIBPARAMETERIVNV) (GLenum target, GLuint index, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETMAPCONTROLPOINTSNV) (GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLboolean packed, void* points);
typedef void (NIV_CALL_TYPE * nivenGLGETMAPPARAMETERFVNV) (GLenum target, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLEVALMAPSNV) (GLenum target, GLenum mode);
typedef void (NIV_CALL_TYPE * nivenGLMAPPARAMETERFVNV) (GLenum target, GLenum pname, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETMAPATTRIBPARAMETERFVNV) (GLenum target, GLuint index, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLMAPPARAMETERIVNV) (GLenum target, GLenum pname, const GLint* params);

// GL_INTEL_texture_scissor
typedef void (NIV_CALL_TYPE * nivenGLTEXSCISSORFUNCINTEL) (GLenum target, GLenum lfunc, GLenum hfunc);
typedef void (NIV_CALL_TYPE * nivenGLTEXSCISSORINTEL) (GLenum target, GLclampf tlow, GLclampf thigh);

// GL_NV_texture_compression_vtc

// GL_SGIS_texture_filter4
typedef void (NIV_CALL_TYPE * nivenGLTEXFILTERFUNCSGIS) (GLenum target, GLenum filter, GLsizei n, const GLfloat* weights);
typedef void (NIV_CALL_TYPE * nivenGLGETTEXFILTERFUNCSGIS) (GLenum target, GLenum filter, GLfloat* weights);

#ifdef _GLX
// GLX_OML_swap_method
#ifndef GLX_SWAP_EXCHANGE_OML
#define GLX_SWAP_EXCHANGE_OML 0x8061
#endif

#ifndef GLX_SWAP_METHOD_OML
#define GLX_SWAP_METHOD_OML 0x8060
#endif

#ifndef GLX_SWAP_UNDEFINED_OML
#define GLX_SWAP_UNDEFINED_OML 0x8063
#endif

#ifndef GLX_SWAP_COPY_OML
#define GLX_SWAP_COPY_OML 0x8062
#endif

#endif // _GLX
// GL_EXT_copy_texture
typedef void (NIV_CALL_TYPE * nivenGLCOPYTEXIMAGE2DEXT) (GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border);
typedef void (NIV_CALL_TYPE * nivenGLCOPYTEXSUBIMAGE2DEXT) (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height);
typedef void (NIV_CALL_TYPE * nivenGLCOPYTEXSUBIMAGE1DEXT) (GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width);
typedef void (NIV_CALL_TYPE * nivenGLCOPYTEXIMAGE1DEXT) (GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border);
typedef void (NIV_CALL_TYPE * nivenGLCOPYTEXSUBIMAGE3DEXT) (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);

// GL_NV_register_combiners2
#ifndef GL_PER_STAGE_CONSTANTS_NV
#define GL_PER_STAGE_CONSTANTS_NV 0x8535
#endif

typedef void (NIV_CALL_TYPE * nivenGLGETCOMBINERSTAGEPARAMETERFVNV) (GLenum stage, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLCOMBINERSTAGEPARAMETERFVNV) (GLenum stage, GLenum pname, const GLfloat* params);

// GL_EXT_fragment_lighting
#ifndef GL_FRAGMENT_LIGHT_MODEL_AMBIENT_EXT
#define GL_FRAGMENT_LIGHT_MODEL_AMBIENT_EXT 0x840A
#endif

#ifndef GL_MAX_FRAGMENT_LIGHTS_EXT
#define GL_MAX_FRAGMENT_LIGHTS_EXT 0x8404
#endif

#ifndef GL_FRAGMENT_LIGHTING_EXT
#define GL_FRAGMENT_LIGHTING_EXT 0x8400
#endif

#ifndef GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_EXT
#define GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_EXT 0x8408
#endif

#ifndef GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_EXT
#define GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_EXT 0x8403
#endif

#ifndef GL_MAX_ACTIVE_LIGHTS_EXT
#define GL_MAX_ACTIVE_LIGHTS_EXT 0x8405
#endif

#ifndef GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_EXT
#define GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_EXT 0x840B
#endif

#ifndef GL_FRAGMENT_LIGHT0_EXT
#define GL_FRAGMENT_LIGHT0_EXT 0x840C
#endif

#ifndef GL_FRAGMENT_COLOR_MATERIAL_EXT
#define GL_FRAGMENT_COLOR_MATERIAL_EXT 0x8401
#endif

#ifndef GL_LIGHT_ENV_MODE_EXT
#define GL_LIGHT_ENV_MODE_EXT 0x8407
#endif

#ifndef GL_FRAGMENT_LIGHT7_EXT
#define GL_FRAGMENT_LIGHT7_EXT 0x8413
#endif

#ifndef GL_CURRENT_RASTER_NORMAL_EXT
#define GL_CURRENT_RASTER_NORMAL_EXT 0x8406
#endif

#ifndef GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_EXT
#define GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_EXT 0x8409
#endif

#ifndef GL_FRAGMENT_COLOR_MATERIAL_FACE_EXT
#define GL_FRAGMENT_COLOR_MATERIAL_FACE_EXT 0x8402
#endif

typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTFVEXT) (GLenum light, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETFRAGMENTLIGHTFVEXT) (GLenum light, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETFRAGMENTLIGHTIVEXT) (GLenum light, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTFEXT) (GLenum light, GLenum pname, GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLLIGHTENVIEXT) (GLenum pname, GLint param);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTIEXT) (GLenum light, GLenum pname, GLint param);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTMATERIALFVEXT) (GLenum face, GLenum pname, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTMATERIALFEXT) (GLenum face, GLenum pname, const GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTCOLORMATERIALEXT) (GLenum face, GLenum mode);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTMODELFVEXT) (GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTMODELIVEXT) (GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTIVEXT) (GLenum light, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTMODELIEXT) (GLenum pname, GLint param);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTMATERIALIVEXT) (GLenum face, GLenum pname, const GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETFRAGMENTMATERIALIVEXT) (GLenum face, GLenum pname, const GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTLIGHTMODELFEXT) (GLenum pname, GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLFRAGMENTMATERIALIEXT) (GLenum face, GLenum pname, const GLint param);
typedef void (NIV_CALL_TYPE * nivenGLGETFRAGMENTMATERIALFVEXT) (GLenum face, GLenum pname, const GLfloat* params);

// GL_SGIX_interlace
#ifndef GL_INTERLACE_SGIX
#define GL_INTERLACE_SGIX 0x8094
#endif


// GL_NV_vertex_program1_1

// GL_EXT_rescale_normal

#ifdef _GLX
// GLX_ATI_render_texture
#ifndef GLX_TEXTURE_CUBE_MAP_ATI
#define GLX_TEXTURE_CUBE_MAP_ATI 0x9808
#endif

#ifndef GLX_AUX4_ATI
#define GLX_AUX4_ATI 0x981B
#endif

#ifndef GLX_FRONT_RIGHT_ATI
#define GLX_FRONT_RIGHT_ATI 0x9814
#endif

#ifndef GLX_AUX8_ATI
#define GLX_AUX8_ATI 0x981F
#endif

#ifndef GLX_TEXTURE_RGBA_ATI
#define GLX_TEXTURE_RGBA_ATI 0x9806
#endif

#ifndef GLX_AUX1_ATI
#define GLX_AUX1_ATI 0x9818
#endif

#ifndef GLX_AUX7_ATI
#define GLX_AUX7_ATI 0x981E
#endif

#ifndef GLX_TEXTURE_CUBE_MAP_POSITIVE_Z_ATI
#define GLX_TEXTURE_CUBE_MAP_POSITIVE_Z_ATI 0x9811
#endif

#ifndef GLX_TEXTURE_CUBE_MAP_NEGATIVE_X_ATI
#define GLX_TEXTURE_CUBE_MAP_NEGATIVE_X_ATI 0x980E
#endif

#ifndef GLX_TEXTURE_RGB_ATI
#define GLX_TEXTURE_RGB_ATI 0x9805
#endif

#ifndef GLX_BIND_TO_TEXTURE_RGB_ATI
#define GLX_BIND_TO_TEXTURE_RGB_ATI 0x9800
#endif

#ifndef GLX_MIPMAP_TEXTURE_ATI
#define GLX_MIPMAP_TEXTURE_ATI 0x9804
#endif

#ifndef GLX_AUX0_ATI
#define GLX_AUX0_ATI 0x9817
#endif

#ifndef GLX_TEXTURE_1D_ATI
#define GLX_TEXTURE_1D_ATI 0x9809
#endif

#ifndef GLX_BACK_RIGHT_ATI
#define GLX_BACK_RIGHT_ATI 0x9816
#endif

#ifndef GLX_AUX2_ATI
#define GLX_AUX2_ATI 0x9819
#endif

#ifndef GLX_MIPMAP_LEVEL_ATI
#define GLX_MIPMAP_LEVEL_ATI 0x980B
#endif

#ifndef GLX_BIND_TO_TEXTURE_INTENSITY_ATI
#define GLX_BIND_TO_TEXTURE_INTENSITY_ATI 0x9822
#endif

#ifndef GLX_AUX5_ATI
#define GLX_AUX5_ATI 0x981C
#endif

#ifndef GLX_AUX9_ATI
#define GLX_AUX9_ATI 0x9820
#endif

#ifndef GLX_TEXTURE_2D_ATI
#define GLX_TEXTURE_2D_ATI 0x980A
#endif

#ifndef GLX_TEXTURE_CUBE_MAP_NEGATIVE_Z_ATI
#define GLX_TEXTURE_CUBE_MAP_NEGATIVE_Z_ATI 0x9812
#endif

#ifndef GLX_NO_TEXTURE_ATI
#define GLX_NO_TEXTURE_ATI 0x9807
#endif

#ifndef GLX_TEXTURE_TARGET_ATI
#define GLX_TEXTURE_TARGET_ATI 0x9803
#endif

#ifndef GLX_AUX6_ATI
#define GLX_AUX6_ATI 0x981D
#endif

#ifndef GLX_AUX3_ATI
#define GLX_AUX3_ATI 0x981A
#endif

#ifndef GLX_BIND_TO_TEXTURE_RGBA_ATI
#define GLX_BIND_TO_TEXTURE_RGBA_ATI 0x9801
#endif

#ifndef GLX_BACK_LEFT_ATI
#define GLX_BACK_LEFT_ATI 0x9815
#endif

#ifndef GLX_TEXTURE_CUBE_MAP_POSITIVE_Y_ATI
#define GLX_TEXTURE_CUBE_MAP_POSITIVE_Y_ATI 0x980F
#endif

#ifndef GLX_TEXTURE_CUBE_MAP_POSITIVE_X_ATI
#define GLX_TEXTURE_CUBE_MAP_POSITIVE_X_ATI 0x980D
#endif

#ifndef GLX_FRONT_LEFT_ATI
#define GLX_FRONT_LEFT_ATI 0x9813
#endif

#ifndef GLX_CUBE_MAP_FACE_ATI
#define GLX_CUBE_MAP_FACE_ATI 0x980C
#endif

#ifndef GLX_BIND_TO_TEXTURE_LUMINANCE_ATI
#define GLX_BIND_TO_TEXTURE_LUMINANCE_ATI 0x9821
#endif

#ifndef GLX_TEXTURE_FORMAT_ATI
#define GLX_TEXTURE_FORMAT_ATI 0x9802
#endif

#ifndef GLX_TEXTURE_CUBE_MAP_NEGATIVE_Y_ATI
#define GLX_TEXTURE_CUBE_MAP_NEGATIVE_Y_ATI 0x9810
#endif

typedef void (NIV_CALL_TYPE * nivenGLXBINDTEXIMAGEATI) (Display* dpy, GLXPbuffer pbuf, int buffer);
typedef void (NIV_CALL_TYPE * nivenGLXRELEASETEXIMAGEATI) (Display* dpy, GLXPbuffer pbuf, int buffer);
typedef void (NIV_CALL_TYPE * nivenGLXDRAWABLEATTRIBATI) (Display* dpy, GLXDrawable draw, const int* attrib_list);
#endif // _GLX
// GL_HP_convolution_border_modes

// GL_SGI_color_table
#ifndef GL_COLOR_TABLE_FORMAT_SGI
#define GL_COLOR_TABLE_FORMAT_SGI 0x80D8
#endif

#ifndef GL_COLOR_TABLE_LUMINANCE_SIZE_SGI
#define GL_COLOR_TABLE_LUMINANCE_SIZE_SGI 0x80DE
#endif

#ifndef GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI
#define GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI 0x80D4
#endif

#ifndef GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI
#define GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI 0x80D2
#endif

#ifndef GL_COLOR_TABLE_RED_SIZE_SGI
#define GL_COLOR_TABLE_RED_SIZE_SGI 0x80DA
#endif

#ifndef GL_PROXY_COLOR_TABLE_SGI
#define GL_PROXY_COLOR_TABLE_SGI 0x80D3
#endif

#ifndef GL_COLOR_TABLE_WIDTH_SGI
#define GL_COLOR_TABLE_WIDTH_SGI 0x80D9
#endif

#ifndef GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI
#define GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI 0x80D5
#endif

#ifndef GL_COLOR_TABLE_BIAS_SGI
#define GL_COLOR_TABLE_BIAS_SGI 0x80D7
#endif

#ifndef GL_COLOR_TABLE_SGI
#define GL_COLOR_TABLE_SGI 0x80D0
#endif

#ifndef GL_COLOR_TABLE_SCALE_SGI
#define GL_COLOR_TABLE_SCALE_SGI 0x80D6
#endif

#ifndef GL_COLOR_TABLE_BLUE_SIZE_SGI
#define GL_COLOR_TABLE_BLUE_SIZE_SGI 0x80DC
#endif

#ifndef GL_COLOR_TABLE_ALPHA_SIZE_SGI
#define GL_COLOR_TABLE_ALPHA_SIZE_SGI 0x80DD
#endif

#ifndef GL_COLOR_TABLE_GREEN_SIZE_SGI
#define GL_COLOR_TABLE_GREEN_SIZE_SGI 0x80DB
#endif

#ifndef GL_POST_CONVOLUTION_COLOR_TABLE_SGI
#define GL_POST_CONVOLUTION_COLOR_TABLE_SGI 0x80D1
#endif

#ifndef GL_COLOR_TABLE_INTENSITY_SIZE_SGI
#define GL_COLOR_TABLE_INTENSITY_SIZE_SGI 0x80DF
#endif

typedef void (NIV_CALL_TYPE * nivenGLCOLORTABLEPARAMETERFVSGI) (GLenum target, GLenum pname, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLCOPYCOLORTABLESGI) (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width);
typedef void (NIV_CALL_TYPE * nivenGLGETCOLORTABLEPARAMETERIVSGI) (GLenum target, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLGETCOLORTABLESGI) (GLenum target, GLenum format, GLenum type, void* table);
typedef void (NIV_CALL_TYPE * nivenGLCOLORTABLESGI) (GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void* table);
typedef void (NIV_CALL_TYPE * nivenGLGETCOLORTABLEPARAMETERFVSGI) (GLenum target, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLCOLORTABLEPARAMETERIVSGI) (GLenum target, GLenum pname, const GLint* params);

// GL_SGIX_resample
#ifndef GL_UNPACK_RESAMPLE_SGIX
#define GL_UNPACK_RESAMPLE_SGIX 0x842F
#endif

#ifndef GL_PACK_RESAMPLE_SGIX
#define GL_PACK_RESAMPLE_SGIX 0x842E
#endif

#ifndef GL_RESAMPLE_REPLICATE_SGIX
#define GL_RESAMPLE_REPLICATE_SGIX 0x8433
#endif

#ifndef GL_RESAMPLE_DECIMATE_SGIX
#define GL_RESAMPLE_DECIMATE_SGIX 0x8430
#endif

#ifndef GL_RESAMPLE_ZERO_FILL_SGIX
#define GL_RESAMPLE_ZERO_FILL_SGIX 0x8434
#endif


// GL_SGIX_ir_instrument1

// GL_SGIX_list_priority

// GL_SGIX_framezoom
typedef void (NIV_CALL_TYPE * nivenGLFRAMEZOOMSGIX) (GLint factor);

// GL_EXT_index_material
typedef void (NIV_CALL_TYPE * nivenGLINDEXMATERIALEXT) (GLenum face, GLenum mode);

// GL_SGIS_texture4D
typedef void (NIV_CALL_TYPE * nivenGLTEXSUBIMAGE4DSGIS) (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint woffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei extent, GLenum format, GLenum type, const void* pixels);
typedef void (NIV_CALL_TYPE * nivenGLTEXIMAGE4DSGIS) (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLsizei extent, GLint border, GLenum format, GLenum type, const void* pixels);

// GL_EXT_texture3D
#ifndef GL_UNPACK_SKIP_IMAGES_EXT
#define GL_UNPACK_SKIP_IMAGES_EXT 0x806D
#endif

#ifndef GL_PACK_IMAGE_HEIGHT_EXT
#define GL_PACK_IMAGE_HEIGHT_EXT 0x806C
#endif

#ifndef GL_TEXTURE_WRAP_R_EXT
#define GL_TEXTURE_WRAP_R_EXT 0x8072
#endif

#ifndef GL_TEXTURE_DEPTH_EXT
#define GL_TEXTURE_DEPTH_EXT 0x8071
#endif

#ifndef GL_MAX_3D_TEXTURE_SIZE_EXT
#define GL_MAX_3D_TEXTURE_SIZE_EXT 0x8073
#endif

#ifndef GL_UNPACK_IMAGE_HEIGHT_EXT
#define GL_UNPACK_IMAGE_HEIGHT_EXT 0x806E
#endif

#ifndef GL_PACK_SKIP_IMAGES_EXT
#define GL_PACK_SKIP_IMAGES_EXT 0x806B
#endif

typedef void (NIV_CALL_TYPE * nivenGLTEXIMAGE3DEXT) (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void* pixels);

// GL_REND_screen_coordinates
#ifndef GL_INVERTED_SCREEN_W_REND
#define GL_INVERTED_SCREEN_W_REND 0x8491
#endif

#ifndef GL_SCREEN_COORDINATES_REND
#define GL_SCREEN_COORDINATES_REND 0x8490
#endif


// GL_ARB_multitexture
#ifndef GL_TEXTURE0_ARB
#define GL_TEXTURE0_ARB 0x84C0
#endif

#ifndef GL_TEXTURE23_ARB
#define GL_TEXTURE23_ARB 0x84D7
#endif

#ifndef GL_TEXTURE5_ARB
#define GL_TEXTURE5_ARB 0x84C5
#endif

#ifndef GL_TEXTURE11_ARB
#define GL_TEXTURE11_ARB 0x84CB
#endif

#ifndef GL_TEXTURE13_ARB
#define GL_TEXTURE13_ARB 0x84CD
#endif

#ifndef GL_MAX_TEXTURE_UNITS_ARB
#define GL_MAX_TEXTURE_UNITS_ARB 0x84E2
#endif

#ifndef GL_TEXTURE31_ARB
#define GL_TEXTURE31_ARB 0x84DF
#endif

#ifndef GL_ACTIVE_TEXTURE_ARB
#define GL_ACTIVE_TEXTURE_ARB 0x84E0
#endif

#ifndef GL_TEXTURE8_ARB
#define GL_TEXTURE8_ARB 0x84C8
#endif

#ifndef GL_TEXTURE2_ARB
#define GL_TEXTURE2_ARB 0x84C2
#endif

#ifndef GL_TEXTURE28_ARB
#define GL_TEXTURE28_ARB 0x84DC
#endif

#ifndef GL_TEXTURE10_ARB
#define GL_TEXTURE10_ARB 0x84CA
#endif

#ifndef GL_TEXTURE19_ARB
#define GL_TEXTURE19_ARB 0x84D3
#endif

#ifndef GL_TEXTURE4_ARB
#define GL_TEXTURE4_ARB 0x84C4
#endif

#ifndef GL_TEXTURE26_ARB
#define GL_TEXTURE26_ARB 0x84DA
#endif

#ifndef GL_TEXTURE15_ARB
#define GL_TEXTURE15_ARB 0x84CF
#endif

#ifndef GL_TEXTURE12_ARB
#define GL_TEXTURE12_ARB 0x84CC
#endif

#ifndef GL_TEXTURE3_ARB
#define GL_TEXTURE3_ARB 0x84C3
#endif

#ifndef GL_TEXTURE30_ARB
#define GL_TEXTURE30_ARB 0x84DE
#endif

#ifndef GL_TEXTURE20_ARB
#define GL_TEXTURE20_ARB 0x84D4
#endif

#ifndef GL_TEXTURE27_ARB
#define GL_TEXTURE27_ARB 0x84DB
#endif

#ifndef GL_TEXTURE1_ARB
#define GL_TEXTURE1_ARB 0x84C1
#endif

#ifndef GL_TEXTURE17_ARB
#define GL_TEXTURE17_ARB 0x84D1
#endif

#ifndef GL_TEXTURE22_ARB
#define GL_TEXTURE22_ARB 0x84D6
#endif

#ifndef GL_CLIENT_ACTIVE_TEXTURE_ARB
#define GL_CLIENT_ACTIVE_TEXTURE_ARB 0x84E1
#endif

#ifndef GL_TEXTURE25_ARB
#define GL_TEXTURE25_ARB 0x84D9
#endif

#ifndef GL_TEXTURE29_ARB
#define GL_TEXTURE29_ARB 0x84DD
#endif

#ifndef GL_TEXTURE6_ARB
#define GL_TEXTURE6_ARB 0x84C6
#endif

#ifndef GL_TEXTURE24_ARB
#define GL_TEXTURE24_ARB 0x84D8
#endif

#ifndef GL_TEXTURE18_ARB
#define GL_TEXTURE18_ARB 0x84D2
#endif

#ifndef GL_TEXTURE14_ARB
#define GL_TEXTURE14_ARB 0x84CE
#endif

#ifndef GL_TEXTURE9_ARB
#define GL_TEXTURE9_ARB 0x84C9
#endif

#ifndef GL_TEXTURE21_ARB
#define GL_TEXTURE21_ARB 0x84D5
#endif

#ifndef GL_TEXTURE7_ARB
#define GL_TEXTURE7_ARB 0x84C7
#endif

#ifndef GL_TEXTURE16_ARB
#define GL_TEXTURE16_ARB 0x84D0
#endif

typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD2SVARB) (GLenum target, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD1IVARB) (GLenum target, const GLint* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD4FARB) (GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD4FVARB) (GLenum target, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLCLIENTACTIVETEXTUREARB) (GLenum texture);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD3SVARB) (GLenum target, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD4SARB) (GLenum target, GLshort s, GLshort t, GLshort r, GLshort q);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD4DVARB) (GLenum target, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD1FARB) (GLenum target, GLfloat s);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD2FVARB) (GLenum target, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD3IARB) (GLenum target, GLint s, GLint t, GLint r);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD1DVARB) (GLenum target, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD3DARB) (GLenum target, GLdouble s, GLdouble t, GLdouble r);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD4SVARB) (GLenum target, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD2SARB) (GLenum target, GLshort s, GLshort t);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD3SARB) (GLenum target, GLshort s, GLshort t, GLshort r);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD2DVARB) (GLenum target, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD3IVARB) (GLenum target, const GLint* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD1FVARB) (GLenum target, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD1SARB) (GLenum target, GLshort s);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD1SVARB) (GLenum target, const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLACTIVETEXTUREARB) (GLenum texture);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD4IVARB) (GLenum target, const GLint* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD2FARB) (GLenum target, GLfloat s, GLfloat t);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD2IARB) (GLenum target, GLint s, GLint t);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD3FARB) (GLenum target, GLfloat s, GLfloat t, GLfloat r);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD4DARB) (GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD3DVARB) (GLenum target, const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD1IARB) (GLenum target, GLint s);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD2IVARB) (GLenum target, const GLint* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD4IARB) (GLenum target, GLint s, GLint t, GLint r, GLint q);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD3FVARB) (GLenum target, const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD1DARB) (GLenum target, GLdouble s);
typedef void (NIV_CALL_TYPE * nivenGLMULTITEXCOORD2DARB) (GLenum target, GLdouble s, GLdouble t);

// GL_EXT_secondary_color
#ifndef GL_SECONDARY_COLOR_ARRAY_POINTER_EXT
#define GL_SECONDARY_COLOR_ARRAY_POINTER_EXT 0x845D
#endif

#ifndef GL_COLOR_SUM_EXT
#define GL_COLOR_SUM_EXT 0x8458
#endif

#ifndef GL_SECONDARY_COLOR_ARRAY_TYPE_EXT
#define GL_SECONDARY_COLOR_ARRAY_TYPE_EXT 0x845B
#endif

#ifndef GL_SECONDARY_COLOR_ARRAY_EXT
#define GL_SECONDARY_COLOR_ARRAY_EXT 0x845E
#endif

#ifndef GL_CURRENT_SECONDARY_COLOR_EXT
#define GL_CURRENT_SECONDARY_COLOR_EXT 0x8459
#endif

#ifndef GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT
#define GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT 0x845C
#endif

#ifndef GL_SECONDARY_COLOR_ARRAY_SIZE_EXT
#define GL_SECONDARY_COLOR_ARRAY_SIZE_EXT 0x845A
#endif

typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3USEXT) (GLushort red, GLushort green, GLushort blue);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3DVEXT) (const GLdouble* v);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3BEXT) (GLbyte red, GLbyte green, GLbyte blue);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3BVEXT) (const GLbyte* v);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3DEXT) (GLdouble red, GLdouble green, GLdouble blue);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3SEXT) (GLshort red, GLshort green, GLshort blue);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3SVEXT) (const GLshort* v);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3UBEXT) (GLubyte red, GLubyte green, GLubyte blue);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3UIEXT) (GLuint red, GLuint green, GLuint blue);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3IEXT) (GLint red, GLint green, GLint blue);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3FEXT) (GLfloat red, GLfloat green, GLfloat blue);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3FVEXT) (const GLfloat* v);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3UBVEXT) (const GLubyte* v);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3IVEXT) (const GLint* v);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLORPOINTEREXT) (GLint size, GLenum type, GLsizei stride, GLvoid* pointer);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3UIVEXT) (const GLuint* v);
typedef void (NIV_CALL_TYPE * nivenGLSECONDARYCOLOR3USVEXT) (const GLushort* v);

// GL_SGIS_color_range
#ifndef GL_EXTENDED_RANGE_SGIS
#define GL_EXTENDED_RANGE_SGIS 0x85A5
#endif

#ifndef GL_MAX_ALPHA_SGIS
#define GL_MAX_ALPHA_SGIS 0x85AD
#endif

#ifndef GL_MIN_BLUE_SGIS
#define GL_MIN_BLUE_SGIS 0x85AA
#endif

#ifndef GL_MAX_GREEN_SGIS
#define GL_MAX_GREEN_SGIS 0x85A9
#endif

#ifndef GL_MAX_RED_SGIS
#define GL_MAX_RED_SGIS 0x85A7
#endif

#ifndef GL_MIN_RED_SGIS
#define GL_MIN_RED_SGIS 0x85A6
#endif

#ifndef GL_MAX_BLUE_SGIS
#define GL_MAX_BLUE_SGIS 0x85AB
#endif

#ifndef GL_MIN_GREEN_SGIS
#define GL_MIN_GREEN_SGIS 0x85A8
#endif

#ifndef GL_MIN_ALPHA_SGIS
#define GL_MIN_ALPHA_SGIS 0x85AC
#endif


// GL_SGIX_fog_offset
#ifndef GL_FOG_OFFSET_VALUE_SGIX
#define GL_FOG_OFFSET_VALUE_SGIX 0x8199
#endif

#ifndef GL_FOG_OFFSET_SGIX
#define GL_FOG_OFFSET_SGIX 0x8198
#endif


// WGL_ARB_make_current_read
#ifdef WIN32
typedef HDC (NIV_CALL_TYPE * nivenWGLGETCURRENTREADDCARB) (VOID );
typedef BOOL (NIV_CALL_TYPE * nivenWGLMAKECONTEXTCURRENTARB) (HDC hDrawDC, HDC hReadDC, HGLRC hglrc);
#endif
// GL_NV_copy_depth_to_color
#ifndef GL_DEPTH_STENCIL_TO_RGBA_NV
#define GL_DEPTH_STENCIL_TO_RGBA_NV 0x886E
#endif

#ifndef GL_DEPTH_STENCIL_TO_BGRA_NV
#define GL_DEPTH_STENCIL_TO_BGRA_NV 0x886F
#endif


// GL_EXT_vertex_array
#ifndef GL_VERTEX_ARRAY_EXT
#define GL_VERTEX_ARRAY_EXT 0x8074
#endif

#ifndef GL_DOUBLE_EXT
#define GL_DOUBLE_EXT 0x140A
#endif

#ifndef GL_TEXTURE_COORD_ARRAY_SIZE_EXT
#define GL_TEXTURE_COORD_ARRAY_SIZE_EXT 0x8088
#endif

#ifndef GL_COLOR_ARRAY_TYPE_EXT
#define GL_COLOR_ARRAY_TYPE_EXT 0x8082
#endif

#ifndef GL_NORMAL_ARRAY_TYPE_EXT
#define GL_NORMAL_ARRAY_TYPE_EXT 0x807E
#endif

#ifndef GL_EDGE_FLAG_ARRAY_POINTER_EXT
#define GL_EDGE_FLAG_ARRAY_POINTER_EXT 0x8093
#endif

#ifndef GL_TEXTURE_COORD_ARRAY_EXT
#define GL_TEXTURE_COORD_ARRAY_EXT 0x8078
#endif

#ifndef GL_COLOR_ARRAY_EXT
#define GL_COLOR_ARRAY_EXT 0x8076
#endif

#ifndef GL_INDEX_ARRAY_STRIDE_EXT
#define GL_INDEX_ARRAY_STRIDE_EXT 0x8086
#endif

#ifndef GL_NORMAL_ARRAY_EXT
#define GL_NORMAL_ARRAY_EXT 0x8075
#endif

#ifndef GL_EDGE_FLAG_ARRAY_STRIDE_EXT
#define GL_EDGE_FLAG_ARRAY_STRIDE_EXT 0x808C
#endif

#ifndef GL_TEXTURE_COORD_ARRAY_TYPE_EXT
#define GL_TEXTURE_COORD_ARRAY_TYPE_EXT 0x8089
#endif

#ifndef GL_EDGE_FLAG_ARRAY_EXT
#define GL_EDGE_FLAG_ARRAY_EXT 0x8079
#endif

#ifndef GL_INDEX_ARRAY_TYPE_EXT
#define GL_INDEX_ARRAY_TYPE_EXT 0x8085
#endif

#ifndef GL_VERTEX_ARRAY_SIZE_EXT
#define GL_VERTEX_ARRAY_SIZE_EXT 0x807A
#endif

#ifndef GL_TEXTURE_COORD_ARRAY_STRIDE_EXT
#define GL_TEXTURE_COORD_ARRAY_STRIDE_EXT 0x808A
#endif

#ifndef GL_TEXTURE_COORD_ARRAY_COUNT_EXT
#define GL_TEXTURE_COORD_ARRAY_COUNT_EXT 0x808B
#endif

#ifndef GL_NORMAL_ARRAY_COUNT_EXT
#define GL_NORMAL_ARRAY_COUNT_EXT 0x8080
#endif

#ifndef GL_COLOR_ARRAY_STRIDE_EXT
#define GL_COLOR_ARRAY_STRIDE_EXT 0x8083
#endif

#ifndef GL_COLOR_ARRAY_COUNT_EXT
#define GL_COLOR_ARRAY_COUNT_EXT 0x8084
#endif

#ifndef GL_INDEX_ARRAY_COUNT_EXT
#define GL_INDEX_ARRAY_COUNT_EXT 0x8087
#endif

#ifndef GL_INDEX_ARRAY_EXT
#define GL_INDEX_ARRAY_EXT 0x8077
#endif

#ifndef GL_COLOR_ARRAY_SIZE_EXT
#define GL_COLOR_ARRAY_SIZE_EXT 0x8081
#endif

#ifndef GL_VERTEX_ARRAY_COUNT_EXT
#define GL_VERTEX_ARRAY_COUNT_EXT 0x807D
#endif

#ifndef GL_EDGE_FLAG_ARRAY_COUNT_EXT
#define GL_EDGE_FLAG_ARRAY_COUNT_EXT 0x808D
#endif

#ifndef GL_NORMAL_ARRAY_STRIDE_EXT
#define GL_NORMAL_ARRAY_STRIDE_EXT 0x807F
#endif

#ifndef GL_COLOR_ARRAY_POINTER_EXT
#define GL_COLOR_ARRAY_POINTER_EXT 0x8090
#endif

#ifndef GL_VERTEX_ARRAY_STRIDE_EXT
#define GL_VERTEX_ARRAY_STRIDE_EXT 0x807C
#endif

#ifndef GL_NORMAL_ARRAY_POINTER_EXT
#define GL_NORMAL_ARRAY_POINTER_EXT 0x808F
#endif

#ifndef GL_VERTEX_ARRAY_TYPE_EXT
#define GL_VERTEX_ARRAY_TYPE_EXT 0x807B
#endif

#ifndef GL_TEXTURE_COORD_ARRAY_POINTER_EXT
#define GL_TEXTURE_COORD_ARRAY_POINTER_EXT 0x8092
#endif

#ifndef GL_VERTEX_ARRAY_POINTER_EXT
#define GL_VERTEX_ARRAY_POINTER_EXT 0x808E
#endif

#ifndef GL_INDEX_ARRAY_POINTER_EXT
#define GL_INDEX_ARRAY_POINTER_EXT 0x8091
#endif

typedef void (NIV_CALL_TYPE * nivenGLVERTEXPOINTEREXT) (GLint size, GLenum type, GLsizei stride, GLsizei count, const void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLCOLORPOINTEREXT) (GLint size, GLenum type, GLsizei stride, GLsizei count, const void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLGETPOINTERVEXT) (GLenum pname, void* *params);
typedef void (NIV_CALL_TYPE * nivenGLNORMALPOINTEREXT) (GLenum type, GLsizei stride, GLsizei count, const void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLINDEXPOINTEREXT) (GLenum type, GLsizei stride, GLsizei count, const void* pointer);
typedef void (NIV_CALL_TYPE * nivenGLEDGEFLAGPOINTEREXT) (GLsizei stride, GLsizei count, const GLboolean* pointer);
typedef void (NIV_CALL_TYPE * nivenGLDRAWARRAYSEXT) (GLenum mode, GLint first, GLsizei count);
typedef void (NIV_CALL_TYPE * nivenGLARRAYELEMENTEXT) (GLint i);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORDPOINTEREXT) (GLint size, GLenum type, GLsizei stride, GLsizei count, const void* pointer);

// GL_INTEL_parallel_arrays
#ifndef GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL
#define GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL 0x83F5
#endif

#ifndef GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL
#define GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL 0x83F6
#endif

#ifndef GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL
#define GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL 0x83F7
#endif

#ifndef GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL
#define GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL 0x83F8
#endif

#ifndef GL_PARALLEL_ARRAYS_INTEL
#define GL_PARALLEL_ARRAYS_INTEL 0x83F4
#endif

typedef void (NIV_CALL_TYPE * nivenGLVERTEXPOINTERVINTEL) (GLint size, GLenum type, const void* *pointer);
typedef void (NIV_CALL_TYPE * nivenGLTEXCOORDPOINTERVINTEL) (GLint size, GLenum type, const void* *pointer);
typedef void (NIV_CALL_TYPE * nivenGLNORMALPOINTERVINTEL) (GLenum type, const void* *pointer);
typedef void (NIV_CALL_TYPE * nivenGLCOLORPOINTERVINTEL) (GLint size, GLenum type, const void* *pointer);

// GL_ATI_draw_buffers
#ifndef GL_DRAW_BUFFER15_ATI
#define GL_DRAW_BUFFER15_ATI 0x8834
#endif

#ifndef GL_DRAW_BUFFER1_ATI
#define GL_DRAW_BUFFER1_ATI 0x8826
#endif

#ifndef GL_DRAW_BUFFER0_ATI
#define GL_DRAW_BUFFER0_ATI 0x8825
#endif

#ifndef GL_DRAW_BUFFER11_ATI
#define GL_DRAW_BUFFER11_ATI 0x8830
#endif

#ifndef GL_DRAW_BUFFER10_ATI
#define GL_DRAW_BUFFER10_ATI 0x882F
#endif

#ifndef GL_MAX_DRAW_BUFFERS_ATI
#define GL_MAX_DRAW_BUFFERS_ATI 0x8824
#endif

#ifndef GL_DRAW_BUFFER12_ATI
#define GL_DRAW_BUFFER12_ATI 0x8831
#endif

#ifndef GL_DRAW_BUFFER3_ATI
#define GL_DRAW_BUFFER3_ATI 0x8828
#endif

#ifndef GL_DRAW_BUFFER7_ATI
#define GL_DRAW_BUFFER7_ATI 0x882C
#endif

#ifndef GL_DRAW_BUFFER14_ATI
#define GL_DRAW_BUFFER14_ATI 0x8833
#endif

#ifndef GL_DRAW_BUFFER13_ATI
#define GL_DRAW_BUFFER13_ATI 0x8832
#endif

#ifndef GL_DRAW_BUFFER2_ATI
#define GL_DRAW_BUFFER2_ATI 0x8827
#endif

#ifndef GL_DRAW_BUFFER5_ATI
#define GL_DRAW_BUFFER5_ATI 0x882A
#endif

#ifndef GL_DRAW_BUFFER4_ATI
#define GL_DRAW_BUFFER4_ATI 0x8829
#endif

#ifndef GL_DRAW_BUFFER9_ATI
#define GL_DRAW_BUFFER9_ATI 0x882E
#endif

#ifndef GL_DRAW_BUFFER8_ATI
#define GL_DRAW_BUFFER8_ATI 0x882D
#endif

#ifndef GL_DRAW_BUFFER6_ATI
#define GL_DRAW_BUFFER6_ATI 0x882B
#endif

typedef void (NIV_CALL_TYPE * nivenGLDRAWBUFFERSATI) (GLsizei n, const GLenum* bufs);

#ifdef _GLX
// GLX_SGIX_fbconfig
#ifndef GLX_DRAWABLE_TYPE_SGIX
#define GLX_DRAWABLE_TYPE_SGIX 0x8010
#endif

#ifndef GLX_FBCONFIG_ID_SGIX
#define GLX_FBCONFIG_ID_SGIX 0x8013
#endif

#ifndef GLX_RGBA_BIT_SGIX
#define GLX_RGBA_BIT_SGIX 0x00000001
#endif

#ifndef GLX_COLOR_INDEX_BIT_SGIX
#define GLX_COLOR_INDEX_BIT_SGIX 0x00000002
#endif

#ifndef GLX_RENDER_TYPE_SGIX
#define GLX_RENDER_TYPE_SGIX 0x8011
#endif

#ifndef GLX_RGBA_TYPE_SGIX
#define GLX_RGBA_TYPE_SGIX 0x8014
#endif

#ifndef GLX_PIXMAP_BIT_SGIX
#define GLX_PIXMAP_BIT_SGIX 0x00000002
#endif

#ifndef GLX_WINDOW_BIT_SGIX
#define GLX_WINDOW_BIT_SGIX 0x00000001
#endif

#ifndef GLX_X_RENDERABLE_SGIX
#define GLX_X_RENDERABLE_SGIX 0x8012
#endif

#ifndef GLX_COLOR_INDEX_TYPE_SGIX
#define GLX_COLOR_INDEX_TYPE_SGIX 0x8015
#endif

#ifndef TYPE_*GLXFBCONFIGSGIX_DEFINED
typedef struct __GLXFBConfigRec *GLXFBConfigSGIX;
#endif
#ifndef TYPE_GLXFBCONFIGIDSGIX_DEFINED
typedef XID GLXFBConfigIDSGIX;
#endif
typedef GLXContext (NIV_CALL_TYPE * nivenGLXCREATECONTEXTWITHCONFIGSGIX) (Display* dpy, GLXFBConfig config, int render_type, GLXContext share_list, Bool direct);
typedef GLXFBConfigSGIX (NIV_CALL_TYPE * nivenGLXGETFBCONFIGFROMVISUALSGIX) (Display* dpy, XVisualInfo* vis);
typedef GLXPixmap (NIV_CALL_TYPE * nivenGLXCREATEGLXPIXMAPWITHCONFIGSGIX) (Display* dpy, GLXFBConfig config, Pixmap pixmap);
typedef GLXFBConfigSGIX* (NIV_CALL_TYPE * nivenGLXCHOOSEFBCONFIGSGIX) (Display* dpy, int screen, const int* attrib_list, int* nelements);
typedef int (NIV_CALL_TYPE * nivenGLXGETFBCONFIGATTRIBSGIX) (Display* dpy, GLXFBConfigSGIX config, int attribute, int* value);
typedef XVisualInfo* (NIV_CALL_TYPE * nivenGLXGETVISUALFROMFBCONFIGSGIX) (Display* dpy, GLXFBConfig config);
#endif // _GLX
// GL_SGIX_async
#ifndef GL_ASYNC_MARKER_SGIX
#define GL_ASYNC_MARKER_SGIX 0x8329
#endif

typedef GLint (NIV_CALL_TYPE * nivenGLPOLLASYNCSGIX) (GLuint* markerp);
typedef GLuint (NIV_CALL_TYPE * nivenGLGENASYNCMARKERSSGIX) (GLsizei range);
typedef void (NIV_CALL_TYPE * nivenGLDELETEASYNCMARKERSSGIX) (GLuint marker, GLsizei range);
typedef GLint (NIV_CALL_TYPE * nivenGLFINISHASYNCSGIX) (GLuint* markerp);
typedef void (NIV_CALL_TYPE * nivenGLASYNCMARKERSGIX) (GLuint marker);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISASYNCMARKERSGIX) (GLuint marker);

// GL_EXT_depth_bounds_test
#ifndef GL_DEPTH_BOUNDS_TEST_EXT
#define GL_DEPTH_BOUNDS_TEST_EXT 0x8890
#endif

#ifndef GL_DEPTH_BOUNDS_EXT
#define GL_DEPTH_BOUNDS_EXT 0x8891
#endif

typedef void (NIV_CALL_TYPE * nivenGLDEPTHBOUNDSEXT) (GLclampd zmin, GLclampd zmax);

// GL_ATI_vertex_array_object
#ifndef GL_ARRAY_OBJECT_OFFSET_ATI
#define GL_ARRAY_OBJECT_OFFSET_ATI 0x8767
#endif

#ifndef GL_OBJECT_BUFFER_SIZE_ATI
#define GL_OBJECT_BUFFER_SIZE_ATI 0x8764
#endif

#ifndef GL_DISCARD_ATI
#define GL_DISCARD_ATI 0x8763
#endif

#ifndef GL_DYNAMIC_ATI
#define GL_DYNAMIC_ATI 0x8761
#endif

#ifndef GL_STATIC_ATI
#define GL_STATIC_ATI 0x8760
#endif

#ifndef GL_OBJECT_BUFFER_USAGE_ATI
#define GL_OBJECT_BUFFER_USAGE_ATI 0x8765
#endif

#ifndef GL_PRESERVE_ATI
#define GL_PRESERVE_ATI 0x8762
#endif

#ifndef GL_ARRAY_OBJECT_BUFFER_ATI
#define GL_ARRAY_OBJECT_BUFFER_ATI 0x8766
#endif

typedef GLuint (NIV_CALL_TYPE * nivenGLNEWOBJECTBUFFERATI) (GLsizei size, const void* pointer, GLenum usage);
typedef void (NIV_CALL_TYPE * nivenGLGETVARIANTARRAYOBJECTIVATI) (GLuint id, GLenum pname, GLint* params);
typedef GLboolean (NIV_CALL_TYPE * nivenGLISOBJECTBUFFERATI) (GLuint buffer);
typedef void (NIV_CALL_TYPE * nivenGLGETOBJECTBUFFERFVATI) (GLuint buffer, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLUPDATEOBJECTBUFFERATI) (GLuint buffer, GLuint offset, GLsizei size, const void* pointer, GLenum preserve);
typedef void (NIV_CALL_TYPE * nivenGLGETARRAYOBJECTIVATI) (GLenum array, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLFREEOBJECTBUFFERATI) (GLuint buffer);
typedef void (NIV_CALL_TYPE * nivenGLVARIANTARRAYOBJECTATI) (GLuint id, GLenum type, GLsizei stride, GLuint buffer, GLuint offset);
typedef void (NIV_CALL_TYPE * nivenGLGETVARIANTARRAYOBJECTFVATI) (GLuint id, GLenum pname, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLGETOBJECTBUFFERIVATI) (GLuint buffer, GLenum pname, GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLARRAYOBJECTATI) (GLenum array, GLint size, GLenum type, GLsizei stride, GLuint buffer, GLuint offset);
typedef void (NIV_CALL_TYPE * nivenGLGETARRAYOBJECTFVATI) (GLenum array, GLenum pname, GLfloat* params);

// GL_SUN_convolution_border_modes
#ifndef GL_WRAP_BORDER_SUN
#define GL_WRAP_BORDER_SUN 0x81D4
#endif


// GL_SGIX_fog_texture
#ifndef GL_TEXTURE_FOG_SGIX
#define GL_TEXTURE_FOG_SGIX 0
#endif

#ifndef GL_FRAGMENT_FOG_SGIX
#define GL_FRAGMENT_FOG_SGIX 0
#endif

#ifndef GL_FOG_PATCHY_FACTOR_SGIX
#define GL_FOG_PATCHY_FACTOR_SGIX 0
#endif

typedef void (NIV_CALL_TYPE * nivenGLTEXTUREFOGSGIX) (GLenum pname);

// GL_SGIX_pixel_texture
typedef void (NIV_CALL_TYPE * nivenGLPIXELTEXGENSGIX) (GLenum mode);

// GL_APPLE_specular_vector
#ifndef GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE
#define GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE 0x85B0
#endif


// GL_ARB_texture_env_add

#ifdef _GLX
// GLX_SGIX_swap_barrier
typedef Bool (NIV_CALL_TYPE * nivenGLXQUERYMAXSWAPBARRIERSSGIX) (Display* dpy, int screen, int* max);
typedef void (NIV_CALL_TYPE * nivenGLXBINDSWAPBARRIERSGIX) (Display* dpy, GLXDrawable drawable, int barrier);
#endif // _GLX
// GL_NV_fragment_program
#ifndef GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV
#define GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV 0x8868
#endif

#ifndef GL_FRAGMENT_PROGRAM_NV
#define GL_FRAGMENT_PROGRAM_NV 0x8870
#endif

#ifndef GL_PROGRAM_ERROR_STRING_NV
#define GL_PROGRAM_ERROR_STRING_NV 0x8874
#endif

#ifndef GL_MAX_TEXTURE_COORDS_NV
#define GL_MAX_TEXTURE_COORDS_NV 0x8871
#endif

#ifndef GL_FRAGMENT_PROGRAM_BINDING_NV
#define GL_FRAGMENT_PROGRAM_BINDING_NV 0x8873
#endif

#ifndef GL_MAX_TEXTURE_IMAGE_UNITS_NV
#define GL_MAX_TEXTURE_IMAGE_UNITS_NV 0x8872
#endif

typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMNAMEDPARAMETERFVNV) (GLuint id, GLsizei len, const GLubyte* name, GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMNAMEDPARAMETER4FNV) (GLuint id, GLsizei len, const GLubyte* name, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMNAMEDPARAMETER4DVNV) (GLuint id, GLsizei len, const GLubyte* name, const GLdouble v[]);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMNAMEDPARAMETER4DNV) (GLuint id, GLsizei len, const GLubyte* name, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
typedef void (NIV_CALL_TYPE * nivenGLPROGRAMNAMEDPARAMETER4FVNV) (GLuint id, GLsizei len, const GLubyte* name, const GLfloat v[]);
typedef void (NIV_CALL_TYPE * nivenGLGETPROGRAMNAMEDPARAMETERDVNV) (GLuint id, GLsizei len, const GLubyte* name, GLdouble* params);

// GL_SGIX_texture_coordinate_clamp
#ifndef GL_TEXTURE_MAX_CLAMP_R_SGIX
#define GL_TEXTURE_MAX_CLAMP_R_SGIX 0x836B
#endif

#ifndef GL_TEXTURE_MAX_CLAMP_T_SGIX
#define GL_TEXTURE_MAX_CLAMP_T_SGIX 0x836A
#endif

#ifndef GL_TEXTURE_MAX_CLAMP_S_SGIX
#define GL_TEXTURE_MAX_CLAMP_S_SGIX 0x8369
#endif


// GL_EXT_pixel_transform
#ifndef GL_PIXEL_MIN_FILTER_EXT
#define GL_PIXEL_MIN_FILTER_EXT 0x8332
#endif

#ifndef GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT
#define GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT 0x8337
#endif

#ifndef GL_CUBIC_EXT
#define GL_CUBIC_EXT 0x8334
#endif

#ifndef GL_AVERAGE_EXT
#define GL_AVERAGE_EXT 0x8335
#endif

#ifndef GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT
#define GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT 0x8336
#endif

#ifndef GL_PIXEL_MAG_FILTER_EXT
#define GL_PIXEL_MAG_FILTER_EXT 0x8331
#endif

#ifndef GL_PIXEL_TRANSFORM_2D_MATRIX_EXT
#define GL_PIXEL_TRANSFORM_2D_MATRIX_EXT 0x8338
#endif

#ifndef GL_PIXEL_TRANSFORM_2D_EXT
#define GL_PIXEL_TRANSFORM_2D_EXT 0x8330
#endif

#ifndef GL_PIXEL_CUBIC_WEIGHT_EXT
#define GL_PIXEL_CUBIC_WEIGHT_EXT 0x8333
#endif

typedef void (NIV_CALL_TYPE * nivenGLPIXELTRANSFORMPARAMETERFEXT) (GLenum target, GLenum pname, const GLfloat param);
typedef void (NIV_CALL_TYPE * nivenGLGETPIXELTRANSFORMPARAMETERFVEXT) (GLenum target, GLenum pname, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLPIXELTRANSFORMPARAMETERIEXT) (GLenum target, GLenum pname, const GLint param);
typedef void (NIV_CALL_TYPE * nivenGLGETPIXELTRANSFORMPARAMETERIVEXT) (GLenum target, GLenum pname, const GLint* params);
typedef void (NIV_CALL_TYPE * nivenGLPIXELTRANSFORMPARAMETERFVEXT) (GLenum target, GLenum pname, const GLfloat* params);
typedef void (NIV_CALL_TYPE * nivenGLPIXELTRANSFORMPARAMETERIVEXT) (GLenum target, GLenum pname, const GLint* params);

#ifdef _GLX
// GLX_MESA_copy_sub_buffer
typedef void (NIV_CALL_TYPE * nivenGLXCOPYSUBBUFFERMESA) (Display* dpy, GLXDrawable drawable, int x, int y, int width, int height);
#endif // _GLX
// GL_SGIX_texture_add_env

#ifdef _GLX
// GLX_SGI_cushion
typedef void (NIV_CALL_TYPE * nivenGLXCUSHIONSGI) (Display* dpy, Window window, float cushion);
#endif // _GLX
// GL_ARB_matrix_palette
#ifndef GL_MATRIX_PALETTE_ARB
#define GL_MATRIX_PALETTE_ARB 0x8840
#endif

#ifndef GL_CURRENT_MATRIX_INDEX_ARB
#define GL_CURRENT_MATRIX_INDEX_ARB 0x8845
#endif

#ifndef GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB
#define GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB 0x8841
#endif

#ifndef GL_MATRIX_INDEX_ARRAY_ARB
#define GL_MATRIX_INDEX_ARRAY_ARB 0x8844
#endif

#ifndef GL_MAX_PALETTE_MATRICES_ARB
#define GL_MAX_PALETTE_MATRICES_ARB 0x8842
#endif

#ifndef GL_MATRIX_INDEX_ARRAY_TYPE_ARB
#define GL_MATRIX_INDEX_ARRAY_TYPE_ARB 0x8847
#endif

#ifndef GL_CURRENT_PALETTE_MATRIX_ARB
#define GL_CURRENT_PALETTE_MATRIX_ARB 0x8843
#endif

#ifndef GL_MATRIX_INDEX_ARRAY_POINTER_ARB
#define GL_MATRIX_INDEX_ARRAY_POINTER_ARB 0x8849
#endif

#ifndef GL_MATRIX_INDEX_ARRAY_STRIDE_ARB
#define GL_MATRIX_INDEX_ARRAY_STRIDE_ARB 0x8848
#endif

#ifndef GL_MATRIX_INDEX_ARRAY_SIZE_ARB
#define GL_MATRIX_INDEX_ARRAY_SIZE_ARB 0x8846
#endif

typedef void (NIV_CALL_TYPE * nivenGLMATRIXINDEXPOINTERARB) (GLint size, GLenum type, GLsizei stride, GLvoid* pointer);
typedef void (NIV_CALL_TYPE * nivenGLMATRIXINDEXUIVARB) (GLint size, GLuint* indices);
typedef void (NIV_CALL_TYPE * nivenGLMATRIXINDEXUSVARB) (GLint size, GLushort* indices);
typedef void (NIV_CALL_TYPE * nivenGLCURRENTPALETTEMATRIXARB) (GLint index);
typedef void (NIV_CALL_TYPE * nivenGLMATRIXINDEXUBVARB) (GLint size, GLubyte* indices);

#ifdef _GLX
// GLX_SUN_get_transparent_index
typedef Status (NIV_CALL_TYPE * nivenGLXGETTRANSPARENTINDEXSUN) (Display* dpy, Window overlay, Window underlay, unsigned long* pTransparentIndex);
#endif // _GLX
// GL_SGI_color_matrix
#ifndef GL_POST_COLOR_MATRIX_RED_SCALE_SGI
#define GL_POST_COLOR_MATRIX_RED_SCALE_SGI 0x80B4
#endif

#ifndef GL_POST_COLOR_MATRIX_RED_BIAS_SGI
#define GL_POST_COLOR_MATRIX_RED_BIAS_SGI 0x80B8
#endif

#ifndef GL_COLOR_MATRIX_SGI
#define GL_COLOR_MATRIX_SGI 0x80B1
#endif

#ifndef GL_COLOR_MATRIX_STACK_DEPTH_SGI
#define GL_COLOR_MATRIX_STACK_DEPTH_SGI 0x80B2
#endif

#ifndef GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI
#define GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI 0x80B7
#endif

#ifndef GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI
#define GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI 0x80B9
#endif

#ifndef GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI
#define GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI 0x80B3
#endif

#ifndef GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI
#define GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI 0x80B5
#endif

#ifndef GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI
#define GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI 0x80BA
#endif

#ifndef GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI
#define GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI 0x80BB
#endif

#ifndef GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI
#define GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI 0x80B6
#endif


// GL_EXT_packed_pixels
#ifndef GL_UNSIGNED_INT_10_10_10_2_EXT
#define GL_UNSIGNED_INT_10_10_10_2_EXT 0x8036
#endif

#ifndef GL_UNSIGNED_BYTE_3_3_2_EXT
#define GL_UNSIGNED_BYTE_3_3_2_EXT 0x8032
#endif

#ifndef GL_UNSIGNED_INT_8_8_8_8_EXT
#define GL_UNSIGNED_INT_8_8_8_8_EXT 0x8035
#endif

#ifndef GL_UNSIGNED_SHORT_5_5_5_1_EXT
#define GL_UNSIGNED_SHORT_5_5_5_1_EXT 0x8034
#endif

#ifndef GL_UNSIGNED_SHORT_4_4_4_4_EXT
#define GL_UNSIGNED_SHORT_4_4_4_4_EXT 0x8033
#endif


// GL_EXT_draw_range_elements
#ifndef GL_MAX_ELEMENTS_VERTICES
#define GL_MAX_ELEMENTS_VERTICES 0x80E8
#endif

#ifndef GL_MAX_ELEMENTS_INDICES
#define GL_MAX_ELEMENTS_INDICES 0x80E9
#endif

typedef void (NIV_CALL_TYPE * nivenGLDRAWRANGEELEMENTSEXT) (GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const GLvoid* indices);

// GL_ARB_pixel_buffer_object
#ifndef GL_PIXEL_UNPACK_BUFFER_ARB
#define GL_PIXEL_UNPACK_BUFFER_ARB 0x88EC
#endif

#ifndef GL_PIXEL_PACK_BUFFER_ARB
#define GL_PIXEL_PACK_BUFFER_ARB 0x88EB
#endif

#ifndef GL_PIXEL_UNPACK_BUFFER_BINDING_ARB
#define GL_PIXEL_UNPACK_BUFFER_BINDING_ARB 0x88EF
#endif

#ifndef GL_PIXEL_PACK_BUFFER_BINDING_ARB
#define GL_PIXEL_PACK_BUFFER_BINDING_ARB 0x88ED
#endif


// GL_S3_s3tc
#ifndef GL_RGB_S3TC
#define GL_RGB_S3TC 0x83A0
#endif

#ifndef GL_RGBA_DXT5_S3TC
#define GL_RGBA_DXT5_S3TC 0x83A4
#endif

#ifndef GL_RGBA4_S3TC
#define GL_RGBA4_S3TC 0x83A3
#endif

#ifndef GL_RGBA4_DXT5_S3TC
#define GL_RGBA4_DXT5_S3TC 0x83A5
#endif

#ifndef GL_RGB4_S3TC
#define GL_RGB4_S3TC 0x83A1
#endif

#ifndef GL_RGBA_S3TC
#define GL_RGBA_S3TC 0x83A2
#endif


#ifdef _GLX
// GLX_NV_vertex_array_range
typedef void * (NIV_CALL_TYPE * nivenGLXALLOCATEMEMORYNV) (GLsizei size, GLfloat readFrequency, GLfloat writeFrequency, GLfloat priority);
typedef void (NIV_CALL_TYPE * nivenGLXFREEMEMORYNV) (void* pointer);
#endif // _GLX
// GL_SGIX_blend_alpha_minmax
#ifndef GL_ALPHA_MIN_SGIX
#define GL_ALPHA_MIN_SGIX 0x8320
#endif

#ifndef GL_ALPHA_MAX_SGIX
#define GL_ALPHA_MAX_SGIX 0x8321
#endif




// Extension flag handler
struct GLExtensionFlags
{
public:
  bool NIV_GL_ARB_texture_compression;
  bool NIV_GL_SGIX_vertex_preclip;
  bool NIV_GL_SGIX_async_pixel;
  bool NIV_GL_NV_point_sprite;
  bool NIV_GL_APPLE_element_array;
  bool NIV_GLX_EXT_import_context;
  bool NIV_GL_NV_vertex_array_range2;
  bool NIV_GL_EXT_blend_color;
  bool NIV_GL_EXT_blend_subtract;
  bool NIV_GL_SGIX_tag_sample_buffer;
  bool NIV_GL_EXT_stencil_wrap;
  bool NIV_GL_EXT_index_array_formats;
  bool NIV_GL_EXT_index_texture;
  bool NIV_GL_IBM_texture_mirrored_repeat;
  bool NIV_GL_NV_half_float;
  bool NIV_WGL_ARB_extensions_string;
  bool NIV_GL_SGIX_texture_scale_bias;
  bool NIV_GL_EXT_texture_compression_s3tc;
  bool NIV_GL_APPLE_transform_hint;
  bool NIV_GL_ATI_separate_stencil;
  bool NIV_GL_EXT_polygon_offset;
  bool NIV_GL_NV_vertex_program2_option;
  bool NIV_GL_ARB_depth_texture;
  bool NIV_GL_NV_packed_depth_stencil;
  bool NIV_GL_NV_fragment_program_option;
  bool NIV_GL_ARB_vertex_blend;
  bool NIV_GL_SGIX_ycrcb;
  bool NIV_GL_EXT_stencil_two_side;
  bool NIV_WGL_NV_vertex_array_range;
  bool NIV_GL_EXT_shadow_funcs;
  bool NIV_GL_EXT_Cg_shader;
  bool NIV_GLX_SGIS_multisample;
  bool NIV_GL_EXT_convolution;
  bool NIV_WGL_EXT_pbuffer;
  bool NIV_WGL_I3D_genlock;
  bool NIV_GLX_ATI_pixel_format_float;
  bool NIV_GLX_ARB_multisample;
  bool NIV_WGL_ARB_pixel_format;
  bool NIV_WGL_3DFX_multisample;
  bool NIV_GLX_SGIX_swap_group;
  bool NIV_GL_EXT_vertex_shader;
  bool NIV_GL_APPLE_pixel_buffer;
  bool NIV_GL_EXT_misc_attribute;
  bool NIV_GL_NV_texture_shader3;
  bool NIV_GL_NV_texture_shader2;
  bool NIV_GL_EXT_blend_func_separate;
  bool NIV_GL_SGIX_pixel_texture_bits;
  bool NIV_GL_EXT_texture;
  bool NIV_GL_APPLE_fence;
  bool NIV_GL_EXT_multisample;
  bool NIV_GL_EXT_texture_cube_map;
  bool NIV_GL_ARB_occlusion_query;
  bool NIV_GL_INGR_color_clamp;
  bool NIV_GL_EXT_422_pixels;
  bool NIV_GL_EXT_index_func;
  bool NIV_GLX_MESA_set_3dfx_mode;
  bool NIV_WGL_NV_float_buffer;
  bool NIV_GL_SUN_read_video_pixels;
  bool NIV_GL_ARB_transpose_matrix;
  bool NIV_WGL_EXT_extensions_string;
  bool NIV_WGL_ATI_pixel_format_float;
  bool NIV_WGL_I3D_image_buffer;
  bool NIV_GL_NV_fence;
  bool NIV_WGL_ATI_render_texture_rectangle;
  bool NIV_GL_ARB_texture_border_clamp;
  bool NIV_GL_EXT_fog_coord;
  bool NIV_GL_NV_depth_clamp;
  bool NIV_WGL_I3D_digital_video_control;
  bool NIV_GL_ARB_texture_cube_map;
  bool NIV_GL_EXT_color_subtable;
  bool NIV_GL_EXT_blend_equation_separate;
  bool NIV_WGL_I3D_swap_frame_lock;
  bool NIV_GL_SUN_mesh_array;
  bool NIV_GL_SUNX_constant_data;
  bool NIV_GL_ARB_point_parameters;
  bool NIV_GL_EXT_texture_env_dot3;
  bool NIV_WGL_ARB_buffer_region;
  bool NIV_GL_ATI_texture_env_combine3;
  bool NIV_GL_SGIX_shadow_ambient;
  bool NIV_GL_EXT_multi_draw_arrays;
  bool NIV_GL_SGIX_depth_texture;
  bool NIV_GL_EXT_texture_compression_dxt1;
  bool NIV_GL_NV_texgen_emboss;
  bool NIV_GL_HP_occlusion_test;
  bool NIV_GL_WIN_phong_shading;
  bool NIV_GLX_SGIS_shared_multisample;
  bool NIV_GL_ATIX_texture_env_combine3;
  bool NIV_GL_EXT_texture_filter_anisotropic;
  bool NIV_GL_EXT_texture_perturb_normal;
  bool NIV_GL_NV_fog_distance;
  bool NIV_GL_ATIX_vertex_shader_output_point_size;
  bool NIV_GL_SUN_global_alpha;
  bool NIV_WGL_EXT_pixel_format;
  bool NIV_GL_SGIX_async_histogram;
  bool NIV_GL_ARB_vertex_program;
  bool NIV_GL_MESA_resize_buffers;
  bool NIV_GL_3DFX_multisample;
  bool NIV_WGL_NV_render_texture_rectangle;
  bool NIV_GL_ARB_texture_env_dot3;
  bool NIV_GL_EXT_bgra;
  bool NIV_GL_NV_float_buffer;
  bool NIV_GL_INGR_interlace_read;
  bool NIV_GL_NV_texture_env_combine4;
  bool NIV_GL_OML_interlace;
  bool NIV_GLX_SGI_swap_control;
  bool NIV_WGL_EXT_depth_float;
  bool NIV_WGL_ARB_multisample;
  bool NIV_GL_ATI_fragment_shader;
  bool NIV_GL_ARB_texture_env_combine;
  bool NIV_GL_ARB_vertex_buffer_object;
  bool NIV_GL_SUN_triangle_list;
  bool NIV_WGL_EXT_swap_control;
  bool NIV_GLX_EXT_scene_marker;
  bool NIV_GL_ATI_text_fragment_shader;
  bool NIV_GL_EXT_histogram;
  bool NIV_GL_NV_vertex_program3;
  bool NIV_GL_NV_vertex_array_range;
  bool NIV_GL_HP_texture_lighting;
  bool NIV_WGL_EXT_display_color_table;
  bool NIV_GL_NV_texture_expand_normal;
  bool NIV_GL_EXT_separate_specular_color;
  bool NIV_GL_EXT_paletted_texture;
  bool NIV_GL_ATI_texture_float;
  bool NIV_GL_EXT_texture_env_add;
  bool NIV_GL_EXT_texture_mirror_clamp;
  bool NIV_GL_ATI_pn_triangles;
  bool NIV_GL_NV_texture_rectangle;
  bool NIV_WGL_OML_sync_control;
  bool NIV_GL_NV_multisample_filter_hint;
  bool NIV_GL_APPLE_float_pixels;
  bool NIV_GL_SGIS_texture_border_clamp;
  bool NIV_GL_ATI_vertex_attrib_array_object;
  bool NIV_GL_SGIX_clipmap;
  bool NIV_GL_HP_image_transform;
  bool NIV_GL_SGIX_flush_raster;
  bool NIV_GL_EXT_light_texture;
  bool NIV_GL_ARB_point_sprite;
  bool NIV_GL_MESA_ycbcr_texture;
  bool NIV_GL_ARB_shading_language_100;
  bool NIV_GL_SGIS_texture_select;
  bool NIV_GL_NV_vertex_program2;
  bool NIV_GLX_SGI_make_current_read;
  bool NIV_GL_ARB_half_float_pixel;
  bool NIV_GL_KTX_buffer_region;
  bool NIV_GL_EXT_vertex_weighting;
  bool NIV_GL_ATIX_point_sprites;
  bool NIV_GL_APPLE_vertex_array_range;
  bool NIV_GLX_NV_float_buffer;
  bool NIV_GL_SGIS_detail_texture;
  bool NIV_GL_SGIX_sprite;
  bool NIV_GL_NV_register_combiners;
  bool NIV_GL_ARB_draw_buffers;
  bool NIV_GL_ARB_fragment_program_shadow;
  bool NIV_WGL_EXT_make_current_read;
  bool NIV_GL_EXT_shared_texture_palette;
  bool NIV_GL_ATI_element_array;
  bool NIV_GLX_ARB_get_proc_address;
  bool NIV_GL_OML_resample;
  bool NIV_GL_EXT_coordinate_frame;
  bool NIV_GL_ATI_texture_mirror_once;
  bool NIV_WGL_ARB_pbuffer;
  bool NIV_GL_EXT_cull_vertex;
  bool NIV_GL_IBM_rasterpos_clip;
  bool NIV_GL_SGIX_reference_plane;
  bool NIV_GL_APPLE_texture_range;
  bool NIV_GL_SGIX_shadow;
  bool NIV_GL_SGIX_texture_lod_bias;
  bool NIV_GLX_SGIX_pbuffer;
  bool NIV_GL_NV_texgen_reflection;
  bool NIV_GL_SUN_slice_accum;
  bool NIV_GL_IBM_multimode_draw_arrays;
  bool NIV_GL_IBM_static_data;
  bool NIV_GLX_EXT_visual_info;
  bool NIV_GL_EXT_clip_volume_hint;
  bool NIV_GL_EXT_cmyka;
  bool NIV_GL_EXT_compiled_vertex_array;
  bool NIV_GL_3DFX_tbuffer;
  bool NIV_GL_EXT_point_parameters;
  bool NIV_GL_APPLE_vertex_array_object;
  bool NIV_GL_3DFX_texture_compression_FXT1;
  bool NIV_GL_NV_occlusion_query;
  bool NIV_GLX_OML_sync_control;
  bool NIV_WGL_ARB_render_texture;
  bool NIV_GL_SGIS_multisample;
  bool NIV_GL_ARB_vertex_shader;
  bool NIV_WGL_NV_render_depth_texture;
  bool NIV_GL_EXT_texture_env;
  bool NIV_GL_SGIX_fragment_specular_lighting;
  bool NIV_GLX_3DFX_multisample;
  bool NIV_GL_ARB_fragment_shader;
  bool NIV_GLX_SGI_video_sync;
  bool NIV_GL_NV_texture_shader;
  bool NIV_GL_NV_pixel_data_range;
  bool NIV_WGL_EXT_multisample;
  bool NIV_GL_SGIS_texture_edge_clamp;
  bool NIV_GL_ARB_imaging;
  bool NIV_GL_WIN_specular_fog;
  bool NIV_GL_APPLE_client_storage;
  bool NIV_GL_IBM_vertex_array_lists;
  bool NIV_GL_ARB_fragment_program;
  bool NIV_GL_ARB_shader_objects;
  bool NIV_GL_EXT_framebuffer_object;
  bool NIV_WGL_I3D_gamma;
  bool NIV_GL_ATI_vertex_streams;
  bool NIV_GL_APPLE_ycbcr_422;
  bool NIV_GL_NV_blend_square;
  bool NIV_GL_MESA_window_pos;
  bool NIV_GL_ATI_envmap_bumpmap;
  bool NIV_GL_ARB_texture_non_power_of_two;
  bool NIV_GL_EXT_texture_env_combine;
  bool NIV_GL_EXT_texture_object;
  bool NIV_GL_ATI_texture_compression_3dc;
  bool NIV_GL_OML_subsample;
  bool NIV_GL_EXT_texture_lod_bias;
  bool NIV_WGL_ARB_pixel_format_float;
  bool NIV_GL_EXT_scene_marker;
  bool NIV_GL_NV_primitive_restart;
  bool NIV_GL_ARB_shadow_ambient;
  bool NIV_GL_SGIX_vertex_preclip_hint;
  bool NIV_GLX_MESA_pixmap_colormap;
  bool NIV_GL_EXT_pixel_buffer_object;
  bool NIV_GL_EXT_abgr;
  bool NIV_GL_NV_vertex_program;
  bool NIV_GL_SGIX_texture_multi_buffer;
  bool NIV_GLX_SGIS_blended_overlay;
  bool NIV_GL_ARB_texture_rectangle;
  bool NIV_GL_SGI_texture_color_table;
  bool NIV_GLX_SGIX_visual_select_group;
  bool NIV_GL_SGIS_pixel_texture;
  bool NIV_GL_ARB_multisample;
  bool NIV_GL_SGIS_generate_mipmap;
  bool NIV_GLX_EXT_visual_rating;
  bool NIV_GL_ATI_map_object_buffer;
  bool NIV_GL_EXT_texture_edge_clamp;
  bool NIV_GLX_MESA_agp_offset;
  bool NIV_GL_NV_light_max_exponent;
  bool NIV_GL_EXT_blend_minmax;
  bool NIV_GL_ARB_texture_float;
  bool NIV_GL_SUN_vertex;
  bool NIV_GL_ARB_texture_env_crossbar;
  bool NIV_GL_SGIS_texture_lod;
  bool NIV_GL_MESA_pack_invert;
  bool NIV_GL_ATIX_texture_env_route;
  bool NIV_GLX_MESA_release_buffers;
  bool NIV_GL_SGIS_sharpen_texture;
  bool NIV_GL_SGIX_texture_range;
  bool NIV_GL_EXT_texture_rectangle;
  bool NIV_GL_EXT_blend_logic_op;
  bool NIV_GL_SGIS_fog_function;
  bool NIV_GLX_SUN_video_resize;
  bool NIV_GL_IBM_cull_vertex;
  bool NIV_GL_PGI_vertex_hints;
  bool NIV_GL_GREMEDY_string_marker;
  bool NIV_GLX_SGIS_color_range;
  bool NIV_GL_EXT_subtexture;
  bool NIV_GL_WIN_swap_hint;
  bool NIV_GL_ARB_color_buffer_float;
  bool NIV_GL_EXT_pixel_transform_color_table;
  bool NIV_GLX_ARB_fbconfig_float;
  bool NIV_GL_ARB_window_pos;
  bool NIV_GL_NV_fragment_program2;
  bool NIV_GL_ARB_shadow;
  bool NIV_GL_ARB_texture_mirrored_repeat;
  bool NIV_GLX_SGIX_video_resize;
  bool NIV_WGL_I3D_swap_frame_usage;
  bool NIV_GL_PGI_misc_hints;
  bool NIV_GL_NV_evaluators;
  bool NIV_GL_INTEL_texture_scissor;
  bool NIV_GL_NV_texture_compression_vtc;
  bool NIV_GL_SGIS_texture_filter4;
  bool NIV_GLX_OML_swap_method;
  bool NIV_GL_EXT_copy_texture;
  bool NIV_GL_NV_register_combiners2;
  bool NIV_GL_EXT_fragment_lighting;
  bool NIV_GL_SGIX_interlace;
  bool NIV_GL_NV_vertex_program1_1;
  bool NIV_GL_EXT_rescale_normal;
  bool NIV_GLX_ATI_render_texture;
  bool NIV_GL_HP_convolution_border_modes;
  bool NIV_GL_SGI_color_table;
  bool NIV_GL_SGIX_resample;
  bool NIV_GL_SGIX_ir_instrument1;
  bool NIV_GL_SGIX_list_priority;
  bool NIV_GL_SGIX_framezoom;
  bool NIV_GL_EXT_index_material;
  bool NIV_GL_SGIS_texture4D;
  bool NIV_GL_EXT_texture3D;
  bool NIV_GL_REND_screen_coordinates;
  bool NIV_GL_ARB_multitexture;
  bool NIV_GL_EXT_secondary_color;
  bool NIV_GL_SGIS_color_range;
  bool NIV_GL_SGIX_fog_offset;
  bool NIV_WGL_ARB_make_current_read;
  bool NIV_GL_NV_copy_depth_to_color;
  bool NIV_GL_EXT_vertex_array;
  bool NIV_GL_INTEL_parallel_arrays;
  bool NIV_GL_ATI_draw_buffers;
  bool NIV_GLX_SGIX_fbconfig;
  bool NIV_GL_SGIX_async;
  bool NIV_GL_EXT_depth_bounds_test;
  bool NIV_GL_ATI_vertex_array_object;
  bool NIV_GL_SUN_convolution_border_modes;
  bool NIV_GL_SGIX_fog_texture;
  bool NIV_GL_SGIX_pixel_texture;
  bool NIV_GL_APPLE_specular_vector;
  bool NIV_GL_ARB_texture_env_add;
  bool NIV_GLX_SGIX_swap_barrier;
  bool NIV_GL_NV_fragment_program;
  bool NIV_GL_SGIX_texture_coordinate_clamp;
  bool NIV_GL_EXT_pixel_transform;
  bool NIV_GLX_MESA_copy_sub_buffer;
  bool NIV_GL_SGIX_texture_add_env;
  bool NIV_GLX_SGI_cushion;
  bool NIV_GL_ARB_matrix_palette;
  bool NIV_GLX_SUN_get_transparent_index;
  bool NIV_GL_SGI_color_matrix;
  bool NIV_GL_EXT_packed_pixels;
  bool NIV_GL_EXT_draw_range_elements;
  bool NIV_GL_ARB_pixel_buffer_object;
  bool NIV_GL_S3_s3tc;
  bool NIV_GLX_NV_vertex_array_range;
  bool NIV_GL_SGIX_blend_alpha_minmax;


protected:
  bool checked_GL_ARB_texture_compression;
  bool checked_GL_SGIX_vertex_preclip;
  bool checked_GL_SGIX_async_pixel;
  bool checked_GL_NV_point_sprite;
  bool checked_GL_APPLE_element_array;
  bool checked_GLX_EXT_import_context;
  bool checked_GL_NV_vertex_array_range2;
  bool checked_GL_EXT_blend_color;
  bool checked_GL_EXT_blend_subtract;
  bool checked_GL_SGIX_tag_sample_buffer;
  bool checked_GL_EXT_stencil_wrap;
  bool checked_GL_EXT_index_array_formats;
  bool checked_GL_EXT_index_texture;
  bool checked_GL_IBM_texture_mirrored_repeat;
  bool checked_GL_NV_half_float;
  bool checked_WGL_ARB_extensions_string;
  bool checked_GL_SGIX_texture_scale_bias;
  bool checked_GL_EXT_texture_compression_s3tc;
  bool checked_GL_APPLE_transform_hint;
  bool checked_GL_ATI_separate_stencil;
  bool checked_GL_EXT_polygon_offset;
  bool checked_GL_NV_vertex_program2_option;
  bool checked_GL_ARB_depth_texture;
  bool checked_GL_NV_packed_depth_stencil;
  bool checked_GL_NV_fragment_program_option;
  bool checked_GL_ARB_vertex_blend;
  bool checked_GL_SGIX_ycrcb;
  bool checked_GL_EXT_stencil_two_side;
  bool checked_WGL_NV_vertex_array_range;
  bool checked_GL_EXT_shadow_funcs;
  bool checked_GL_EXT_Cg_shader;
  bool checked_GLX_SGIS_multisample;
  bool checked_GL_EXT_convolution;
  bool checked_WGL_EXT_pbuffer;
  bool checked_WGL_I3D_genlock;
  bool checked_GLX_ATI_pixel_format_float;
  bool checked_GLX_ARB_multisample;
  bool checked_WGL_ARB_pixel_format;
  bool checked_WGL_3DFX_multisample;
  bool checked_GLX_SGIX_swap_group;
  bool checked_GL_EXT_vertex_shader;
  bool checked_GL_APPLE_pixel_buffer;
  bool checked_GL_EXT_misc_attribute;
  bool checked_GL_NV_texture_shader3;
  bool checked_GL_NV_texture_shader2;
  bool checked_GL_EXT_blend_func_separate;
  bool checked_GL_SGIX_pixel_texture_bits;
  bool checked_GL_EXT_texture;
  bool checked_GL_APPLE_fence;
  bool checked_GL_EXT_multisample;
  bool checked_GL_EXT_texture_cube_map;
  bool checked_GL_ARB_occlusion_query;
  bool checked_GL_INGR_color_clamp;
  bool checked_GL_EXT_422_pixels;
  bool checked_GL_EXT_index_func;
  bool checked_GLX_MESA_set_3dfx_mode;
  bool checked_WGL_NV_float_buffer;
  bool checked_GL_SUN_read_video_pixels;
  bool checked_GL_ARB_transpose_matrix;
  bool checked_WGL_EXT_extensions_string;
  bool checked_WGL_ATI_pixel_format_float;
  bool checked_WGL_I3D_image_buffer;
  bool checked_GL_NV_fence;
  bool checked_WGL_ATI_render_texture_rectangle;
  bool checked_GL_ARB_texture_border_clamp;
  bool checked_GL_EXT_fog_coord;
  bool checked_GL_NV_depth_clamp;
  bool checked_WGL_I3D_digital_video_control;
  bool checked_GL_ARB_texture_cube_map;
  bool checked_GL_EXT_color_subtable;
  bool checked_GL_EXT_blend_equation_separate;
  bool checked_WGL_I3D_swap_frame_lock;
  bool checked_GL_SUN_mesh_array;
  bool checked_GL_SUNX_constant_data;
  bool checked_GL_ARB_point_parameters;
  bool checked_GL_EXT_texture_env_dot3;
  bool checked_WGL_ARB_buffer_region;
  bool checked_GL_ATI_texture_env_combine3;
  bool checked_GL_SGIX_shadow_ambient;
  bool checked_GL_EXT_multi_draw_arrays;
  bool checked_GL_SGIX_depth_texture;
  bool checked_GL_EXT_texture_compression_dxt1;
  bool checked_GL_NV_texgen_emboss;
  bool checked_GL_HP_occlusion_test;
  bool checked_GL_WIN_phong_shading;
  bool checked_GLX_SGIS_shared_multisample;
  bool checked_GL_ATIX_texture_env_combine3;
  bool checked_GL_EXT_texture_filter_anisotropic;
  bool checked_GL_EXT_texture_perturb_normal;
  bool checked_GL_NV_fog_distance;
  bool checked_GL_ATIX_vertex_shader_output_point_size;
  bool checked_GL_SUN_global_alpha;
  bool checked_WGL_EXT_pixel_format;
  bool checked_GL_SGIX_async_histogram;
  bool checked_GL_ARB_vertex_program;
  bool checked_GL_MESA_resize_buffers;
  bool checked_GL_3DFX_multisample;
  bool checked_WGL_NV_render_texture_rectangle;
  bool checked_GL_ARB_texture_env_dot3;
  bool checked_GL_EXT_bgra;
  bool checked_GL_NV_float_buffer;
  bool checked_GL_INGR_interlace_read;
  bool checked_GL_NV_texture_env_combine4;
  bool checked_GL_OML_interlace;
  bool checked_GLX_SGI_swap_control;
  bool checked_WGL_EXT_depth_float;
  bool checked_WGL_ARB_multisample;
  bool checked_GL_ATI_fragment_shader;
  bool checked_GL_ARB_texture_env_combine;
  bool checked_GL_ARB_vertex_buffer_object;
  bool checked_GL_SUN_triangle_list;
  bool checked_WGL_EXT_swap_control;
  bool checked_GLX_EXT_scene_marker;
  bool checked_GL_ATI_text_fragment_shader;
  bool checked_GL_EXT_histogram;
  bool checked_GL_NV_vertex_program3;
  bool checked_GL_NV_vertex_array_range;
  bool checked_GL_HP_texture_lighting;
  bool checked_WGL_EXT_display_color_table;
  bool checked_GL_NV_texture_expand_normal;
  bool checked_GL_EXT_separate_specular_color;
  bool checked_GL_EXT_paletted_texture;
  bool checked_GL_ATI_texture_float;
  bool checked_GL_EXT_texture_env_add;
  bool checked_GL_EXT_texture_mirror_clamp;
  bool checked_GL_ATI_pn_triangles;
  bool checked_GL_NV_texture_rectangle;
  bool checked_WGL_OML_sync_control;
  bool checked_GL_NV_multisample_filter_hint;
  bool checked_GL_APPLE_float_pixels;
  bool checked_GL_SGIS_texture_border_clamp;
  bool checked_GL_ATI_vertex_attrib_array_object;
  bool checked_GL_SGIX_clipmap;
  bool checked_GL_HP_image_transform;
  bool checked_GL_SGIX_flush_raster;
  bool checked_GL_EXT_light_texture;
  bool checked_GL_ARB_point_sprite;
  bool checked_GL_MESA_ycbcr_texture;
  bool checked_GL_ARB_shading_language_100;
  bool checked_GL_SGIS_texture_select;
  bool checked_GL_NV_vertex_program2;
  bool checked_GLX_SGI_make_current_read;
  bool checked_GL_ARB_half_float_pixel;
  bool checked_GL_KTX_buffer_region;
  bool checked_GL_EXT_vertex_weighting;
  bool checked_GL_ATIX_point_sprites;
  bool checked_GL_APPLE_vertex_array_range;
  bool checked_GLX_NV_float_buffer;
  bool checked_GL_SGIS_detail_texture;
  bool checked_GL_SGIX_sprite;
  bool checked_GL_NV_register_combiners;
  bool checked_GL_ARB_draw_buffers;
  bool checked_GL_ARB_fragment_program_shadow;
  bool checked_WGL_EXT_make_current_read;
  bool checked_GL_EXT_shared_texture_palette;
  bool checked_GL_ATI_element_array;
  bool checked_GLX_ARB_get_proc_address;
  bool checked_GL_OML_resample;
  bool checked_GL_EXT_coordinate_frame;
  bool checked_GL_ATI_texture_mirror_once;
  bool checked_WGL_ARB_pbuffer;
  bool checked_GL_EXT_cull_vertex;
  bool checked_GL_IBM_rasterpos_clip;
  bool checked_GL_SGIX_reference_plane;
  bool checked_GL_APPLE_texture_range;
  bool checked_GL_SGIX_shadow;
  bool checked_GL_SGIX_texture_lod_bias;
  bool checked_GLX_SGIX_pbuffer;
  bool checked_GL_NV_texgen_reflection;
  bool checked_GL_SUN_slice_accum;
  bool checked_GL_IBM_multimode_draw_arrays;
  bool checked_GL_IBM_static_data;
  bool checked_GLX_EXT_visual_info;
  bool checked_GL_EXT_clip_volume_hint;
  bool checked_GL_EXT_cmyka;
  bool checked_GL_EXT_compiled_vertex_array;
  bool checked_GL_3DFX_tbuffer;
  bool checked_GL_EXT_point_parameters;
  bool checked_GL_APPLE_vertex_array_object;
  bool checked_GL_3DFX_texture_compression_FXT1;
  bool checked_GL_NV_occlusion_query;
  bool checked_GLX_OML_sync_control;
  bool checked_WGL_ARB_render_texture;
  bool checked_GL_SGIS_multisample;
  bool checked_GL_ARB_vertex_shader;
  bool checked_WGL_NV_render_depth_texture;
  bool checked_GL_EXT_texture_env;
  bool checked_GL_SGIX_fragment_specular_lighting;
  bool checked_GLX_3DFX_multisample;
  bool checked_GL_ARB_fragment_shader;
  bool checked_GLX_SGI_video_sync;
  bool checked_GL_NV_texture_shader;
  bool checked_GL_NV_pixel_data_range;
  bool checked_WGL_EXT_multisample;
  bool checked_GL_SGIS_texture_edge_clamp;
  bool checked_GL_ARB_imaging;
  bool checked_GL_WIN_specular_fog;
  bool checked_GL_APPLE_client_storage;
  bool checked_GL_IBM_vertex_array_lists;
  bool checked_GL_ARB_fragment_program;
  bool checked_GL_ARB_shader_objects;
  bool checked_GL_EXT_framebuffer_object;
  bool checked_WGL_I3D_gamma;
  bool checked_GL_ATI_vertex_streams;
  bool checked_GL_APPLE_ycbcr_422;
  bool checked_GL_NV_blend_square;
  bool checked_GL_MESA_window_pos;
  bool checked_GL_ATI_envmap_bumpmap;
  bool checked_GL_ARB_texture_non_power_of_two;
  bool checked_GL_EXT_texture_env_combine;
  bool checked_GL_EXT_texture_object;
  bool checked_GL_ATI_texture_compression_3dc;
  bool checked_GL_OML_subsample;
  bool checked_GL_EXT_texture_lod_bias;
  bool checked_WGL_ARB_pixel_format_float;
  bool checked_GL_EXT_scene_marker;
  bool checked_GL_NV_primitive_restart;
  bool checked_GL_ARB_shadow_ambient;
  bool checked_GL_SGIX_vertex_preclip_hint;
  bool checked_GLX_MESA_pixmap_colormap;
  bool checked_GL_EXT_pixel_buffer_object;
  bool checked_GL_EXT_abgr;
  bool checked_GL_NV_vertex_program;
  bool checked_GL_SGIX_texture_multi_buffer;
  bool checked_GLX_SGIS_blended_overlay;
  bool checked_GL_ARB_texture_rectangle;
  bool checked_GL_SGI_texture_color_table;
  bool checked_GLX_SGIX_visual_select_group;
  bool checked_GL_SGIS_pixel_texture;
  bool checked_GL_ARB_multisample;
  bool checked_GL_SGIS_generate_mipmap;
  bool checked_GLX_EXT_visual_rating;
  bool checked_GL_ATI_map_object_buffer;
  bool checked_GL_EXT_texture_edge_clamp;
  bool checked_GLX_MESA_agp_offset;
  bool checked_GL_NV_light_max_exponent;
  bool checked_GL_EXT_blend_minmax;
  bool checked_GL_ARB_texture_float;
  bool checked_GL_SUN_vertex;
  bool checked_GL_ARB_texture_env_crossbar;
  bool checked_GL_SGIS_texture_lod;
  bool checked_GL_MESA_pack_invert;
  bool checked_GL_ATIX_texture_env_route;
  bool checked_GLX_MESA_release_buffers;
  bool checked_GL_SGIS_sharpen_texture;
  bool checked_GL_SGIX_texture_range;
  bool checked_GL_EXT_texture_rectangle;
  bool checked_GL_EXT_blend_logic_op;
  bool checked_GL_SGIS_fog_function;
  bool checked_GLX_SUN_video_resize;
  bool checked_GL_IBM_cull_vertex;
  bool checked_GL_PGI_vertex_hints;
  bool checked_GL_GREMEDY_string_marker;
  bool checked_GLX_SGIS_color_range;
  bool checked_GL_EXT_subtexture;
  bool checked_GL_WIN_swap_hint;
  bool checked_GL_ARB_color_buffer_float;
  bool checked_GL_EXT_pixel_transform_color_table;
  bool checked_GLX_ARB_fbconfig_float;
  bool checked_GL_ARB_window_pos;
  bool checked_GL_NV_fragment_program2;
  bool checked_GL_ARB_shadow;
  bool checked_GL_ARB_texture_mirrored_repeat;
  bool checked_GLX_SGIX_video_resize;
  bool checked_WGL_I3D_swap_frame_usage;
  bool checked_GL_PGI_misc_hints;
  bool checked_GL_NV_evaluators;
  bool checked_GL_INTEL_texture_scissor;
  bool checked_GL_NV_texture_compression_vtc;
  bool checked_GL_SGIS_texture_filter4;
  bool checked_GLX_OML_swap_method;
  bool checked_GL_EXT_copy_texture;
  bool checked_GL_NV_register_combiners2;
  bool checked_GL_EXT_fragment_lighting;
  bool checked_GL_SGIX_interlace;
  bool checked_GL_NV_vertex_program1_1;
  bool checked_GL_EXT_rescale_normal;
  bool checked_GLX_ATI_render_texture;
  bool checked_GL_HP_convolution_border_modes;
  bool checked_GL_SGI_color_table;
  bool checked_GL_SGIX_resample;
  bool checked_GL_SGIX_ir_instrument1;
  bool checked_GL_SGIX_list_priority;
  bool checked_GL_SGIX_framezoom;
  bool checked_GL_EXT_index_material;
  bool checked_GL_SGIS_texture4D;
  bool checked_GL_EXT_texture3D;
  bool checked_GL_REND_screen_coordinates;
  bool checked_GL_ARB_multitexture;
  bool checked_GL_EXT_secondary_color;
  bool checked_GL_SGIS_color_range;
  bool checked_GL_SGIX_fog_offset;
  bool checked_WGL_ARB_make_current_read;
  bool checked_GL_NV_copy_depth_to_color;
  bool checked_GL_EXT_vertex_array;
  bool checked_GL_INTEL_parallel_arrays;
  bool checked_GL_ATI_draw_buffers;
  bool checked_GLX_SGIX_fbconfig;
  bool checked_GL_SGIX_async;
  bool checked_GL_EXT_depth_bounds_test;
  bool checked_GL_ATI_vertex_array_object;
  bool checked_GL_SUN_convolution_border_modes;
  bool checked_GL_SGIX_fog_texture;
  bool checked_GL_SGIX_pixel_texture;
  bool checked_GL_APPLE_specular_vector;
  bool checked_GL_ARB_texture_env_add;
  bool checked_GLX_SGIX_swap_barrier;
  bool checked_GL_NV_fragment_program;
  bool checked_GL_SGIX_texture_coordinate_clamp;
  bool checked_GL_EXT_pixel_transform;
  bool checked_GLX_MESA_copy_sub_buffer;
  bool checked_GL_SGIX_texture_add_env;
  bool checked_GLX_SGI_cushion;
  bool checked_GL_ARB_matrix_palette;
  bool checked_GLX_SUN_get_transparent_index;
  bool checked_GL_SGI_color_matrix;
  bool checked_GL_EXT_packed_pixels;
  bool checked_GL_EXT_draw_range_elements;
  bool checked_GL_ARB_pixel_buffer_object;
  bool checked_GL_S3_s3tc;
  bool checked_GLX_NV_vertex_array_range;
  bool checked_GL_SGIX_blend_alpha_minmax;

};

// The extension loader class
class GLExtensionHandler : public GLExtensionFlags
{
public:
  GLExtensionHandler ()
  {
    initialize ();
  }

  void initialize ()
  {
    // Clean up
    memset (this, 0, sizeof (GLExtensionHandler));

    GLExtensionString = strdup ((const char*)glGetString (GL_EXTENSIONS));

#ifdef WIN32
    InitWGL_EXT_extensions_string();
    if (wglGetExtensionsStringEXT != 0)
    {
      WGLExtensionString = strdup ((const char*)wglGetExtensionsStringEXT ());
    }
#endif
  }

  ~GLExtensionHandler ()
  {
    if (GLExtensionString != 0) free ((void*)GLExtensionString);
#ifdef WIN32
    if (WGLExtensionString  != 0) free ((void*)WGLExtensionString);
#endif
  }

  // GL_ARB_texture_compression
#ifndef NIV_GLCOMPRESSEDTEXIMAGE1DARB_DECLARATION
#define NIV_GLCOMPRESSEDTEXIMAGE1DARB_DECLARATION
  nivenGLCOMPRESSEDTEXIMAGE1DARB glCompressedTexImage1DARB;
#endif

#ifndef NIV_GLGETCOMPRESSEDTEXIMAGEARB_DECLARATION
#define NIV_GLGETCOMPRESSEDTEXIMAGEARB_DECLARATION
  nivenGLGETCOMPRESSEDTEXIMAGEARB glGetCompressedTexImageARB;
#endif

#ifndef NIV_GLCOMPRESSEDTEXSUBIMAGE1DARB_DECLARATION
#define NIV_GLCOMPRESSEDTEXSUBIMAGE1DARB_DECLARATION
  nivenGLCOMPRESSEDTEXSUBIMAGE1DARB glCompressedTexSubImage1DARB;
#endif

#ifndef NIV_GLCOMPRESSEDTEXIMAGE3DARB_DECLARATION
#define NIV_GLCOMPRESSEDTEXIMAGE3DARB_DECLARATION
  nivenGLCOMPRESSEDTEXIMAGE3DARB glCompressedTexImage3DARB;
#endif

#ifndef NIV_GLCOMPRESSEDTEXSUBIMAGE2DARB_DECLARATION
#define NIV_GLCOMPRESSEDTEXSUBIMAGE2DARB_DECLARATION
  nivenGLCOMPRESSEDTEXSUBIMAGE2DARB glCompressedTexSubImage2DARB;
#endif

#ifndef NIV_GLCOMPRESSEDTEXSUBIMAGE3DARB_DECLARATION
#define NIV_GLCOMPRESSEDTEXSUBIMAGE3DARB_DECLARATION
  nivenGLCOMPRESSEDTEXSUBIMAGE3DARB glCompressedTexSubImage3DARB;
#endif

#ifndef NIV_GLCOMPRESSEDTEXIMAGE2DARB_DECLARATION
#define NIV_GLCOMPRESSEDTEXIMAGE2DARB_DECLARATION
  nivenGLCOMPRESSEDTEXIMAGE2DARB glCompressedTexImage2DARB;
#endif


  // GL_SGIX_vertex_preclip

  // GL_SGIX_async_pixel

  // GL_NV_point_sprite
#ifndef NIV_GLPOINTPARAMETERINV_DECLARATION
#define NIV_GLPOINTPARAMETERINV_DECLARATION
  nivenGLPOINTPARAMETERINV glPointParameteriNV;
#endif

#ifndef NIV_GLPOINTPARAMETERIVNV_DECLARATION
#define NIV_GLPOINTPARAMETERIVNV_DECLARATION
  nivenGLPOINTPARAMETERIVNV glPointParameterivNV;
#endif


  // GL_APPLE_element_array
#ifndef NIV_GLMULTIDRAWRANGEELEMENTARRAYAPPLE_DECLARATION
#define NIV_GLMULTIDRAWRANGEELEMENTARRAYAPPLE_DECLARATION
  nivenGLMULTIDRAWRANGEELEMENTARRAYAPPLE glMultiDrawRangeElementArrayAPPLE;
#endif

#ifndef NIV_GLELEMENTPOINTERAPPLE_DECLARATION
#define NIV_GLELEMENTPOINTERAPPLE_DECLARATION
  nivenGLELEMENTPOINTERAPPLE glElementPointerAPPLE;
#endif

#ifndef NIV_GLDRAWRANGEELEMENTARRAYAPPLE_DECLARATION
#define NIV_GLDRAWRANGEELEMENTARRAYAPPLE_DECLARATION
  nivenGLDRAWRANGEELEMENTARRAYAPPLE glDrawRangeElementArrayAPPLE;
#endif

#ifndef NIV_GLMULTIDRAWELEMENTARRAYAPPLE_DECLARATION
#define NIV_GLMULTIDRAWELEMENTARRAYAPPLE_DECLARATION
  nivenGLMULTIDRAWELEMENTARRAYAPPLE glMultiDrawElementArrayAPPLE;
#endif

#ifndef NIV_GLDRAWELEMENTARRAYAPPLE_DECLARATION
#define NIV_GLDRAWELEMENTARRAYAPPLE_DECLARATION
  nivenGLDRAWELEMENTARRAYAPPLE glDrawElementArrayAPPLE;
#endif


#ifdef _GLX
  // GLX_EXT_import_context
#ifndef NIV_GLXIMPORTCONTEXTEXT_DECLARATION
#define NIV_GLXIMPORTCONTEXTEXT_DECLARATION
  nivenGLXIMPORTCONTEXTEXT glXImportContextEXT;
#endif

#ifndef NIV_GLXGETCONTEXTIDEXT_DECLARATION
#define NIV_GLXGETCONTEXTIDEXT_DECLARATION
  nivenGLXGETCONTEXTIDEXT glXGetContextIDEXT;
#endif

#ifndef NIV_GLXFREECONTEXTEXT_DECLARATION
#define NIV_GLXFREECONTEXTEXT_DECLARATION
  nivenGLXFREECONTEXTEXT glXFreeContextEXT;
#endif

#ifndef NIV_GLXQUERYCONTEXTINFOEXT_DECLARATION
#define NIV_GLXQUERYCONTEXTINFOEXT_DECLARATION
  nivenGLXQUERYCONTEXTINFOEXT glXQueryContextInfoEXT;
#endif

#endif // _GLX
  // GL_NV_vertex_array_range2

  // GL_EXT_blend_color
#ifndef NIV_GLBLENDCOLOREXT_DECLARATION
#define NIV_GLBLENDCOLOREXT_DECLARATION
  nivenGLBLENDCOLOREXT glBlendColorEXT;
#endif


  // GL_EXT_blend_subtract

  // GL_SGIX_tag_sample_buffer
#ifndef NIV_GLTAGSAMPLEBUFFERSGIX_DECLARATION
#define NIV_GLTAGSAMPLEBUFFERSGIX_DECLARATION
  nivenGLTAGSAMPLEBUFFERSGIX glTagSampleBufferSGIX;
#endif


  // GL_EXT_stencil_wrap

  // GL_EXT_index_array_formats

  // GL_EXT_index_texture

  // GL_IBM_texture_mirrored_repeat

  // GL_NV_half_float
#ifndef NIV_GLMULTITEXCOORD2HVNV_DECLARATION
#define NIV_GLMULTITEXCOORD2HVNV_DECLARATION
  nivenGLMULTITEXCOORD2HVNV glMultiTexCoord2hvNV;
#endif

#ifndef NIV_GLVERTEXWEIGHTHNV_DECLARATION
#define NIV_GLVERTEXWEIGHTHNV_DECLARATION
  nivenGLVERTEXWEIGHTHNV glVertexWeighthNV;
#endif

#ifndef NIV_GLTEXCOORD4HVNV_DECLARATION
#define NIV_GLTEXCOORD4HVNV_DECLARATION
  nivenGLTEXCOORD4HVNV glTexCoord4hvNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS3HVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS3HVNV_DECLARATION
  nivenGLVERTEXATTRIBS3HVNV glVertexAttribs3hvNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS2HVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS2HVNV_DECLARATION
  nivenGLVERTEXATTRIBS2HVNV glVertexAttribs2hvNV;
#endif

#ifndef NIV_GLVERTEX4HVNV_DECLARATION
#define NIV_GLVERTEX4HVNV_DECLARATION
  nivenGLVERTEX4HVNV glVertex4hvNV;
#endif

#ifndef NIV_GLSECONDARYCOLOR3HVNV_DECLARATION
#define NIV_GLSECONDARYCOLOR3HVNV_DECLARATION
  nivenGLSECONDARYCOLOR3HVNV glSecondaryColor3hvNV;
#endif

#ifndef NIV_GLFOGCOORDHVNV_DECLARATION
#define NIV_GLFOGCOORDHVNV_DECLARATION
  nivenGLFOGCOORDHVNV glFogCoordhvNV;
#endif

#ifndef NIV_GLTEXCOORD3HVNV_DECLARATION
#define NIV_GLTEXCOORD3HVNV_DECLARATION
  nivenGLTEXCOORD3HVNV glTexCoord3hvNV;
#endif

#ifndef NIV_GLVERTEX2HNV_DECLARATION
#define NIV_GLVERTEX2HNV_DECLARATION
  nivenGLVERTEX2HNV glVertex2hNV;
#endif

#ifndef NIV_GLTEXCOORD1HNV_DECLARATION
#define NIV_GLTEXCOORD1HNV_DECLARATION
  nivenGLTEXCOORD1HNV glTexCoord1hNV;
#endif

#ifndef NIV_GLVERTEXATTRIB3HVNV_DECLARATION
#define NIV_GLVERTEXATTRIB3HVNV_DECLARATION
  nivenGLVERTEXATTRIB3HVNV glVertexAttrib3hvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB1HVNV_DECLARATION
#define NIV_GLVERTEXATTRIB1HVNV_DECLARATION
  nivenGLVERTEXATTRIB1HVNV glVertexAttrib1hvNV;
#endif

#ifndef NIV_GLMULTITEXCOORD1HVNV_DECLARATION
#define NIV_GLMULTITEXCOORD1HVNV_DECLARATION
  nivenGLMULTITEXCOORD1HVNV glMultiTexCoord1hvNV;
#endif

#ifndef NIV_GLTEXCOORD2HVNV_DECLARATION
#define NIV_GLTEXCOORD2HVNV_DECLARATION
  nivenGLTEXCOORD2HVNV glTexCoord2hvNV;
#endif

#ifndef NIV_GLMULTITEXCOORD4HVNV_DECLARATION
#define NIV_GLMULTITEXCOORD4HVNV_DECLARATION
  nivenGLMULTITEXCOORD4HVNV glMultiTexCoord4hvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB4HNV_DECLARATION
#define NIV_GLVERTEXATTRIB4HNV_DECLARATION
  nivenGLVERTEXATTRIB4HNV glVertexAttrib4hNV;
#endif

#ifndef NIV_GLMULTITEXCOORD1HNV_DECLARATION
#define NIV_GLMULTITEXCOORD1HNV_DECLARATION
  nivenGLMULTITEXCOORD1HNV glMultiTexCoord1hNV;
#endif

#ifndef NIV_GLVERTEXWEIGHTHVNV_DECLARATION
#define NIV_GLVERTEXWEIGHTHVNV_DECLARATION
  nivenGLVERTEXWEIGHTHVNV glVertexWeighthvNV;
#endif

#ifndef NIV_GLNORMAL3HNV_DECLARATION
#define NIV_GLNORMAL3HNV_DECLARATION
  nivenGLNORMAL3HNV glNormal3hNV;
#endif

#ifndef NIV_GLTEXCOORD3HNV_DECLARATION
#define NIV_GLTEXCOORD3HNV_DECLARATION
  nivenGLTEXCOORD3HNV glTexCoord3hNV;
#endif

#ifndef NIV_GLCOLOR4HNV_DECLARATION
#define NIV_GLCOLOR4HNV_DECLARATION
  nivenGLCOLOR4HNV glColor4hNV;
#endif

#ifndef NIV_GLFOGCOORDHNV_DECLARATION
#define NIV_GLFOGCOORDHNV_DECLARATION
  nivenGLFOGCOORDHNV glFogCoordhNV;
#endif

#ifndef NIV_GLVERTEX2HVNV_DECLARATION
#define NIV_GLVERTEX2HVNV_DECLARATION
  nivenGLVERTEX2HVNV glVertex2hvNV;
#endif

#ifndef NIV_GLSECONDARYCOLOR3HNV_DECLARATION
#define NIV_GLSECONDARYCOLOR3HNV_DECLARATION
  nivenGLSECONDARYCOLOR3HNV glSecondaryColor3hNV;
#endif

#ifndef NIV_GLNORMAL3HVNV_DECLARATION
#define NIV_GLNORMAL3HVNV_DECLARATION
  nivenGLNORMAL3HVNV glNormal3hvNV;
#endif

#ifndef NIV_GLTEXCOORD2HNV_DECLARATION
#define NIV_GLTEXCOORD2HNV_DECLARATION
  nivenGLTEXCOORD2HNV glTexCoord2hNV;
#endif

#ifndef NIV_GLVERTEXATTRIB4HVNV_DECLARATION
#define NIV_GLVERTEXATTRIB4HVNV_DECLARATION
  nivenGLVERTEXATTRIB4HVNV glVertexAttrib4hvNV;
#endif

#ifndef NIV_GLVERTEX3HVNV_DECLARATION
#define NIV_GLVERTEX3HVNV_DECLARATION
  nivenGLVERTEX3HVNV glVertex3hvNV;
#endif

#ifndef NIV_GLVERTEX3HNV_DECLARATION
#define NIV_GLVERTEX3HNV_DECLARATION
  nivenGLVERTEX3HNV glVertex3hNV;
#endif

#ifndef NIV_GLCOLOR3HVNV_DECLARATION
#define NIV_GLCOLOR3HVNV_DECLARATION
  nivenGLCOLOR3HVNV glColor3hvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB2HVNV_DECLARATION
#define NIV_GLVERTEXATTRIB2HVNV_DECLARATION
  nivenGLVERTEXATTRIB2HVNV glVertexAttrib2hvNV;
#endif

#ifndef NIV_GLCOLOR3HNV_DECLARATION
#define NIV_GLCOLOR3HNV_DECLARATION
  nivenGLCOLOR3HNV glColor3hNV;
#endif

#ifndef NIV_GLMULTITEXCOORD4HNV_DECLARATION
#define NIV_GLMULTITEXCOORD4HNV_DECLARATION
  nivenGLMULTITEXCOORD4HNV glMultiTexCoord4hNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS4HVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS4HVNV_DECLARATION
  nivenGLVERTEXATTRIBS4HVNV glVertexAttribs4hvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB1HNV_DECLARATION
#define NIV_GLVERTEXATTRIB1HNV_DECLARATION
  nivenGLVERTEXATTRIB1HNV glVertexAttrib1hNV;
#endif

#ifndef NIV_GLMULTITEXCOORD3HVNV_DECLARATION
#define NIV_GLMULTITEXCOORD3HVNV_DECLARATION
  nivenGLMULTITEXCOORD3HVNV glMultiTexCoord3hvNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS1HVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS1HVNV_DECLARATION
  nivenGLVERTEXATTRIBS1HVNV glVertexAttribs1hvNV;
#endif

#ifndef NIV_GLTEXCOORD4HNV_DECLARATION
#define NIV_GLTEXCOORD4HNV_DECLARATION
  nivenGLTEXCOORD4HNV glTexCoord4hNV;
#endif

#ifndef NIV_GLVERTEX4HNV_DECLARATION
#define NIV_GLVERTEX4HNV_DECLARATION
  nivenGLVERTEX4HNV glVertex4hNV;
#endif

#ifndef NIV_GLMULTITEXCOORD2HNV_DECLARATION
#define NIV_GLMULTITEXCOORD2HNV_DECLARATION
  nivenGLMULTITEXCOORD2HNV glMultiTexCoord2hNV;
#endif

#ifndef NIV_GLCOLOR4HVNV_DECLARATION
#define NIV_GLCOLOR4HVNV_DECLARATION
  nivenGLCOLOR4HVNV glColor4hvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB2HNV_DECLARATION
#define NIV_GLVERTEXATTRIB2HNV_DECLARATION
  nivenGLVERTEXATTRIB2HNV glVertexAttrib2hNV;
#endif

#ifndef NIV_GLMULTITEXCOORD3HNV_DECLARATION
#define NIV_GLMULTITEXCOORD3HNV_DECLARATION
  nivenGLMULTITEXCOORD3HNV glMultiTexCoord3hNV;
#endif

#ifndef NIV_GLVERTEXATTRIB3HNV_DECLARATION
#define NIV_GLVERTEXATTRIB3HNV_DECLARATION
  nivenGLVERTEXATTRIB3HNV glVertexAttrib3hNV;
#endif

#ifndef NIV_GLTEXCOORD1HVNV_DECLARATION
#define NIV_GLTEXCOORD1HVNV_DECLARATION
  nivenGLTEXCOORD1HVNV glTexCoord1hvNV;
#endif


#ifdef WIN32
  // WGL_ARB_extensions_string
#ifndef NIV_WGLGETEXTENSIONSSTRINGARB_DECLARATION
#define NIV_WGLGETEXTENSIONSSTRINGARB_DECLARATION
  nivenWGLGETEXTENSIONSSTRINGARB wglGetExtensionsStringARB;
#endif

#endif
  // GL_SGIX_texture_scale_bias

  // GL_EXT_texture_compression_s3tc

  // GL_APPLE_transform_hint

  // GL_ATI_separate_stencil
#ifndef NIV_GLSTENCILOPSEPARATEATI_DECLARATION
#define NIV_GLSTENCILOPSEPARATEATI_DECLARATION
  nivenGLSTENCILOPSEPARATEATI glStencilOpSeparateATI;
#endif

#ifndef NIV_GLSTENCILFUNCSEPARATEATI_DECLARATION
#define NIV_GLSTENCILFUNCSEPARATEATI_DECLARATION
  nivenGLSTENCILFUNCSEPARATEATI glStencilFuncSeparateATI;
#endif


  // GL_EXT_polygon_offset
#ifndef NIV_GLPOLYGONOFFSETEXT_DECLARATION
#define NIV_GLPOLYGONOFFSETEXT_DECLARATION
  nivenGLPOLYGONOFFSETEXT glPolygonOffsetEXT;
#endif


  // GL_NV_vertex_program2_option

  // GL_ARB_depth_texture

  // GL_NV_packed_depth_stencil

  // GL_NV_fragment_program_option

  // GL_ARB_vertex_blend
#ifndef NIV_GLWEIGHTUBVARB_DECLARATION
#define NIV_GLWEIGHTUBVARB_DECLARATION
  nivenGLWEIGHTUBVARB glWeightubvARB;
#endif

#ifndef NIV_GLWEIGHTSVARB_DECLARATION
#define NIV_GLWEIGHTSVARB_DECLARATION
  nivenGLWEIGHTSVARB glWeightsvARB;
#endif

#ifndef NIV_GLVERTEXBLENDARB_DECLARATION
#define NIV_GLVERTEXBLENDARB_DECLARATION
  nivenGLVERTEXBLENDARB glVertexBlendARB;
#endif

#ifndef NIV_GLWEIGHTIVARB_DECLARATION
#define NIV_GLWEIGHTIVARB_DECLARATION
  nivenGLWEIGHTIVARB glWeightivARB;
#endif

#ifndef NIV_GLWEIGHTBVARB_DECLARATION
#define NIV_GLWEIGHTBVARB_DECLARATION
  nivenGLWEIGHTBVARB glWeightbvARB;
#endif

#ifndef NIV_GLWEIGHTUSVARB_DECLARATION
#define NIV_GLWEIGHTUSVARB_DECLARATION
  nivenGLWEIGHTUSVARB glWeightusvARB;
#endif

#ifndef NIV_GLWEIGHTPOINTERARB_DECLARATION
#define NIV_GLWEIGHTPOINTERARB_DECLARATION
  nivenGLWEIGHTPOINTERARB glWeightPointerARB;
#endif

#ifndef NIV_GLWEIGHTFVARB_DECLARATION
#define NIV_GLWEIGHTFVARB_DECLARATION
  nivenGLWEIGHTFVARB glWeightfvARB;
#endif

#ifndef NIV_GLWEIGHTUIVARB_DECLARATION
#define NIV_GLWEIGHTUIVARB_DECLARATION
  nivenGLWEIGHTUIVARB glWeightuivARB;
#endif

#ifndef NIV_GLWEIGHTDVARB_DECLARATION
#define NIV_GLWEIGHTDVARB_DECLARATION
  nivenGLWEIGHTDVARB glWeightdvARB;
#endif


  // GL_SGIX_ycrcb

  // GL_EXT_stencil_two_side
#ifndef NIV_GLACTIVESTENCILFACEEXT_DECLARATION
#define NIV_GLACTIVESTENCILFACEEXT_DECLARATION
  nivenGLACTIVESTENCILFACEEXT glActiveStencilFaceEXT;
#endif


#ifdef WIN32
  // WGL_NV_vertex_array_range
#ifndef NIV_WGLFREEMEMORYNV_DECLARATION
#define NIV_WGLFREEMEMORYNV_DECLARATION
  nivenWGLFREEMEMORYNV wglFreeMemoryNV;
#endif

#ifndef NIV_WGLALLOCATEMEMORYNV_DECLARATION
#define NIV_WGLALLOCATEMEMORYNV_DECLARATION
  nivenWGLALLOCATEMEMORYNV wglAllocateMemoryNV;
#endif

#endif
  // GL_EXT_shadow_funcs

  // GL_EXT_Cg_shader

#ifdef _GLX
  // GLX_SGIS_multisample
#endif // _GLX
  // GL_EXT_convolution
#ifndef NIV_GLGETCONVOLUTIONPARAMETERIVEXT_DECLARATION
#define NIV_GLGETCONVOLUTIONPARAMETERIVEXT_DECLARATION
  nivenGLGETCONVOLUTIONPARAMETERIVEXT glGetConvolutionParameterivEXT;
#endif

#ifndef NIV_GLSEPARABLEFILTER2DEXT_DECLARATION
#define NIV_GLSEPARABLEFILTER2DEXT_DECLARATION
  nivenGLSEPARABLEFILTER2DEXT glSeparableFilter2DEXT;
#endif

#ifndef NIV_GLCONVOLUTIONPARAMETERIEXT_DECLARATION
#define NIV_GLCONVOLUTIONPARAMETERIEXT_DECLARATION
  nivenGLCONVOLUTIONPARAMETERIEXT glConvolutionParameteriEXT;
#endif

#ifndef NIV_GLCONVOLUTIONPARAMETERIVEXT_DECLARATION
#define NIV_GLCONVOLUTIONPARAMETERIVEXT_DECLARATION
  nivenGLCONVOLUTIONPARAMETERIVEXT glConvolutionParameterivEXT;
#endif

#ifndef NIV_GLGETCONVOLUTIONPARAMETERFVEXT_DECLARATION
#define NIV_GLGETCONVOLUTIONPARAMETERFVEXT_DECLARATION
  nivenGLGETCONVOLUTIONPARAMETERFVEXT glGetConvolutionParameterfvEXT;
#endif

#ifndef NIV_GLGETSEPARABLEFILTEREXT_DECLARATION
#define NIV_GLGETSEPARABLEFILTEREXT_DECLARATION
  nivenGLGETSEPARABLEFILTEREXT glGetSeparableFilterEXT;
#endif

#ifndef NIV_GLCOPYCONVOLUTIONFILTER2DEXT_DECLARATION
#define NIV_GLCOPYCONVOLUTIONFILTER2DEXT_DECLARATION
  nivenGLCOPYCONVOLUTIONFILTER2DEXT glCopyConvolutionFilter2DEXT;
#endif

#ifndef NIV_GLCOPYCONVOLUTIONFILTER1DEXT_DECLARATION
#define NIV_GLCOPYCONVOLUTIONFILTER1DEXT_DECLARATION
  nivenGLCOPYCONVOLUTIONFILTER1DEXT glCopyConvolutionFilter1DEXT;
#endif

#ifndef NIV_GLGETCONVOLUTIONFILTEREXT_DECLARATION
#define NIV_GLGETCONVOLUTIONFILTEREXT_DECLARATION
  nivenGLGETCONVOLUTIONFILTEREXT glGetConvolutionFilterEXT;
#endif

#ifndef NIV_GLCONVOLUTIONFILTER1DEXT_DECLARATION
#define NIV_GLCONVOLUTIONFILTER1DEXT_DECLARATION
  nivenGLCONVOLUTIONFILTER1DEXT glConvolutionFilter1DEXT;
#endif

#ifndef NIV_GLCONVOLUTIONFILTER2DEXT_DECLARATION
#define NIV_GLCONVOLUTIONFILTER2DEXT_DECLARATION
  nivenGLCONVOLUTIONFILTER2DEXT glConvolutionFilter2DEXT;
#endif

#ifndef NIV_GLCONVOLUTIONPARAMETERFEXT_DECLARATION
#define NIV_GLCONVOLUTIONPARAMETERFEXT_DECLARATION
  nivenGLCONVOLUTIONPARAMETERFEXT glConvolutionParameterfEXT;
#endif

#ifndef NIV_GLCONVOLUTIONPARAMETERFVEXT_DECLARATION
#define NIV_GLCONVOLUTIONPARAMETERFVEXT_DECLARATION
  nivenGLCONVOLUTIONPARAMETERFVEXT glConvolutionParameterfvEXT;
#endif


#ifdef WIN32
  // WGL_EXT_pbuffer
#ifndef NIV_WGLCREATEPBUFFEREXT_DECLARATION
#define NIV_WGLCREATEPBUFFEREXT_DECLARATION
  nivenWGLCREATEPBUFFEREXT wglCreatePbufferEXT;
#endif

#ifndef NIV_WGLQUERYPBUFFEREXT_DECLARATION
#define NIV_WGLQUERYPBUFFEREXT_DECLARATION
  nivenWGLQUERYPBUFFEREXT wglQueryPbufferEXT;
#endif

#ifndef NIV_WGLRELEASEPBUFFERDCEXT_DECLARATION
#define NIV_WGLRELEASEPBUFFERDCEXT_DECLARATION
  nivenWGLRELEASEPBUFFERDCEXT wglReleasePbufferDCEXT;
#endif

#ifndef NIV_WGLGETPBUFFERDCEXT_DECLARATION
#define NIV_WGLGETPBUFFERDCEXT_DECLARATION
  nivenWGLGETPBUFFERDCEXT wglGetPbufferDCEXT;
#endif

#ifndef NIV_WGLDESTROYPBUFFEREXT_DECLARATION
#define NIV_WGLDESTROYPBUFFEREXT_DECLARATION
  nivenWGLDESTROYPBUFFEREXT wglDestroyPbufferEXT;
#endif

#endif
#ifdef WIN32
  // WGL_I3D_genlock
#ifndef NIV_WGLGENLOCKSOURCEEDGEI3D_DECLARATION
#define NIV_WGLGENLOCKSOURCEEDGEI3D_DECLARATION
  nivenWGLGENLOCKSOURCEEDGEI3D wglGenlockSourceEdgeI3D;
#endif

#ifndef NIV_WGLGETGENLOCKSOURCEDELAYI3D_DECLARATION
#define NIV_WGLGETGENLOCKSOURCEDELAYI3D_DECLARATION
  nivenWGLGETGENLOCKSOURCEDELAYI3D wglGetGenlockSourceDelayI3D;
#endif

#ifndef NIV_WGLGENLOCKSOURCEDELAYI3D_DECLARATION
#define NIV_WGLGENLOCKSOURCEDELAYI3D_DECLARATION
  nivenWGLGENLOCKSOURCEDELAYI3D wglGenlockSourceDelayI3D;
#endif

#ifndef NIV_WGLGETGENLOCKSOURCEI3D_DECLARATION
#define NIV_WGLGETGENLOCKSOURCEI3D_DECLARATION
  nivenWGLGETGENLOCKSOURCEI3D wglGetGenlockSourceI3D;
#endif

#ifndef NIV_WGLGENLOCKSAMPLERATEI3D_DECLARATION
#define NIV_WGLGENLOCKSAMPLERATEI3D_DECLARATION
  nivenWGLGENLOCKSAMPLERATEI3D wglGenlockSampleRateI3D;
#endif

#ifndef NIV_WGLISENABLEDGENLOCKI3D_DECLARATION
#define NIV_WGLISENABLEDGENLOCKI3D_DECLARATION
  nivenWGLISENABLEDGENLOCKI3D wglIsEnabledGenlockI3D;
#endif

#ifndef NIV_WGLDISABLEGENLOCKI3D_DECLARATION
#define NIV_WGLDISABLEGENLOCKI3D_DECLARATION
  nivenWGLDISABLEGENLOCKI3D wglDisableGenlockI3D;
#endif

#ifndef NIV_WGLGETGENLOCKSAMPLERATEI3D_DECLARATION
#define NIV_WGLGETGENLOCKSAMPLERATEI3D_DECLARATION
  nivenWGLGETGENLOCKSAMPLERATEI3D wglGetGenlockSampleRateI3D;
#endif

#ifndef NIV_WGLQUERYGENLOCKMAXSOURCEDELAYI3D_DECLARATION
#define NIV_WGLQUERYGENLOCKMAXSOURCEDELAYI3D_DECLARATION
  nivenWGLQUERYGENLOCKMAXSOURCEDELAYI3D wglQueryGenlockMaxSourceDelayI3D;
#endif

#ifndef NIV_WGLGETGENLOCKSOURCEEDGEI3D_DECLARATION
#define NIV_WGLGETGENLOCKSOURCEEDGEI3D_DECLARATION
  nivenWGLGETGENLOCKSOURCEEDGEI3D wglGetGenlockSourceEdgeI3D;
#endif

#ifndef NIV_WGLENABLEGENLOCKI3D_DECLARATION
#define NIV_WGLENABLEGENLOCKI3D_DECLARATION
  nivenWGLENABLEGENLOCKI3D wglEnableGenlockI3D;
#endif

#ifndef NIV_WGLGENLOCKSOURCEI3D_DECLARATION
#define NIV_WGLGENLOCKSOURCEI3D_DECLARATION
  nivenWGLGENLOCKSOURCEI3D wglGenlockSourceI3D;
#endif

#endif
#ifdef _GLX
  // GLX_ATI_pixel_format_float
#endif // _GLX
#ifdef _GLX
  // GLX_ARB_multisample
#endif // _GLX
#ifdef WIN32
  // WGL_ARB_pixel_format
#ifndef NIV_WGLGETPIXELFORMATATTRIBFVARB_DECLARATION
#define NIV_WGLGETPIXELFORMATATTRIBFVARB_DECLARATION
  nivenWGLGETPIXELFORMATATTRIBFVARB wglGetPixelFormatAttribfvARB;
#endif

#ifndef NIV_WGLCHOOSEPIXELFORMATARB_DECLARATION
#define NIV_WGLCHOOSEPIXELFORMATARB_DECLARATION
  nivenWGLCHOOSEPIXELFORMATARB wglChoosePixelFormatARB;
#endif

#ifndef NIV_WGLGETPIXELFORMATATTRIBIVARB_DECLARATION
#define NIV_WGLGETPIXELFORMATATTRIBIVARB_DECLARATION
  nivenWGLGETPIXELFORMATATTRIBIVARB wglGetPixelFormatAttribivARB;
#endif

#endif
#ifdef WIN32
  // WGL_3DFX_multisample
#endif
#ifdef _GLX
  // GLX_SGIX_swap_group
#ifndef NIV_GLXJOINSWAPGROUPSGIX_DECLARATION
#define NIV_GLXJOINSWAPGROUPSGIX_DECLARATION
  nivenGLXJOINSWAPGROUPSGIX glXJoinSwapGroupSGIX;
#endif

#endif // _GLX
  // GL_EXT_vertex_shader
#ifndef NIV_GLVARIANTUBVEXT_DECLARATION
#define NIV_GLVARIANTUBVEXT_DECLARATION
  nivenGLVARIANTUBVEXT glVariantubvEXT;
#endif

#ifndef NIV_GLSETINVARIANTEXT_DECLARATION
#define NIV_GLSETINVARIANTEXT_DECLARATION
  nivenGLSETINVARIANTEXT glSetInvariantEXT;
#endif

#ifndef NIV_GLVARIANTSVEXT_DECLARATION
#define NIV_GLVARIANTSVEXT_DECLARATION
  nivenGLVARIANTSVEXT glVariantsvEXT;
#endif

#ifndef NIV_GLGETLOCALCONSTANTINTEGERVEXT_DECLARATION
#define NIV_GLGETLOCALCONSTANTINTEGERVEXT_DECLARATION
  nivenGLGETLOCALCONSTANTINTEGERVEXT glGetLocalConstantIntegervEXT;
#endif

#ifndef NIV_GLGETVARIANTINTEGERVEXT_DECLARATION
#define NIV_GLGETVARIANTINTEGERVEXT_DECLARATION
  nivenGLGETVARIANTINTEGERVEXT glGetVariantIntegervEXT;
#endif

#ifndef NIV_GLVARIANTPOINTEREXT_DECLARATION
#define NIV_GLVARIANTPOINTEREXT_DECLARATION
  nivenGLVARIANTPOINTEREXT glVariantPointerEXT;
#endif

#ifndef NIV_GLGENVERTEXSHADERSEXT_DECLARATION
#define NIV_GLGENVERTEXSHADERSEXT_DECLARATION
  nivenGLGENVERTEXSHADERSEXT glGenVertexShadersEXT;
#endif

#ifndef NIV_GLENDVERTEXSHADEREXT_DECLARATION
#define NIV_GLENDVERTEXSHADEREXT_DECLARATION
  nivenGLENDVERTEXSHADEREXT glEndVertexShaderEXT;
#endif

#ifndef NIV_GLBINDVERTEXSHADEREXT_DECLARATION
#define NIV_GLBINDVERTEXSHADEREXT_DECLARATION
  nivenGLBINDVERTEXSHADEREXT glBindVertexShaderEXT;
#endif

#ifndef NIV_GLGETVARIANTFLOATVEXT_DECLARATION
#define NIV_GLGETVARIANTFLOATVEXT_DECLARATION
  nivenGLGETVARIANTFLOATVEXT glGetVariantFloatvEXT;
#endif

#ifndef NIV_GLEXTRACTCOMPONENTEXT_DECLARATION
#define NIV_GLEXTRACTCOMPONENTEXT_DECLARATION
  nivenGLEXTRACTCOMPONENTEXT glExtractComponentEXT;
#endif

#ifndef NIV_GLBEGINVERTEXSHADEREXT_DECLARATION
#define NIV_GLBEGINVERTEXSHADEREXT_DECLARATION
  nivenGLBEGINVERTEXSHADEREXT glBeginVertexShaderEXT;
#endif

#ifndef NIV_GLDELETEVERTEXSHADEREXT_DECLARATION
#define NIV_GLDELETEVERTEXSHADEREXT_DECLARATION
  nivenGLDELETEVERTEXSHADEREXT glDeleteVertexShaderEXT;
#endif

#ifndef NIV_GLVARIANTDVEXT_DECLARATION
#define NIV_GLVARIANTDVEXT_DECLARATION
  nivenGLVARIANTDVEXT glVariantdvEXT;
#endif

#ifndef NIV_GLGETLOCALCONSTANTBOOLEANVEXT_DECLARATION
#define NIV_GLGETLOCALCONSTANTBOOLEANVEXT_DECLARATION
  nivenGLGETLOCALCONSTANTBOOLEANVEXT glGetLocalConstantBooleanvEXT;
#endif

#ifndef NIV_GLISVARIANTENABLEDEXT_DECLARATION
#define NIV_GLISVARIANTENABLEDEXT_DECLARATION
  nivenGLISVARIANTENABLEDEXT glIsVariantEnabledEXT;
#endif

#ifndef NIV_GLVARIANTUIVEXT_DECLARATION
#define NIV_GLVARIANTUIVEXT_DECLARATION
  nivenGLVARIANTUIVEXT glVariantuivEXT;
#endif

#ifndef NIV_GLWRITEMASKEXT_DECLARATION
#define NIV_GLWRITEMASKEXT_DECLARATION
  nivenGLWRITEMASKEXT glWriteMaskEXT;
#endif

#ifndef NIV_GLENABLEVARIANTCLIENTSTATEEXT_DECLARATION
#define NIV_GLENABLEVARIANTCLIENTSTATEEXT_DECLARATION
  nivenGLENABLEVARIANTCLIENTSTATEEXT glEnableVariantClientStateEXT;
#endif

#ifndef NIV_GLVARIANTUSVEXT_DECLARATION
#define NIV_GLVARIANTUSVEXT_DECLARATION
  nivenGLVARIANTUSVEXT glVariantusvEXT;
#endif

#ifndef NIV_GLGENSYMBOLSEXT_DECLARATION
#define NIV_GLGENSYMBOLSEXT_DECLARATION
  nivenGLGENSYMBOLSEXT glGenSymbolsEXT;
#endif

#ifndef NIV_GLGETINVARIANTINTEGERVEXT_DECLARATION
#define NIV_GLGETINVARIANTINTEGERVEXT_DECLARATION
  nivenGLGETINVARIANTINTEGERVEXT glGetInvariantIntegervEXT;
#endif

#ifndef NIV_GLSHADEROP2EXT_DECLARATION
#define NIV_GLSHADEROP2EXT_DECLARATION
  nivenGLSHADEROP2EXT glShaderOp2EXT;
#endif

#ifndef NIV_GLBINDPARAMETEREXT_DECLARATION
#define NIV_GLBINDPARAMETEREXT_DECLARATION
  nivenGLBINDPARAMETEREXT glBindParameterEXT;
#endif

#ifndef NIV_GLDISABLEVARIANTCLIENTSTATEEXT_DECLARATION
#define NIV_GLDISABLEVARIANTCLIENTSTATEEXT_DECLARATION
  nivenGLDISABLEVARIANTCLIENTSTATEEXT glDisableVariantClientStateEXT;
#endif

#ifndef NIV_GLVARIANTIVEXT_DECLARATION
#define NIV_GLVARIANTIVEXT_DECLARATION
  nivenGLVARIANTIVEXT glVariantivEXT;
#endif

#ifndef NIV_GLSWIZZLEEXT_DECLARATION
#define NIV_GLSWIZZLEEXT_DECLARATION
  nivenGLSWIZZLEEXT glSwizzleEXT;
#endif

#ifndef NIV_GLGETINVARIANTBOOLEANVEXT_DECLARATION
#define NIV_GLGETINVARIANTBOOLEANVEXT_DECLARATION
  nivenGLGETINVARIANTBOOLEANVEXT glGetInvariantBooleanvEXT;
#endif

#ifndef NIV_GLBINDTEXTUREUNITPARAMETEREXT_DECLARATION
#define NIV_GLBINDTEXTUREUNITPARAMETEREXT_DECLARATION
  nivenGLBINDTEXTUREUNITPARAMETEREXT glBindTextureUnitParameterEXT;
#endif

#ifndef NIV_GLBINDTEXGENPARAMETEREXT_DECLARATION
#define NIV_GLBINDTEXGENPARAMETEREXT_DECLARATION
  nivenGLBINDTEXGENPARAMETEREXT glBindTexGenParameterEXT;
#endif

#ifndef NIV_GLGETINVARIANTFLOATVEXT_DECLARATION
#define NIV_GLGETINVARIANTFLOATVEXT_DECLARATION
  nivenGLGETINVARIANTFLOATVEXT glGetInvariantFloatvEXT;
#endif

#ifndef NIV_GLGETVARIANTBOOLEANVEXT_DECLARATION
#define NIV_GLGETVARIANTBOOLEANVEXT_DECLARATION
  nivenGLGETVARIANTBOOLEANVEXT glGetVariantBooleanvEXT;
#endif

#ifndef NIV_GLGETVARIANTPOINTERVEXT_DECLARATION
#define NIV_GLGETVARIANTPOINTERVEXT_DECLARATION
  nivenGLGETVARIANTPOINTERVEXT glGetVariantPointervEXT;
#endif

#ifndef NIV_GLBINDLIGHTPARAMETEREXT_DECLARATION
#define NIV_GLBINDLIGHTPARAMETEREXT_DECLARATION
  nivenGLBINDLIGHTPARAMETEREXT glBindLightParameterEXT;
#endif

#ifndef NIV_GLSETLOCALCONSTANTEXT_DECLARATION
#define NIV_GLSETLOCALCONSTANTEXT_DECLARATION
  nivenGLSETLOCALCONSTANTEXT glSetLocalConstantEXT;
#endif

#ifndef NIV_GLGETLOCALCONSTANTFLOATVEXT_DECLARATION
#define NIV_GLGETLOCALCONSTANTFLOATVEXT_DECLARATION
  nivenGLGETLOCALCONSTANTFLOATVEXT glGetLocalConstantFloatvEXT;
#endif

#ifndef NIV_GLSHADEROP1EXT_DECLARATION
#define NIV_GLSHADEROP1EXT_DECLARATION
  nivenGLSHADEROP1EXT glShaderOp1EXT;
#endif

#ifndef NIV_GLBINDMATERIALPARAMETEREXT_DECLARATION
#define NIV_GLBINDMATERIALPARAMETEREXT_DECLARATION
  nivenGLBINDMATERIALPARAMETEREXT glBindMaterialParameterEXT;
#endif

#ifndef NIV_GLINSERTCOMPONENTEXT_DECLARATION
#define NIV_GLINSERTCOMPONENTEXT_DECLARATION
  nivenGLINSERTCOMPONENTEXT glInsertComponentEXT;
#endif

#ifndef NIV_GLVARIANTFVEXT_DECLARATION
#define NIV_GLVARIANTFVEXT_DECLARATION
  nivenGLVARIANTFVEXT glVariantfvEXT;
#endif

#ifndef NIV_GLSHADEROP3EXT_DECLARATION
#define NIV_GLSHADEROP3EXT_DECLARATION
  nivenGLSHADEROP3EXT glShaderOp3EXT;
#endif

#ifndef NIV_GLVARIANTBVEXT_DECLARATION
#define NIV_GLVARIANTBVEXT_DECLARATION
  nivenGLVARIANTBVEXT glVariantbvEXT;
#endif


  // GL_APPLE_pixel_buffer

  // GL_EXT_misc_attribute

  // GL_NV_texture_shader3

  // GL_NV_texture_shader2

  // GL_EXT_blend_func_separate
#ifndef NIV_GLBLENDFUNCSEPARATEEXT_DECLARATION
#define NIV_GLBLENDFUNCSEPARATEEXT_DECLARATION
  nivenGLBLENDFUNCSEPARATEEXT glBlendFuncSeparateEXT;
#endif


  // GL_SGIX_pixel_texture_bits

  // GL_EXT_texture

  // GL_APPLE_fence
#ifndef NIV_GLDELETEFENCESAPPLE_DECLARATION
#define NIV_GLDELETEFENCESAPPLE_DECLARATION
  nivenGLDELETEFENCESAPPLE glDeleteFencesAPPLE;
#endif

#ifndef NIV_GLISFENCEAPPLE_DECLARATION
#define NIV_GLISFENCEAPPLE_DECLARATION
  nivenGLISFENCEAPPLE glIsFenceAPPLE;
#endif

#ifndef NIV_GLFINISHOBJECTAPPLE_DECLARATION
#define NIV_GLFINISHOBJECTAPPLE_DECLARATION
  nivenGLFINISHOBJECTAPPLE glFinishObjectAPPLE;
#endif

#ifndef NIV_GLTESTOBJECTAPPLE_DECLARATION
#define NIV_GLTESTOBJECTAPPLE_DECLARATION
  nivenGLTESTOBJECTAPPLE glTestObjectAPPLE;
#endif

#ifndef NIV_GLTESTFENCEAPPLE_DECLARATION
#define NIV_GLTESTFENCEAPPLE_DECLARATION
  nivenGLTESTFENCEAPPLE glTestFenceAPPLE;
#endif

#ifndef NIV_GLFINISHFENCEAPPLE_DECLARATION
#define NIV_GLFINISHFENCEAPPLE_DECLARATION
  nivenGLFINISHFENCEAPPLE glFinishFenceAPPLE;
#endif

#ifndef NIV_GLGENFENCESAPPLE_DECLARATION
#define NIV_GLGENFENCESAPPLE_DECLARATION
  nivenGLGENFENCESAPPLE glGenFencesAPPLE;
#endif

#ifndef NIV_GLSETFENCEAPPLE_DECLARATION
#define NIV_GLSETFENCEAPPLE_DECLARATION
  nivenGLSETFENCEAPPLE glSetFenceAPPLE;
#endif


  // GL_EXT_multisample
#ifndef NIV_GLSAMPLEMASKEXT_DECLARATION
#define NIV_GLSAMPLEMASKEXT_DECLARATION
  nivenGLSAMPLEMASKEXT glSampleMaskEXT;
#endif

#ifndef NIV_GLSAMPLEPATTERNEXT_DECLARATION
#define NIV_GLSAMPLEPATTERNEXT_DECLARATION
  nivenGLSAMPLEPATTERNEXT glSamplePatternEXT;
#endif


  // GL_EXT_texture_cube_map

  // GL_ARB_occlusion_query
#ifndef NIV_GLGETQUERYOBJECTUIVARB_DECLARATION
#define NIV_GLGETQUERYOBJECTUIVARB_DECLARATION
  nivenGLGETQUERYOBJECTUIVARB glGetQueryObjectuivARB;
#endif

#ifndef NIV_GLGETQUERYIVARB_DECLARATION
#define NIV_GLGETQUERYIVARB_DECLARATION
  nivenGLGETQUERYIVARB glGetQueryivARB;
#endif

#ifndef NIV_GLGENQUERIESARB_DECLARATION
#define NIV_GLGENQUERIESARB_DECLARATION
  nivenGLGENQUERIESARB glGenQueriesARB;
#endif

#ifndef NIV_GLGETQUERYOBJECTIVARB_DECLARATION
#define NIV_GLGETQUERYOBJECTIVARB_DECLARATION
  nivenGLGETQUERYOBJECTIVARB glGetQueryObjectivARB;
#endif

#ifndef NIV_GLENDQUERYARB_DECLARATION
#define NIV_GLENDQUERYARB_DECLARATION
  nivenGLENDQUERYARB glEndQueryARB;
#endif

#ifndef NIV_GLISQUERYARB_DECLARATION
#define NIV_GLISQUERYARB_DECLARATION
  nivenGLISQUERYARB glIsQueryARB;
#endif

#ifndef NIV_GLBEGINQUERYARB_DECLARATION
#define NIV_GLBEGINQUERYARB_DECLARATION
  nivenGLBEGINQUERYARB glBeginQueryARB;
#endif

#ifndef NIV_GLDELETEQUERIESARB_DECLARATION
#define NIV_GLDELETEQUERIESARB_DECLARATION
  nivenGLDELETEQUERIESARB glDeleteQueriesARB;
#endif


  // GL_INGR_color_clamp

  // GL_EXT_422_pixels

  // GL_EXT_index_func
#ifndef NIV_GLINDEXFUNCEXT_DECLARATION
#define NIV_GLINDEXFUNCEXT_DECLARATION
  nivenGLINDEXFUNCEXT glIndexFuncEXT;
#endif


#ifdef _GLX
  // GLX_MESA_set_3dfx_mode
#ifndef NIV_GLXSET3DFXMODEMESA_DECLARATION
#define NIV_GLXSET3DFXMODEMESA_DECLARATION
  nivenGLXSET3DFXMODEMESA glXSet3DfxModeMESA;
#endif

#endif // _GLX
#ifdef WIN32
  // WGL_NV_float_buffer
#endif
  // GL_SUN_read_video_pixels
#ifndef NIV_GLREADVIDEOPIXELSSUN_DECLARATION
#define NIV_GLREADVIDEOPIXELSSUN_DECLARATION
  nivenGLREADVIDEOPIXELSSUN glReadVideoPixelsSUN;
#endif


  // GL_ARB_transpose_matrix
#ifndef NIV_GLMULTTRANSPOSEMATRIXDARB_DECLARATION
#define NIV_GLMULTTRANSPOSEMATRIXDARB_DECLARATION
  nivenGLMULTTRANSPOSEMATRIXDARB glMultTransposeMatrixdARB;
#endif

#ifndef NIV_GLLOADTRANSPOSEMATRIXDARB_DECLARATION
#define NIV_GLLOADTRANSPOSEMATRIXDARB_DECLARATION
  nivenGLLOADTRANSPOSEMATRIXDARB glLoadTransposeMatrixdARB;
#endif

#ifndef NIV_GLLOADTRANSPOSEMATRIXFARB_DECLARATION
#define NIV_GLLOADTRANSPOSEMATRIXFARB_DECLARATION
  nivenGLLOADTRANSPOSEMATRIXFARB glLoadTransposeMatrixfARB;
#endif

#ifndef NIV_GLMULTTRANSPOSEMATRIXFARB_DECLARATION
#define NIV_GLMULTTRANSPOSEMATRIXFARB_DECLARATION
  nivenGLMULTTRANSPOSEMATRIXFARB glMultTransposeMatrixfARB;
#endif


#ifdef WIN32
  // WGL_EXT_extensions_string
#ifndef NIV_WGLGETEXTENSIONSSTRINGEXT_DECLARATION
#define NIV_WGLGETEXTENSIONSSTRINGEXT_DECLARATION
  nivenWGLGETEXTENSIONSSTRINGEXT wglGetExtensionsStringEXT;
#endif

#endif
#ifdef WIN32
  // WGL_ATI_pixel_format_float
#endif
#ifdef WIN32
  // WGL_I3D_image_buffer
#ifndef NIV_WGLASSOCIATEIMAGEBUFFEREVENTSI3D_DECLARATION
#define NIV_WGLASSOCIATEIMAGEBUFFEREVENTSI3D_DECLARATION
  nivenWGLASSOCIATEIMAGEBUFFEREVENTSI3D wglAssociateImageBufferEventsI3D;
#endif

#ifndef NIV_WGLDESTROYIMAGEBUFFERI3D_DECLARATION
#define NIV_WGLDESTROYIMAGEBUFFERI3D_DECLARATION
  nivenWGLDESTROYIMAGEBUFFERI3D wglDestroyImageBufferI3D;
#endif

#ifndef NIV_WGLRELEASEIMAGEBUFFEREVENTSI3D_DECLARATION
#define NIV_WGLRELEASEIMAGEBUFFEREVENTSI3D_DECLARATION
  nivenWGLRELEASEIMAGEBUFFEREVENTSI3D wglReleaseImageBufferEventsI3D;
#endif

#ifndef NIV_WGLCREATEIMAGEBUFFERI3D_DECLARATION
#define NIV_WGLCREATEIMAGEBUFFERI3D_DECLARATION
  nivenWGLCREATEIMAGEBUFFERI3D wglCreateImageBufferI3D;
#endif

#endif
  // GL_NV_fence
#ifndef NIV_GLDELETEFENCESNV_DECLARATION
#define NIV_GLDELETEFENCESNV_DECLARATION
  nivenGLDELETEFENCESNV glDeleteFencesNV;
#endif

#ifndef NIV_GLTESTFENCENV_DECLARATION
#define NIV_GLTESTFENCENV_DECLARATION
  nivenGLTESTFENCENV glTestFenceNV;
#endif

#ifndef NIV_GLGENFENCESNV_DECLARATION
#define NIV_GLGENFENCESNV_DECLARATION
  nivenGLGENFENCESNV glGenFencesNV;
#endif

#ifndef NIV_GLGETFENCEIVNV_DECLARATION
#define NIV_GLGETFENCEIVNV_DECLARATION
  nivenGLGETFENCEIVNV glGetFenceivNV;
#endif

#ifndef NIV_GLFINISHFENCENV_DECLARATION
#define NIV_GLFINISHFENCENV_DECLARATION
  nivenGLFINISHFENCENV glFinishFenceNV;
#endif

#ifndef NIV_GLSETFENCENV_DECLARATION
#define NIV_GLSETFENCENV_DECLARATION
  nivenGLSETFENCENV glSetFenceNV;
#endif

#ifndef NIV_GLISFENCENV_DECLARATION
#define NIV_GLISFENCENV_DECLARATION
  nivenGLISFENCENV glIsFenceNV;
#endif


#ifdef WIN32
  // WGL_ATI_render_texture_rectangle
#endif
  // GL_ARB_texture_border_clamp

  // GL_EXT_fog_coord
#ifndef NIV_GLFOGCOORDDEXT_DECLARATION
#define NIV_GLFOGCOORDDEXT_DECLARATION
  nivenGLFOGCOORDDEXT glFogCoorddEXT;
#endif

#ifndef NIV_GLFOGCOORDPOINTEREXT_DECLARATION
#define NIV_GLFOGCOORDPOINTEREXT_DECLARATION
  nivenGLFOGCOORDPOINTEREXT glFogCoordPointerEXT;
#endif

#ifndef NIV_GLFOGCOORDFVEXT_DECLARATION
#define NIV_GLFOGCOORDFVEXT_DECLARATION
  nivenGLFOGCOORDFVEXT glFogCoordfvEXT;
#endif

#ifndef NIV_GLFOGCOORDDVEXT_DECLARATION
#define NIV_GLFOGCOORDDVEXT_DECLARATION
  nivenGLFOGCOORDDVEXT glFogCoorddvEXT;
#endif

#ifndef NIV_GLFOGCOORDFEXT_DECLARATION
#define NIV_GLFOGCOORDFEXT_DECLARATION
  nivenGLFOGCOORDFEXT glFogCoordfEXT;
#endif


  // GL_NV_depth_clamp

#ifdef WIN32
  // WGL_I3D_digital_video_control
#ifndef NIV_WGLSETDIGITALVIDEOPARAMETERSI3D_DECLARATION
#define NIV_WGLSETDIGITALVIDEOPARAMETERSI3D_DECLARATION
  nivenWGLSETDIGITALVIDEOPARAMETERSI3D wglSetDigitalVideoParametersI3D;
#endif

#ifndef NIV_WGLGETDIGITALVIDEOPARAMETERSI3D_DECLARATION
#define NIV_WGLGETDIGITALVIDEOPARAMETERSI3D_DECLARATION
  nivenWGLGETDIGITALVIDEOPARAMETERSI3D wglGetDigitalVideoParametersI3D;
#endif

#endif
  // GL_ARB_texture_cube_map

  // GL_EXT_color_subtable
#ifndef NIV_GLCOPYCOLORSUBTABLEEXT_DECLARATION
#define NIV_GLCOPYCOLORSUBTABLEEXT_DECLARATION
  nivenGLCOPYCOLORSUBTABLEEXT glCopyColorSubTableEXT;
#endif

#ifndef NIV_GLCOLORSUBTABLEEXT_DECLARATION
#define NIV_GLCOLORSUBTABLEEXT_DECLARATION
  nivenGLCOLORSUBTABLEEXT glColorSubTableEXT;
#endif


  // GL_EXT_blend_equation_separate
#ifndef NIV_GLBLENDEQUATIONSEPARATEEXT_DECLARATION
#define NIV_GLBLENDEQUATIONSEPARATEEXT_DECLARATION
  nivenGLBLENDEQUATIONSEPARATEEXT glBlendEquationSeparateEXT;
#endif


#ifdef WIN32
  // WGL_I3D_swap_frame_lock
#ifndef NIV_WGLENABLEFRAMELOCKI3D_DECLARATION
#define NIV_WGLENABLEFRAMELOCKI3D_DECLARATION
  nivenWGLENABLEFRAMELOCKI3D wglEnableFrameLockI3D;
#endif

#ifndef NIV_WGLQUERYFRAMELOCKMASTERI3D_DECLARATION
#define NIV_WGLQUERYFRAMELOCKMASTERI3D_DECLARATION
  nivenWGLQUERYFRAMELOCKMASTERI3D wglQueryFrameLockMasterI3D;
#endif

#ifndef NIV_WGLDISABLEFRAMELOCKI3D_DECLARATION
#define NIV_WGLDISABLEFRAMELOCKI3D_DECLARATION
  nivenWGLDISABLEFRAMELOCKI3D wglDisableFrameLockI3D;
#endif

#ifndef NIV_WGLISENABLEDFRAMELOCKI3D_DECLARATION
#define NIV_WGLISENABLEDFRAMELOCKI3D_DECLARATION
  nivenWGLISENABLEDFRAMELOCKI3D wglIsEnabledFrameLockI3D;
#endif

#endif
  // GL_SUN_mesh_array

  // GL_SUNX_constant_data
#ifndef NIV_GLFINISHTEXTURESUNX_DECLARATION
#define NIV_GLFINISHTEXTURESUNX_DECLARATION
  nivenGLFINISHTEXTURESUNX glFinishTextureSUNX;
#endif


  // GL_ARB_point_parameters
#ifndef NIV_GLPOINTPARAMETERFARB_DECLARATION
#define NIV_GLPOINTPARAMETERFARB_DECLARATION
  nivenGLPOINTPARAMETERFARB glPointParameterfARB;
#endif

#ifndef NIV_GLPOINTPARAMETERFVARB_DECLARATION
#define NIV_GLPOINTPARAMETERFVARB_DECLARATION
  nivenGLPOINTPARAMETERFVARB glPointParameterfvARB;
#endif


  // GL_EXT_texture_env_dot3

#ifdef WIN32
  // WGL_ARB_buffer_region
#ifndef NIV_WGLSAVEBUFFERREGIONARB_DECLARATION
#define NIV_WGLSAVEBUFFERREGIONARB_DECLARATION
  nivenWGLSAVEBUFFERREGIONARB wglSaveBufferRegionARB;
#endif

#ifndef NIV_WGLCREATEBUFFERREGIONARB_DECLARATION
#define NIV_WGLCREATEBUFFERREGIONARB_DECLARATION
  nivenWGLCREATEBUFFERREGIONARB wglCreateBufferRegionARB;
#endif

#ifndef NIV_WGLDELETEBUFFERREGIONARB_DECLARATION
#define NIV_WGLDELETEBUFFERREGIONARB_DECLARATION
  nivenWGLDELETEBUFFERREGIONARB wglDeleteBufferRegionARB;
#endif

#ifndef NIV_WGLRESTOREBUFFERREGIONARB_DECLARATION
#define NIV_WGLRESTOREBUFFERREGIONARB_DECLARATION
  nivenWGLRESTOREBUFFERREGIONARB wglRestoreBufferRegionARB;
#endif

#endif
  // GL_ATI_texture_env_combine3

  // GL_SGIX_shadow_ambient

  // GL_EXT_multi_draw_arrays
#ifndef NIV_GLMULTIDRAWELEMENTSEXT_DECLARATION
#define NIV_GLMULTIDRAWELEMENTSEXT_DECLARATION
  nivenGLMULTIDRAWELEMENTSEXT glMultiDrawElementsEXT;
#endif

#ifndef NIV_GLMULTIDRAWARRAYSEXT_DECLARATION
#define NIV_GLMULTIDRAWARRAYSEXT_DECLARATION
  nivenGLMULTIDRAWARRAYSEXT glMultiDrawArraysEXT;
#endif


  // GL_SGIX_depth_texture

  // GL_EXT_texture_compression_dxt1

  // GL_NV_texgen_emboss

  // GL_HP_occlusion_test

  // GL_WIN_phong_shading

#ifdef _GLX
  // GLX_SGIS_shared_multisample
#endif // _GLX
  // GL_ATIX_texture_env_combine3

  // GL_EXT_texture_filter_anisotropic

  // GL_EXT_texture_perturb_normal
#ifndef NIV_GLTEXTURENORMALEXT_DECLARATION
#define NIV_GLTEXTURENORMALEXT_DECLARATION
  nivenGLTEXTURENORMALEXT glTextureNormalEXT;
#endif


  // GL_NV_fog_distance

  // GL_ATIX_vertex_shader_output_point_size

  // GL_SUN_global_alpha
#ifndef NIV_GLGLOBALALPHAFACTORDSUN_DECLARATION
#define NIV_GLGLOBALALPHAFACTORDSUN_DECLARATION
  nivenGLGLOBALALPHAFACTORDSUN glGlobalAlphaFactordSUN;
#endif

#ifndef NIV_GLGLOBALALPHAFACTORSSUN_DECLARATION
#define NIV_GLGLOBALALPHAFACTORSSUN_DECLARATION
  nivenGLGLOBALALPHAFACTORSSUN glGlobalAlphaFactorsSUN;
#endif

#ifndef NIV_GLGLOBALALPHAFACTORISUN_DECLARATION
#define NIV_GLGLOBALALPHAFACTORISUN_DECLARATION
  nivenGLGLOBALALPHAFACTORISUN glGlobalAlphaFactoriSUN;
#endif

#ifndef NIV_GLGLOBALALPHAFACTORUSSUN_DECLARATION
#define NIV_GLGLOBALALPHAFACTORUSSUN_DECLARATION
  nivenGLGLOBALALPHAFACTORUSSUN glGlobalAlphaFactorusSUN;
#endif

#ifndef NIV_GLGLOBALALPHAFACTORFSUN_DECLARATION
#define NIV_GLGLOBALALPHAFACTORFSUN_DECLARATION
  nivenGLGLOBALALPHAFACTORFSUN glGlobalAlphaFactorfSUN;
#endif

#ifndef NIV_GLGLOBALALPHAFACTORBSUN_DECLARATION
#define NIV_GLGLOBALALPHAFACTORBSUN_DECLARATION
  nivenGLGLOBALALPHAFACTORBSUN glGlobalAlphaFactorbSUN;
#endif

#ifndef NIV_GLGLOBALALPHAFACTORUISUN_DECLARATION
#define NIV_GLGLOBALALPHAFACTORUISUN_DECLARATION
  nivenGLGLOBALALPHAFACTORUISUN glGlobalAlphaFactoruiSUN;
#endif

#ifndef NIV_GLGLOBALALPHAFACTORUBSUN_DECLARATION
#define NIV_GLGLOBALALPHAFACTORUBSUN_DECLARATION
  nivenGLGLOBALALPHAFACTORUBSUN glGlobalAlphaFactorubSUN;
#endif


#ifdef WIN32
  // WGL_EXT_pixel_format
#ifndef NIV_WGLGETPIXELFORMATATTRIBFVEXT_DECLARATION
#define NIV_WGLGETPIXELFORMATATTRIBFVEXT_DECLARATION
  nivenWGLGETPIXELFORMATATTRIBFVEXT wglGetPixelFormatAttribfvEXT;
#endif

#ifndef NIV_WGLCHOOSEPIXELFORMATEXT_DECLARATION
#define NIV_WGLCHOOSEPIXELFORMATEXT_DECLARATION
  nivenWGLCHOOSEPIXELFORMATEXT wglChoosePixelFormatEXT;
#endif

#ifndef NIV_WGLGETPIXELFORMATATTRIBIVEXT_DECLARATION
#define NIV_WGLGETPIXELFORMATATTRIBIVEXT_DECLARATION
  nivenWGLGETPIXELFORMATATTRIBIVEXT wglGetPixelFormatAttribivEXT;
#endif

#endif
  // GL_SGIX_async_histogram

  // GL_ARB_vertex_program
#ifndef NIV_GLVERTEXATTRIB4UBVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4UBVARB_DECLARATION
  nivenGLVERTEXATTRIB4UBVARB glVertexAttrib4ubvARB;
#endif

#ifndef NIV_GLDISABLEVERTEXATTRIBARRAYARB_DECLARATION
#define NIV_GLDISABLEVERTEXATTRIBARRAYARB_DECLARATION
  nivenGLDISABLEVERTEXATTRIBARRAYARB glDisableVertexAttribArrayARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4NSVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4NSVARB_DECLARATION
  nivenGLVERTEXATTRIB4NSVARB glVertexAttrib4NsvARB;
#endif

#ifndef NIV_GLGETPROGRAMLOCALPARAMETERFVARB_DECLARATION
#define NIV_GLGETPROGRAMLOCALPARAMETERFVARB_DECLARATION
  nivenGLGETPROGRAMLOCALPARAMETERFVARB glGetProgramLocalParameterfvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB2DVARB_DECLARATION
#define NIV_GLVERTEXATTRIB2DVARB_DECLARATION
  nivenGLVERTEXATTRIB2DVARB glVertexAttrib2dvARB;
#endif

#ifndef NIV_GLPROGRAMENVPARAMETER4FVARB_DECLARATION
#define NIV_GLPROGRAMENVPARAMETER4FVARB_DECLARATION
  nivenGLPROGRAMENVPARAMETER4FVARB glProgramEnvParameter4fvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4NIVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4NIVARB_DECLARATION
  nivenGLVERTEXATTRIB4NIVARB glVertexAttrib4NivARB;
#endif

#ifndef NIV_GLVERTEXATTRIB1SARB_DECLARATION
#define NIV_GLVERTEXATTRIB1SARB_DECLARATION
  nivenGLVERTEXATTRIB1SARB glVertexAttrib1sARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4UIVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4UIVARB_DECLARATION
  nivenGLVERTEXATTRIB4UIVARB glVertexAttrib4uivARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4NUBARB_DECLARATION
#define NIV_GLVERTEXATTRIB4NUBARB_DECLARATION
  nivenGLVERTEXATTRIB4NUBARB glVertexAttrib4NubARB;
#endif

#ifndef NIV_GLPROGRAMLOCALPARAMETER4DARB_DECLARATION
#define NIV_GLPROGRAMLOCALPARAMETER4DARB_DECLARATION
  nivenGLPROGRAMLOCALPARAMETER4DARB glProgramLocalParameter4dARB;
#endif

#ifndef NIV_GLVERTEXATTRIB3FVARB_DECLARATION
#define NIV_GLVERTEXATTRIB3FVARB_DECLARATION
  nivenGLVERTEXATTRIB3FVARB glVertexAttrib3fvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB1FVARB_DECLARATION
#define NIV_GLVERTEXATTRIB1FVARB_DECLARATION
  nivenGLVERTEXATTRIB1FVARB glVertexAttrib1fvARB;
#endif

#ifndef NIV_GLGETPROGRAMSTRINGARB_DECLARATION
#define NIV_GLGETPROGRAMSTRINGARB_DECLARATION
  nivenGLGETPROGRAMSTRINGARB glGetProgramStringARB;
#endif

#ifndef NIV_GLGETPROGRAMLOCALPARAMETERDVARB_DECLARATION
#define NIV_GLGETPROGRAMLOCALPARAMETERDVARB_DECLARATION
  nivenGLGETPROGRAMLOCALPARAMETERDVARB glGetProgramLocalParameterdvARB;
#endif

#ifndef NIV_GLENABLEVERTEXATTRIBARRAYARB_DECLARATION
#define NIV_GLENABLEVERTEXATTRIBARRAYARB_DECLARATION
  nivenGLENABLEVERTEXATTRIBARRAYARB glEnableVertexAttribArrayARB;
#endif

#ifndef NIV_GLVERTEXATTRIB2FVARB_DECLARATION
#define NIV_GLVERTEXATTRIB2FVARB_DECLARATION
  nivenGLVERTEXATTRIB2FVARB glVertexAttrib2fvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB3DVARB_DECLARATION
#define NIV_GLVERTEXATTRIB3DVARB_DECLARATION
  nivenGLVERTEXATTRIB3DVARB glVertexAttrib3dvARB;
#endif

#ifndef NIV_GLPROGRAMENVPARAMETER4FARB_DECLARATION
#define NIV_GLPROGRAMENVPARAMETER4FARB_DECLARATION
  nivenGLPROGRAMENVPARAMETER4FARB glProgramEnvParameter4fARB;
#endif

#ifndef NIV_GLGETVERTEXATTRIBIVARB_DECLARATION
#define NIV_GLGETVERTEXATTRIBIVARB_DECLARATION
  nivenGLGETVERTEXATTRIBIVARB glGetVertexAttribivARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4SVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4SVARB_DECLARATION
  nivenGLVERTEXATTRIB4SVARB glVertexAttrib4svARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4FARB_DECLARATION
#define NIV_GLVERTEXATTRIB4FARB_DECLARATION
  nivenGLVERTEXATTRIB4FARB glVertexAttrib4fARB;
#endif

#ifndef NIV_GLVERTEXATTRIB3DARB_DECLARATION
#define NIV_GLVERTEXATTRIB3DARB_DECLARATION
  nivenGLVERTEXATTRIB3DARB glVertexAttrib3dARB;
#endif

#ifndef NIV_GLISPROGRAMARB_DECLARATION
#define NIV_GLISPROGRAMARB_DECLARATION
  nivenGLISPROGRAMARB glIsProgramARB;
#endif

#ifndef NIV_GLPROGRAMLOCALPARAMETER4DVARB_DECLARATION
#define NIV_GLPROGRAMLOCALPARAMETER4DVARB_DECLARATION
  nivenGLPROGRAMLOCALPARAMETER4DVARB glProgramLocalParameter4dvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB2SVARB_DECLARATION
#define NIV_GLVERTEXATTRIB2SVARB_DECLARATION
  nivenGLVERTEXATTRIB2SVARB glVertexAttrib2svARB;
#endif

#ifndef NIV_GLVERTEXATTRIB1DARB_DECLARATION
#define NIV_GLVERTEXATTRIB1DARB_DECLARATION
  nivenGLVERTEXATTRIB1DARB glVertexAttrib1dARB;
#endif

#ifndef NIV_GLVERTEXATTRIB1FARB_DECLARATION
#define NIV_GLVERTEXATTRIB1FARB_DECLARATION
  nivenGLVERTEXATTRIB1FARB glVertexAttrib1fARB;
#endif

#ifndef NIV_GLPROGRAMLOCALPARAMETER4FVARB_DECLARATION
#define NIV_GLPROGRAMLOCALPARAMETER4FVARB_DECLARATION
  nivenGLPROGRAMLOCALPARAMETER4FVARB glProgramLocalParameter4fvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB2FARB_DECLARATION
#define NIV_GLVERTEXATTRIB2FARB_DECLARATION
  nivenGLVERTEXATTRIB2FARB glVertexAttrib2fARB;
#endif

#ifndef NIV_GLPROGRAMENVPARAMETER4DARB_DECLARATION
#define NIV_GLPROGRAMENVPARAMETER4DARB_DECLARATION
  nivenGLPROGRAMENVPARAMETER4DARB glProgramEnvParameter4dARB;
#endif

#ifndef NIV_GLVERTEXATTRIB2DARB_DECLARATION
#define NIV_GLVERTEXATTRIB2DARB_DECLARATION
  nivenGLVERTEXATTRIB2DARB glVertexAttrib2dARB;
#endif

#ifndef NIV_GLGETVERTEXATTRIBFVARB_DECLARATION
#define NIV_GLGETVERTEXATTRIBFVARB_DECLARATION
  nivenGLGETVERTEXATTRIBFVARB glGetVertexAttribfvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4NUSVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4NUSVARB_DECLARATION
  nivenGLVERTEXATTRIB4NUSVARB glVertexAttrib4NusvARB;
#endif

#ifndef NIV_GLGETVERTEXATTRIBPOINTERVARB_DECLARATION
#define NIV_GLGETVERTEXATTRIBPOINTERVARB_DECLARATION
  nivenGLGETVERTEXATTRIBPOINTERVARB glGetVertexAttribPointervARB;
#endif

#ifndef NIV_GLVERTEXATTRIB3FARB_DECLARATION
#define NIV_GLVERTEXATTRIB3FARB_DECLARATION
  nivenGLVERTEXATTRIB3FARB glVertexAttrib3fARB;
#endif

#ifndef NIV_GLGETPROGRAMENVPARAMETERDVARB_DECLARATION
#define NIV_GLGETPROGRAMENVPARAMETERDVARB_DECLARATION
  nivenGLGETPROGRAMENVPARAMETERDVARB glGetProgramEnvParameterdvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4NUBVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4NUBVARB_DECLARATION
  nivenGLVERTEXATTRIB4NUBVARB glVertexAttrib4NubvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB3SARB_DECLARATION
#define NIV_GLVERTEXATTRIB3SARB_DECLARATION
  nivenGLVERTEXATTRIB3SARB glVertexAttrib3sARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4IVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4IVARB_DECLARATION
  nivenGLVERTEXATTRIB4IVARB glVertexAttrib4ivARB;
#endif

#ifndef NIV_GLDELETEPROGRAMSARB_DECLARATION
#define NIV_GLDELETEPROGRAMSARB_DECLARATION
  nivenGLDELETEPROGRAMSARB glDeleteProgramsARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4NBVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4NBVARB_DECLARATION
  nivenGLVERTEXATTRIB4NBVARB glVertexAttrib4NbvARB;
#endif

#ifndef NIV_GLGETPROGRAMIVARB_DECLARATION
#define NIV_GLGETPROGRAMIVARB_DECLARATION
  nivenGLGETPROGRAMIVARB glGetProgramivARB;
#endif

#ifndef NIV_GLPROGRAMENVPARAMETER4DVARB_DECLARATION
#define NIV_GLPROGRAMENVPARAMETER4DVARB_DECLARATION
  nivenGLPROGRAMENVPARAMETER4DVARB glProgramEnvParameter4dvARB;
#endif

#ifndef NIV_GLGETVERTEXATTRIBDVARB_DECLARATION
#define NIV_GLGETVERTEXATTRIBDVARB_DECLARATION
  nivenGLGETVERTEXATTRIBDVARB glGetVertexAttribdvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4USVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4USVARB_DECLARATION
  nivenGLVERTEXATTRIB4USVARB glVertexAttrib4usvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB1SVARB_DECLARATION
#define NIV_GLVERTEXATTRIB1SVARB_DECLARATION
  nivenGLVERTEXATTRIB1SVARB glVertexAttrib1svARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4SARB_DECLARATION
#define NIV_GLVERTEXATTRIB4SARB_DECLARATION
  nivenGLVERTEXATTRIB4SARB glVertexAttrib4sARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4DVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4DVARB_DECLARATION
  nivenGLVERTEXATTRIB4DVARB glVertexAttrib4dvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4BVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4BVARB_DECLARATION
  nivenGLVERTEXATTRIB4BVARB glVertexAttrib4bvARB;
#endif

#ifndef NIV_GLVERTEXATTRIBPOINTERARB_DECLARATION
#define NIV_GLVERTEXATTRIBPOINTERARB_DECLARATION
  nivenGLVERTEXATTRIBPOINTERARB glVertexAttribPointerARB;
#endif

#ifndef NIV_GLVERTEXATTRIB3SVARB_DECLARATION
#define NIV_GLVERTEXATTRIB3SVARB_DECLARATION
  nivenGLVERTEXATTRIB3SVARB glVertexAttrib3svARB;
#endif

#ifndef NIV_GLBINDPROGRAMARB_DECLARATION
#define NIV_GLBINDPROGRAMARB_DECLARATION
  nivenGLBINDPROGRAMARB glBindProgramARB;
#endif

#ifndef NIV_GLPROGRAMSTRINGARB_DECLARATION
#define NIV_GLPROGRAMSTRINGARB_DECLARATION
  nivenGLPROGRAMSTRINGARB glProgramStringARB;
#endif

#ifndef NIV_GLPROGRAMLOCALPARAMETER4FARB_DECLARATION
#define NIV_GLPROGRAMLOCALPARAMETER4FARB_DECLARATION
  nivenGLPROGRAMLOCALPARAMETER4FARB glProgramLocalParameter4fARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4FVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4FVARB_DECLARATION
  nivenGLVERTEXATTRIB4FVARB glVertexAttrib4fvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4DARB_DECLARATION
#define NIV_GLVERTEXATTRIB4DARB_DECLARATION
  nivenGLVERTEXATTRIB4DARB glVertexAttrib4dARB;
#endif

#ifndef NIV_GLGETPROGRAMENVPARAMETERFVARB_DECLARATION
#define NIV_GLGETPROGRAMENVPARAMETERFVARB_DECLARATION
  nivenGLGETPROGRAMENVPARAMETERFVARB glGetProgramEnvParameterfvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB1DVARB_DECLARATION
#define NIV_GLVERTEXATTRIB1DVARB_DECLARATION
  nivenGLVERTEXATTRIB1DVARB glVertexAttrib1dvARB;
#endif

#ifndef NIV_GLVERTEXATTRIB2SARB_DECLARATION
#define NIV_GLVERTEXATTRIB2SARB_DECLARATION
  nivenGLVERTEXATTRIB2SARB glVertexAttrib2sARB;
#endif

#ifndef NIV_GLVERTEXATTRIB4NUIVARB_DECLARATION
#define NIV_GLVERTEXATTRIB4NUIVARB_DECLARATION
  nivenGLVERTEXATTRIB4NUIVARB glVertexAttrib4NuivARB;
#endif

#ifndef NIV_GLGENPROGRAMSARB_DECLARATION
#define NIV_GLGENPROGRAMSARB_DECLARATION
  nivenGLGENPROGRAMSARB glGenProgramsARB;
#endif


  // GL_MESA_resize_buffers
#ifndef NIV_GLRESIZEBUFFERSMESA_DECLARATION
#define NIV_GLRESIZEBUFFERSMESA_DECLARATION
  nivenGLRESIZEBUFFERSMESA glResizeBuffersMESA;
#endif


  // GL_3DFX_multisample

#ifdef WIN32
  // WGL_NV_render_texture_rectangle
#endif
  // GL_ARB_texture_env_dot3

  // GL_EXT_bgra

  // GL_NV_float_buffer

  // GL_INGR_interlace_read

  // GL_NV_texture_env_combine4

  // GL_OML_interlace

#ifdef _GLX
  // GLX_SGI_swap_control
#ifndef NIV_GLXSWAPINTERVALSGI_DECLARATION
#define NIV_GLXSWAPINTERVALSGI_DECLARATION
  nivenGLXSWAPINTERVALSGI glXSwapIntervalSGI;
#endif

#endif // _GLX
#ifdef WIN32
  // WGL_EXT_depth_float
#endif
#ifdef WIN32
  // WGL_ARB_multisample
#endif
  // GL_ATI_fragment_shader
#ifndef NIV_GLBEGINFRAGMENTSHADERATI_DECLARATION
#define NIV_GLBEGINFRAGMENTSHADERATI_DECLARATION
  nivenGLBEGINFRAGMENTSHADERATI glBeginFragmentShaderATI;
#endif

#ifndef NIV_GLALPHAFRAGMENTOP3ATI_DECLARATION
#define NIV_GLALPHAFRAGMENTOP3ATI_DECLARATION
  nivenGLALPHAFRAGMENTOP3ATI glAlphaFragmentOp3ATI;
#endif

#ifndef NIV_GLCOLORFRAGMENTOP3ATI_DECLARATION
#define NIV_GLCOLORFRAGMENTOP3ATI_DECLARATION
  nivenGLCOLORFRAGMENTOP3ATI glColorFragmentOp3ATI;
#endif

#ifndef NIV_GLDELETEFRAGMENTSHADERATI_DECLARATION
#define NIV_GLDELETEFRAGMENTSHADERATI_DECLARATION
  nivenGLDELETEFRAGMENTSHADERATI glDeleteFragmentShaderATI;
#endif

#ifndef NIV_GLSAMPLEMAPATI_DECLARATION
#define NIV_GLSAMPLEMAPATI_DECLARATION
  nivenGLSAMPLEMAPATI glSampleMapATI;
#endif

#ifndef NIV_GLGENFRAGMENTSHADERSATI_DECLARATION
#define NIV_GLGENFRAGMENTSHADERSATI_DECLARATION
  nivenGLGENFRAGMENTSHADERSATI glGenFragmentShadersATI;
#endif

#ifndef NIV_GLSETFRAGMENTSHADERCONSTANTATI_DECLARATION
#define NIV_GLSETFRAGMENTSHADERCONSTANTATI_DECLARATION
  nivenGLSETFRAGMENTSHADERCONSTANTATI glSetFragmentShaderConstantATI;
#endif

#ifndef NIV_GLCOLORFRAGMENTOP2ATI_DECLARATION
#define NIV_GLCOLORFRAGMENTOP2ATI_DECLARATION
  nivenGLCOLORFRAGMENTOP2ATI glColorFragmentOp2ATI;
#endif

#ifndef NIV_GLCOLORFRAGMENTOP1ATI_DECLARATION
#define NIV_GLCOLORFRAGMENTOP1ATI_DECLARATION
  nivenGLCOLORFRAGMENTOP1ATI glColorFragmentOp1ATI;
#endif

#ifndef NIV_GLALPHAFRAGMENTOP1ATI_DECLARATION
#define NIV_GLALPHAFRAGMENTOP1ATI_DECLARATION
  nivenGLALPHAFRAGMENTOP1ATI glAlphaFragmentOp1ATI;
#endif

#ifndef NIV_GLALPHAFRAGMENTOP2ATI_DECLARATION
#define NIV_GLALPHAFRAGMENTOP2ATI_DECLARATION
  nivenGLALPHAFRAGMENTOP2ATI glAlphaFragmentOp2ATI;
#endif

#ifndef NIV_GLBINDFRAGMENTSHADERATI_DECLARATION
#define NIV_GLBINDFRAGMENTSHADERATI_DECLARATION
  nivenGLBINDFRAGMENTSHADERATI glBindFragmentShaderATI;
#endif

#ifndef NIV_GLENDFRAGMENTSHADERATI_DECLARATION
#define NIV_GLENDFRAGMENTSHADERATI_DECLARATION
  nivenGLENDFRAGMENTSHADERATI glEndFragmentShaderATI;
#endif

#ifndef NIV_GLPASSTEXCOORDATI_DECLARATION
#define NIV_GLPASSTEXCOORDATI_DECLARATION
  nivenGLPASSTEXCOORDATI glPassTexCoordATI;
#endif


  // GL_ARB_texture_env_combine

  // GL_ARB_vertex_buffer_object
#ifndef NIV_GLGENBUFFERSARB_DECLARATION
#define NIV_GLGENBUFFERSARB_DECLARATION
  nivenGLGENBUFFERSARB glGenBuffersARB;
#endif

#ifndef NIV_GLBUFFERSUBDATAARB_DECLARATION
#define NIV_GLBUFFERSUBDATAARB_DECLARATION
  nivenGLBUFFERSUBDATAARB glBufferSubDataARB;
#endif

#ifndef NIV_GLDELETEBUFFERSARB_DECLARATION
#define NIV_GLDELETEBUFFERSARB_DECLARATION
  nivenGLDELETEBUFFERSARB glDeleteBuffersARB;
#endif

#ifndef NIV_GLUNMAPBUFFERARB_DECLARATION
#define NIV_GLUNMAPBUFFERARB_DECLARATION
  nivenGLUNMAPBUFFERARB glUnmapBufferARB;
#endif

#ifndef NIV_GLBINDBUFFERARB_DECLARATION
#define NIV_GLBINDBUFFERARB_DECLARATION
  nivenGLBINDBUFFERARB glBindBufferARB;
#endif

#ifndef NIV_GLGETBUFFERPARAMETERIVARB_DECLARATION
#define NIV_GLGETBUFFERPARAMETERIVARB_DECLARATION
  nivenGLGETBUFFERPARAMETERIVARB glGetBufferParameterivARB;
#endif

#ifndef NIV_GLGETBUFFERPOINTERVARB_DECLARATION
#define NIV_GLGETBUFFERPOINTERVARB_DECLARATION
  nivenGLGETBUFFERPOINTERVARB glGetBufferPointervARB;
#endif

#ifndef NIV_GLGETBUFFERSUBDATAARB_DECLARATION
#define NIV_GLGETBUFFERSUBDATAARB_DECLARATION
  nivenGLGETBUFFERSUBDATAARB glGetBufferSubDataARB;
#endif

#ifndef NIV_GLMAPBUFFERARB_DECLARATION
#define NIV_GLMAPBUFFERARB_DECLARATION
  nivenGLMAPBUFFERARB glMapBufferARB;
#endif

#ifndef NIV_GLBUFFERDATAARB_DECLARATION
#define NIV_GLBUFFERDATAARB_DECLARATION
  nivenGLBUFFERDATAARB glBufferDataARB;
#endif

#ifndef NIV_GLISBUFFERARB_DECLARATION
#define NIV_GLISBUFFERARB_DECLARATION
  nivenGLISBUFFERARB glIsBufferARB;
#endif


  // GL_SUN_triangle_list
#ifndef NIV_GLREPLACEMENTCODEUBVSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUBVSUN_DECLARATION
  nivenGLREPLACEMENTCODEUBVSUN glReplacementCodeubvSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUISUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUISUN_DECLARATION
  nivenGLREPLACEMENTCODEUISUN glReplacementCodeuiSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUIVSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUIVSUN_DECLARATION
  nivenGLREPLACEMENTCODEUIVSUN glReplacementCodeuivSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEPOINTERSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEPOINTERSUN_DECLARATION
  nivenGLREPLACEMENTCODEPOINTERSUN glReplacementCodePointerSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUSVSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUSVSUN_DECLARATION
  nivenGLREPLACEMENTCODEUSVSUN glReplacementCodeusvSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUSSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUSSUN_DECLARATION
  nivenGLREPLACEMENTCODEUSSUN glReplacementCodeusSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUBSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUBSUN_DECLARATION
  nivenGLREPLACEMENTCODEUBSUN glReplacementCodeubSUN;
#endif


#ifdef WIN32
  // WGL_EXT_swap_control
#ifndef NIV_WGLGETSWAPINTERVALEXT_DECLARATION
#define NIV_WGLGETSWAPINTERVALEXT_DECLARATION
  nivenWGLGETSWAPINTERVALEXT wglGetSwapIntervalEXT;
#endif

#ifndef NIV_WGLSWAPINTERVALEXT_DECLARATION
#define NIV_WGLSWAPINTERVALEXT_DECLARATION
  nivenWGLSWAPINTERVALEXT wglSwapIntervalEXT;
#endif

#endif
#ifdef _GLX
  // GLX_EXT_scene_marker
#endif // _GLX
  // GL_ATI_text_fragment_shader

  // GL_EXT_histogram
#ifndef NIV_GLGETMINMAXPARAMETERFVEXT_DECLARATION
#define NIV_GLGETMINMAXPARAMETERFVEXT_DECLARATION
  nivenGLGETMINMAXPARAMETERFVEXT glGetMinmaxParameterfvEXT;
#endif

#ifndef NIV_GLMINMAXEXT_DECLARATION
#define NIV_GLMINMAXEXT_DECLARATION
  nivenGLMINMAXEXT glMinmaxEXT;
#endif

#ifndef NIV_GLGETHISTOGRAMPARAMETERIVEXT_DECLARATION
#define NIV_GLGETHISTOGRAMPARAMETERIVEXT_DECLARATION
  nivenGLGETHISTOGRAMPARAMETERIVEXT glGetHistogramParameterivEXT;
#endif

#ifndef NIV_GLGETMINMAXPARAMETERIVEXT_DECLARATION
#define NIV_GLGETMINMAXPARAMETERIVEXT_DECLARATION
  nivenGLGETMINMAXPARAMETERIVEXT glGetMinmaxParameterivEXT;
#endif

#ifndef NIV_GLRESETHISTOGRAMEXT_DECLARATION
#define NIV_GLRESETHISTOGRAMEXT_DECLARATION
  nivenGLRESETHISTOGRAMEXT glResetHistogramEXT;
#endif

#ifndef NIV_GLRESETMINMAXEXT_DECLARATION
#define NIV_GLRESETMINMAXEXT_DECLARATION
  nivenGLRESETMINMAXEXT glResetMinmaxEXT;
#endif

#ifndef NIV_GLGETMINMAXEXT_DECLARATION
#define NIV_GLGETMINMAXEXT_DECLARATION
  nivenGLGETMINMAXEXT glGetMinmaxEXT;
#endif

#ifndef NIV_GLGETHISTOGRAMEXT_DECLARATION
#define NIV_GLGETHISTOGRAMEXT_DECLARATION
  nivenGLGETHISTOGRAMEXT glGetHistogramEXT;
#endif

#ifndef NIV_GLHISTOGRAMEXT_DECLARATION
#define NIV_GLHISTOGRAMEXT_DECLARATION
  nivenGLHISTOGRAMEXT glHistogramEXT;
#endif

#ifndef NIV_GLGETHISTOGRAMPARAMETERFVEXT_DECLARATION
#define NIV_GLGETHISTOGRAMPARAMETERFVEXT_DECLARATION
  nivenGLGETHISTOGRAMPARAMETERFVEXT glGetHistogramParameterfvEXT;
#endif


  // GL_NV_vertex_program3

  // GL_NV_vertex_array_range
#ifndef NIV_GLFLUSHVERTEXARRAYRANGENV_DECLARATION
#define NIV_GLFLUSHVERTEXARRAYRANGENV_DECLARATION
  nivenGLFLUSHVERTEXARRAYRANGENV glFlushVertexArrayRangeNV;
#endif

#ifndef NIV_GLVERTEXARRAYRANGENV_DECLARATION
#define NIV_GLVERTEXARRAYRANGENV_DECLARATION
  nivenGLVERTEXARRAYRANGENV glVertexArrayRangeNV;
#endif


  // GL_HP_texture_lighting

#ifdef WIN32
  // WGL_EXT_display_color_table
#ifndef NIV_WGLDESTROYDISPLAYCOLORTABLEEXT_DECLARATION
#define NIV_WGLDESTROYDISPLAYCOLORTABLEEXT_DECLARATION
  nivenWGLDESTROYDISPLAYCOLORTABLEEXT wglDestroyDisplayColorTableEXT;
#endif

#ifndef NIV_WGLCREATEDISPLAYCOLORTABLEEXT_DECLARATION
#define NIV_WGLCREATEDISPLAYCOLORTABLEEXT_DECLARATION
  nivenWGLCREATEDISPLAYCOLORTABLEEXT wglCreateDisplayColorTableEXT;
#endif

#ifndef NIV_WGLBINDDISPLAYCOLORTABLEEXT_DECLARATION
#define NIV_WGLBINDDISPLAYCOLORTABLEEXT_DECLARATION
  nivenWGLBINDDISPLAYCOLORTABLEEXT wglBindDisplayColorTableEXT;
#endif

#ifndef NIV_WGLLOADDISPLAYCOLORTABLEEXT_DECLARATION
#define NIV_WGLLOADDISPLAYCOLORTABLEEXT_DECLARATION
  nivenWGLLOADDISPLAYCOLORTABLEEXT wglLoadDisplayColorTableEXT;
#endif

#endif
  // GL_NV_texture_expand_normal

  // GL_EXT_separate_specular_color

  // GL_EXT_paletted_texture
#ifndef NIV_GLCOLORTABLEEXT_DECLARATION
#define NIV_GLCOLORTABLEEXT_DECLARATION
  nivenGLCOLORTABLEEXT glColorTableEXT;
#endif

#ifndef NIV_GLGETCOLORTABLEPARAMETERFVEXT_DECLARATION
#define NIV_GLGETCOLORTABLEPARAMETERFVEXT_DECLARATION
  nivenGLGETCOLORTABLEPARAMETERFVEXT glGetColorTableParameterfvEXT;
#endif

#ifndef NIV_GLGETCOLORTABLEPARAMETERIVEXT_DECLARATION
#define NIV_GLGETCOLORTABLEPARAMETERIVEXT_DECLARATION
  nivenGLGETCOLORTABLEPARAMETERIVEXT glGetColorTableParameterivEXT;
#endif

#ifndef NIV_GLGETCOLORTABLEEXT_DECLARATION
#define NIV_GLGETCOLORTABLEEXT_DECLARATION
  nivenGLGETCOLORTABLEEXT glGetColorTableEXT;
#endif


  // GL_ATI_texture_float

  // GL_EXT_texture_env_add

  // GL_EXT_texture_mirror_clamp

  // GL_ATI_pn_triangles
#ifndef NIV_GLPNTRIANGLESFATI_DECLARATION
#define NIV_GLPNTRIANGLESFATI_DECLARATION
  nivenGLPNTRIANGLESFATI glPNTrianglesfATI;
#endif

#ifndef NIV_GLPNTRIANGLESIATI_DECLARATION
#define NIV_GLPNTRIANGLESIATI_DECLARATION
  nivenGLPNTRIANGLESIATI glPNTrianglesiATI;
#endif


  // GL_NV_texture_rectangle

#ifdef WIN32
  // WGL_OML_sync_control
#ifndef NIV_WGLGETSYNCVALUESOML_DECLARATION
#define NIV_WGLGETSYNCVALUESOML_DECLARATION
  nivenWGLGETSYNCVALUESOML wglGetSyncValuesOML;
#endif

#ifndef NIV_WGLGETMSCRATEOML_DECLARATION
#define NIV_WGLGETMSCRATEOML_DECLARATION
  nivenWGLGETMSCRATEOML wglGetMscRateOML;
#endif

#ifndef NIV_WGLSWAPBUFFERSMSCOML_DECLARATION
#define NIV_WGLSWAPBUFFERSMSCOML_DECLARATION
  nivenWGLSWAPBUFFERSMSCOML wglSwapBuffersMscOML;
#endif

#ifndef NIV_WGLSWAPLAYERBUFFERSMSCOML_DECLARATION
#define NIV_WGLSWAPLAYERBUFFERSMSCOML_DECLARATION
  nivenWGLSWAPLAYERBUFFERSMSCOML wglSwapLayerBuffersMscOML;
#endif

#ifndef NIV_WGLWAITFORSBCOML_DECLARATION
#define NIV_WGLWAITFORSBCOML_DECLARATION
  nivenWGLWAITFORSBCOML wglWaitForSbcOML;
#endif

#ifndef NIV_WGLWAITFORMSCOML_DECLARATION
#define NIV_WGLWAITFORMSCOML_DECLARATION
  nivenWGLWAITFORMSCOML wglWaitForMscOML;
#endif

#endif
  // GL_NV_multisample_filter_hint

  // GL_APPLE_float_pixels

  // GL_SGIS_texture_border_clamp

  // GL_ATI_vertex_attrib_array_object
#ifndef NIV_GLGETVERTEXATTRIBARRAYOBJECTIVATI_DECLARATION
#define NIV_GLGETVERTEXATTRIBARRAYOBJECTIVATI_DECLARATION
  nivenGLGETVERTEXATTRIBARRAYOBJECTIVATI glGetVertexAttribArrayObjectivATI;
#endif

#ifndef NIV_GLGETVERTEXATTRIBARRAYOBJECTFVATI_DECLARATION
#define NIV_GLGETVERTEXATTRIBARRAYOBJECTFVATI_DECLARATION
  nivenGLGETVERTEXATTRIBARRAYOBJECTFVATI glGetVertexAttribArrayObjectfvATI;
#endif

#ifndef NIV_GLVERTEXATTRIBARRAYOBJECTATI_DECLARATION
#define NIV_GLVERTEXATTRIBARRAYOBJECTATI_DECLARATION
  nivenGLVERTEXATTRIBARRAYOBJECTATI glVertexAttribArrayObjectATI;
#endif


  // GL_SGIX_clipmap

  // GL_HP_image_transform
#ifndef NIV_GLIMAGETRANSFORMPARAMETERFHP_DECLARATION
#define NIV_GLIMAGETRANSFORMPARAMETERFHP_DECLARATION
  nivenGLIMAGETRANSFORMPARAMETERFHP glImageTransformParameterfHP;
#endif

#ifndef NIV_GLGETIMAGETRANSFORMPARAMETERIVHP_DECLARATION
#define NIV_GLGETIMAGETRANSFORMPARAMETERIVHP_DECLARATION
  nivenGLGETIMAGETRANSFORMPARAMETERIVHP glGetImageTransformParameterivHP;
#endif

#ifndef NIV_GLIMAGETRANSFORMPARAMETERIVHP_DECLARATION
#define NIV_GLIMAGETRANSFORMPARAMETERIVHP_DECLARATION
  nivenGLIMAGETRANSFORMPARAMETERIVHP glImageTransformParameterivHP;
#endif

#ifndef NIV_GLGETIMAGETRANSFORMPARAMETERFVHP_DECLARATION
#define NIV_GLGETIMAGETRANSFORMPARAMETERFVHP_DECLARATION
  nivenGLGETIMAGETRANSFORMPARAMETERFVHP glGetImageTransformParameterfvHP;
#endif

#ifndef NIV_GLIMAGETRANSFORMPARAMETERFVHP_DECLARATION
#define NIV_GLIMAGETRANSFORMPARAMETERFVHP_DECLARATION
  nivenGLIMAGETRANSFORMPARAMETERFVHP glImageTransformParameterfvHP;
#endif

#ifndef NIV_GLIMAGETRANSFORMPARAMETERIHP_DECLARATION
#define NIV_GLIMAGETRANSFORMPARAMETERIHP_DECLARATION
  nivenGLIMAGETRANSFORMPARAMETERIHP glImageTransformParameteriHP;
#endif


  // GL_SGIX_flush_raster
#ifndef NIV_GLFLUSHRASTERSGIX_DECLARATION
#define NIV_GLFLUSHRASTERSGIX_DECLARATION
  nivenGLFLUSHRASTERSGIX glFlushRasterSGIX;
#endif


  // GL_EXT_light_texture
#ifndef NIV_GLTEXTUREMATERIALEXT_DECLARATION
#define NIV_GLTEXTUREMATERIALEXT_DECLARATION
  nivenGLTEXTUREMATERIALEXT glTextureMaterialEXT;
#endif

#ifndef NIV_GLAPPLYTEXTUREEXT_DECLARATION
#define NIV_GLAPPLYTEXTUREEXT_DECLARATION
  nivenGLAPPLYTEXTUREEXT glApplyTextureEXT;
#endif

#ifndef NIV_GLTEXTURELIGHTEXT_DECLARATION
#define NIV_GLTEXTURELIGHTEXT_DECLARATION
  nivenGLTEXTURELIGHTEXT glTextureLightEXT;
#endif


  // GL_ARB_point_sprite

  // GL_MESA_ycbcr_texture

  // GL_ARB_shading_language_100

  // GL_SGIS_texture_select

  // GL_NV_vertex_program2

#ifdef _GLX
  // GLX_SGI_make_current_read
#ifndef NIV_GLXGETCURRENTREADDRAWABLESGI_DECLARATION
#define NIV_GLXGETCURRENTREADDRAWABLESGI_DECLARATION
  nivenGLXGETCURRENTREADDRAWABLESGI glXGetCurrentReadDrawableSGI;
#endif

#ifndef NIV_GLXMAKECURRENTREADSGI_DECLARATION
#define NIV_GLXMAKECURRENTREADSGI_DECLARATION
  nivenGLXMAKECURRENTREADSGI glXMakeCurrentReadSGI;
#endif

#endif // _GLX
  // GL_ARB_half_float_pixel

  // GL_KTX_buffer_region
#ifndef NIV_GLDELETEBUFFERREGIONEXT_DECLARATION
#define NIV_GLDELETEBUFFERREGIONEXT_DECLARATION
  nivenGLDELETEBUFFERREGIONEXT glDeleteBufferRegionEXT;
#endif

#ifndef NIV_GLREADBUFFERREGIONEXT_DECLARATION
#define NIV_GLREADBUFFERREGIONEXT_DECLARATION
  nivenGLREADBUFFERREGIONEXT glReadBufferRegionEXT;
#endif

#ifndef NIV_GLBUFFERREGIONENABLEDEXT_DECLARATION
#define NIV_GLBUFFERREGIONENABLEDEXT_DECLARATION
  nivenGLBUFFERREGIONENABLEDEXT glBufferRegionEnabledEXT;
#endif

#ifndef NIV_GLNEWBUFFERREGIONEXT_DECLARATION
#define NIV_GLNEWBUFFERREGIONEXT_DECLARATION
  nivenGLNEWBUFFERREGIONEXT glNewBufferRegionEXT;
#endif

#ifndef NIV_GLDRAWBUFFERREGIONEXT_DECLARATION
#define NIV_GLDRAWBUFFERREGIONEXT_DECLARATION
  nivenGLDRAWBUFFERREGIONEXT glDrawBufferRegionEXT;
#endif


  // GL_EXT_vertex_weighting
#ifndef NIV_GLVERTEXWEIGHTFVEXT_DECLARATION
#define NIV_GLVERTEXWEIGHTFVEXT_DECLARATION
  nivenGLVERTEXWEIGHTFVEXT glVertexWeightfvEXT;
#endif

#ifndef NIV_GLVERTEXWEIGHTFEXT_DECLARATION
#define NIV_GLVERTEXWEIGHTFEXT_DECLARATION
  nivenGLVERTEXWEIGHTFEXT glVertexWeightfEXT;
#endif

#ifndef NIV_GLVERTEXWEIGHTPOINTEREXT_DECLARATION
#define NIV_GLVERTEXWEIGHTPOINTEREXT_DECLARATION
  nivenGLVERTEXWEIGHTPOINTEREXT glVertexWeightPointerEXT;
#endif


  // GL_ATIX_point_sprites

  // GL_APPLE_vertex_array_range
#ifndef NIV_GLVERTEXARRAYRANGEAPPLE_DECLARATION
#define NIV_GLVERTEXARRAYRANGEAPPLE_DECLARATION
  nivenGLVERTEXARRAYRANGEAPPLE glVertexArrayRangeAPPLE;
#endif

#ifndef NIV_GLFLUSHVERTEXARRAYRANGEAPPLE_DECLARATION
#define NIV_GLFLUSHVERTEXARRAYRANGEAPPLE_DECLARATION
  nivenGLFLUSHVERTEXARRAYRANGEAPPLE glFlushVertexArrayRangeAPPLE;
#endif

#ifndef NIV_GLVERTEXARRAYPARAMETERIAPPLE_DECLARATION
#define NIV_GLVERTEXARRAYPARAMETERIAPPLE_DECLARATION
  nivenGLVERTEXARRAYPARAMETERIAPPLE glVertexArrayParameteriAPPLE;
#endif


#ifdef _GLX
  // GLX_NV_float_buffer
#endif // _GLX
  // GL_SGIS_detail_texture
#ifndef NIV_GLDETAILTEXFUNCSGIS_DECLARATION
#define NIV_GLDETAILTEXFUNCSGIS_DECLARATION
  nivenGLDETAILTEXFUNCSGIS glDetailTexFuncSGIS;
#endif

#ifndef NIV_GLGETDETAILTEXFUNCSGIS_DECLARATION
#define NIV_GLGETDETAILTEXFUNCSGIS_DECLARATION
  nivenGLGETDETAILTEXFUNCSGIS glGetDetailTexFuncSGIS;
#endif


  // GL_SGIX_sprite
#ifndef NIV_GLSPRITEPARAMETERFSGIX_DECLARATION
#define NIV_GLSPRITEPARAMETERFSGIX_DECLARATION
  nivenGLSPRITEPARAMETERFSGIX glSpriteParameterfSGIX;
#endif

#ifndef NIV_GLSPRITEPARAMETERISGIX_DECLARATION
#define NIV_GLSPRITEPARAMETERISGIX_DECLARATION
  nivenGLSPRITEPARAMETERISGIX glSpriteParameteriSGIX;
#endif

#ifndef NIV_GLSPRITEPARAMETERIVSGIX_DECLARATION
#define NIV_GLSPRITEPARAMETERIVSGIX_DECLARATION
  nivenGLSPRITEPARAMETERIVSGIX glSpriteParameterivSGIX;
#endif

#ifndef NIV_GLSPRITEPARAMETERFVSGIX_DECLARATION
#define NIV_GLSPRITEPARAMETERFVSGIX_DECLARATION
  nivenGLSPRITEPARAMETERFVSGIX glSpriteParameterfvSGIX;
#endif


  // GL_NV_register_combiners
#ifndef NIV_GLCOMBINERPARAMETERFVNV_DECLARATION
#define NIV_GLCOMBINERPARAMETERFVNV_DECLARATION
  nivenGLCOMBINERPARAMETERFVNV glCombinerParameterfvNV;
#endif

#ifndef NIV_GLCOMBINERPARAMETERIVNV_DECLARATION
#define NIV_GLCOMBINERPARAMETERIVNV_DECLARATION
  nivenGLCOMBINERPARAMETERIVNV glCombinerParameterivNV;
#endif

#ifndef NIV_GLGETFINALCOMBINERINPUTPARAMETERIVNV_DECLARATION
#define NIV_GLGETFINALCOMBINERINPUTPARAMETERIVNV_DECLARATION
  nivenGLGETFINALCOMBINERINPUTPARAMETERIVNV glGetFinalCombinerInputParameterivNV;
#endif

#ifndef NIV_GLCOMBINERPARAMETERINV_DECLARATION
#define NIV_GLCOMBINERPARAMETERINV_DECLARATION
  nivenGLCOMBINERPARAMETERINV glCombinerParameteriNV;
#endif

#ifndef NIV_GLCOMBINERINPUTNV_DECLARATION
#define NIV_GLCOMBINERINPUTNV_DECLARATION
  nivenGLCOMBINERINPUTNV glCombinerInputNV;
#endif

#ifndef NIV_GLCOMBINEROUTPUTNV_DECLARATION
#define NIV_GLCOMBINEROUTPUTNV_DECLARATION
  nivenGLCOMBINEROUTPUTNV glCombinerOutputNV;
#endif

#ifndef NIV_GLGETCOMBINEROUTPUTPARAMETERFVNV_DECLARATION
#define NIV_GLGETCOMBINEROUTPUTPARAMETERFVNV_DECLARATION
  nivenGLGETCOMBINEROUTPUTPARAMETERFVNV glGetCombinerOutputParameterfvNV;
#endif

#ifndef NIV_GLCOMBINERPARAMETERFNV_DECLARATION
#define NIV_GLCOMBINERPARAMETERFNV_DECLARATION
  nivenGLCOMBINERPARAMETERFNV glCombinerParameterfNV;
#endif

#ifndef NIV_GLFINALCOMBINERINPUTNV_DECLARATION
#define NIV_GLFINALCOMBINERINPUTNV_DECLARATION
  nivenGLFINALCOMBINERINPUTNV glFinalCombinerInputNV;
#endif

#ifndef NIV_GLGETFINALCOMBINERINPUTPARAMETERFVNV_DECLARATION
#define NIV_GLGETFINALCOMBINERINPUTPARAMETERFVNV_DECLARATION
  nivenGLGETFINALCOMBINERINPUTPARAMETERFVNV glGetFinalCombinerInputParameterfvNV;
#endif

#ifndef NIV_GLGETCOMBINERINPUTPARAMETERFVNV_DECLARATION
#define NIV_GLGETCOMBINERINPUTPARAMETERFVNV_DECLARATION
  nivenGLGETCOMBINERINPUTPARAMETERFVNV glGetCombinerInputParameterfvNV;
#endif

#ifndef NIV_GLGETCOMBINERINPUTPARAMETERIVNV_DECLARATION
#define NIV_GLGETCOMBINERINPUTPARAMETERIVNV_DECLARATION
  nivenGLGETCOMBINERINPUTPARAMETERIVNV glGetCombinerInputParameterivNV;
#endif

#ifndef NIV_GLGETCOMBINEROUTPUTPARAMETERIVNV_DECLARATION
#define NIV_GLGETCOMBINEROUTPUTPARAMETERIVNV_DECLARATION
  nivenGLGETCOMBINEROUTPUTPARAMETERIVNV glGetCombinerOutputParameterivNV;
#endif


  // GL_ARB_draw_buffers
#ifndef NIV_GLDRAWBUFFERSARB_DECLARATION
#define NIV_GLDRAWBUFFERSARB_DECLARATION
  nivenGLDRAWBUFFERSARB glDrawBuffersARB;
#endif


  // GL_ARB_fragment_program_shadow

#ifdef WIN32
  // WGL_EXT_make_current_read
#ifndef NIV_WGLGETCURRENTREADDCEXT_DECLARATION
#define NIV_WGLGETCURRENTREADDCEXT_DECLARATION
  nivenWGLGETCURRENTREADDCEXT wglGetCurrentReadDCEXT;
#endif

#ifndef NIV_WGLMAKECONTEXTCURRENTEXT_DECLARATION
#define NIV_WGLMAKECONTEXTCURRENTEXT_DECLARATION
  nivenWGLMAKECONTEXTCURRENTEXT wglMakeContextCurrentEXT;
#endif

#endif
  // GL_EXT_shared_texture_palette

  // GL_ATI_element_array
#ifndef NIV_GLDRAWELEMENTARRAYATI_DECLARATION
#define NIV_GLDRAWELEMENTARRAYATI_DECLARATION
  nivenGLDRAWELEMENTARRAYATI glDrawElementArrayATI;
#endif

#ifndef NIV_GLELEMENTPOINTERATI_DECLARATION
#define NIV_GLELEMENTPOINTERATI_DECLARATION
  nivenGLELEMENTPOINTERATI glElementPointerATI;
#endif

#ifndef NIV_GLDRAWRANGEELEMENTARRAYATI_DECLARATION
#define NIV_GLDRAWRANGEELEMENTARRAYATI_DECLARATION
  nivenGLDRAWRANGEELEMENTARRAYATI glDrawRangeElementArrayATI;
#endif


#ifdef _GLX
  // GLX_ARB_get_proc_address
#endif // _GLX
  // GL_OML_resample

  // GL_EXT_coordinate_frame
#ifndef NIV_GLTANGENTPOINTEREXT_DECLARATION
#define NIV_GLTANGENTPOINTEREXT_DECLARATION
  nivenGLTANGENTPOINTEREXT glTangentPointerEXT;
#endif

#ifndef NIV_GLBINORMALPOINTEREXT_DECLARATION
#define NIV_GLBINORMALPOINTEREXT_DECLARATION
  nivenGLBINORMALPOINTEREXT glBinormalPointerEXT;
#endif


  // GL_ATI_texture_mirror_once

#ifdef WIN32
  // WGL_ARB_pbuffer
#ifndef NIV_WGLRELEASEPBUFFERDCARB_DECLARATION
#define NIV_WGLRELEASEPBUFFERDCARB_DECLARATION
  nivenWGLRELEASEPBUFFERDCARB wglReleasePbufferDCARB;
#endif

#ifndef NIV_WGLCREATEPBUFFERARB_DECLARATION
#define NIV_WGLCREATEPBUFFERARB_DECLARATION
  nivenWGLCREATEPBUFFERARB wglCreatePbufferARB;
#endif

#ifndef NIV_WGLQUERYPBUFFERARB_DECLARATION
#define NIV_WGLQUERYPBUFFERARB_DECLARATION
  nivenWGLQUERYPBUFFERARB wglQueryPbufferARB;
#endif

#ifndef NIV_WGLGETPBUFFERDCARB_DECLARATION
#define NIV_WGLGETPBUFFERDCARB_DECLARATION
  nivenWGLGETPBUFFERDCARB wglGetPbufferDCARB;
#endif

#ifndef NIV_WGLDESTROYPBUFFERARB_DECLARATION
#define NIV_WGLDESTROYPBUFFERARB_DECLARATION
  nivenWGLDESTROYPBUFFERARB wglDestroyPbufferARB;
#endif

#endif
  // GL_EXT_cull_vertex
#ifndef NIV_GLCULLPARAMETERDVEXT_DECLARATION
#define NIV_GLCULLPARAMETERDVEXT_DECLARATION
  nivenGLCULLPARAMETERDVEXT glCullParameterdvEXT;
#endif

#ifndef NIV_GLCULLPARAMETERFVEXT_DECLARATION
#define NIV_GLCULLPARAMETERFVEXT_DECLARATION
  nivenGLCULLPARAMETERFVEXT glCullParameterfvEXT;
#endif


  // GL_IBM_rasterpos_clip

  // GL_SGIX_reference_plane
#ifndef NIV_GLREFERENCEPLANESGIX_DECLARATION
#define NIV_GLREFERENCEPLANESGIX_DECLARATION
  nivenGLREFERENCEPLANESGIX glReferencePlaneSGIX;
#endif


  // GL_APPLE_texture_range
#ifndef NIV_GLTEXTURERANGEAPPLE_DECLARATION
#define NIV_GLTEXTURERANGEAPPLE_DECLARATION
  nivenGLTEXTURERANGEAPPLE glTextureRangeAPPLE;
#endif

#ifndef NIV_GLGETTEXPARAMETERPOINTERVAPPLE_DECLARATION
#define NIV_GLGETTEXPARAMETERPOINTERVAPPLE_DECLARATION
  nivenGLGETTEXPARAMETERPOINTERVAPPLE glGetTexParameterPointervAPPLE;
#endif


  // GL_SGIX_shadow

  // GL_SGIX_texture_lod_bias

#ifdef _GLX
  // GLX_SGIX_pbuffer
#ifndef NIV_GLXCREATEGLXPBUFFERSGIX_DECLARATION
#define NIV_GLXCREATEGLXPBUFFERSGIX_DECLARATION
  nivenGLXCREATEGLXPBUFFERSGIX glXCreateGLXPbufferSGIX;
#endif

#ifndef NIV_GLXGETSELECTEDEVENTSGIX_DECLARATION
#define NIV_GLXGETSELECTEDEVENTSGIX_DECLARATION
  nivenGLXGETSELECTEDEVENTSGIX glXGetSelectedEventSGIX;
#endif

#ifndef NIV_GLXDESTROYGLXPBUFFERSGIX_DECLARATION
#define NIV_GLXDESTROYGLXPBUFFERSGIX_DECLARATION
  nivenGLXDESTROYGLXPBUFFERSGIX glXDestroyGLXPbufferSGIX;
#endif

#ifndef NIV_GLXSELECTEVENTSGIX_DECLARATION
#define NIV_GLXSELECTEVENTSGIX_DECLARATION
  nivenGLXSELECTEVENTSGIX glXSelectEventSGIX;
#endif

#ifndef NIV_GLXQUERYGLXPBUFFERSGIX_DECLARATION
#define NIV_GLXQUERYGLXPBUFFERSGIX_DECLARATION
  nivenGLXQUERYGLXPBUFFERSGIX glXQueryGLXPbufferSGIX;
#endif

#endif // _GLX
  // GL_NV_texgen_reflection

  // GL_SUN_slice_accum

  // GL_IBM_multimode_draw_arrays
#ifndef NIV_GLMULTIMODEDRAWELEMENTSIBM_DECLARATION
#define NIV_GLMULTIMODEDRAWELEMENTSIBM_DECLARATION
  nivenGLMULTIMODEDRAWELEMENTSIBM glMultiModeDrawElementsIBM;
#endif

#ifndef NIV_GLMULTIMODEDRAWARRAYSIBM_DECLARATION
#define NIV_GLMULTIMODEDRAWARRAYSIBM_DECLARATION
  nivenGLMULTIMODEDRAWARRAYSIBM glMultiModeDrawArraysIBM;
#endif


  // GL_IBM_static_data

#ifdef _GLX
  // GLX_EXT_visual_info
#endif // _GLX
  // GL_EXT_clip_volume_hint

  // GL_EXT_cmyka

  // GL_EXT_compiled_vertex_array
#ifndef NIV_GLLOCKARRAYSEXT_DECLARATION
#define NIV_GLLOCKARRAYSEXT_DECLARATION
  nivenGLLOCKARRAYSEXT glLockArraysEXT;
#endif

#ifndef NIV_GLUNLOCKARRAYSEXT_DECLARATION
#define NIV_GLUNLOCKARRAYSEXT_DECLARATION
  nivenGLUNLOCKARRAYSEXT glUnlockArraysEXT;
#endif


  // GL_3DFX_tbuffer
#ifndef NIV_GLTBUFFERMASK3DFX_DECLARATION
#define NIV_GLTBUFFERMASK3DFX_DECLARATION
  nivenGLTBUFFERMASK3DFX glTbufferMask3DFX;
#endif


  // GL_EXT_point_parameters
#ifndef NIV_GLPOINTPARAMETERFEXT_DECLARATION
#define NIV_GLPOINTPARAMETERFEXT_DECLARATION
  nivenGLPOINTPARAMETERFEXT glPointParameterfEXT;
#endif

#ifndef NIV_GLPOINTPARAMETERFVEXT_DECLARATION
#define NIV_GLPOINTPARAMETERFVEXT_DECLARATION
  nivenGLPOINTPARAMETERFVEXT glPointParameterfvEXT;
#endif


  // GL_APPLE_vertex_array_object
#ifndef NIV_GLGENVERTEXARRAYSAPPLE_DECLARATION
#define NIV_GLGENVERTEXARRAYSAPPLE_DECLARATION
  nivenGLGENVERTEXARRAYSAPPLE glGenVertexArraysAPPLE;
#endif

#ifndef NIV_GLBINDVERTEXARRAYAPPLE_DECLARATION
#define NIV_GLBINDVERTEXARRAYAPPLE_DECLARATION
  nivenGLBINDVERTEXARRAYAPPLE glBindVertexArrayAPPLE;
#endif

#ifndef NIV_GLISVERTEXARRAYAPPLE_DECLARATION
#define NIV_GLISVERTEXARRAYAPPLE_DECLARATION
  nivenGLISVERTEXARRAYAPPLE glIsVertexArrayAPPLE;
#endif

#ifndef NIV_GLDELETEVERTEXARRAYSAPPLE_DECLARATION
#define NIV_GLDELETEVERTEXARRAYSAPPLE_DECLARATION
  nivenGLDELETEVERTEXARRAYSAPPLE glDeleteVertexArraysAPPLE;
#endif


  // GL_3DFX_texture_compression_FXT1

  // GL_NV_occlusion_query
#ifndef NIV_GLENDOCCLUSIONQUERYNV_DECLARATION
#define NIV_GLENDOCCLUSIONQUERYNV_DECLARATION
  nivenGLENDOCCLUSIONQUERYNV glEndOcclusionQueryNV;
#endif

#ifndef NIV_GLDELETEOCCLUSIONQUERIESNV_DECLARATION
#define NIV_GLDELETEOCCLUSIONQUERIESNV_DECLARATION
  nivenGLDELETEOCCLUSIONQUERIESNV glDeleteOcclusionQueriesNV;
#endif

#ifndef NIV_GLGETOCCLUSIONQUERYUIVNV_DECLARATION
#define NIV_GLGETOCCLUSIONQUERYUIVNV_DECLARATION
  nivenGLGETOCCLUSIONQUERYUIVNV glGetOcclusionQueryuivNV;
#endif

#ifndef NIV_GLGENOCCLUSIONQUERIESNV_DECLARATION
#define NIV_GLGENOCCLUSIONQUERIESNV_DECLARATION
  nivenGLGENOCCLUSIONQUERIESNV glGenOcclusionQueriesNV;
#endif

#ifndef NIV_GLGETOCCLUSIONQUERYIVNV_DECLARATION
#define NIV_GLGETOCCLUSIONQUERYIVNV_DECLARATION
  nivenGLGETOCCLUSIONQUERYIVNV glGetOcclusionQueryivNV;
#endif

#ifndef NIV_GLBEGINOCCLUSIONQUERYNV_DECLARATION
#define NIV_GLBEGINOCCLUSIONQUERYNV_DECLARATION
  nivenGLBEGINOCCLUSIONQUERYNV glBeginOcclusionQueryNV;
#endif

#ifndef NIV_GLISOCCLUSIONQUERYNV_DECLARATION
#define NIV_GLISOCCLUSIONQUERYNV_DECLARATION
  nivenGLISOCCLUSIONQUERYNV glIsOcclusionQueryNV;
#endif


#ifdef _GLX
  // GLX_OML_sync_control
#ifndef NIV_GLXGETSYNCVALUESOML_DECLARATION
#define NIV_GLXGETSYNCVALUESOML_DECLARATION
  nivenGLXGETSYNCVALUESOML glXGetSyncValuesOML;
#endif

#ifndef NIV_GLXGETMSCRATEOML_DECLARATION
#define NIV_GLXGETMSCRATEOML_DECLARATION
  nivenGLXGETMSCRATEOML glXGetMscRateOML;
#endif

#ifndef NIV_GLXWAITFORSBCOML_DECLARATION
#define NIV_GLXWAITFORSBCOML_DECLARATION
  nivenGLXWAITFORSBCOML glXWaitForSbcOML;
#endif

#ifndef NIV_GLXWAITFORMSCOML_DECLARATION
#define NIV_GLXWAITFORMSCOML_DECLARATION
  nivenGLXWAITFORMSCOML glXWaitForMscOML;
#endif

#ifndef NIV_GLXSWAPBUFFERSMSCOML_DECLARATION
#define NIV_GLXSWAPBUFFERSMSCOML_DECLARATION
  nivenGLXSWAPBUFFERSMSCOML glXSwapBuffersMscOML;
#endif

#endif // _GLX
#ifdef WIN32
  // WGL_ARB_render_texture
#ifndef NIV_WGLRELEASETEXIMAGEARB_DECLARATION
#define NIV_WGLRELEASETEXIMAGEARB_DECLARATION
  nivenWGLRELEASETEXIMAGEARB wglReleaseTexImageARB;
#endif

#ifndef NIV_WGLBINDTEXIMAGEARB_DECLARATION
#define NIV_WGLBINDTEXIMAGEARB_DECLARATION
  nivenWGLBINDTEXIMAGEARB wglBindTexImageARB;
#endif

#ifndef NIV_WGLSETPBUFFERATTRIBARB_DECLARATION
#define NIV_WGLSETPBUFFERATTRIBARB_DECLARATION
  nivenWGLSETPBUFFERATTRIBARB wglSetPbufferAttribARB;
#endif

#endif
  // GL_SGIS_multisample
#ifndef NIV_GLSAMPLEMASKSGIS_DECLARATION
#define NIV_GLSAMPLEMASKSGIS_DECLARATION
  nivenGLSAMPLEMASKSGIS glSampleMaskSGIS;
#endif

#ifndef NIV_GLSAMPLEPATTERNSGIS_DECLARATION
#define NIV_GLSAMPLEPATTERNSGIS_DECLARATION
  nivenGLSAMPLEPATTERNSGIS glSamplePatternSGIS;
#endif


  // GL_ARB_vertex_shader
#ifndef NIV_GLGETACTIVEATTRIBARB_DECLARATION
#define NIV_GLGETACTIVEATTRIBARB_DECLARATION
  nivenGLGETACTIVEATTRIBARB glGetActiveAttribARB;
#endif

#ifndef NIV_GLBINDATTRIBLOCATIONARB_DECLARATION
#define NIV_GLBINDATTRIBLOCATIONARB_DECLARATION
  nivenGLBINDATTRIBLOCATIONARB glBindAttribLocationARB;
#endif

#ifndef NIV_GLGETATTRIBLOCATIONARB_DECLARATION
#define NIV_GLGETATTRIBLOCATIONARB_DECLARATION
  nivenGLGETATTRIBLOCATIONARB glGetAttribLocationARB;
#endif


#ifdef WIN32
  // WGL_NV_render_depth_texture
#endif
  // GL_EXT_texture_env

  // GL_SGIX_fragment_specular_lighting
#ifndef NIV_GLGETFRAGMENTLIGHTFVSGIX_DECLARATION
#define NIV_GLGETFRAGMENTLIGHTFVSGIX_DECLARATION
  nivenGLGETFRAGMENTLIGHTFVSGIX glGetFragmentLightfvSGIX;
#endif

#ifndef NIV_GLFRAGMENTMATERIALISGIX_DECLARATION
#define NIV_GLFRAGMENTMATERIALISGIX_DECLARATION
  nivenGLFRAGMENTMATERIALISGIX glFragmentMaterialiSGIX;
#endif

#ifndef NIV_GLFRAGMENTCOLORMATERIALSGIX_DECLARATION
#define NIV_GLFRAGMENTCOLORMATERIALSGIX_DECLARATION
  nivenGLFRAGMENTCOLORMATERIALSGIX glFragmentColorMaterialSGIX;
#endif

#ifndef NIV_GLFRAGMENTMATERIALFVSGIX_DECLARATION
#define NIV_GLFRAGMENTMATERIALFVSGIX_DECLARATION
  nivenGLFRAGMENTMATERIALFVSGIX glFragmentMaterialfvSGIX;
#endif

#ifndef NIV_GLFRAGMENTLIGHTISGIX_DECLARATION
#define NIV_GLFRAGMENTLIGHTISGIX_DECLARATION
  nivenGLFRAGMENTLIGHTISGIX glFragmentLightiSGIX;
#endif

#ifndef NIV_GLFRAGMENTLIGHTMODELIVSGIX_DECLARATION
#define NIV_GLFRAGMENTLIGHTMODELIVSGIX_DECLARATION
  nivenGLFRAGMENTLIGHTMODELIVSGIX glFragmentLightModelivSGIX;
#endif

#ifndef NIV_GLFRAGMENTLIGHTFSGIX_DECLARATION
#define NIV_GLFRAGMENTLIGHTFSGIX_DECLARATION
  nivenGLFRAGMENTLIGHTFSGIX glFragmentLightfSGIX;
#endif

#ifndef NIV_GLFRAGMENTLIGHTFVSGIX_DECLARATION
#define NIV_GLFRAGMENTLIGHTFVSGIX_DECLARATION
  nivenGLFRAGMENTLIGHTFVSGIX glFragmentLightfvSGIX;
#endif

#ifndef NIV_GLFRAGMENTLIGHTMODELFSGIX_DECLARATION
#define NIV_GLFRAGMENTLIGHTMODELFSGIX_DECLARATION
  nivenGLFRAGMENTLIGHTMODELFSGIX glFragmentLightModelfSGIX;
#endif

#ifndef NIV_GLFRAGMENTLIGHTIVSGIX_DECLARATION
#define NIV_GLFRAGMENTLIGHTIVSGIX_DECLARATION
  nivenGLFRAGMENTLIGHTIVSGIX glFragmentLightivSGIX;
#endif

#ifndef NIV_GLFRAGMENTLIGHTMODELFVSGIX_DECLARATION
#define NIV_GLFRAGMENTLIGHTMODELFVSGIX_DECLARATION
  nivenGLFRAGMENTLIGHTMODELFVSGIX glFragmentLightModelfvSGIX;
#endif

#ifndef NIV_GLFRAGMENTMATERIALIVSGIX_DECLARATION
#define NIV_GLFRAGMENTMATERIALIVSGIX_DECLARATION
  nivenGLFRAGMENTMATERIALIVSGIX glFragmentMaterialivSGIX;
#endif

#ifndef NIV_GLGETFRAGMENTMATERIALIVSGIX_DECLARATION
#define NIV_GLGETFRAGMENTMATERIALIVSGIX_DECLARATION
  nivenGLGETFRAGMENTMATERIALIVSGIX glGetFragmentMaterialivSGIX;
#endif

#ifndef NIV_GLGETFRAGMENTMATERIALFVSGIX_DECLARATION
#define NIV_GLGETFRAGMENTMATERIALFVSGIX_DECLARATION
  nivenGLGETFRAGMENTMATERIALFVSGIX glGetFragmentMaterialfvSGIX;
#endif

#ifndef NIV_GLFRAGMENTLIGHTMODELISGIX_DECLARATION
#define NIV_GLFRAGMENTLIGHTMODELISGIX_DECLARATION
  nivenGLFRAGMENTLIGHTMODELISGIX glFragmentLightModeliSGIX;
#endif

#ifndef NIV_GLFRAGMENTMATERIALFSGIX_DECLARATION
#define NIV_GLFRAGMENTMATERIALFSGIX_DECLARATION
  nivenGLFRAGMENTMATERIALFSGIX glFragmentMaterialfSGIX;
#endif

#ifndef NIV_GLGETFRAGMENTLIGHTIVSGIX_DECLARATION
#define NIV_GLGETFRAGMENTLIGHTIVSGIX_DECLARATION
  nivenGLGETFRAGMENTLIGHTIVSGIX glGetFragmentLightivSGIX;
#endif


#ifdef _GLX
  // GLX_3DFX_multisample
#endif // _GLX
  // GL_ARB_fragment_shader

#ifdef _GLX
  // GLX_SGI_video_sync
#ifndef NIV_GLXWAITVIDEOSYNCSGI_DECLARATION
#define NIV_GLXWAITVIDEOSYNCSGI_DECLARATION
  nivenGLXWAITVIDEOSYNCSGI glXWaitVideoSyncSGI;
#endif

#ifndef NIV_GLXGETVIDEOSYNCSGI_DECLARATION
#define NIV_GLXGETVIDEOSYNCSGI_DECLARATION
  nivenGLXGETVIDEOSYNCSGI glXGetVideoSyncSGI;
#endif

#endif // _GLX
  // GL_NV_texture_shader

  // GL_NV_pixel_data_range
#ifndef NIV_GLPIXELDATARANGENV_DECLARATION
#define NIV_GLPIXELDATARANGENV_DECLARATION
  nivenGLPIXELDATARANGENV glPixelDataRangeNV;
#endif

#ifndef NIV_GLFLUSHPIXELDATARANGENV_DECLARATION
#define NIV_GLFLUSHPIXELDATARANGENV_DECLARATION
  nivenGLFLUSHPIXELDATARANGENV glFlushPixelDataRangeNV;
#endif


#ifdef WIN32
  // WGL_EXT_multisample
#endif
  // GL_SGIS_texture_edge_clamp

  // GL_ARB_imaging
#ifndef NIV_GLCONVOLUTIONPARAMETERI_DECLARATION
#define NIV_GLCONVOLUTIONPARAMETERI_DECLARATION
  nivenGLCONVOLUTIONPARAMETERI glConvolutionParameteri;
#endif

#ifndef NIV_GLGETCONVOLUTIONPARAMETERIV_DECLARATION
#define NIV_GLGETCONVOLUTIONPARAMETERIV_DECLARATION
  nivenGLGETCONVOLUTIONPARAMETERIV glGetConvolutionParameteriv;
#endif

#ifndef NIV_GLGETMINMAXPARAMETERFV_DECLARATION
#define NIV_GLGETMINMAXPARAMETERFV_DECLARATION
  nivenGLGETMINMAXPARAMETERFV glGetMinmaxParameterfv;
#endif

#ifndef NIV_GLCONVOLUTIONPARAMETERF_DECLARATION
#define NIV_GLCONVOLUTIONPARAMETERF_DECLARATION
  nivenGLCONVOLUTIONPARAMETERF glConvolutionParameterf;
#endif

#ifndef NIV_GLCOLORTABLEPARAMETERIV_DECLARATION
#define NIV_GLCOLORTABLEPARAMETERIV_DECLARATION
  nivenGLCOLORTABLEPARAMETERIV glColorTableParameteriv;
#endif

#ifndef NIV_GLCOLORTABLE_DECLARATION
#define NIV_GLCOLORTABLE_DECLARATION
  nivenGLCOLORTABLE glColorTable;
#endif

#ifndef NIV_GLCONVOLUTIONPARAMETERIV_DECLARATION
#define NIV_GLCONVOLUTIONPARAMETERIV_DECLARATION
  nivenGLCONVOLUTIONPARAMETERIV glConvolutionParameteriv;
#endif

#ifndef NIV_GLGETMINMAX_DECLARATION
#define NIV_GLGETMINMAX_DECLARATION
  nivenGLGETMINMAX glGetMinmax;
#endif

#ifndef NIV_GLMINMAX_DECLARATION
#define NIV_GLMINMAX_DECLARATION
  nivenGLMINMAX glMinmax;
#endif

#ifndef NIV_GLCOPYCOLORSUBTABLE_DECLARATION
#define NIV_GLCOPYCOLORSUBTABLE_DECLARATION
  nivenGLCOPYCOLORSUBTABLE glCopyColorSubTable;
#endif

#ifndef NIV_GLCONVOLUTIONFILTER2D_DECLARATION
#define NIV_GLCONVOLUTIONFILTER2D_DECLARATION
  nivenGLCONVOLUTIONFILTER2D glConvolutionFilter2D;
#endif

#ifndef NIV_GLGETSEPARABLEFILTER_DECLARATION
#define NIV_GLGETSEPARABLEFILTER_DECLARATION
  nivenGLGETSEPARABLEFILTER glGetSeparableFilter;
#endif

#ifndef NIV_GLGETCOLORTABLEPARAMETERIV_DECLARATION
#define NIV_GLGETCOLORTABLEPARAMETERIV_DECLARATION
  nivenGLGETCOLORTABLEPARAMETERIV glGetColorTableParameteriv;
#endif

#ifndef NIV_GLCOPYCOLORTABLE_DECLARATION
#define NIV_GLCOPYCOLORTABLE_DECLARATION
  nivenGLCOPYCOLORTABLE glCopyColorTable;
#endif

#ifndef NIV_GLSEPARABLEFILTER2D_DECLARATION
#define NIV_GLSEPARABLEFILTER2D_DECLARATION
  nivenGLSEPARABLEFILTER2D glSeparableFilter2D;
#endif

#ifndef NIV_GLCOPYCONVOLUTIONFILTER1D_DECLARATION
#define NIV_GLCOPYCONVOLUTIONFILTER1D_DECLARATION
  nivenGLCOPYCONVOLUTIONFILTER1D glCopyConvolutionFilter1D;
#endif

#ifndef NIV_GLCONVOLUTIONPARAMETERFV_DECLARATION
#define NIV_GLCONVOLUTIONPARAMETERFV_DECLARATION
  nivenGLCONVOLUTIONPARAMETERFV glConvolutionParameterfv;
#endif

#ifndef NIV_GLGETCONVOLUTIONFILTER_DECLARATION
#define NIV_GLGETCONVOLUTIONFILTER_DECLARATION
  nivenGLGETCONVOLUTIONFILTER glGetConvolutionFilter;
#endif

#ifndef NIV_GLCOLORTABLEPARAMETERFV_DECLARATION
#define NIV_GLCOLORTABLEPARAMETERFV_DECLARATION
  nivenGLCOLORTABLEPARAMETERFV glColorTableParameterfv;
#endif

#ifndef NIV_GLRESETMINMAX_DECLARATION
#define NIV_GLRESETMINMAX_DECLARATION
  nivenGLRESETMINMAX glResetMinmax;
#endif

#ifndef NIV_GLCOPYCONVOLUTIONFILTER2D_DECLARATION
#define NIV_GLCOPYCONVOLUTIONFILTER2D_DECLARATION
  nivenGLCOPYCONVOLUTIONFILTER2D glCopyConvolutionFilter2D;
#endif

#ifndef NIV_GLHISTOGRAM_DECLARATION
#define NIV_GLHISTOGRAM_DECLARATION
  nivenGLHISTOGRAM glHistogram;
#endif

#ifndef NIV_GLGETMINMAXPARAMETERIV_DECLARATION
#define NIV_GLGETMINMAXPARAMETERIV_DECLARATION
  nivenGLGETMINMAXPARAMETERIV glGetMinmaxParameteriv;
#endif

#ifndef NIV_GLGETHISTOGRAMPARAMETERFV_DECLARATION
#define NIV_GLGETHISTOGRAMPARAMETERFV_DECLARATION
  nivenGLGETHISTOGRAMPARAMETERFV glGetHistogramParameterfv;
#endif

#ifndef NIV_GLGETCOLORTABLE_DECLARATION
#define NIV_GLGETCOLORTABLE_DECLARATION
  nivenGLGETCOLORTABLE glGetColorTable;
#endif

#ifndef NIV_GLGETCONVOLUTIONPARAMETERFV_DECLARATION
#define NIV_GLGETCONVOLUTIONPARAMETERFV_DECLARATION
  nivenGLGETCONVOLUTIONPARAMETERFV glGetConvolutionParameterfv;
#endif

#ifndef NIV_GLRESETHISTOGRAM_DECLARATION
#define NIV_GLRESETHISTOGRAM_DECLARATION
  nivenGLRESETHISTOGRAM glResetHistogram;
#endif

#ifndef NIV_GLCONVOLUTIONFILTER1D_DECLARATION
#define NIV_GLCONVOLUTIONFILTER1D_DECLARATION
  nivenGLCONVOLUTIONFILTER1D glConvolutionFilter1D;
#endif

#ifndef NIV_GLGETCOLORTABLEPARAMETERFV_DECLARATION
#define NIV_GLGETCOLORTABLEPARAMETERFV_DECLARATION
  nivenGLGETCOLORTABLEPARAMETERFV glGetColorTableParameterfv;
#endif

#ifndef NIV_GLGETHISTOGRAM_DECLARATION
#define NIV_GLGETHISTOGRAM_DECLARATION
  nivenGLGETHISTOGRAM glGetHistogram;
#endif

#ifndef NIV_GLGETHISTOGRAMPARAMETERIV_DECLARATION
#define NIV_GLGETHISTOGRAMPARAMETERIV_DECLARATION
  nivenGLGETHISTOGRAMPARAMETERIV glGetHistogramParameteriv;
#endif

#ifndef NIV_GLCOLORSUBTABLE_DECLARATION
#define NIV_GLCOLORSUBTABLE_DECLARATION
  nivenGLCOLORSUBTABLE glColorSubTable;
#endif


  // GL_WIN_specular_fog

  // GL_APPLE_client_storage

  // GL_IBM_vertex_array_lists
#ifndef NIV_GLTEXCOORDPOINTERLISTIBM_DECLARATION
#define NIV_GLTEXCOORDPOINTERLISTIBM_DECLARATION
  nivenGLTEXCOORDPOINTERLISTIBM glTexCoordPointerListIBM;
#endif

#ifndef NIV_GLEDGEFLAGPOINTERLISTIBM_DECLARATION
#define NIV_GLEDGEFLAGPOINTERLISTIBM_DECLARATION
  nivenGLEDGEFLAGPOINTERLISTIBM glEdgeFlagPointerListIBM;
#endif

#ifndef NIV_GLNORMALPOINTERLISTIBM_DECLARATION
#define NIV_GLNORMALPOINTERLISTIBM_DECLARATION
  nivenGLNORMALPOINTERLISTIBM glNormalPointerListIBM;
#endif

#ifndef NIV_GLSECONDARYCOLORPOINTERLISTIBM_DECLARATION
#define NIV_GLSECONDARYCOLORPOINTERLISTIBM_DECLARATION
  nivenGLSECONDARYCOLORPOINTERLISTIBM glSecondaryColorPointerListIBM;
#endif

#ifndef NIV_GLINDEXPOINTERLISTIBM_DECLARATION
#define NIV_GLINDEXPOINTERLISTIBM_DECLARATION
  nivenGLINDEXPOINTERLISTIBM glIndexPointerListIBM;
#endif

#ifndef NIV_GLCOLORPOINTERLISTIBM_DECLARATION
#define NIV_GLCOLORPOINTERLISTIBM_DECLARATION
  nivenGLCOLORPOINTERLISTIBM glColorPointerListIBM;
#endif

#ifndef NIV_GLFOGCOORDPOINTERLISTIBM_DECLARATION
#define NIV_GLFOGCOORDPOINTERLISTIBM_DECLARATION
  nivenGLFOGCOORDPOINTERLISTIBM glFogCoordPointerListIBM;
#endif

#ifndef NIV_GLVERTEXPOINTERLISTIBM_DECLARATION
#define NIV_GLVERTEXPOINTERLISTIBM_DECLARATION
  nivenGLVERTEXPOINTERLISTIBM glVertexPointerListIBM;
#endif


  // GL_ARB_fragment_program

  // GL_ARB_shader_objects
#ifndef NIV_GLGETHANDLEARB_DECLARATION
#define NIV_GLGETHANDLEARB_DECLARATION
  nivenGLGETHANDLEARB glGetHandleARB;
#endif

#ifndef NIV_GLUNIFORM3FVARB_DECLARATION
#define NIV_GLUNIFORM3FVARB_DECLARATION
  nivenGLUNIFORM3FVARB glUniform3fvARB;
#endif

#ifndef NIV_GLUNIFORM4IARB_DECLARATION
#define NIV_GLUNIFORM4IARB_DECLARATION
  nivenGLUNIFORM4IARB glUniform4iARB;
#endif

#ifndef NIV_GLUNIFORM2FARB_DECLARATION
#define NIV_GLUNIFORM2FARB_DECLARATION
  nivenGLUNIFORM2FARB glUniform2fARB;
#endif

#ifndef NIV_GLUNIFORM3FARB_DECLARATION
#define NIV_GLUNIFORM3FARB_DECLARATION
  nivenGLUNIFORM3FARB glUniform3fARB;
#endif

#ifndef NIV_GLUNIFORM1IARB_DECLARATION
#define NIV_GLUNIFORM1IARB_DECLARATION
  nivenGLUNIFORM1IARB glUniform1iARB;
#endif

#ifndef NIV_GLUNIFORM1FVARB_DECLARATION
#define NIV_GLUNIFORM1FVARB_DECLARATION
  nivenGLUNIFORM1FVARB glUniform1fvARB;
#endif

#ifndef NIV_GLVALIDATEPROGRAMARB_DECLARATION
#define NIV_GLVALIDATEPROGRAMARB_DECLARATION
  nivenGLVALIDATEPROGRAMARB glValidateProgramARB;
#endif

#ifndef NIV_GLUNIFORM3IARB_DECLARATION
#define NIV_GLUNIFORM3IARB_DECLARATION
  nivenGLUNIFORM3IARB glUniform3iARB;
#endif

#ifndef NIV_GLDELETEOBJECTARB_DECLARATION
#define NIV_GLDELETEOBJECTARB_DECLARATION
  nivenGLDELETEOBJECTARB glDeleteObjectARB;
#endif

#ifndef NIV_GLCOMPILESHADERARB_DECLARATION
#define NIV_GLCOMPILESHADERARB_DECLARATION
  nivenGLCOMPILESHADERARB glCompileShaderARB;
#endif

#ifndef NIV_GLGETOBJECTPARAMETERFVARB_DECLARATION
#define NIV_GLGETOBJECTPARAMETERFVARB_DECLARATION
  nivenGLGETOBJECTPARAMETERFVARB glGetObjectParameterfvARB;
#endif

#ifndef NIV_GLGETUNIFORMLOCATIONARB_DECLARATION
#define NIV_GLGETUNIFORMLOCATIONARB_DECLARATION
  nivenGLGETUNIFORMLOCATIONARB glGetUniformLocationARB;
#endif

#ifndef NIV_GLCREATEPROGRAMOBJECTARB_DECLARATION
#define NIV_GLCREATEPROGRAMOBJECTARB_DECLARATION
  nivenGLCREATEPROGRAMOBJECTARB glCreateProgramObjectARB;
#endif

#ifndef NIV_GLGETSHADERSOURCEARB_DECLARATION
#define NIV_GLGETSHADERSOURCEARB_DECLARATION
  nivenGLGETSHADERSOURCEARB glGetShaderSourceARB;
#endif

#ifndef NIV_GLUNIFORM2IVARB_DECLARATION
#define NIV_GLUNIFORM2IVARB_DECLARATION
  nivenGLUNIFORM2IVARB glUniform2ivARB;
#endif

#ifndef NIV_GLUSEPROGRAMOBJECTARB_DECLARATION
#define NIV_GLUSEPROGRAMOBJECTARB_DECLARATION
  nivenGLUSEPROGRAMOBJECTARB glUseProgramObjectARB;
#endif

#ifndef NIV_GLUNIFORMMATRIX2FVARB_DECLARATION
#define NIV_GLUNIFORMMATRIX2FVARB_DECLARATION
  nivenGLUNIFORMMATRIX2FVARB glUniformMatrix2fvARB;
#endif

#ifndef NIV_GLLINKPROGRAMARB_DECLARATION
#define NIV_GLLINKPROGRAMARB_DECLARATION
  nivenGLLINKPROGRAMARB glLinkProgramARB;
#endif

#ifndef NIV_GLGETUNIFORMFVARB_DECLARATION
#define NIV_GLGETUNIFORMFVARB_DECLARATION
  nivenGLGETUNIFORMFVARB glGetUniformfvARB;
#endif

#ifndef NIV_GLUNIFORM1IVARB_DECLARATION
#define NIV_GLUNIFORM1IVARB_DECLARATION
  nivenGLUNIFORM1IVARB glUniform1ivARB;
#endif

#ifndef NIV_GLUNIFORM2IARB_DECLARATION
#define NIV_GLUNIFORM2IARB_DECLARATION
  nivenGLUNIFORM2IARB glUniform2iARB;
#endif

#ifndef NIV_GLATTACHOBJECTARB_DECLARATION
#define NIV_GLATTACHOBJECTARB_DECLARATION
  nivenGLATTACHOBJECTARB glAttachObjectARB;
#endif

#ifndef NIV_GLUNIFORMMATRIX3FVARB_DECLARATION
#define NIV_GLUNIFORMMATRIX3FVARB_DECLARATION
  nivenGLUNIFORMMATRIX3FVARB glUniformMatrix3fvARB;
#endif

#ifndef NIV_GLCREATESHADEROBJECTARB_DECLARATION
#define NIV_GLCREATESHADEROBJECTARB_DECLARATION
  nivenGLCREATESHADEROBJECTARB glCreateShaderObjectARB;
#endif

#ifndef NIV_GLGETATTACHEDOBJECTSARB_DECLARATION
#define NIV_GLGETATTACHEDOBJECTSARB_DECLARATION
  nivenGLGETATTACHEDOBJECTSARB glGetAttachedObjectsARB;
#endif

#ifndef NIV_GLUNIFORM4FARB_DECLARATION
#define NIV_GLUNIFORM4FARB_DECLARATION
  nivenGLUNIFORM4FARB glUniform4fARB;
#endif

#ifndef NIV_GLUNIFORM4IVARB_DECLARATION
#define NIV_GLUNIFORM4IVARB_DECLARATION
  nivenGLUNIFORM4IVARB glUniform4ivARB;
#endif

#ifndef NIV_GLUNIFORM3IVARB_DECLARATION
#define NIV_GLUNIFORM3IVARB_DECLARATION
  nivenGLUNIFORM3IVARB glUniform3ivARB;
#endif

#ifndef NIV_GLGETUNIFORMIVARB_DECLARATION
#define NIV_GLGETUNIFORMIVARB_DECLARATION
  nivenGLGETUNIFORMIVARB glGetUniformivARB;
#endif

#ifndef NIV_GLGETACTIVEUNIFORMARB_DECLARATION
#define NIV_GLGETACTIVEUNIFORMARB_DECLARATION
  nivenGLGETACTIVEUNIFORMARB glGetActiveUniformARB;
#endif

#ifndef NIV_GLUNIFORMMATRIX4FVARB_DECLARATION
#define NIV_GLUNIFORMMATRIX4FVARB_DECLARATION
  nivenGLUNIFORMMATRIX4FVARB glUniformMatrix4fvARB;
#endif

#ifndef NIV_GLGETOBJECTPARAMETERIVARB_DECLARATION
#define NIV_GLGETOBJECTPARAMETERIVARB_DECLARATION
  nivenGLGETOBJECTPARAMETERIVARB glGetObjectParameterivARB;
#endif

#ifndef NIV_GLUNIFORM1FARB_DECLARATION
#define NIV_GLUNIFORM1FARB_DECLARATION
  nivenGLUNIFORM1FARB glUniform1fARB;
#endif

#ifndef NIV_GLDETACHOBJECTARB_DECLARATION
#define NIV_GLDETACHOBJECTARB_DECLARATION
  nivenGLDETACHOBJECTARB glDetachObjectARB;
#endif

#ifndef NIV_GLSHADERSOURCEARB_DECLARATION
#define NIV_GLSHADERSOURCEARB_DECLARATION
  nivenGLSHADERSOURCEARB glShaderSourceARB;
#endif

#ifndef NIV_GLUNIFORM4FVARB_DECLARATION
#define NIV_GLUNIFORM4FVARB_DECLARATION
  nivenGLUNIFORM4FVARB glUniform4fvARB;
#endif

#ifndef NIV_GLGETINFOLOGARB_DECLARATION
#define NIV_GLGETINFOLOGARB_DECLARATION
  nivenGLGETINFOLOGARB glGetInfoLogARB;
#endif

#ifndef NIV_GLUNIFORM2FVARB_DECLARATION
#define NIV_GLUNIFORM2FVARB_DECLARATION
  nivenGLUNIFORM2FVARB glUniform2fvARB;
#endif


  // GL_EXT_framebuffer_object
#ifndef NIV_GLCHECKFRAMEBUFFERSTATUSEXT_DECLARATION
#define NIV_GLCHECKFRAMEBUFFERSTATUSEXT_DECLARATION
  nivenGLCHECKFRAMEBUFFERSTATUSEXT glCheckFramebufferStatusEXT;
#endif

#ifndef NIV_GLDELETERENDERBUFFERSEXT_DECLARATION
#define NIV_GLDELETERENDERBUFFERSEXT_DECLARATION
  nivenGLDELETERENDERBUFFERSEXT glDeleteRenderbuffersEXT;
#endif

#ifndef NIV_GLFRAMEBUFFERTEXTURE1DEXT_DECLARATION
#define NIV_GLFRAMEBUFFERTEXTURE1DEXT_DECLARATION
  nivenGLFRAMEBUFFERTEXTURE1DEXT glFramebufferTexture1DEXT;
#endif

#ifndef NIV_GLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXT_DECLARATION
#define NIV_GLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXT_DECLARATION
  nivenGLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXT glGetFramebufferAttachmentParameterivEXT;
#endif

#ifndef NIV_GLFRAMEBUFFERTEXTURE2DEXT_DECLARATION
#define NIV_GLFRAMEBUFFERTEXTURE2DEXT_DECLARATION
  nivenGLFRAMEBUFFERTEXTURE2DEXT glFramebufferTexture2DEXT;
#endif

#ifndef NIV_GLGENRENDERBUFFERSEXT_DECLARATION
#define NIV_GLGENRENDERBUFFERSEXT_DECLARATION
  nivenGLGENRENDERBUFFERSEXT glGenRenderbuffersEXT;
#endif

#ifndef NIV_GLGENFRAMEBUFFERSEXT_DECLARATION
#define NIV_GLGENFRAMEBUFFERSEXT_DECLARATION
  nivenGLGENFRAMEBUFFERSEXT glGenFramebuffersEXT;
#endif

#ifndef NIV_GLDELETEFRAMEBUFFERSEXT_DECLARATION
#define NIV_GLDELETEFRAMEBUFFERSEXT_DECLARATION
  nivenGLDELETEFRAMEBUFFERSEXT glDeleteFramebuffersEXT;
#endif

#ifndef NIV_GLISFRAMEBUFFEREXT_DECLARATION
#define NIV_GLISFRAMEBUFFEREXT_DECLARATION
  nivenGLISFRAMEBUFFEREXT glIsFramebufferEXT;
#endif

#ifndef NIV_GLFRAMEBUFFERTEXTURE3DEXT_DECLARATION
#define NIV_GLFRAMEBUFFERTEXTURE3DEXT_DECLARATION
  nivenGLFRAMEBUFFERTEXTURE3DEXT glFramebufferTexture3DEXT;
#endif

#ifndef NIV_GLISRENDERBUFFEREXT_DECLARATION
#define NIV_GLISRENDERBUFFEREXT_DECLARATION
  nivenGLISRENDERBUFFEREXT glIsRenderbufferEXT;
#endif

#ifndef NIV_GLFRAMEBUFFERRENDERBUFFEREXT_DECLARATION
#define NIV_GLFRAMEBUFFERRENDERBUFFEREXT_DECLARATION
  nivenGLFRAMEBUFFERRENDERBUFFEREXT glFramebufferRenderbufferEXT;
#endif

#ifndef NIV_GLGENERATEMIPMAPEXT_DECLARATION
#define NIV_GLGENERATEMIPMAPEXT_DECLARATION
  nivenGLGENERATEMIPMAPEXT glGenerateMipmapEXT;
#endif

#ifndef NIV_GLBINDFRAMEBUFFEREXT_DECLARATION
#define NIV_GLBINDFRAMEBUFFEREXT_DECLARATION
  nivenGLBINDFRAMEBUFFEREXT glBindFramebufferEXT;
#endif

#ifndef NIV_GLGETRENDERBUFFERPARAMETERIVEXT_DECLARATION
#define NIV_GLGETRENDERBUFFERPARAMETERIVEXT_DECLARATION
  nivenGLGETRENDERBUFFERPARAMETERIVEXT glGetRenderbufferParameterivEXT;
#endif

#ifndef NIV_GLBINDRENDERBUFFEREXT_DECLARATION
#define NIV_GLBINDRENDERBUFFEREXT_DECLARATION
  nivenGLBINDRENDERBUFFEREXT glBindRenderbufferEXT;
#endif

#ifndef NIV_GLRENDERBUFFERSTORAGEEXT_DECLARATION
#define NIV_GLRENDERBUFFERSTORAGEEXT_DECLARATION
  nivenGLRENDERBUFFERSTORAGEEXT glRenderbufferStorageEXT;
#endif


#ifdef WIN32
  // WGL_I3D_gamma
#ifndef NIV_WGLGETGAMMATABLEPARAMETERSI3D_DECLARATION
#define NIV_WGLGETGAMMATABLEPARAMETERSI3D_DECLARATION
  nivenWGLGETGAMMATABLEPARAMETERSI3D wglGetGammaTableParametersI3D;
#endif

#ifndef NIV_WGLGETGAMMATABLEI3D_DECLARATION
#define NIV_WGLGETGAMMATABLEI3D_DECLARATION
  nivenWGLGETGAMMATABLEI3D wglGetGammaTableI3D;
#endif

#ifndef NIV_WGLSETGAMMATABLEPARAMETERSI3D_DECLARATION
#define NIV_WGLSETGAMMATABLEPARAMETERSI3D_DECLARATION
  nivenWGLSETGAMMATABLEPARAMETERSI3D wglSetGammaTableParametersI3D;
#endif

#ifndef NIV_WGLSETGAMMATABLEI3D_DECLARATION
#define NIV_WGLSETGAMMATABLEI3D_DECLARATION
  nivenWGLSETGAMMATABLEI3D wglSetGammaTableI3D;
#endif

#endif
  // GL_ATI_vertex_streams
#ifndef NIV_GLNORMALSTREAM3BVATI_DECLARATION
#define NIV_GLNORMALSTREAM3BVATI_DECLARATION
  nivenGLNORMALSTREAM3BVATI glNormalStream3bvATI;
#endif

#ifndef NIV_GLVERTEXSTREAM2DATI_DECLARATION
#define NIV_GLVERTEXSTREAM2DATI_DECLARATION
  nivenGLVERTEXSTREAM2DATI glVertexStream2dATI;
#endif

#ifndef NIV_GLNORMALSTREAM3SATI_DECLARATION
#define NIV_GLNORMALSTREAM3SATI_DECLARATION
  nivenGLNORMALSTREAM3SATI glNormalStream3sATI;
#endif

#ifndef NIV_GLVERTEXSTREAM2IVATI_DECLARATION
#define NIV_GLVERTEXSTREAM2IVATI_DECLARATION
  nivenGLVERTEXSTREAM2IVATI glVertexStream2ivATI;
#endif

#ifndef NIV_GLVERTEXSTREAM3DVATI_DECLARATION
#define NIV_GLVERTEXSTREAM3DVATI_DECLARATION
  nivenGLVERTEXSTREAM3DVATI glVertexStream3dvATI;
#endif

#ifndef NIV_GLVERTEXSTREAM3SVATI_DECLARATION
#define NIV_GLVERTEXSTREAM3SVATI_DECLARATION
  nivenGLVERTEXSTREAM3SVATI glVertexStream3svATI;
#endif

#ifndef NIV_GLVERTEXSTREAM3SATI_DECLARATION
#define NIV_GLVERTEXSTREAM3SATI_DECLARATION
  nivenGLVERTEXSTREAM3SATI glVertexStream3sATI;
#endif

#ifndef NIV_GLVERTEXSTREAM4IATI_DECLARATION
#define NIV_GLVERTEXSTREAM4IATI_DECLARATION
  nivenGLVERTEXSTREAM4IATI glVertexStream4iATI;
#endif

#ifndef NIV_GLVERTEXSTREAM3FATI_DECLARATION
#define NIV_GLVERTEXSTREAM3FATI_DECLARATION
  nivenGLVERTEXSTREAM3FATI glVertexStream3fATI;
#endif

#ifndef NIV_GLVERTEXSTREAM2SVATI_DECLARATION
#define NIV_GLVERTEXSTREAM2SVATI_DECLARATION
  nivenGLVERTEXSTREAM2SVATI glVertexStream2svATI;
#endif

#ifndef NIV_GLNORMALSTREAM3DVATI_DECLARATION
#define NIV_GLNORMALSTREAM3DVATI_DECLARATION
  nivenGLNORMALSTREAM3DVATI glNormalStream3dvATI;
#endif

#ifndef NIV_GLVERTEXSTREAM2SATI_DECLARATION
#define NIV_GLVERTEXSTREAM2SATI_DECLARATION
  nivenGLVERTEXSTREAM2SATI glVertexStream2sATI;
#endif

#ifndef NIV_GLVERTEXSTREAM4IVATI_DECLARATION
#define NIV_GLVERTEXSTREAM4IVATI_DECLARATION
  nivenGLVERTEXSTREAM4IVATI glVertexStream4ivATI;
#endif

#ifndef NIV_GLVERTEXSTREAM3IVATI_DECLARATION
#define NIV_GLVERTEXSTREAM3IVATI_DECLARATION
  nivenGLVERTEXSTREAM3IVATI glVertexStream3ivATI;
#endif

#ifndef NIV_GLVERTEXSTREAM3IATI_DECLARATION
#define NIV_GLVERTEXSTREAM3IATI_DECLARATION
  nivenGLVERTEXSTREAM3IATI glVertexStream3iATI;
#endif

#ifndef NIV_GLNORMALSTREAM3BATI_DECLARATION
#define NIV_GLNORMALSTREAM3BATI_DECLARATION
  nivenGLNORMALSTREAM3BATI glNormalStream3bATI;
#endif

#ifndef NIV_GLVERTEXSTREAM3FVATI_DECLARATION
#define NIV_GLVERTEXSTREAM3FVATI_DECLARATION
  nivenGLVERTEXSTREAM3FVATI glVertexStream3fvATI;
#endif

#ifndef NIV_GLVERTEXSTREAM2DVATI_DECLARATION
#define NIV_GLVERTEXSTREAM2DVATI_DECLARATION
  nivenGLVERTEXSTREAM2DVATI glVertexStream2dvATI;
#endif

#ifndef NIV_GLVERTEXSTREAM2FVATI_DECLARATION
#define NIV_GLVERTEXSTREAM2FVATI_DECLARATION
  nivenGLVERTEXSTREAM2FVATI glVertexStream2fvATI;
#endif

#ifndef NIV_GLNORMALSTREAM3IATI_DECLARATION
#define NIV_GLNORMALSTREAM3IATI_DECLARATION
  nivenGLNORMALSTREAM3IATI glNormalStream3iATI;
#endif

#ifndef NIV_GLVERTEXSTREAM3DATI_DECLARATION
#define NIV_GLVERTEXSTREAM3DATI_DECLARATION
  nivenGLVERTEXSTREAM3DATI glVertexStream3dATI;
#endif

#ifndef NIV_GLNORMALSTREAM3FATI_DECLARATION
#define NIV_GLNORMALSTREAM3FATI_DECLARATION
  nivenGLNORMALSTREAM3FATI glNormalStream3fATI;
#endif

#ifndef NIV_GLVERTEXSTREAM4FVATI_DECLARATION
#define NIV_GLVERTEXSTREAM4FVATI_DECLARATION
  nivenGLVERTEXSTREAM4FVATI glVertexStream4fvATI;
#endif

#ifndef NIV_GLNORMALSTREAM3FVATI_DECLARATION
#define NIV_GLNORMALSTREAM3FVATI_DECLARATION
  nivenGLNORMALSTREAM3FVATI glNormalStream3fvATI;
#endif

#ifndef NIV_GLVERTEXBLENDENVFATI_DECLARATION
#define NIV_GLVERTEXBLENDENVFATI_DECLARATION
  nivenGLVERTEXBLENDENVFATI glVertexBlendEnvfATI;
#endif

#ifndef NIV_GLNORMALSTREAM3DATI_DECLARATION
#define NIV_GLNORMALSTREAM3DATI_DECLARATION
  nivenGLNORMALSTREAM3DATI glNormalStream3dATI;
#endif

#ifndef NIV_GLNORMALSTREAM3IVATI_DECLARATION
#define NIV_GLNORMALSTREAM3IVATI_DECLARATION
  nivenGLNORMALSTREAM3IVATI glNormalStream3ivATI;
#endif

#ifndef NIV_GLVERTEXSTREAM4FATI_DECLARATION
#define NIV_GLVERTEXSTREAM4FATI_DECLARATION
  nivenGLVERTEXSTREAM4FATI glVertexStream4fATI;
#endif

#ifndef NIV_GLVERTEXBLENDENVIATI_DECLARATION
#define NIV_GLVERTEXBLENDENVIATI_DECLARATION
  nivenGLVERTEXBLENDENVIATI glVertexBlendEnviATI;
#endif

#ifndef NIV_GLVERTEXSTREAM4DVATI_DECLARATION
#define NIV_GLVERTEXSTREAM4DVATI_DECLARATION
  nivenGLVERTEXSTREAM4DVATI glVertexStream4dvATI;
#endif

#ifndef NIV_GLVERTEXSTREAM4SVATI_DECLARATION
#define NIV_GLVERTEXSTREAM4SVATI_DECLARATION
  nivenGLVERTEXSTREAM4SVATI glVertexStream4svATI;
#endif

#ifndef NIV_GLVERTEXSTREAM2IATI_DECLARATION
#define NIV_GLVERTEXSTREAM2IATI_DECLARATION
  nivenGLVERTEXSTREAM2IATI glVertexStream2iATI;
#endif

#ifndef NIV_GLVERTEXSTREAM2FATI_DECLARATION
#define NIV_GLVERTEXSTREAM2FATI_DECLARATION
  nivenGLVERTEXSTREAM2FATI glVertexStream2fATI;
#endif

#ifndef NIV_GLVERTEXSTREAM4SATI_DECLARATION
#define NIV_GLVERTEXSTREAM4SATI_DECLARATION
  nivenGLVERTEXSTREAM4SATI glVertexStream4sATI;
#endif

#ifndef NIV_GLNORMALSTREAM3SVATI_DECLARATION
#define NIV_GLNORMALSTREAM3SVATI_DECLARATION
  nivenGLNORMALSTREAM3SVATI glNormalStream3svATI;
#endif

#ifndef NIV_GLVERTEXSTREAM4DATI_DECLARATION
#define NIV_GLVERTEXSTREAM4DATI_DECLARATION
  nivenGLVERTEXSTREAM4DATI glVertexStream4dATI;
#endif

#ifndef NIV_GLCLIENTACTIVEVERTEXSTREAMATI_DECLARATION
#define NIV_GLCLIENTACTIVEVERTEXSTREAMATI_DECLARATION
  nivenGLCLIENTACTIVEVERTEXSTREAMATI glClientActiveVertexStreamATI;
#endif


  // GL_APPLE_ycbcr_422

  // GL_NV_blend_square

  // GL_MESA_window_pos
#ifndef NIV_GLWINDOWPOS4IMESA_DECLARATION
#define NIV_GLWINDOWPOS4IMESA_DECLARATION
  nivenGLWINDOWPOS4IMESA glWindowPos4iMESA;
#endif

#ifndef NIV_GLWINDOWPOS3IMESA_DECLARATION
#define NIV_GLWINDOWPOS3IMESA_DECLARATION
  nivenGLWINDOWPOS3IMESA glWindowPos3iMESA;
#endif

#ifndef NIV_GLWINDOWPOS2IVMESA_DECLARATION
#define NIV_GLWINDOWPOS2IVMESA_DECLARATION
  nivenGLWINDOWPOS2IVMESA glWindowPos2ivMESA;
#endif

#ifndef NIV_GLWINDOWPOS2DMESA_DECLARATION
#define NIV_GLWINDOWPOS2DMESA_DECLARATION
  nivenGLWINDOWPOS2DMESA glWindowPos2dMESA;
#endif

#ifndef NIV_GLWINDOWPOS3DMESA_DECLARATION
#define NIV_GLWINDOWPOS3DMESA_DECLARATION
  nivenGLWINDOWPOS3DMESA glWindowPos3dMESA;
#endif

#ifndef NIV_GLWINDOWPOS3IVMESA_DECLARATION
#define NIV_GLWINDOWPOS3IVMESA_DECLARATION
  nivenGLWINDOWPOS3IVMESA glWindowPos3ivMESA;
#endif

#ifndef NIV_GLWINDOWPOS4DMESA_DECLARATION
#define NIV_GLWINDOWPOS4DMESA_DECLARATION
  nivenGLWINDOWPOS4DMESA glWindowPos4dMESA;
#endif

#ifndef NIV_GLWINDOWPOS3FVMESA_DECLARATION
#define NIV_GLWINDOWPOS3FVMESA_DECLARATION
  nivenGLWINDOWPOS3FVMESA glWindowPos3fvMESA;
#endif

#ifndef NIV_GLWINDOWPOS2FVMESA_DECLARATION
#define NIV_GLWINDOWPOS2FVMESA_DECLARATION
  nivenGLWINDOWPOS2FVMESA glWindowPos2fvMESA;
#endif

#ifndef NIV_GLWINDOWPOS3SMESA_DECLARATION
#define NIV_GLWINDOWPOS3SMESA_DECLARATION
  nivenGLWINDOWPOS3SMESA glWindowPos3sMESA;
#endif

#ifndef NIV_GLWINDOWPOS2SMESA_DECLARATION
#define NIV_GLWINDOWPOS2SMESA_DECLARATION
  nivenGLWINDOWPOS2SMESA glWindowPos2sMESA;
#endif

#ifndef NIV_GLWINDOWPOS3FMESA_DECLARATION
#define NIV_GLWINDOWPOS3FMESA_DECLARATION
  nivenGLWINDOWPOS3FMESA glWindowPos3fMESA;
#endif

#ifndef NIV_GLWINDOWPOS3SVMESA_DECLARATION
#define NIV_GLWINDOWPOS3SVMESA_DECLARATION
  nivenGLWINDOWPOS3SVMESA glWindowPos3svMESA;
#endif

#ifndef NIV_GLWINDOWPOS4IVMESA_DECLARATION
#define NIV_GLWINDOWPOS4IVMESA_DECLARATION
  nivenGLWINDOWPOS4IVMESA glWindowPos4ivMESA;
#endif

#ifndef NIV_GLWINDOWPOS4SVMESA_DECLARATION
#define NIV_GLWINDOWPOS4SVMESA_DECLARATION
  nivenGLWINDOWPOS4SVMESA glWindowPos4svMESA;
#endif

#ifndef NIV_GLWINDOWPOS3DVMESA_DECLARATION
#define NIV_GLWINDOWPOS3DVMESA_DECLARATION
  nivenGLWINDOWPOS3DVMESA glWindowPos3dvMESA;
#endif

#ifndef NIV_GLWINDOWPOS4FMESA_DECLARATION
#define NIV_GLWINDOWPOS4FMESA_DECLARATION
  nivenGLWINDOWPOS4FMESA glWindowPos4fMESA;
#endif

#ifndef NIV_GLWINDOWPOS4DVMESA_DECLARATION
#define NIV_GLWINDOWPOS4DVMESA_DECLARATION
  nivenGLWINDOWPOS4DVMESA glWindowPos4dvMESA;
#endif

#ifndef NIV_GLWINDOWPOS2FMESA_DECLARATION
#define NIV_GLWINDOWPOS2FMESA_DECLARATION
  nivenGLWINDOWPOS2FMESA glWindowPos2fMESA;
#endif

#ifndef NIV_GLWINDOWPOS4SMESA_DECLARATION
#define NIV_GLWINDOWPOS4SMESA_DECLARATION
  nivenGLWINDOWPOS4SMESA glWindowPos4sMESA;
#endif

#ifndef NIV_GLWINDOWPOS2SVMESA_DECLARATION
#define NIV_GLWINDOWPOS2SVMESA_DECLARATION
  nivenGLWINDOWPOS2SVMESA glWindowPos2svMESA;
#endif

#ifndef NIV_GLWINDOWPOS2IMESA_DECLARATION
#define NIV_GLWINDOWPOS2IMESA_DECLARATION
  nivenGLWINDOWPOS2IMESA glWindowPos2iMESA;
#endif

#ifndef NIV_GLWINDOWPOS4FVMESA_DECLARATION
#define NIV_GLWINDOWPOS4FVMESA_DECLARATION
  nivenGLWINDOWPOS4FVMESA glWindowPos4fvMESA;
#endif

#ifndef NIV_GLWINDOWPOS2DVMESA_DECLARATION
#define NIV_GLWINDOWPOS2DVMESA_DECLARATION
  nivenGLWINDOWPOS2DVMESA glWindowPos2dvMESA;
#endif


  // GL_ATI_envmap_bumpmap
#ifndef NIV_GLTEXBUMPPARAMETERFVATI_DECLARATION
#define NIV_GLTEXBUMPPARAMETERFVATI_DECLARATION
  nivenGLTEXBUMPPARAMETERFVATI glTexBumpParameterfvATI;
#endif

#ifndef NIV_GLTEXBUMPPARAMETERIVATI_DECLARATION
#define NIV_GLTEXBUMPPARAMETERIVATI_DECLARATION
  nivenGLTEXBUMPPARAMETERIVATI glTexBumpParameterivATI;
#endif

#ifndef NIV_GLGETTEXBUMPPARAMETERIVATI_DECLARATION
#define NIV_GLGETTEXBUMPPARAMETERIVATI_DECLARATION
  nivenGLGETTEXBUMPPARAMETERIVATI glGetTexBumpParameterivATI;
#endif

#ifndef NIV_GLGETTEXBUMPPARAMETERFVATI_DECLARATION
#define NIV_GLGETTEXBUMPPARAMETERFVATI_DECLARATION
  nivenGLGETTEXBUMPPARAMETERFVATI glGetTexBumpParameterfvATI;
#endif


  // GL_ARB_texture_non_power_of_two

  // GL_EXT_texture_env_combine

  // GL_EXT_texture_object
#ifndef NIV_GLBINDTEXTUREEXT_DECLARATION
#define NIV_GLBINDTEXTUREEXT_DECLARATION
  nivenGLBINDTEXTUREEXT glBindTextureEXT;
#endif

#ifndef NIV_GLPRIORITIZETEXTURESEXT_DECLARATION
#define NIV_GLPRIORITIZETEXTURESEXT_DECLARATION
  nivenGLPRIORITIZETEXTURESEXT glPrioritizeTexturesEXT;
#endif

#ifndef NIV_GLISTEXTUREEXT_DECLARATION
#define NIV_GLISTEXTUREEXT_DECLARATION
  nivenGLISTEXTUREEXT glIsTextureEXT;
#endif

#ifndef NIV_GLDELETETEXTURESEXT_DECLARATION
#define NIV_GLDELETETEXTURESEXT_DECLARATION
  nivenGLDELETETEXTURESEXT glDeleteTexturesEXT;
#endif

#ifndef NIV_GLGENTEXTURESEXT_DECLARATION
#define NIV_GLGENTEXTURESEXT_DECLARATION
  nivenGLGENTEXTURESEXT glGenTexturesEXT;
#endif

#ifndef NIV_GLARETEXTURESRESIDENTEXT_DECLARATION
#define NIV_GLARETEXTURESRESIDENTEXT_DECLARATION
  nivenGLARETEXTURESRESIDENTEXT glAreTexturesResidentEXT;
#endif


  // GL_ATI_texture_compression_3dc

  // GL_OML_subsample

  // GL_EXT_texture_lod_bias

#ifdef WIN32
  // WGL_ARB_pixel_format_float
#endif
  // GL_EXT_scene_marker
#ifndef NIV_GLBEGINSCENEEXT_DECLARATION
#define NIV_GLBEGINSCENEEXT_DECLARATION
  nivenGLBEGINSCENEEXT glBeginSceneEXT;
#endif

#ifndef NIV_GLENDSCENEEXT_DECLARATION
#define NIV_GLENDSCENEEXT_DECLARATION
  nivenGLENDSCENEEXT glEndSceneEXT;
#endif


  // GL_NV_primitive_restart
#ifndef NIV_GLPRIMITIVERESTARTINDEXNV_DECLARATION
#define NIV_GLPRIMITIVERESTARTINDEXNV_DECLARATION
  nivenGLPRIMITIVERESTARTINDEXNV glPrimitiveRestartIndexNV;
#endif

#ifndef NIV_GLPRIMITIVERESTARTNV_DECLARATION
#define NIV_GLPRIMITIVERESTARTNV_DECLARATION
  nivenGLPRIMITIVERESTARTNV glPrimitiveRestartNV;
#endif


  // GL_ARB_shadow_ambient

  // GL_SGIX_vertex_preclip_hint

#ifdef _GLX
  // GLX_MESA_pixmap_colormap
#ifndef NIV_GLXCREATEGLXPIXMAPMESA_DECLARATION
#define NIV_GLXCREATEGLXPIXMAPMESA_DECLARATION
  nivenGLXCREATEGLXPIXMAPMESA glXCreateGLXPixmapMESA;
#endif

#endif // _GLX
  // GL_EXT_pixel_buffer_object

  // GL_EXT_abgr

  // GL_NV_vertex_program
#ifndef NIV_GLVERTEXATTRIBS2FVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS2FVNV_DECLARATION
  nivenGLVERTEXATTRIBS2FVNV glVertexAttribs2fvNV;
#endif

#ifndef NIV_GLTRACKMATRIXNV_DECLARATION
#define NIV_GLTRACKMATRIXNV_DECLARATION
  nivenGLTRACKMATRIXNV glTrackMatrixNV;
#endif

#ifndef NIV_GLBINDPROGRAMNV_DECLARATION
#define NIV_GLBINDPROGRAMNV_DECLARATION
  nivenGLBINDPROGRAMNV glBindProgramNV;
#endif

#ifndef NIV_GLGETVERTEXATTRIBFVNV_DECLARATION
#define NIV_GLGETVERTEXATTRIBFVNV_DECLARATION
  nivenGLGETVERTEXATTRIBFVNV glGetVertexAttribfvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB3SNV_DECLARATION
#define NIV_GLVERTEXATTRIB3SNV_DECLARATION
  nivenGLVERTEXATTRIB3SNV glVertexAttrib3sNV;
#endif

#ifndef NIV_GLGETPROGRAMPARAMETERDVNV_DECLARATION
#define NIV_GLGETPROGRAMPARAMETERDVNV_DECLARATION
  nivenGLGETPROGRAMPARAMETERDVNV glGetProgramParameterdvNV;
#endif

#ifndef NIV_GLGETTRACKMATRIXIVNV_DECLARATION
#define NIV_GLGETTRACKMATRIXIVNV_DECLARATION
  nivenGLGETTRACKMATRIXIVNV glGetTrackMatrixivNV;
#endif

#ifndef NIV_GLVERTEXATTRIB4FNV_DECLARATION
#define NIV_GLVERTEXATTRIB4FNV_DECLARATION
  nivenGLVERTEXATTRIB4FNV glVertexAttrib4fNV;
#endif

#ifndef NIV_GLAREPROGRAMSRESIDENTNV_DECLARATION
#define NIV_GLAREPROGRAMSRESIDENTNV_DECLARATION
  nivenGLAREPROGRAMSRESIDENTNV glAreProgramsResidentNV;
#endif

#ifndef NIV_GLVERTEXATTRIB1DNV_DECLARATION
#define NIV_GLVERTEXATTRIB1DNV_DECLARATION
  nivenGLVERTEXATTRIB1DNV glVertexAttrib1dNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS3DVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS3DVNV_DECLARATION
  nivenGLVERTEXATTRIBS3DVNV glVertexAttribs3dvNV;
#endif

#ifndef NIV_GLDELETEPROGRAMSNV_DECLARATION
#define NIV_GLDELETEPROGRAMSNV_DECLARATION
  nivenGLDELETEPROGRAMSNV glDeleteProgramsNV;
#endif

#ifndef NIV_GLVERTEXATTRIBPOINTERNV_DECLARATION
#define NIV_GLVERTEXATTRIBPOINTERNV_DECLARATION
  nivenGLVERTEXATTRIBPOINTERNV glVertexAttribPointerNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS1SVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS1SVNV_DECLARATION
  nivenGLVERTEXATTRIBS1SVNV glVertexAttribs1svNV;
#endif

#ifndef NIV_GLVERTEXATTRIB2DNV_DECLARATION
#define NIV_GLVERTEXATTRIB2DNV_DECLARATION
  nivenGLVERTEXATTRIB2DNV glVertexAttrib2dNV;
#endif

#ifndef NIV_GLVERTEXATTRIB3DNV_DECLARATION
#define NIV_GLVERTEXATTRIB3DNV_DECLARATION
  nivenGLVERTEXATTRIB3DNV glVertexAttrib3dNV;
#endif

#ifndef NIV_GLVERTEXATTRIB1SVNV_DECLARATION
#define NIV_GLVERTEXATTRIB1SVNV_DECLARATION
  nivenGLVERTEXATTRIB1SVNV glVertexAttrib1svNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS3SVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS3SVNV_DECLARATION
  nivenGLVERTEXATTRIBS3SVNV glVertexAttribs3svNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS1DVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS1DVNV_DECLARATION
  nivenGLVERTEXATTRIBS1DVNV glVertexAttribs1dvNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS4FVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS4FVNV_DECLARATION
  nivenGLVERTEXATTRIBS4FVNV glVertexAttribs4fvNV;
#endif

#ifndef NIV_GLPROGRAMPARAMETER4FNV_DECLARATION
#define NIV_GLPROGRAMPARAMETER4FNV_DECLARATION
  nivenGLPROGRAMPARAMETER4FNV glProgramParameter4fNV;
#endif

#ifndef NIV_GLPROGRAMPARAMETERS4DVNV_DECLARATION
#define NIV_GLPROGRAMPARAMETERS4DVNV_DECLARATION
  nivenGLPROGRAMPARAMETERS4DVNV glProgramParameters4dvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB4UBNV_DECLARATION
#define NIV_GLVERTEXATTRIB4UBNV_DECLARATION
  nivenGLVERTEXATTRIB4UBNV glVertexAttrib4ubNV;
#endif

#ifndef NIV_GLGETPROGRAMIVNV_DECLARATION
#define NIV_GLGETPROGRAMIVNV_DECLARATION
  nivenGLGETPROGRAMIVNV glGetProgramivNV;
#endif

#ifndef NIV_GLVERTEXATTRIB4SVNV_DECLARATION
#define NIV_GLVERTEXATTRIB4SVNV_DECLARATION
  nivenGLVERTEXATTRIB4SVNV glVertexAttrib4svNV;
#endif

#ifndef NIV_GLVERTEXATTRIB4FVNV_DECLARATION
#define NIV_GLVERTEXATTRIB4FVNV_DECLARATION
  nivenGLVERTEXATTRIB4FVNV glVertexAttrib4fvNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS4SVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS4SVNV_DECLARATION
  nivenGLVERTEXATTRIBS4SVNV glVertexAttribs4svNV;
#endif

#ifndef NIV_GLLOADPROGRAMNV_DECLARATION
#define NIV_GLLOADPROGRAMNV_DECLARATION
  nivenGLLOADPROGRAMNV glLoadProgramNV;
#endif

#ifndef NIV_GLVERTEXATTRIB1FVNV_DECLARATION
#define NIV_GLVERTEXATTRIB1FVNV_DECLARATION
  nivenGLVERTEXATTRIB1FVNV glVertexAttrib1fvNV;
#endif

#ifndef NIV_GLEXECUTEPROGRAMNV_DECLARATION
#define NIV_GLEXECUTEPROGRAMNV_DECLARATION
  nivenGLEXECUTEPROGRAMNV glExecuteProgramNV;
#endif

#ifndef NIV_GLISPROGRAMNV_DECLARATION
#define NIV_GLISPROGRAMNV_DECLARATION
  nivenGLISPROGRAMNV glIsProgramNV;
#endif

#ifndef NIV_GLVERTEXATTRIB4DVNV_DECLARATION
#define NIV_GLVERTEXATTRIB4DVNV_DECLARATION
  nivenGLVERTEXATTRIB4DVNV glVertexAttrib4dvNV;
#endif

#ifndef NIV_GLPROGRAMPARAMETER4DNV_DECLARATION
#define NIV_GLPROGRAMPARAMETER4DNV_DECLARATION
  nivenGLPROGRAMPARAMETER4DNV glProgramParameter4dNV;
#endif

#ifndef NIV_GLVERTEXATTRIB2FNV_DECLARATION
#define NIV_GLVERTEXATTRIB2FNV_DECLARATION
  nivenGLVERTEXATTRIB2FNV glVertexAttrib2fNV;
#endif

#ifndef NIV_GLVERTEXATTRIB3FNV_DECLARATION
#define NIV_GLVERTEXATTRIB3FNV_DECLARATION
  nivenGLVERTEXATTRIB3FNV glVertexAttrib3fNV;
#endif

#ifndef NIV_GLVERTEXATTRIB1DVNV_DECLARATION
#define NIV_GLVERTEXATTRIB1DVNV_DECLARATION
  nivenGLVERTEXATTRIB1DVNV glVertexAttrib1dvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB1FNV_DECLARATION
#define NIV_GLVERTEXATTRIB1FNV_DECLARATION
  nivenGLVERTEXATTRIB1FNV glVertexAttrib1fNV;
#endif

#ifndef NIV_GLVERTEXATTRIB2DVNV_DECLARATION
#define NIV_GLVERTEXATTRIB2DVNV_DECLARATION
  nivenGLVERTEXATTRIB2DVNV glVertexAttrib2dvNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS1FVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS1FVNV_DECLARATION
  nivenGLVERTEXATTRIBS1FVNV glVertexAttribs1fvNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS2DVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS2DVNV_DECLARATION
  nivenGLVERTEXATTRIBS2DVNV glVertexAttribs2dvNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS2SVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS2SVNV_DECLARATION
  nivenGLVERTEXATTRIBS2SVNV glVertexAttribs2svNV;
#endif

#ifndef NIV_GLGETPROGRAMPARAMETERFVNV_DECLARATION
#define NIV_GLGETPROGRAMPARAMETERFVNV_DECLARATION
  nivenGLGETPROGRAMPARAMETERFVNV glGetProgramParameterfvNV;
#endif

#ifndef NIV_GLGETPROGRAMSTRINGNV_DECLARATION
#define NIV_GLGETPROGRAMSTRINGNV_DECLARATION
  nivenGLGETPROGRAMSTRINGNV glGetProgramStringNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS3FVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS3FVNV_DECLARATION
  nivenGLVERTEXATTRIBS3FVNV glVertexAttribs3fvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB4DNV_DECLARATION
#define NIV_GLVERTEXATTRIB4DNV_DECLARATION
  nivenGLVERTEXATTRIB4DNV glVertexAttrib4dNV;
#endif

#ifndef NIV_GLVERTEXATTRIB4UBVNV_DECLARATION
#define NIV_GLVERTEXATTRIB4UBVNV_DECLARATION
  nivenGLVERTEXATTRIB4UBVNV glVertexAttrib4ubvNV;
#endif

#ifndef NIV_GLGENPROGRAMSNV_DECLARATION
#define NIV_GLGENPROGRAMSNV_DECLARATION
  nivenGLGENPROGRAMSNV glGenProgramsNV;
#endif

#ifndef NIV_GLVERTEXATTRIB4SNV_DECLARATION
#define NIV_GLVERTEXATTRIB4SNV_DECLARATION
  nivenGLVERTEXATTRIB4SNV glVertexAttrib4sNV;
#endif

#ifndef NIV_GLREQUESTRESIDENTPROGRAMSNV_DECLARATION
#define NIV_GLREQUESTRESIDENTPROGRAMSNV_DECLARATION
  nivenGLREQUESTRESIDENTPROGRAMSNV glRequestResidentProgramsNV;
#endif

#ifndef NIV_GLVERTEXATTRIB3FVNV_DECLARATION
#define NIV_GLVERTEXATTRIB3FVNV_DECLARATION
  nivenGLVERTEXATTRIB3FVNV glVertexAttrib3fvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB1SNV_DECLARATION
#define NIV_GLVERTEXATTRIB1SNV_DECLARATION
  nivenGLVERTEXATTRIB1SNV glVertexAttrib1sNV;
#endif

#ifndef NIV_GLGETVERTEXATTRIBIVNV_DECLARATION
#define NIV_GLGETVERTEXATTRIBIVNV_DECLARATION
  nivenGLGETVERTEXATTRIBIVNV glGetVertexAttribivNV;
#endif

#ifndef NIV_GLVERTEXATTRIB3SVNV_DECLARATION
#define NIV_GLVERTEXATTRIB3SVNV_DECLARATION
  nivenGLVERTEXATTRIB3SVNV glVertexAttrib3svNV;
#endif

#ifndef NIV_GLPROGRAMPARAMETER4FVNV_DECLARATION
#define NIV_GLPROGRAMPARAMETER4FVNV_DECLARATION
  nivenGLPROGRAMPARAMETER4FVNV glProgramParameter4fvNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS4UBVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS4UBVNV_DECLARATION
  nivenGLVERTEXATTRIBS4UBVNV glVertexAttribs4ubvNV;
#endif

#ifndef NIV_GLGETVERTEXATTRIBDVNV_DECLARATION
#define NIV_GLGETVERTEXATTRIBDVNV_DECLARATION
  nivenGLGETVERTEXATTRIBDVNV glGetVertexAttribdvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB3DVNV_DECLARATION
#define NIV_GLVERTEXATTRIB3DVNV_DECLARATION
  nivenGLVERTEXATTRIB3DVNV glVertexAttrib3dvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB2FVNV_DECLARATION
#define NIV_GLVERTEXATTRIB2FVNV_DECLARATION
  nivenGLVERTEXATTRIB2FVNV glVertexAttrib2fvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB2SNV_DECLARATION
#define NIV_GLVERTEXATTRIB2SNV_DECLARATION
  nivenGLVERTEXATTRIB2SNV glVertexAttrib2sNV;
#endif

#ifndef NIV_GLPROGRAMPARAMETERS4FVNV_DECLARATION
#define NIV_GLPROGRAMPARAMETERS4FVNV_DECLARATION
  nivenGLPROGRAMPARAMETERS4FVNV glProgramParameters4fvNV;
#endif

#ifndef NIV_GLGETVERTEXATTRIBPOINTERVNV_DECLARATION
#define NIV_GLGETVERTEXATTRIBPOINTERVNV_DECLARATION
  nivenGLGETVERTEXATTRIBPOINTERVNV glGetVertexAttribPointervNV;
#endif

#ifndef NIV_GLVERTEXATTRIBS4DVNV_DECLARATION
#define NIV_GLVERTEXATTRIBS4DVNV_DECLARATION
  nivenGLVERTEXATTRIBS4DVNV glVertexAttribs4dvNV;
#endif

#ifndef NIV_GLVERTEXATTRIB2SVNV_DECLARATION
#define NIV_GLVERTEXATTRIB2SVNV_DECLARATION
  nivenGLVERTEXATTRIB2SVNV glVertexAttrib2svNV;
#endif

#ifndef NIV_GLPROGRAMPARAMETER4DVNV_DECLARATION
#define NIV_GLPROGRAMPARAMETER4DVNV_DECLARATION
  nivenGLPROGRAMPARAMETER4DVNV glProgramParameter4dvNV;
#endif


  // GL_SGIX_texture_multi_buffer

#ifdef _GLX
  // GLX_SGIS_blended_overlay
#endif // _GLX
  // GL_ARB_texture_rectangle

  // GL_SGI_texture_color_table

#ifdef _GLX
  // GLX_SGIX_visual_select_group
#endif // _GLX
  // GL_SGIS_pixel_texture

  // GL_ARB_multisample
#ifndef NIV_GLSAMPLECOVERAGEARB_DECLARATION
#define NIV_GLSAMPLECOVERAGEARB_DECLARATION
  nivenGLSAMPLECOVERAGEARB glSampleCoverageARB;
#endif


  // GL_SGIS_generate_mipmap

#ifdef _GLX
  // GLX_EXT_visual_rating
#endif // _GLX
  // GL_ATI_map_object_buffer
#ifndef NIV_GLMAPOBJECTBUFFERATI_DECLARATION
#define NIV_GLMAPOBJECTBUFFERATI_DECLARATION
  nivenGLMAPOBJECTBUFFERATI glMapObjectBufferATI;
#endif

#ifndef NIV_GLUNMAPOBJECTBUFFERATI_DECLARATION
#define NIV_GLUNMAPOBJECTBUFFERATI_DECLARATION
  nivenGLUNMAPOBJECTBUFFERATI glUnmapObjectBufferATI;
#endif


  // GL_EXT_texture_edge_clamp

#ifdef _GLX
  // GLX_MESA_agp_offset
#ifndef NIV_GLXGETAGPOFFSETMESA_DECLARATION
#define NIV_GLXGETAGPOFFSETMESA_DECLARATION
  nivenGLXGETAGPOFFSETMESA glXGetAGPOffsetMESA;
#endif

#endif // _GLX
  // GL_NV_light_max_exponent

  // GL_EXT_blend_minmax
#ifndef NIV_GLBLENDEQUATIONEXT_DECLARATION
#define NIV_GLBLENDEQUATIONEXT_DECLARATION
  nivenGLBLENDEQUATIONEXT glBlendEquationEXT;
#endif


  // GL_ARB_texture_float

  // GL_SUN_vertex
#ifndef NIV_GLCOLOR3FVERTEX3FVSUN_DECLARATION
#define NIV_GLCOLOR3FVERTEX3FVSUN_DECLARATION
  nivenGLCOLOR3FVERTEX3FVSUN glColor3fVertex3fvSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUN_DECLARATION
  nivenGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUN glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUIVERTEX3FSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUIVERTEX3FSUN_DECLARATION
  nivenGLREPLACEMENTCODEUIVERTEX3FSUN glReplacementCodeuiVertex3fSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FVSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FVSUN_DECLARATION
  nivenGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FVSUN glReplacementCodeuiColor4fNormal3fVertex3fvSUN;
#endif

#ifndef NIV_GLTEXCOORD4FVERTEX4FVSUN_DECLARATION
#define NIV_GLTEXCOORD4FVERTEX4FVSUN_DECLARATION
  nivenGLTEXCOORD4FVERTEX4FVSUN glTexCoord4fVertex4fvSUN;
#endif

#ifndef NIV_GLTEXCOORD2FCOLOR3FVERTEX3FSUN_DECLARATION
#define NIV_GLTEXCOORD2FCOLOR3FVERTEX3FSUN_DECLARATION
  nivenGLTEXCOORD2FCOLOR3FVERTEX3FSUN glTexCoord2fColor3fVertex3fSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FSUN_DECLARATION
  nivenGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FSUN glReplacementCodeuiColor4fNormal3fVertex3fSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUINORMAL3FVERTEX3FSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUINORMAL3FVERTEX3FSUN_DECLARATION
  nivenGLREPLACEMENTCODEUINORMAL3FVERTEX3FSUN glReplacementCodeuiNormal3fVertex3fSUN;
#endif

#ifndef NIV_GLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUN_DECLARATION
#define NIV_GLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUN_DECLARATION
  nivenGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUN glTexCoord2fColor4fNormal3fVertex3fvSUN;
#endif

#ifndef NIV_GLTEXCOORD2FNORMAL3FVERTEX3FSUN_DECLARATION
#define NIV_GLTEXCOORD2FNORMAL3FVERTEX3FSUN_DECLARATION
  nivenGLTEXCOORD2FNORMAL3FVERTEX3FSUN glTexCoord2fNormal3fVertex3fSUN;
#endif

#ifndef NIV_GLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FSUN_DECLARATION
#define NIV_GLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FSUN_DECLARATION
  nivenGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FSUN glTexCoord4fColor4fNormal3fVertex4fSUN;
#endif

#ifndef NIV_GLTEXCOORD2FCOLOR3FVERTEX3FVSUN_DECLARATION
#define NIV_GLTEXCOORD2FCOLOR3FVERTEX3FVSUN_DECLARATION
  nivenGLTEXCOORD2FCOLOR3FVERTEX3FVSUN glTexCoord2fColor3fVertex3fvSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUITEXCOORD2FVERTEX3FSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUITEXCOORD2FVERTEX3FSUN_DECLARATION
  nivenGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FSUN glReplacementCodeuiTexCoord2fVertex3fSUN;
#endif

#ifndef NIV_GLNORMAL3FVERTEX3FVSUN_DECLARATION
#define NIV_GLNORMAL3FVERTEX3FVSUN_DECLARATION
  nivenGLNORMAL3FVERTEX3FVSUN glNormal3fVertex3fvSUN;
#endif

#ifndef NIV_GLCOLOR4FNORMAL3FVERTEX3FSUN_DECLARATION
#define NIV_GLCOLOR4FNORMAL3FVERTEX3FSUN_DECLARATION
  nivenGLCOLOR4FNORMAL3FVERTEX3FSUN glColor4fNormal3fVertex3fSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUICOLOR3FVERTEX3FSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUICOLOR3FVERTEX3FSUN_DECLARATION
  nivenGLREPLACEMENTCODEUICOLOR3FVERTEX3FSUN glReplacementCodeuiColor3fVertex3fSUN;
#endif

#ifndef NIV_GLNORMAL3FVERTEX3FSUN_DECLARATION
#define NIV_GLNORMAL3FVERTEX3FSUN_DECLARATION
  nivenGLNORMAL3FVERTEX3FSUN glNormal3fVertex3fSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUICOLOR4UBVERTEX3FSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUICOLOR4UBVERTEX3FSUN_DECLARATION
  nivenGLREPLACEMENTCODEUICOLOR4UBVERTEX3FSUN glReplacementCodeuiColor4ubVertex3fSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUICOLOR4UBVERTEX3FVSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUICOLOR4UBVERTEX3FVSUN_DECLARATION
  nivenGLREPLACEMENTCODEUICOLOR4UBVERTEX3FVSUN glReplacementCodeuiColor4ubVertex3fvSUN;
#endif

#ifndef NIV_GLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FVSUN_DECLARATION
#define NIV_GLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FVSUN_DECLARATION
  nivenGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FVSUN glTexCoord4fColor4fNormal3fVertex4fvSUN;
#endif

#ifndef NIV_GLTEXCOORD2FCOLOR4UBVERTEX3FVSUN_DECLARATION
#define NIV_GLTEXCOORD2FCOLOR4UBVERTEX3FVSUN_DECLARATION
  nivenGLTEXCOORD2FCOLOR4UBVERTEX3FVSUN glTexCoord2fColor4ubVertex3fvSUN;
#endif

#ifndef NIV_GLTEXCOORD2FCOLOR4UBVERTEX3FSUN_DECLARATION
#define NIV_GLTEXCOORD2FCOLOR4UBVERTEX3FSUN_DECLARATION
  nivenGLTEXCOORD2FCOLOR4UBVERTEX3FSUN glTexCoord2fColor4ubVertex3fSUN;
#endif

#ifndef NIV_GLTEXCOORD4FVERTEX4FSUN_DECLARATION
#define NIV_GLTEXCOORD4FVERTEX4FSUN_DECLARATION
  nivenGLTEXCOORD4FVERTEX4FSUN glTexCoord4fVertex4fSUN;
#endif

#ifndef NIV_GLCOLOR4UBVERTEX2FSUN_DECLARATION
#define NIV_GLCOLOR4UBVERTEX2FSUN_DECLARATION
  nivenGLCOLOR4UBVERTEX2FSUN glColor4ubVertex2fSUN;
#endif

#ifndef NIV_GLCOLOR3FVERTEX3FSUN_DECLARATION
#define NIV_GLCOLOR3FVERTEX3FSUN_DECLARATION
  nivenGLCOLOR3FVERTEX3FSUN glColor3fVertex3fSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUIVERTEX3FVSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUIVERTEX3FVSUN_DECLARATION
  nivenGLREPLACEMENTCODEUIVERTEX3FVSUN glReplacementCodeuiVertex3fvSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FSUN_DECLARATION
  nivenGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FSUN glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUITEXCOORD2FVERTEX3FVSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUITEXCOORD2FVERTEX3FVSUN_DECLARATION
  nivenGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FVSUN glReplacementCodeuiTexCoord2fVertex3fvSUN;
#endif

#ifndef NIV_GLTEXCOORD2FVERTEX3FVSUN_DECLARATION
#define NIV_GLTEXCOORD2FVERTEX3FVSUN_DECLARATION
  nivenGLTEXCOORD2FVERTEX3FVSUN glTexCoord2fVertex3fvSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUINORMAL3FVERTEX3FVSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUINORMAL3FVERTEX3FVSUN_DECLARATION
  nivenGLREPLACEMENTCODEUINORMAL3FVERTEX3FVSUN glReplacementCodeuiNormal3fVertex3fvSUN;
#endif

#ifndef NIV_GLCOLOR4UBVERTEX2FVSUN_DECLARATION
#define NIV_GLCOLOR4UBVERTEX2FVSUN_DECLARATION
  nivenGLCOLOR4UBVERTEX2FVSUN glColor4ubVertex2fvSUN;
#endif

#ifndef NIV_GLCOLOR4UBVERTEX3FVSUN_DECLARATION
#define NIV_GLCOLOR4UBVERTEX3FVSUN_DECLARATION
  nivenGLCOLOR4UBVERTEX3FVSUN glColor4ubVertex3fvSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUN_DECLARATION
  nivenGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUN glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN;
#endif

#ifndef NIV_GLTEXCOORD2FNORMAL3FVERTEX3FVSUN_DECLARATION
#define NIV_GLTEXCOORD2FNORMAL3FVERTEX3FVSUN_DECLARATION
  nivenGLTEXCOORD2FNORMAL3FVERTEX3FVSUN glTexCoord2fNormal3fVertex3fvSUN;
#endif

#ifndef NIV_GLCOLOR4FNORMAL3FVERTEX3FVSUN_DECLARATION
#define NIV_GLCOLOR4FNORMAL3FVERTEX3FVSUN_DECLARATION
  nivenGLCOLOR4FNORMAL3FVERTEX3FVSUN glColor4fNormal3fVertex3fvSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FVSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FVSUN_DECLARATION
  nivenGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FVSUN glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN;
#endif

#ifndef NIV_GLREPLACEMENTCODEUICOLOR3FVERTEX3FVSUN_DECLARATION
#define NIV_GLREPLACEMENTCODEUICOLOR3FVERTEX3FVSUN_DECLARATION
  nivenGLREPLACEMENTCODEUICOLOR3FVERTEX3FVSUN glReplacementCodeuiColor3fVertex3fvSUN;
#endif

#ifndef NIV_GLCOLOR4UBVERTEX3FSUN_DECLARATION
#define NIV_GLCOLOR4UBVERTEX3FSUN_DECLARATION
  nivenGLCOLOR4UBVERTEX3FSUN glColor4ubVertex3fSUN;
#endif

#ifndef NIV_GLTEXCOORD2FVERTEX3FSUN_DECLARATION
#define NIV_GLTEXCOORD2FVERTEX3FSUN_DECLARATION
  nivenGLTEXCOORD2FVERTEX3FSUN glTexCoord2fVertex3fSUN;
#endif

#ifndef NIV_GLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUN_DECLARATION
#define NIV_GLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUN_DECLARATION
  nivenGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUN glTexCoord2fColor4fNormal3fVertex3fSUN;
#endif


  // GL_ARB_texture_env_crossbar

  // GL_SGIS_texture_lod

  // GL_MESA_pack_invert

  // GL_ATIX_texture_env_route

#ifdef _GLX
  // GLX_MESA_release_buffers
#ifndef NIV_GLXRELEASEBUFFERSMESA_DECLARATION
#define NIV_GLXRELEASEBUFFERSMESA_DECLARATION
  nivenGLXRELEASEBUFFERSMESA glXReleaseBuffersMESA;
#endif

#endif // _GLX
  // GL_SGIS_sharpen_texture
#ifndef NIV_GLGETSHARPENTEXFUNCSGIS_DECLARATION
#define NIV_GLGETSHARPENTEXFUNCSGIS_DECLARATION
  nivenGLGETSHARPENTEXFUNCSGIS glGetSharpenTexFuncSGIS;
#endif

#ifndef NIV_GLSHARPENTEXFUNCSGIS_DECLARATION
#define NIV_GLSHARPENTEXFUNCSGIS_DECLARATION
  nivenGLSHARPENTEXFUNCSGIS glSharpenTexFuncSGIS;
#endif


  // GL_SGIX_texture_range

  // GL_EXT_texture_rectangle

  // GL_EXT_blend_logic_op

  // GL_SGIS_fog_function
#ifndef NIV_GLGETFOGFUNCSGIS_DECLARATION
#define NIV_GLGETFOGFUNCSGIS_DECLARATION
  nivenGLGETFOGFUNCSGIS glGetFogFuncSGIS;
#endif

#ifndef NIV_GLFOGFUNCSGIS_DECLARATION
#define NIV_GLFOGFUNCSGIS_DECLARATION
  nivenGLFOGFUNCSGIS glFogFuncSGIS;
#endif


#ifdef _GLX
  // GLX_SUN_video_resize
#ifndef NIV_GLXGETVIDEORESIZESUN_DECLARATION
#define NIV_GLXGETVIDEORESIZESUN_DECLARATION
  nivenGLXGETVIDEORESIZESUN glXGetVideoResizeSUN;
#endif

#ifndef NIV_GLXVIDEORESIZESUN_DECLARATION
#define NIV_GLXVIDEORESIZESUN_DECLARATION
  nivenGLXVIDEORESIZESUN glXVideoResizeSUN;
#endif

#endif // _GLX
  // GL_IBM_cull_vertex

  // GL_PGI_vertex_hints

  // GL_GREMEDY_string_marker
#ifndef NIV_GLSTRINGMARKERGREMEDY_DECLARATION
#define NIV_GLSTRINGMARKERGREMEDY_DECLARATION
  nivenGLSTRINGMARKERGREMEDY glStringMarkerGREMEDY;
#endif


#ifdef _GLX
  // GLX_SGIS_color_range
#endif // _GLX
  // GL_EXT_subtexture
#ifndef NIV_GLTEXSUBIMAGE1DEXT_DECLARATION
#define NIV_GLTEXSUBIMAGE1DEXT_DECLARATION
  nivenGLTEXSUBIMAGE1DEXT glTexSubImage1DEXT;
#endif

#ifndef NIV_GLTEXSUBIMAGE2DEXT_DECLARATION
#define NIV_GLTEXSUBIMAGE2DEXT_DECLARATION
  nivenGLTEXSUBIMAGE2DEXT glTexSubImage2DEXT;
#endif

#ifndef NIV_GLTEXSUBIMAGE3DEXT_DECLARATION
#define NIV_GLTEXSUBIMAGE3DEXT_DECLARATION
  nivenGLTEXSUBIMAGE3DEXT glTexSubImage3DEXT;
#endif


  // GL_WIN_swap_hint
#ifndef NIV_GLADDSWAPHINTRECTWIN_DECLARATION
#define NIV_GLADDSWAPHINTRECTWIN_DECLARATION
  nivenGLADDSWAPHINTRECTWIN glAddSwapHintRectWIN;
#endif


  // GL_ARB_color_buffer_float
#ifndef NIV_GLCLAMPCOLORARB_DECLARATION
#define NIV_GLCLAMPCOLORARB_DECLARATION
  nivenGLCLAMPCOLORARB glClampColorARB;
#endif


  // GL_EXT_pixel_transform_color_table

#ifdef _GLX
  // GLX_ARB_fbconfig_float
#endif // _GLX
  // GL_ARB_window_pos
#ifndef NIV_GLWINDOWPOS2SARB_DECLARATION
#define NIV_GLWINDOWPOS2SARB_DECLARATION
  nivenGLWINDOWPOS2SARB glWindowPos2sARB;
#endif

#ifndef NIV_GLWINDOWPOS2SVARB_DECLARATION
#define NIV_GLWINDOWPOS2SVARB_DECLARATION
  nivenGLWINDOWPOS2SVARB glWindowPos2svARB;
#endif

#ifndef NIV_GLWINDOWPOS3FARB_DECLARATION
#define NIV_GLWINDOWPOS3FARB_DECLARATION
  nivenGLWINDOWPOS3FARB glWindowPos3fARB;
#endif

#ifndef NIV_GLWINDOWPOS2FVARB_DECLARATION
#define NIV_GLWINDOWPOS2FVARB_DECLARATION
  nivenGLWINDOWPOS2FVARB glWindowPos2fvARB;
#endif

#ifndef NIV_GLWINDOWPOS2DARB_DECLARATION
#define NIV_GLWINDOWPOS2DARB_DECLARATION
  nivenGLWINDOWPOS2DARB glWindowPos2dARB;
#endif

#ifndef NIV_GLWINDOWPOS2FARB_DECLARATION
#define NIV_GLWINDOWPOS2FARB_DECLARATION
  nivenGLWINDOWPOS2FARB glWindowPos2fARB;
#endif

#ifndef NIV_GLWINDOWPOS3DARB_DECLARATION
#define NIV_GLWINDOWPOS3DARB_DECLARATION
  nivenGLWINDOWPOS3DARB glWindowPos3dARB;
#endif

#ifndef NIV_GLWINDOWPOS3SARB_DECLARATION
#define NIV_GLWINDOWPOS3SARB_DECLARATION
  nivenGLWINDOWPOS3SARB glWindowPos3sARB;
#endif

#ifndef NIV_GLWINDOWPOS3SVARB_DECLARATION
#define NIV_GLWINDOWPOS3SVARB_DECLARATION
  nivenGLWINDOWPOS3SVARB glWindowPos3svARB;
#endif

#ifndef NIV_GLWINDOWPOS2IARB_DECLARATION
#define NIV_GLWINDOWPOS2IARB_DECLARATION
  nivenGLWINDOWPOS2IARB glWindowPos2iARB;
#endif

#ifndef NIV_GLWINDOWPOS2IVARB_DECLARATION
#define NIV_GLWINDOWPOS2IVARB_DECLARATION
  nivenGLWINDOWPOS2IVARB glWindowPos2ivARB;
#endif

#ifndef NIV_GLWINDOWPOS3IVARB_DECLARATION
#define NIV_GLWINDOWPOS3IVARB_DECLARATION
  nivenGLWINDOWPOS3IVARB glWindowPos3ivARB;
#endif

#ifndef NIV_GLWINDOWPOS3IARB_DECLARATION
#define NIV_GLWINDOWPOS3IARB_DECLARATION
  nivenGLWINDOWPOS3IARB glWindowPos3iARB;
#endif

#ifndef NIV_GLWINDOWPOS3FVARB_DECLARATION
#define NIV_GLWINDOWPOS3FVARB_DECLARATION
  nivenGLWINDOWPOS3FVARB glWindowPos3fvARB;
#endif

#ifndef NIV_GLWINDOWPOS2DVARB_DECLARATION
#define NIV_GLWINDOWPOS2DVARB_DECLARATION
  nivenGLWINDOWPOS2DVARB glWindowPos2dvARB;
#endif

#ifndef NIV_GLWINDOWPOS3DVARB_DECLARATION
#define NIV_GLWINDOWPOS3DVARB_DECLARATION
  nivenGLWINDOWPOS3DVARB glWindowPos3dvARB;
#endif


  // GL_NV_fragment_program2

  // GL_ARB_shadow

  // GL_ARB_texture_mirrored_repeat

#ifdef _GLX
  // GLX_SGIX_video_resize
#ifndef NIV_GLXCHANNELRECTSGIX_DECLARATION
#define NIV_GLXCHANNELRECTSGIX_DECLARATION
  nivenGLXCHANNELRECTSGIX glXChannelRectSGIX;
#endif

#ifndef NIV_GLXQUERYCHANNELRECTSGIX_DECLARATION
#define NIV_GLXQUERYCHANNELRECTSGIX_DECLARATION
  nivenGLXQUERYCHANNELRECTSGIX glXQueryChannelRectSGIX;
#endif

#ifndef NIV_GLXBINDCHANNELTOWINDOWSGIX_DECLARATION
#define NIV_GLXBINDCHANNELTOWINDOWSGIX_DECLARATION
  nivenGLXBINDCHANNELTOWINDOWSGIX glXBindChannelToWindowSGIX;
#endif

#ifndef NIV_GLXCHANNELRECTSYNCSGIX_DECLARATION
#define NIV_GLXCHANNELRECTSYNCSGIX_DECLARATION
  nivenGLXCHANNELRECTSYNCSGIX glXChannelRectSyncSGIX;
#endif

#ifndef NIV_GLXQUERYCHANNELDELTASSGIX_DECLARATION
#define NIV_GLXQUERYCHANNELDELTASSGIX_DECLARATION
  nivenGLXQUERYCHANNELDELTASSGIX glXQueryChannelDeltasSGIX;
#endif

#endif // _GLX
#ifdef WIN32
  // WGL_I3D_swap_frame_usage
#ifndef NIV_WGLGETFRAMEUSAGEI3D_DECLARATION
#define NIV_WGLGETFRAMEUSAGEI3D_DECLARATION
  nivenWGLGETFRAMEUSAGEI3D wglGetFrameUsageI3D;
#endif

#ifndef NIV_WGLENDFRAMETRACKINGI3D_DECLARATION
#define NIV_WGLENDFRAMETRACKINGI3D_DECLARATION
  nivenWGLENDFRAMETRACKINGI3D wglEndFrameTrackingI3D;
#endif

#ifndef NIV_WGLBEGINFRAMETRACKINGI3D_DECLARATION
#define NIV_WGLBEGINFRAMETRACKINGI3D_DECLARATION
  nivenWGLBEGINFRAMETRACKINGI3D wglBeginFrameTrackingI3D;
#endif

#ifndef NIV_WGLQUERYFRAMETRACKINGI3D_DECLARATION
#define NIV_WGLQUERYFRAMETRACKINGI3D_DECLARATION
  nivenWGLQUERYFRAMETRACKINGI3D wglQueryFrameTrackingI3D;
#endif

#endif
  // GL_PGI_misc_hints

  // GL_NV_evaluators
#ifndef NIV_GLGETMAPPARAMETERIVNV_DECLARATION
#define NIV_GLGETMAPPARAMETERIVNV_DECLARATION
  nivenGLGETMAPPARAMETERIVNV glGetMapParameterivNV;
#endif

#ifndef NIV_GLMAPCONTROLPOINTSNV_DECLARATION
#define NIV_GLMAPCONTROLPOINTSNV_DECLARATION
  nivenGLMAPCONTROLPOINTSNV glMapControlPointsNV;
#endif

#ifndef NIV_GLGETMAPATTRIBPARAMETERIVNV_DECLARATION
#define NIV_GLGETMAPATTRIBPARAMETERIVNV_DECLARATION
  nivenGLGETMAPATTRIBPARAMETERIVNV glGetMapAttribParameterivNV;
#endif

#ifndef NIV_GLGETMAPCONTROLPOINTSNV_DECLARATION
#define NIV_GLGETMAPCONTROLPOINTSNV_DECLARATION
  nivenGLGETMAPCONTROLPOINTSNV glGetMapControlPointsNV;
#endif

#ifndef NIV_GLGETMAPPARAMETERFVNV_DECLARATION
#define NIV_GLGETMAPPARAMETERFVNV_DECLARATION
  nivenGLGETMAPPARAMETERFVNV glGetMapParameterfvNV;
#endif

#ifndef NIV_GLEVALMAPSNV_DECLARATION
#define NIV_GLEVALMAPSNV_DECLARATION
  nivenGLEVALMAPSNV glEvalMapsNV;
#endif

#ifndef NIV_GLMAPPARAMETERFVNV_DECLARATION
#define NIV_GLMAPPARAMETERFVNV_DECLARATION
  nivenGLMAPPARAMETERFVNV glMapParameterfvNV;
#endif

#ifndef NIV_GLGETMAPATTRIBPARAMETERFVNV_DECLARATION
#define NIV_GLGETMAPATTRIBPARAMETERFVNV_DECLARATION
  nivenGLGETMAPATTRIBPARAMETERFVNV glGetMapAttribParameterfvNV;
#endif

#ifndef NIV_GLMAPPARAMETERIVNV_DECLARATION
#define NIV_GLMAPPARAMETERIVNV_DECLARATION
  nivenGLMAPPARAMETERIVNV glMapParameterivNV;
#endif


  // GL_INTEL_texture_scissor
#ifndef NIV_GLTEXSCISSORFUNCINTEL_DECLARATION
#define NIV_GLTEXSCISSORFUNCINTEL_DECLARATION
  nivenGLTEXSCISSORFUNCINTEL glTexScissorFuncINTEL;
#endif

#ifndef NIV_GLTEXSCISSORINTEL_DECLARATION
#define NIV_GLTEXSCISSORINTEL_DECLARATION
  nivenGLTEXSCISSORINTEL glTexScissorINTEL;
#endif


  // GL_NV_texture_compression_vtc

  // GL_SGIS_texture_filter4
#ifndef NIV_GLTEXFILTERFUNCSGIS_DECLARATION
#define NIV_GLTEXFILTERFUNCSGIS_DECLARATION
  nivenGLTEXFILTERFUNCSGIS glTexFilterFuncSGIS;
#endif

#ifndef NIV_GLGETTEXFILTERFUNCSGIS_DECLARATION
#define NIV_GLGETTEXFILTERFUNCSGIS_DECLARATION
  nivenGLGETTEXFILTERFUNCSGIS glGetTexFilterFuncSGIS;
#endif


#ifdef _GLX
  // GLX_OML_swap_method
#endif // _GLX
  // GL_EXT_copy_texture
#ifndef NIV_GLCOPYTEXIMAGE2DEXT_DECLARATION
#define NIV_GLCOPYTEXIMAGE2DEXT_DECLARATION
  nivenGLCOPYTEXIMAGE2DEXT glCopyTexImage2DEXT;
#endif

#ifndef NIV_GLCOPYTEXSUBIMAGE2DEXT_DECLARATION
#define NIV_GLCOPYTEXSUBIMAGE2DEXT_DECLARATION
  nivenGLCOPYTEXSUBIMAGE2DEXT glCopyTexSubImage2DEXT;
#endif

#ifndef NIV_GLCOPYTEXSUBIMAGE1DEXT_DECLARATION
#define NIV_GLCOPYTEXSUBIMAGE1DEXT_DECLARATION
  nivenGLCOPYTEXSUBIMAGE1DEXT glCopyTexSubImage1DEXT;
#endif

#ifndef NIV_GLCOPYTEXIMAGE1DEXT_DECLARATION
#define NIV_GLCOPYTEXIMAGE1DEXT_DECLARATION
  nivenGLCOPYTEXIMAGE1DEXT glCopyTexImage1DEXT;
#endif

#ifndef NIV_GLCOPYTEXSUBIMAGE3DEXT_DECLARATION
#define NIV_GLCOPYTEXSUBIMAGE3DEXT_DECLARATION
  nivenGLCOPYTEXSUBIMAGE3DEXT glCopyTexSubImage3DEXT;
#endif


  // GL_NV_register_combiners2
#ifndef NIV_GLGETCOMBINERSTAGEPARAMETERFVNV_DECLARATION
#define NIV_GLGETCOMBINERSTAGEPARAMETERFVNV_DECLARATION
  nivenGLGETCOMBINERSTAGEPARAMETERFVNV glGetCombinerStageParameterfvNV;
#endif

#ifndef NIV_GLCOMBINERSTAGEPARAMETERFVNV_DECLARATION
#define NIV_GLCOMBINERSTAGEPARAMETERFVNV_DECLARATION
  nivenGLCOMBINERSTAGEPARAMETERFVNV glCombinerStageParameterfvNV;
#endif


  // GL_EXT_fragment_lighting
#ifndef NIV_GLFRAGMENTLIGHTFVEXT_DECLARATION
#define NIV_GLFRAGMENTLIGHTFVEXT_DECLARATION
  nivenGLFRAGMENTLIGHTFVEXT glFragmentLightfvEXT;
#endif

#ifndef NIV_GLGETFRAGMENTLIGHTFVEXT_DECLARATION
#define NIV_GLGETFRAGMENTLIGHTFVEXT_DECLARATION
  nivenGLGETFRAGMENTLIGHTFVEXT glGetFragmentLightfvEXT;
#endif

#ifndef NIV_GLGETFRAGMENTLIGHTIVEXT_DECLARATION
#define NIV_GLGETFRAGMENTLIGHTIVEXT_DECLARATION
  nivenGLGETFRAGMENTLIGHTIVEXT glGetFragmentLightivEXT;
#endif

#ifndef NIV_GLFRAGMENTLIGHTFEXT_DECLARATION
#define NIV_GLFRAGMENTLIGHTFEXT_DECLARATION
  nivenGLFRAGMENTLIGHTFEXT glFragmentLightfEXT;
#endif

#ifndef NIV_GLLIGHTENVIEXT_DECLARATION
#define NIV_GLLIGHTENVIEXT_DECLARATION
  nivenGLLIGHTENVIEXT glLightEnviEXT;
#endif

#ifndef NIV_GLFRAGMENTLIGHTIEXT_DECLARATION
#define NIV_GLFRAGMENTLIGHTIEXT_DECLARATION
  nivenGLFRAGMENTLIGHTIEXT glFragmentLightiEXT;
#endif

#ifndef NIV_GLFRAGMENTMATERIALFVEXT_DECLARATION
#define NIV_GLFRAGMENTMATERIALFVEXT_DECLARATION
  nivenGLFRAGMENTMATERIALFVEXT glFragmentMaterialfvEXT;
#endif

#ifndef NIV_GLFRAGMENTMATERIALFEXT_DECLARATION
#define NIV_GLFRAGMENTMATERIALFEXT_DECLARATION
  nivenGLFRAGMENTMATERIALFEXT glFragmentMaterialfEXT;
#endif

#ifndef NIV_GLFRAGMENTCOLORMATERIALEXT_DECLARATION
#define NIV_GLFRAGMENTCOLORMATERIALEXT_DECLARATION
  nivenGLFRAGMENTCOLORMATERIALEXT glFragmentColorMaterialEXT;
#endif

#ifndef NIV_GLFRAGMENTLIGHTMODELFVEXT_DECLARATION
#define NIV_GLFRAGMENTLIGHTMODELFVEXT_DECLARATION
  nivenGLFRAGMENTLIGHTMODELFVEXT glFragmentLightModelfvEXT;
#endif

#ifndef NIV_GLFRAGMENTLIGHTMODELIVEXT_DECLARATION
#define NIV_GLFRAGMENTLIGHTMODELIVEXT_DECLARATION
  nivenGLFRAGMENTLIGHTMODELIVEXT glFragmentLightModelivEXT;
#endif

#ifndef NIV_GLFRAGMENTLIGHTIVEXT_DECLARATION
#define NIV_GLFRAGMENTLIGHTIVEXT_DECLARATION
  nivenGLFRAGMENTLIGHTIVEXT glFragmentLightivEXT;
#endif

#ifndef NIV_GLFRAGMENTLIGHTMODELIEXT_DECLARATION
#define NIV_GLFRAGMENTLIGHTMODELIEXT_DECLARATION
  nivenGLFRAGMENTLIGHTMODELIEXT glFragmentLightModeliEXT;
#endif

#ifndef NIV_GLFRAGMENTMATERIALIVEXT_DECLARATION
#define NIV_GLFRAGMENTMATERIALIVEXT_DECLARATION
  nivenGLFRAGMENTMATERIALIVEXT glFragmentMaterialivEXT;
#endif

#ifndef NIV_GLGETFRAGMENTMATERIALIVEXT_DECLARATION
#define NIV_GLGETFRAGMENTMATERIALIVEXT_DECLARATION
  nivenGLGETFRAGMENTMATERIALIVEXT glGetFragmentMaterialivEXT;
#endif

#ifndef NIV_GLFRAGMENTLIGHTMODELFEXT_DECLARATION
#define NIV_GLFRAGMENTLIGHTMODELFEXT_DECLARATION
  nivenGLFRAGMENTLIGHTMODELFEXT glFragmentLightModelfEXT;
#endif

#ifndef NIV_GLFRAGMENTMATERIALIEXT_DECLARATION
#define NIV_GLFRAGMENTMATERIALIEXT_DECLARATION
  nivenGLFRAGMENTMATERIALIEXT glFragmentMaterialiEXT;
#endif

#ifndef NIV_GLGETFRAGMENTMATERIALFVEXT_DECLARATION
#define NIV_GLGETFRAGMENTMATERIALFVEXT_DECLARATION
  nivenGLGETFRAGMENTMATERIALFVEXT glGetFragmentMaterialfvEXT;
#endif


  // GL_SGIX_interlace

  // GL_NV_vertex_program1_1

  // GL_EXT_rescale_normal

#ifdef _GLX
  // GLX_ATI_render_texture
#ifndef NIV_GLXBINDTEXIMAGEATI_DECLARATION
#define NIV_GLXBINDTEXIMAGEATI_DECLARATION
  nivenGLXBINDTEXIMAGEATI glXBindTexImageATI;
#endif

#ifndef NIV_GLXRELEASETEXIMAGEATI_DECLARATION
#define NIV_GLXRELEASETEXIMAGEATI_DECLARATION
  nivenGLXRELEASETEXIMAGEATI glXReleaseTexImageATI;
#endif

#ifndef NIV_GLXDRAWABLEATTRIBATI_DECLARATION
#define NIV_GLXDRAWABLEATTRIBATI_DECLARATION
  nivenGLXDRAWABLEATTRIBATI glXDrawableAttribATI;
#endif

#endif // _GLX
  // GL_HP_convolution_border_modes

  // GL_SGI_color_table
#ifndef NIV_GLCOLORTABLEPARAMETERFVSGI_DECLARATION
#define NIV_GLCOLORTABLEPARAMETERFVSGI_DECLARATION
  nivenGLCOLORTABLEPARAMETERFVSGI glColorTableParameterfvSGI;
#endif

#ifndef NIV_GLCOPYCOLORTABLESGI_DECLARATION
#define NIV_GLCOPYCOLORTABLESGI_DECLARATION
  nivenGLCOPYCOLORTABLESGI glCopyColorTableSGI;
#endif

#ifndef NIV_GLGETCOLORTABLEPARAMETERIVSGI_DECLARATION
#define NIV_GLGETCOLORTABLEPARAMETERIVSGI_DECLARATION
  nivenGLGETCOLORTABLEPARAMETERIVSGI glGetColorTableParameterivSGI;
#endif

#ifndef NIV_GLGETCOLORTABLESGI_DECLARATION
#define NIV_GLGETCOLORTABLESGI_DECLARATION
  nivenGLGETCOLORTABLESGI glGetColorTableSGI;
#endif

#ifndef NIV_GLCOLORTABLESGI_DECLARATION
#define NIV_GLCOLORTABLESGI_DECLARATION
  nivenGLCOLORTABLESGI glColorTableSGI;
#endif

#ifndef NIV_GLGETCOLORTABLEPARAMETERFVSGI_DECLARATION
#define NIV_GLGETCOLORTABLEPARAMETERFVSGI_DECLARATION
  nivenGLGETCOLORTABLEPARAMETERFVSGI glGetColorTableParameterfvSGI;
#endif

#ifndef NIV_GLCOLORTABLEPARAMETERIVSGI_DECLARATION
#define NIV_GLCOLORTABLEPARAMETERIVSGI_DECLARATION
  nivenGLCOLORTABLEPARAMETERIVSGI glColorTableParameterivSGI;
#endif


  // GL_SGIX_resample

  // GL_SGIX_ir_instrument1

  // GL_SGIX_list_priority

  // GL_SGIX_framezoom
#ifndef NIV_GLFRAMEZOOMSGIX_DECLARATION
#define NIV_GLFRAMEZOOMSGIX_DECLARATION
  nivenGLFRAMEZOOMSGIX glFrameZoomSGIX;
#endif


  // GL_EXT_index_material
#ifndef NIV_GLINDEXMATERIALEXT_DECLARATION
#define NIV_GLINDEXMATERIALEXT_DECLARATION
  nivenGLINDEXMATERIALEXT glIndexMaterialEXT;
#endif


  // GL_SGIS_texture4D
#ifndef NIV_GLTEXSUBIMAGE4DSGIS_DECLARATION
#define NIV_GLTEXSUBIMAGE4DSGIS_DECLARATION
  nivenGLTEXSUBIMAGE4DSGIS glTexSubImage4DSGIS;
#endif

#ifndef NIV_GLTEXIMAGE4DSGIS_DECLARATION
#define NIV_GLTEXIMAGE4DSGIS_DECLARATION
  nivenGLTEXIMAGE4DSGIS glTexImage4DSGIS;
#endif


  // GL_EXT_texture3D
#ifndef NIV_GLTEXIMAGE3DEXT_DECLARATION
#define NIV_GLTEXIMAGE3DEXT_DECLARATION
  nivenGLTEXIMAGE3DEXT glTexImage3DEXT;
#endif


  // GL_REND_screen_coordinates

  // GL_ARB_multitexture
#ifndef NIV_GLMULTITEXCOORD2SVARB_DECLARATION
#define NIV_GLMULTITEXCOORD2SVARB_DECLARATION
  nivenGLMULTITEXCOORD2SVARB glMultiTexCoord2svARB;
#endif

#ifndef NIV_GLMULTITEXCOORD1IVARB_DECLARATION
#define NIV_GLMULTITEXCOORD1IVARB_DECLARATION
  nivenGLMULTITEXCOORD1IVARB glMultiTexCoord1ivARB;
#endif

#ifndef NIV_GLMULTITEXCOORD4FARB_DECLARATION
#define NIV_GLMULTITEXCOORD4FARB_DECLARATION
  nivenGLMULTITEXCOORD4FARB glMultiTexCoord4fARB;
#endif

#ifndef NIV_GLMULTITEXCOORD4FVARB_DECLARATION
#define NIV_GLMULTITEXCOORD4FVARB_DECLARATION
  nivenGLMULTITEXCOORD4FVARB glMultiTexCoord4fvARB;
#endif

#ifndef NIV_GLCLIENTACTIVETEXTUREARB_DECLARATION
#define NIV_GLCLIENTACTIVETEXTUREARB_DECLARATION
  nivenGLCLIENTACTIVETEXTUREARB glClientActiveTextureARB;
#endif

#ifndef NIV_GLMULTITEXCOORD3SVARB_DECLARATION
#define NIV_GLMULTITEXCOORD3SVARB_DECLARATION
  nivenGLMULTITEXCOORD3SVARB glMultiTexCoord3svARB;
#endif

#ifndef NIV_GLMULTITEXCOORD4SARB_DECLARATION
#define NIV_GLMULTITEXCOORD4SARB_DECLARATION
  nivenGLMULTITEXCOORD4SARB glMultiTexCoord4sARB;
#endif

#ifndef NIV_GLMULTITEXCOORD4DVARB_DECLARATION
#define NIV_GLMULTITEXCOORD4DVARB_DECLARATION
  nivenGLMULTITEXCOORD4DVARB glMultiTexCoord4dvARB;
#endif

#ifndef NIV_GLMULTITEXCOORD1FARB_DECLARATION
#define NIV_GLMULTITEXCOORD1FARB_DECLARATION
  nivenGLMULTITEXCOORD1FARB glMultiTexCoord1fARB;
#endif

#ifndef NIV_GLMULTITEXCOORD2FVARB_DECLARATION
#define NIV_GLMULTITEXCOORD2FVARB_DECLARATION
  nivenGLMULTITEXCOORD2FVARB glMultiTexCoord2fvARB;
#endif

#ifndef NIV_GLMULTITEXCOORD3IARB_DECLARATION
#define NIV_GLMULTITEXCOORD3IARB_DECLARATION
  nivenGLMULTITEXCOORD3IARB glMultiTexCoord3iARB;
#endif

#ifndef NIV_GLMULTITEXCOORD1DVARB_DECLARATION
#define NIV_GLMULTITEXCOORD1DVARB_DECLARATION
  nivenGLMULTITEXCOORD1DVARB glMultiTexCoord1dvARB;
#endif

#ifndef NIV_GLMULTITEXCOORD3DARB_DECLARATION
#define NIV_GLMULTITEXCOORD3DARB_DECLARATION
  nivenGLMULTITEXCOORD3DARB glMultiTexCoord3dARB;
#endif

#ifndef NIV_GLMULTITEXCOORD4SVARB_DECLARATION
#define NIV_GLMULTITEXCOORD4SVARB_DECLARATION
  nivenGLMULTITEXCOORD4SVARB glMultiTexCoord4svARB;
#endif

#ifndef NIV_GLMULTITEXCOORD2SARB_DECLARATION
#define NIV_GLMULTITEXCOORD2SARB_DECLARATION
  nivenGLMULTITEXCOORD2SARB glMultiTexCoord2sARB;
#endif

#ifndef NIV_GLMULTITEXCOORD3SARB_DECLARATION
#define NIV_GLMULTITEXCOORD3SARB_DECLARATION
  nivenGLMULTITEXCOORD3SARB glMultiTexCoord3sARB;
#endif

#ifndef NIV_GLMULTITEXCOORD2DVARB_DECLARATION
#define NIV_GLMULTITEXCOORD2DVARB_DECLARATION
  nivenGLMULTITEXCOORD2DVARB glMultiTexCoord2dvARB;
#endif

#ifndef NIV_GLMULTITEXCOORD3IVARB_DECLARATION
#define NIV_GLMULTITEXCOORD3IVARB_DECLARATION
  nivenGLMULTITEXCOORD3IVARB glMultiTexCoord3ivARB;
#endif

#ifndef NIV_GLMULTITEXCOORD1FVARB_DECLARATION
#define NIV_GLMULTITEXCOORD1FVARB_DECLARATION
  nivenGLMULTITEXCOORD1FVARB glMultiTexCoord1fvARB;
#endif

#ifndef NIV_GLMULTITEXCOORD1SARB_DECLARATION
#define NIV_GLMULTITEXCOORD1SARB_DECLARATION
  nivenGLMULTITEXCOORD1SARB glMultiTexCoord1sARB;
#endif

#ifndef NIV_GLMULTITEXCOORD1SVARB_DECLARATION
#define NIV_GLMULTITEXCOORD1SVARB_DECLARATION
  nivenGLMULTITEXCOORD1SVARB glMultiTexCoord1svARB;
#endif

#ifndef NIV_GLACTIVETEXTUREARB_DECLARATION
#define NIV_GLACTIVETEXTUREARB_DECLARATION
  nivenGLACTIVETEXTUREARB glActiveTextureARB;
#endif

#ifndef NIV_GLMULTITEXCOORD4IVARB_DECLARATION
#define NIV_GLMULTITEXCOORD4IVARB_DECLARATION
  nivenGLMULTITEXCOORD4IVARB glMultiTexCoord4ivARB;
#endif

#ifndef NIV_GLMULTITEXCOORD2FARB_DECLARATION
#define NIV_GLMULTITEXCOORD2FARB_DECLARATION
  nivenGLMULTITEXCOORD2FARB glMultiTexCoord2fARB;
#endif

#ifndef NIV_GLMULTITEXCOORD2IARB_DECLARATION
#define NIV_GLMULTITEXCOORD2IARB_DECLARATION
  nivenGLMULTITEXCOORD2IARB glMultiTexCoord2iARB;
#endif

#ifndef NIV_GLMULTITEXCOORD3FARB_DECLARATION
#define NIV_GLMULTITEXCOORD3FARB_DECLARATION
  nivenGLMULTITEXCOORD3FARB glMultiTexCoord3fARB;
#endif

#ifndef NIV_GLMULTITEXCOORD4DARB_DECLARATION
#define NIV_GLMULTITEXCOORD4DARB_DECLARATION
  nivenGLMULTITEXCOORD4DARB glMultiTexCoord4dARB;
#endif

#ifndef NIV_GLMULTITEXCOORD3DVARB_DECLARATION
#define NIV_GLMULTITEXCOORD3DVARB_DECLARATION
  nivenGLMULTITEXCOORD3DVARB glMultiTexCoord3dvARB;
#endif

#ifndef NIV_GLMULTITEXCOORD1IARB_DECLARATION
#define NIV_GLMULTITEXCOORD1IARB_DECLARATION
  nivenGLMULTITEXCOORD1IARB glMultiTexCoord1iARB;
#endif

#ifndef NIV_GLMULTITEXCOORD2IVARB_DECLARATION
#define NIV_GLMULTITEXCOORD2IVARB_DECLARATION
  nivenGLMULTITEXCOORD2IVARB glMultiTexCoord2ivARB;
#endif

#ifndef NIV_GLMULTITEXCOORD4IARB_DECLARATION
#define NIV_GLMULTITEXCOORD4IARB_DECLARATION
  nivenGLMULTITEXCOORD4IARB glMultiTexCoord4iARB;
#endif

#ifndef NIV_GLMULTITEXCOORD3FVARB_DECLARATION
#define NIV_GLMULTITEXCOORD3FVARB_DECLARATION
  nivenGLMULTITEXCOORD3FVARB glMultiTexCoord3fvARB;
#endif

#ifndef NIV_GLMULTITEXCOORD1DARB_DECLARATION
#define NIV_GLMULTITEXCOORD1DARB_DECLARATION
  nivenGLMULTITEXCOORD1DARB glMultiTexCoord1dARB;
#endif

#ifndef NIV_GLMULTITEXCOORD2DARB_DECLARATION
#define NIV_GLMULTITEXCOORD2DARB_DECLARATION
  nivenGLMULTITEXCOORD2DARB glMultiTexCoord2dARB;
#endif


  // GL_EXT_secondary_color
#ifndef NIV_GLSECONDARYCOLOR3USEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3USEXT_DECLARATION
  nivenGLSECONDARYCOLOR3USEXT glSecondaryColor3usEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3DVEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3DVEXT_DECLARATION
  nivenGLSECONDARYCOLOR3DVEXT glSecondaryColor3dvEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3BEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3BEXT_DECLARATION
  nivenGLSECONDARYCOLOR3BEXT glSecondaryColor3bEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3BVEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3BVEXT_DECLARATION
  nivenGLSECONDARYCOLOR3BVEXT glSecondaryColor3bvEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3DEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3DEXT_DECLARATION
  nivenGLSECONDARYCOLOR3DEXT glSecondaryColor3dEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3SEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3SEXT_DECLARATION
  nivenGLSECONDARYCOLOR3SEXT glSecondaryColor3sEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3SVEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3SVEXT_DECLARATION
  nivenGLSECONDARYCOLOR3SVEXT glSecondaryColor3svEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3UBEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3UBEXT_DECLARATION
  nivenGLSECONDARYCOLOR3UBEXT glSecondaryColor3ubEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3UIEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3UIEXT_DECLARATION
  nivenGLSECONDARYCOLOR3UIEXT glSecondaryColor3uiEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3IEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3IEXT_DECLARATION
  nivenGLSECONDARYCOLOR3IEXT glSecondaryColor3iEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3FEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3FEXT_DECLARATION
  nivenGLSECONDARYCOLOR3FEXT glSecondaryColor3fEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3FVEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3FVEXT_DECLARATION
  nivenGLSECONDARYCOLOR3FVEXT glSecondaryColor3fvEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3UBVEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3UBVEXT_DECLARATION
  nivenGLSECONDARYCOLOR3UBVEXT glSecondaryColor3ubvEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3IVEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3IVEXT_DECLARATION
  nivenGLSECONDARYCOLOR3IVEXT glSecondaryColor3ivEXT;
#endif

#ifndef NIV_GLSECONDARYCOLORPOINTEREXT_DECLARATION
#define NIV_GLSECONDARYCOLORPOINTEREXT_DECLARATION
  nivenGLSECONDARYCOLORPOINTEREXT glSecondaryColorPointerEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3UIVEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3UIVEXT_DECLARATION
  nivenGLSECONDARYCOLOR3UIVEXT glSecondaryColor3uivEXT;
#endif

#ifndef NIV_GLSECONDARYCOLOR3USVEXT_DECLARATION
#define NIV_GLSECONDARYCOLOR3USVEXT_DECLARATION
  nivenGLSECONDARYCOLOR3USVEXT glSecondaryColor3usvEXT;
#endif


  // GL_SGIS_color_range

  // GL_SGIX_fog_offset

#ifdef WIN32
  // WGL_ARB_make_current_read
#ifndef NIV_WGLGETCURRENTREADDCARB_DECLARATION
#define NIV_WGLGETCURRENTREADDCARB_DECLARATION
  nivenWGLGETCURRENTREADDCARB wglGetCurrentReadDCARB;
#endif

#ifndef NIV_WGLMAKECONTEXTCURRENTARB_DECLARATION
#define NIV_WGLMAKECONTEXTCURRENTARB_DECLARATION
  nivenWGLMAKECONTEXTCURRENTARB wglMakeContextCurrentARB;
#endif

#endif
  // GL_NV_copy_depth_to_color

  // GL_EXT_vertex_array
#ifndef NIV_GLVERTEXPOINTEREXT_DECLARATION
#define NIV_GLVERTEXPOINTEREXT_DECLARATION
  nivenGLVERTEXPOINTEREXT glVertexPointerEXT;
#endif

#ifndef NIV_GLCOLORPOINTEREXT_DECLARATION
#define NIV_GLCOLORPOINTEREXT_DECLARATION
  nivenGLCOLORPOINTEREXT glColorPointerEXT;
#endif

#ifndef NIV_GLGETPOINTERVEXT_DECLARATION
#define NIV_GLGETPOINTERVEXT_DECLARATION
  nivenGLGETPOINTERVEXT glGetPointervEXT;
#endif

#ifndef NIV_GLNORMALPOINTEREXT_DECLARATION
#define NIV_GLNORMALPOINTEREXT_DECLARATION
  nivenGLNORMALPOINTEREXT glNormalPointerEXT;
#endif

#ifndef NIV_GLINDEXPOINTEREXT_DECLARATION
#define NIV_GLINDEXPOINTEREXT_DECLARATION
  nivenGLINDEXPOINTEREXT glIndexPointerEXT;
#endif

#ifndef NIV_GLEDGEFLAGPOINTEREXT_DECLARATION
#define NIV_GLEDGEFLAGPOINTEREXT_DECLARATION
  nivenGLEDGEFLAGPOINTEREXT glEdgeFlagPointerEXT;
#endif

#ifndef NIV_GLDRAWARRAYSEXT_DECLARATION
#define NIV_GLDRAWARRAYSEXT_DECLARATION
  nivenGLDRAWARRAYSEXT glDrawArraysEXT;
#endif

#ifndef NIV_GLARRAYELEMENTEXT_DECLARATION
#define NIV_GLARRAYELEMENTEXT_DECLARATION
  nivenGLARRAYELEMENTEXT glArrayElementEXT;
#endif

#ifndef NIV_GLTEXCOORDPOINTEREXT_DECLARATION
#define NIV_GLTEXCOORDPOINTEREXT_DECLARATION
  nivenGLTEXCOORDPOINTEREXT glTexCoordPointerEXT;
#endif


  // GL_INTEL_parallel_arrays
#ifndef NIV_GLVERTEXPOINTERVINTEL_DECLARATION
#define NIV_GLVERTEXPOINTERVINTEL_DECLARATION
  nivenGLVERTEXPOINTERVINTEL glVertexPointervINTEL;
#endif

#ifndef NIV_GLTEXCOORDPOINTERVINTEL_DECLARATION
#define NIV_GLTEXCOORDPOINTERVINTEL_DECLARATION
  nivenGLTEXCOORDPOINTERVINTEL glTexCoordPointervINTEL;
#endif

#ifndef NIV_GLNORMALPOINTERVINTEL_DECLARATION
#define NIV_GLNORMALPOINTERVINTEL_DECLARATION
  nivenGLNORMALPOINTERVINTEL glNormalPointervINTEL;
#endif

#ifndef NIV_GLCOLORPOINTERVINTEL_DECLARATION
#define NIV_GLCOLORPOINTERVINTEL_DECLARATION
  nivenGLCOLORPOINTERVINTEL glColorPointervINTEL;
#endif


  // GL_ATI_draw_buffers
#ifndef NIV_GLDRAWBUFFERSATI_DECLARATION
#define NIV_GLDRAWBUFFERSATI_DECLARATION
  nivenGLDRAWBUFFERSATI glDrawBuffersATI;
#endif


#ifdef _GLX
  // GLX_SGIX_fbconfig
#ifndef NIV_GLXCREATECONTEXTWITHCONFIGSGIX_DECLARATION
#define NIV_GLXCREATECONTEXTWITHCONFIGSGIX_DECLARATION
  nivenGLXCREATECONTEXTWITHCONFIGSGIX glXCreateContextWithConfigSGIX;
#endif

#ifndef NIV_GLXGETFBCONFIGFROMVISUALSGIX_DECLARATION
#define NIV_GLXGETFBCONFIGFROMVISUALSGIX_DECLARATION
  nivenGLXGETFBCONFIGFROMVISUALSGIX glXGetFBConfigFromVisualSGIX;
#endif

#ifndef NIV_GLXCREATEGLXPIXMAPWITHCONFIGSGIX_DECLARATION
#define NIV_GLXCREATEGLXPIXMAPWITHCONFIGSGIX_DECLARATION
  nivenGLXCREATEGLXPIXMAPWITHCONFIGSGIX glXCreateGLXPixmapWithConfigSGIX;
#endif

#ifndef NIV_GLXCHOOSEFBCONFIGSGIX_DECLARATION
#define NIV_GLXCHOOSEFBCONFIGSGIX_DECLARATION
  nivenGLXCHOOSEFBCONFIGSGIX glXChooseFBConfigSGIX;
#endif

#ifndef NIV_GLXGETFBCONFIGATTRIBSGIX_DECLARATION
#define NIV_GLXGETFBCONFIGATTRIBSGIX_DECLARATION
  nivenGLXGETFBCONFIGATTRIBSGIX glXGetFBConfigAttribSGIX;
#endif

#ifndef NIV_GLXGETVISUALFROMFBCONFIGSGIX_DECLARATION
#define NIV_GLXGETVISUALFROMFBCONFIGSGIX_DECLARATION
  nivenGLXGETVISUALFROMFBCONFIGSGIX glXGetVisualFromFBConfigSGIX;
#endif

#endif // _GLX
  // GL_SGIX_async
#ifndef NIV_GLPOLLASYNCSGIX_DECLARATION
#define NIV_GLPOLLASYNCSGIX_DECLARATION
  nivenGLPOLLASYNCSGIX glPollAsyncSGIX;
#endif

#ifndef NIV_GLGENASYNCMARKERSSGIX_DECLARATION
#define NIV_GLGENASYNCMARKERSSGIX_DECLARATION
  nivenGLGENASYNCMARKERSSGIX glGenAsyncMarkersSGIX;
#endif

#ifndef NIV_GLDELETEASYNCMARKERSSGIX_DECLARATION
#define NIV_GLDELETEASYNCMARKERSSGIX_DECLARATION
  nivenGLDELETEASYNCMARKERSSGIX glDeleteAsyncMarkersSGIX;
#endif

#ifndef NIV_GLFINISHASYNCSGIX_DECLARATION
#define NIV_GLFINISHASYNCSGIX_DECLARATION
  nivenGLFINISHASYNCSGIX glFinishAsyncSGIX;
#endif

#ifndef NIV_GLASYNCMARKERSGIX_DECLARATION
#define NIV_GLASYNCMARKERSGIX_DECLARATION
  nivenGLASYNCMARKERSGIX glAsyncMarkerSGIX;
#endif

#ifndef NIV_GLISASYNCMARKERSGIX_DECLARATION
#define NIV_GLISASYNCMARKERSGIX_DECLARATION
  nivenGLISASYNCMARKERSGIX glIsAsyncMarkerSGIX;
#endif


  // GL_EXT_depth_bounds_test
#ifndef NIV_GLDEPTHBOUNDSEXT_DECLARATION
#define NIV_GLDEPTHBOUNDSEXT_DECLARATION
  nivenGLDEPTHBOUNDSEXT glDepthBoundsEXT;
#endif


  // GL_ATI_vertex_array_object
#ifndef NIV_GLNEWOBJECTBUFFERATI_DECLARATION
#define NIV_GLNEWOBJECTBUFFERATI_DECLARATION
  nivenGLNEWOBJECTBUFFERATI glNewObjectBufferATI;
#endif

#ifndef NIV_GLGETVARIANTARRAYOBJECTIVATI_DECLARATION
#define NIV_GLGETVARIANTARRAYOBJECTIVATI_DECLARATION
  nivenGLGETVARIANTARRAYOBJECTIVATI glGetVariantArrayObjectivATI;
#endif

#ifndef NIV_GLISOBJECTBUFFERATI_DECLARATION
#define NIV_GLISOBJECTBUFFERATI_DECLARATION
  nivenGLISOBJECTBUFFERATI glIsObjectBufferATI;
#endif

#ifndef NIV_GLGETOBJECTBUFFERFVATI_DECLARATION
#define NIV_GLGETOBJECTBUFFERFVATI_DECLARATION
  nivenGLGETOBJECTBUFFERFVATI glGetObjectBufferfvATI;
#endif

#ifndef NIV_GLUPDATEOBJECTBUFFERATI_DECLARATION
#define NIV_GLUPDATEOBJECTBUFFERATI_DECLARATION
  nivenGLUPDATEOBJECTBUFFERATI glUpdateObjectBufferATI;
#endif

#ifndef NIV_GLGETARRAYOBJECTIVATI_DECLARATION
#define NIV_GLGETARRAYOBJECTIVATI_DECLARATION
  nivenGLGETARRAYOBJECTIVATI glGetArrayObjectivATI;
#endif

#ifndef NIV_GLFREEOBJECTBUFFERATI_DECLARATION
#define NIV_GLFREEOBJECTBUFFERATI_DECLARATION
  nivenGLFREEOBJECTBUFFERATI glFreeObjectBufferATI;
#endif

#ifndef NIV_GLVARIANTARRAYOBJECTATI_DECLARATION
#define NIV_GLVARIANTARRAYOBJECTATI_DECLARATION
  nivenGLVARIANTARRAYOBJECTATI glVariantArrayObjectATI;
#endif

#ifndef NIV_GLGETVARIANTARRAYOBJECTFVATI_DECLARATION
#define NIV_GLGETVARIANTARRAYOBJECTFVATI_DECLARATION
  nivenGLGETVARIANTARRAYOBJECTFVATI glGetVariantArrayObjectfvATI;
#endif

#ifndef NIV_GLGETOBJECTBUFFERIVATI_DECLARATION
#define NIV_GLGETOBJECTBUFFERIVATI_DECLARATION
  nivenGLGETOBJECTBUFFERIVATI glGetObjectBufferivATI;
#endif

#ifndef NIV_GLARRAYOBJECTATI_DECLARATION
#define NIV_GLARRAYOBJECTATI_DECLARATION
  nivenGLARRAYOBJECTATI glArrayObjectATI;
#endif

#ifndef NIV_GLGETARRAYOBJECTFVATI_DECLARATION
#define NIV_GLGETARRAYOBJECTFVATI_DECLARATION
  nivenGLGETARRAYOBJECTFVATI glGetArrayObjectfvATI;
#endif


  // GL_SUN_convolution_border_modes

  // GL_SGIX_fog_texture
#ifndef NIV_GLTEXTUREFOGSGIX_DECLARATION
#define NIV_GLTEXTUREFOGSGIX_DECLARATION
  nivenGLTEXTUREFOGSGIX glTextureFogSGIX;
#endif


  // GL_SGIX_pixel_texture
#ifndef NIV_GLPIXELTEXGENSGIX_DECLARATION
#define NIV_GLPIXELTEXGENSGIX_DECLARATION
  nivenGLPIXELTEXGENSGIX glPixelTexGenSGIX;
#endif


  // GL_APPLE_specular_vector

  // GL_ARB_texture_env_add

#ifdef _GLX
  // GLX_SGIX_swap_barrier
#ifndef NIV_GLXQUERYMAXSWAPBARRIERSSGIX_DECLARATION
#define NIV_GLXQUERYMAXSWAPBARRIERSSGIX_DECLARATION
  nivenGLXQUERYMAXSWAPBARRIERSSGIX glXQueryMaxSwapBarriersSGIX;
#endif

#ifndef NIV_GLXBINDSWAPBARRIERSGIX_DECLARATION
#define NIV_GLXBINDSWAPBARRIERSGIX_DECLARATION
  nivenGLXBINDSWAPBARRIERSGIX glXBindSwapBarrierSGIX;
#endif

#endif // _GLX
  // GL_NV_fragment_program
#ifndef NIV_GLGETPROGRAMNAMEDPARAMETERFVNV_DECLARATION
#define NIV_GLGETPROGRAMNAMEDPARAMETERFVNV_DECLARATION
  nivenGLGETPROGRAMNAMEDPARAMETERFVNV glGetProgramNamedParameterfvNV;
#endif

#ifndef NIV_GLPROGRAMNAMEDPARAMETER4FNV_DECLARATION
#define NIV_GLPROGRAMNAMEDPARAMETER4FNV_DECLARATION
  nivenGLPROGRAMNAMEDPARAMETER4FNV glProgramNamedParameter4fNV;
#endif

#ifndef NIV_GLPROGRAMNAMEDPARAMETER4DVNV_DECLARATION
#define NIV_GLPROGRAMNAMEDPARAMETER4DVNV_DECLARATION
  nivenGLPROGRAMNAMEDPARAMETER4DVNV glProgramNamedParameter4dvNV;
#endif

#ifndef NIV_GLPROGRAMNAMEDPARAMETER4DNV_DECLARATION
#define NIV_GLPROGRAMNAMEDPARAMETER4DNV_DECLARATION
  nivenGLPROGRAMNAMEDPARAMETER4DNV glProgramNamedParameter4dNV;
#endif

#ifndef NIV_GLPROGRAMNAMEDPARAMETER4FVNV_DECLARATION
#define NIV_GLPROGRAMNAMEDPARAMETER4FVNV_DECLARATION
  nivenGLPROGRAMNAMEDPARAMETER4FVNV glProgramNamedParameter4fvNV;
#endif

#ifndef NIV_GLGETPROGRAMNAMEDPARAMETERDVNV_DECLARATION
#define NIV_GLGETPROGRAMNAMEDPARAMETERDVNV_DECLARATION
  nivenGLGETPROGRAMNAMEDPARAMETERDVNV glGetProgramNamedParameterdvNV;
#endif


  // GL_SGIX_texture_coordinate_clamp

  // GL_EXT_pixel_transform
#ifndef NIV_GLPIXELTRANSFORMPARAMETERFEXT_DECLARATION
#define NIV_GLPIXELTRANSFORMPARAMETERFEXT_DECLARATION
  nivenGLPIXELTRANSFORMPARAMETERFEXT glPixelTransformParameterfEXT;
#endif

#ifndef NIV_GLGETPIXELTRANSFORMPARAMETERFVEXT_DECLARATION
#define NIV_GLGETPIXELTRANSFORMPARAMETERFVEXT_DECLARATION
  nivenGLGETPIXELTRANSFORMPARAMETERFVEXT glGetPixelTransformParameterfvEXT;
#endif

#ifndef NIV_GLPIXELTRANSFORMPARAMETERIEXT_DECLARATION
#define NIV_GLPIXELTRANSFORMPARAMETERIEXT_DECLARATION
  nivenGLPIXELTRANSFORMPARAMETERIEXT glPixelTransformParameteriEXT;
#endif

#ifndef NIV_GLGETPIXELTRANSFORMPARAMETERIVEXT_DECLARATION
#define NIV_GLGETPIXELTRANSFORMPARAMETERIVEXT_DECLARATION
  nivenGLGETPIXELTRANSFORMPARAMETERIVEXT glGetPixelTransformParameterivEXT;
#endif

#ifndef NIV_GLPIXELTRANSFORMPARAMETERFVEXT_DECLARATION
#define NIV_GLPIXELTRANSFORMPARAMETERFVEXT_DECLARATION
  nivenGLPIXELTRANSFORMPARAMETERFVEXT glPixelTransformParameterfvEXT;
#endif

#ifndef NIV_GLPIXELTRANSFORMPARAMETERIVEXT_DECLARATION
#define NIV_GLPIXELTRANSFORMPARAMETERIVEXT_DECLARATION
  nivenGLPIXELTRANSFORMPARAMETERIVEXT glPixelTransformParameterivEXT;
#endif


#ifdef _GLX
  // GLX_MESA_copy_sub_buffer
#ifndef NIV_GLXCOPYSUBBUFFERMESA_DECLARATION
#define NIV_GLXCOPYSUBBUFFERMESA_DECLARATION
  nivenGLXCOPYSUBBUFFERMESA glXCopySubBufferMESA;
#endif

#endif // _GLX
  // GL_SGIX_texture_add_env

#ifdef _GLX
  // GLX_SGI_cushion
#ifndef NIV_GLXCUSHIONSGI_DECLARATION
#define NIV_GLXCUSHIONSGI_DECLARATION
  nivenGLXCUSHIONSGI glXCushionSGI;
#endif

#endif // _GLX
  // GL_ARB_matrix_palette
#ifndef NIV_GLMATRIXINDEXPOINTERARB_DECLARATION
#define NIV_GLMATRIXINDEXPOINTERARB_DECLARATION
  nivenGLMATRIXINDEXPOINTERARB glMatrixIndexPointerARB;
#endif

#ifndef NIV_GLMATRIXINDEXUIVARB_DECLARATION
#define NIV_GLMATRIXINDEXUIVARB_DECLARATION
  nivenGLMATRIXINDEXUIVARB glMatrixIndexuivARB;
#endif

#ifndef NIV_GLMATRIXINDEXUSVARB_DECLARATION
#define NIV_GLMATRIXINDEXUSVARB_DECLARATION
  nivenGLMATRIXINDEXUSVARB glMatrixIndexusvARB;
#endif

#ifndef NIV_GLCURRENTPALETTEMATRIXARB_DECLARATION
#define NIV_GLCURRENTPALETTEMATRIXARB_DECLARATION
  nivenGLCURRENTPALETTEMATRIXARB glCurrentPaletteMatrixARB;
#endif

#ifndef NIV_GLMATRIXINDEXUBVARB_DECLARATION
#define NIV_GLMATRIXINDEXUBVARB_DECLARATION
  nivenGLMATRIXINDEXUBVARB glMatrixIndexubvARB;
#endif


#ifdef _GLX
  // GLX_SUN_get_transparent_index
#ifndef NIV_GLXGETTRANSPARENTINDEXSUN_DECLARATION
#define NIV_GLXGETTRANSPARENTINDEXSUN_DECLARATION
  nivenGLXGETTRANSPARENTINDEXSUN glXGetTransparentIndexSUN;
#endif

#endif // _GLX
  // GL_SGI_color_matrix

  // GL_EXT_packed_pixels

  // GL_EXT_draw_range_elements
#ifndef NIV_GLDRAWRANGEELEMENTSEXT_DECLARATION
#define NIV_GLDRAWRANGEELEMENTSEXT_DECLARATION
  nivenGLDRAWRANGEELEMENTSEXT glDrawRangeElementsEXT;
#endif


  // GL_ARB_pixel_buffer_object

  // GL_S3_s3tc

#ifdef _GLX
  // GLX_NV_vertex_array_range
#ifndef NIV_GLXALLOCATEMEMORYNV_DECLARATION
#define NIV_GLXALLOCATEMEMORYNV_DECLARATION
  nivenGLXALLOCATEMEMORYNV glXAllocateMemoryNV;
#endif

#ifndef NIV_GLXFREEMEMORYNV_DECLARATION
#define NIV_GLXFREEMEMORYNV_DECLARATION
  nivenGLXFREEMEMORYNV glXFreeMemoryNV;
#endif

#endif // _GLX
  // GL_SGIX_blend_alpha_minmax



private:
  const char* GLExtensionString;
#ifdef _WIN32
  const char* WGLExtensionString;
#endif

public:
  bool InitGL_ARB_texture_compression ()
  {
    bool error = false;

    if ( checked_GL_ARB_texture_compression == true )
      return NIV_GL_ARB_texture_compression;

    checked_GL_ARB_texture_compression = true;
  
    if (strstr( GLExtensionString, "GL_ARB_texture_compression" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLCOMPRESSEDTEXIMAGE1DARB, glCompressedTexImage1DARB );
    INIT_FUNCTION( nivenGLGETCOMPRESSEDTEXIMAGEARB, glGetCompressedTexImageARB );
    INIT_FUNCTION( nivenGLCOMPRESSEDTEXSUBIMAGE1DARB, glCompressedTexSubImage1DARB );
    INIT_FUNCTION( nivenGLCOMPRESSEDTEXIMAGE3DARB, glCompressedTexImage3DARB );
    INIT_FUNCTION( nivenGLCOMPRESSEDTEXSUBIMAGE2DARB, glCompressedTexSubImage2DARB );
    INIT_FUNCTION( nivenGLCOMPRESSEDTEXSUBIMAGE3DARB, glCompressedTexSubImage3DARB );
    INIT_FUNCTION( nivenGLCOMPRESSEDTEXIMAGE2DARB, glCompressedTexImage2DARB );


    if (error == false)
      NIV_GL_ARB_texture_compression = true;
    
    return !error;
  }

  bool InitGL_SGIX_vertex_preclip ()
  {
    bool error = false;

    if ( checked_GL_SGIX_vertex_preclip == true )
      return NIV_GL_SGIX_vertex_preclip;

    checked_GL_SGIX_vertex_preclip = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_vertex_preclip" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_vertex_preclip = true;
    
    return !error;
  }

  bool InitGL_SGIX_async_pixel ()
  {
    bool error = false;

    if ( checked_GL_SGIX_async_pixel == true )
      return NIV_GL_SGIX_async_pixel;

    checked_GL_SGIX_async_pixel = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_async_pixel" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_async_pixel = true;
    
    return !error;
  }

  bool InitGL_NV_point_sprite ()
  {
    bool error = false;

    if ( checked_GL_NV_point_sprite == true )
      return NIV_GL_NV_point_sprite;

    checked_GL_NV_point_sprite = true;
  
    if (strstr( GLExtensionString, "GL_NV_point_sprite" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLPOINTPARAMETERINV, glPointParameteriNV );
    INIT_FUNCTION( nivenGLPOINTPARAMETERIVNV, glPointParameterivNV );


    if (error == false)
      NIV_GL_NV_point_sprite = true;
    
    return !error;
  }

  bool InitGL_APPLE_element_array ()
  {
    bool error = false;

    if ( checked_GL_APPLE_element_array == true )
      return NIV_GL_APPLE_element_array;

    checked_GL_APPLE_element_array = true;
  
    if (strstr( GLExtensionString, "GL_APPLE_element_array" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLMULTIDRAWRANGEELEMENTARRAYAPPLE, glMultiDrawRangeElementArrayAPPLE );
    INIT_FUNCTION( nivenGLELEMENTPOINTERAPPLE, glElementPointerAPPLE );
    INIT_FUNCTION( nivenGLDRAWRANGEELEMENTARRAYAPPLE, glDrawRangeElementArrayAPPLE );
    INIT_FUNCTION( nivenGLMULTIDRAWELEMENTARRAYAPPLE, glMultiDrawElementArrayAPPLE );
    INIT_FUNCTION( nivenGLDRAWELEMENTARRAYAPPLE, glDrawElementArrayAPPLE );


    if (error == false)
      NIV_GL_APPLE_element_array = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_EXT_import_context ()
  {
    bool error = false;

    if ( checked_GLX_EXT_import_context == true )
      return NIV_GLX_EXT_import_context;

    checked_GLX_EXT_import_context = true;
  
    if (strstr( GLXExtensionString, "GLX_EXT_import_context" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXIMPORTCONTEXTEXT, glXImportContextEXT );
    INIT_FUNCTION( nivenGLXGETCONTEXTIDEXT, glXGetContextIDEXT );
    INIT_FUNCTION( nivenGLXFREECONTEXTEXT, glXFreeContextEXT );
    INIT_FUNCTION( nivenGLXQUERYCONTEXTINFOEXT, glXQueryContextInfoEXT );


    if (error == false)
      NIV_GLX_EXT_import_context = true;
    
    return !error;
  }
#endif

  bool InitGL_NV_vertex_array_range2 ()
  {
    bool error = false;

    if ( checked_GL_NV_vertex_array_range2 == true )
      return NIV_GL_NV_vertex_array_range2;

    checked_GL_NV_vertex_array_range2 = true;
  
    if (strstr( GLExtensionString, "GL_NV_vertex_array_range2" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_vertex_array_range2 = true;
    
    return !error;
  }

  bool InitGL_EXT_blend_color ()
  {
    bool error = false;

    if ( checked_GL_EXT_blend_color == true )
      return NIV_GL_EXT_blend_color;

    checked_GL_EXT_blend_color = true;
  
    if (strstr( GLExtensionString, "GL_EXT_blend_color" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLBLENDCOLOREXT, glBlendColorEXT );


    if (error == false)
      NIV_GL_EXT_blend_color = true;
    
    return !error;
  }

  bool InitGL_EXT_blend_subtract ()
  {
    bool error = false;

    if ( checked_GL_EXT_blend_subtract == true )
      return NIV_GL_EXT_blend_subtract;

    checked_GL_EXT_blend_subtract = true;
  
    if (strstr( GLExtensionString, "GL_EXT_blend_subtract" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_blend_subtract = true;
    
    return !error;
  }

  bool InitGL_SGIX_tag_sample_buffer ()
  {
    bool error = false;

    if ( checked_GL_SGIX_tag_sample_buffer == true )
      return NIV_GL_SGIX_tag_sample_buffer;

    checked_GL_SGIX_tag_sample_buffer = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_tag_sample_buffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTAGSAMPLEBUFFERSGIX, glTagSampleBufferSGIX );


    if (error == false)
      NIV_GL_SGIX_tag_sample_buffer = true;
    
    return !error;
  }

  bool InitGL_EXT_stencil_wrap ()
  {
    bool error = false;

    if ( checked_GL_EXT_stencil_wrap == true )
      return NIV_GL_EXT_stencil_wrap;

    checked_GL_EXT_stencil_wrap = true;
  
    if (strstr( GLExtensionString, "GL_EXT_stencil_wrap" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_stencil_wrap = true;
    
    return !error;
  }

  bool InitGL_EXT_index_array_formats ()
  {
    bool error = false;

    if ( checked_GL_EXT_index_array_formats == true )
      return NIV_GL_EXT_index_array_formats;

    checked_GL_EXT_index_array_formats = true;
  
    if (strstr( GLExtensionString, "GL_EXT_index_array_formats" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_index_array_formats = true;
    
    return !error;
  }

  bool InitGL_EXT_index_texture ()
  {
    bool error = false;

    if ( checked_GL_EXT_index_texture == true )
      return NIV_GL_EXT_index_texture;

    checked_GL_EXT_index_texture = true;
  
    if (strstr( GLExtensionString, "GL_EXT_index_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_index_texture = true;
    
    return !error;
  }

  bool InitGL_IBM_texture_mirrored_repeat ()
  {
    bool error = false;

    if ( checked_GL_IBM_texture_mirrored_repeat == true )
      return NIV_GL_IBM_texture_mirrored_repeat;

    checked_GL_IBM_texture_mirrored_repeat = true;
  
    if (strstr( GLExtensionString, "GL_IBM_texture_mirrored_repeat" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_IBM_texture_mirrored_repeat = true;
    
    return !error;
  }

  bool InitGL_NV_half_float ()
  {
    bool error = false;

    if ( checked_GL_NV_half_float == true )
      return NIV_GL_NV_half_float;

    checked_GL_NV_half_float = true;
  
    if (strstr( GLExtensionString, "GL_NV_half_float" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLMULTITEXCOORD2HVNV, glMultiTexCoord2hvNV );
    INIT_FUNCTION( nivenGLVERTEXWEIGHTHNV, glVertexWeighthNV );
    INIT_FUNCTION( nivenGLTEXCOORD4HVNV, glTexCoord4hvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS3HVNV, glVertexAttribs3hvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS2HVNV, glVertexAttribs2hvNV );
    INIT_FUNCTION( nivenGLVERTEX4HVNV, glVertex4hvNV );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3HVNV, glSecondaryColor3hvNV );
    INIT_FUNCTION( nivenGLFOGCOORDHVNV, glFogCoordhvNV );
    INIT_FUNCTION( nivenGLTEXCOORD3HVNV, glTexCoord3hvNV );
    INIT_FUNCTION( nivenGLVERTEX2HNV, glVertex2hNV );
    INIT_FUNCTION( nivenGLTEXCOORD1HNV, glTexCoord1hNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3HVNV, glVertexAttrib3hvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1HVNV, glVertexAttrib1hvNV );
    INIT_FUNCTION( nivenGLMULTITEXCOORD1HVNV, glMultiTexCoord1hvNV );
    INIT_FUNCTION( nivenGLTEXCOORD2HVNV, glTexCoord2hvNV );
    INIT_FUNCTION( nivenGLMULTITEXCOORD4HVNV, glMultiTexCoord4hvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4HNV, glVertexAttrib4hNV );
    INIT_FUNCTION( nivenGLMULTITEXCOORD1HNV, glMultiTexCoord1hNV );
    INIT_FUNCTION( nivenGLVERTEXWEIGHTHVNV, glVertexWeighthvNV );
    INIT_FUNCTION( nivenGLNORMAL3HNV, glNormal3hNV );
    INIT_FUNCTION( nivenGLTEXCOORD3HNV, glTexCoord3hNV );
    INIT_FUNCTION( nivenGLCOLOR4HNV, glColor4hNV );
    INIT_FUNCTION( nivenGLFOGCOORDHNV, glFogCoordhNV );
    INIT_FUNCTION( nivenGLVERTEX2HVNV, glVertex2hvNV );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3HNV, glSecondaryColor3hNV );
    INIT_FUNCTION( nivenGLNORMAL3HVNV, glNormal3hvNV );
    INIT_FUNCTION( nivenGLTEXCOORD2HNV, glTexCoord2hNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4HVNV, glVertexAttrib4hvNV );
    INIT_FUNCTION( nivenGLVERTEX3HVNV, glVertex3hvNV );
    INIT_FUNCTION( nivenGLVERTEX3HNV, glVertex3hNV );
    INIT_FUNCTION( nivenGLCOLOR3HVNV, glColor3hvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2HVNV, glVertexAttrib2hvNV );
    INIT_FUNCTION( nivenGLCOLOR3HNV, glColor3hNV );
    INIT_FUNCTION( nivenGLMULTITEXCOORD4HNV, glMultiTexCoord4hNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS4HVNV, glVertexAttribs4hvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1HNV, glVertexAttrib1hNV );
    INIT_FUNCTION( nivenGLMULTITEXCOORD3HVNV, glMultiTexCoord3hvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS1HVNV, glVertexAttribs1hvNV );
    INIT_FUNCTION( nivenGLTEXCOORD4HNV, glTexCoord4hNV );
    INIT_FUNCTION( nivenGLVERTEX4HNV, glVertex4hNV );
    INIT_FUNCTION( nivenGLMULTITEXCOORD2HNV, glMultiTexCoord2hNV );
    INIT_FUNCTION( nivenGLCOLOR4HVNV, glColor4hvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2HNV, glVertexAttrib2hNV );
    INIT_FUNCTION( nivenGLMULTITEXCOORD3HNV, glMultiTexCoord3hNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3HNV, glVertexAttrib3hNV );
    INIT_FUNCTION( nivenGLTEXCOORD1HVNV, glTexCoord1hvNV );


    if (error == false)
      NIV_GL_NV_half_float = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_ARB_extensions_string ()
  {
    bool error = false;

    if ( checked_WGL_ARB_extensions_string == true )
      return NIV_WGL_ARB_extensions_string;

    checked_WGL_ARB_extensions_string = true;
  
    if (strstr( WGLExtensionString, "WGL_ARB_extensions_string" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLGETEXTENSIONSSTRINGARB, wglGetExtensionsStringARB );


    if (error == false)
      NIV_WGL_ARB_extensions_string = true;
    
    return !error;
  }
#endif

  bool InitGL_SGIX_texture_scale_bias ()
  {
    bool error = false;

    if ( checked_GL_SGIX_texture_scale_bias == true )
      return NIV_GL_SGIX_texture_scale_bias;

    checked_GL_SGIX_texture_scale_bias = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_texture_scale_bias" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_texture_scale_bias = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_compression_s3tc ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_compression_s3tc == true )
      return NIV_GL_EXT_texture_compression_s3tc;

    checked_GL_EXT_texture_compression_s3tc = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_compression_s3tc" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_compression_s3tc = true;
    
    return !error;
  }

  bool InitGL_APPLE_transform_hint ()
  {
    bool error = false;

    if ( checked_GL_APPLE_transform_hint == true )
      return NIV_GL_APPLE_transform_hint;

    checked_GL_APPLE_transform_hint = true;
  
    if (strstr( GLExtensionString, "GL_APPLE_transform_hint" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_APPLE_transform_hint = true;
    
    return !error;
  }

  bool InitGL_ATI_separate_stencil ()
  {
    bool error = false;

    if ( checked_GL_ATI_separate_stencil == true )
      return NIV_GL_ATI_separate_stencil;

    checked_GL_ATI_separate_stencil = true;
  
    if (strstr( GLExtensionString, "GL_ATI_separate_stencil" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLSTENCILOPSEPARATEATI, glStencilOpSeparateATI );
    INIT_FUNCTION( nivenGLSTENCILFUNCSEPARATEATI, glStencilFuncSeparateATI );


    if (error == false)
      NIV_GL_ATI_separate_stencil = true;
    
    return !error;
  }

  bool InitGL_EXT_polygon_offset ()
  {
    bool error = false;

    if ( checked_GL_EXT_polygon_offset == true )
      return NIV_GL_EXT_polygon_offset;

    checked_GL_EXT_polygon_offset = true;
  
    if (strstr( GLExtensionString, "GL_EXT_polygon_offset" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLPOLYGONOFFSETEXT, glPolygonOffsetEXT );


    if (error == false)
      NIV_GL_EXT_polygon_offset = true;
    
    return !error;
  }

  bool InitGL_NV_vertex_program2_option ()
  {
    bool error = false;

    if ( checked_GL_NV_vertex_program2_option == true )
      return NIV_GL_NV_vertex_program2_option;

    checked_GL_NV_vertex_program2_option = true;
  
    if (strstr( GLExtensionString, "GL_NV_vertex_program2_option" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_vertex_program2_option = true;
    
    return !error;
  }

  bool InitGL_ARB_depth_texture ()
  {
    bool error = false;

    if ( checked_GL_ARB_depth_texture == true )
      return NIV_GL_ARB_depth_texture;

    checked_GL_ARB_depth_texture = true;
  
    if (strstr( GLExtensionString, "GL_ARB_depth_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_depth_texture = true;
    
    return !error;
  }

  bool InitGL_NV_packed_depth_stencil ()
  {
    bool error = false;

    if ( checked_GL_NV_packed_depth_stencil == true )
      return NIV_GL_NV_packed_depth_stencil;

    checked_GL_NV_packed_depth_stencil = true;
  
    if (strstr( GLExtensionString, "GL_NV_packed_depth_stencil" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_packed_depth_stencil = true;
    
    return !error;
  }

  bool InitGL_NV_fragment_program_option ()
  {
    bool error = false;

    if ( checked_GL_NV_fragment_program_option == true )
      return NIV_GL_NV_fragment_program_option;

    checked_GL_NV_fragment_program_option = true;
  
    if (strstr( GLExtensionString, "GL_NV_fragment_program_option" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_fragment_program_option = true;
    
    return !error;
  }

  bool InitGL_ARB_vertex_blend ()
  {
    bool error = false;

    if ( checked_GL_ARB_vertex_blend == true )
      return NIV_GL_ARB_vertex_blend;

    checked_GL_ARB_vertex_blend = true;
  
    if (strstr( GLExtensionString, "GL_ARB_vertex_blend" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLWEIGHTUBVARB, glWeightubvARB );
    INIT_FUNCTION( nivenGLWEIGHTSVARB, glWeightsvARB );
    INIT_FUNCTION( nivenGLVERTEXBLENDARB, glVertexBlendARB );
    INIT_FUNCTION( nivenGLWEIGHTIVARB, glWeightivARB );
    INIT_FUNCTION( nivenGLWEIGHTBVARB, glWeightbvARB );
    INIT_FUNCTION( nivenGLWEIGHTUSVARB, glWeightusvARB );
    INIT_FUNCTION( nivenGLWEIGHTPOINTERARB, glWeightPointerARB );
    INIT_FUNCTION( nivenGLWEIGHTFVARB, glWeightfvARB );
    INIT_FUNCTION( nivenGLWEIGHTUIVARB, glWeightuivARB );
    INIT_FUNCTION( nivenGLWEIGHTDVARB, glWeightdvARB );


    if (error == false)
      NIV_GL_ARB_vertex_blend = true;
    
    return !error;
  }

  bool InitGL_SGIX_ycrcb ()
  {
    bool error = false;

    if ( checked_GL_SGIX_ycrcb == true )
      return NIV_GL_SGIX_ycrcb;

    checked_GL_SGIX_ycrcb = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_ycrcb" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_ycrcb = true;
    
    return !error;
  }

  bool InitGL_EXT_stencil_two_side ()
  {
    bool error = false;

    if ( checked_GL_EXT_stencil_two_side == true )
      return NIV_GL_EXT_stencil_two_side;

    checked_GL_EXT_stencil_two_side = true;
  
    if (strstr( GLExtensionString, "GL_EXT_stencil_two_side" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLACTIVESTENCILFACEEXT, glActiveStencilFaceEXT );


    if (error == false)
      NIV_GL_EXT_stencil_two_side = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_NV_vertex_array_range ()
  {
    bool error = false;

    if ( checked_WGL_NV_vertex_array_range == true )
      return NIV_WGL_NV_vertex_array_range;

    checked_WGL_NV_vertex_array_range = true;
  
    if (strstr( WGLExtensionString, "WGL_NV_vertex_array_range" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLFREEMEMORYNV, wglFreeMemoryNV );
    INIT_FUNCTION( nivenWGLALLOCATEMEMORYNV, wglAllocateMemoryNV );


    if (error == false)
      NIV_WGL_NV_vertex_array_range = true;
    
    return !error;
  }
#endif

  bool InitGL_EXT_shadow_funcs ()
  {
    bool error = false;

    if ( checked_GL_EXT_shadow_funcs == true )
      return NIV_GL_EXT_shadow_funcs;

    checked_GL_EXT_shadow_funcs = true;
  
    if (strstr( GLExtensionString, "GL_EXT_shadow_funcs" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_shadow_funcs = true;
    
    return !error;
  }

  bool InitGL_EXT_Cg_shader ()
  {
    bool error = false;

    if ( checked_GL_EXT_Cg_shader == true )
      return NIV_GL_EXT_Cg_shader;

    checked_GL_EXT_Cg_shader = true;
  
    if (strstr( GLExtensionString, "GL_EXT_Cg_shader" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_Cg_shader = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGIS_multisample ()
  {
    bool error = false;

    if ( checked_GLX_SGIS_multisample == true )
      return NIV_GLX_SGIS_multisample;

    checked_GLX_SGIS_multisample = true;
  
    if (strstr( GLXExtensionString, "GLX_SGIS_multisample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_SGIS_multisample = true;
    
    return !error;
  }
#endif

  bool InitGL_EXT_convolution ()
  {
    bool error = false;

    if ( checked_GL_EXT_convolution == true )
      return NIV_GL_EXT_convolution;

    checked_GL_EXT_convolution = true;
  
    if (strstr( GLExtensionString, "GL_EXT_convolution" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETCONVOLUTIONPARAMETERIVEXT, glGetConvolutionParameterivEXT );
    INIT_FUNCTION( nivenGLSEPARABLEFILTER2DEXT, glSeparableFilter2DEXT );
    INIT_FUNCTION( nivenGLCONVOLUTIONPARAMETERIEXT, glConvolutionParameteriEXT );
    INIT_FUNCTION( nivenGLCONVOLUTIONPARAMETERIVEXT, glConvolutionParameterivEXT );
    INIT_FUNCTION( nivenGLGETCONVOLUTIONPARAMETERFVEXT, glGetConvolutionParameterfvEXT );
    INIT_FUNCTION( nivenGLGETSEPARABLEFILTEREXT, glGetSeparableFilterEXT );
    INIT_FUNCTION( nivenGLCOPYCONVOLUTIONFILTER2DEXT, glCopyConvolutionFilter2DEXT );
    INIT_FUNCTION( nivenGLCOPYCONVOLUTIONFILTER1DEXT, glCopyConvolutionFilter1DEXT );
    INIT_FUNCTION( nivenGLGETCONVOLUTIONFILTEREXT, glGetConvolutionFilterEXT );
    INIT_FUNCTION( nivenGLCONVOLUTIONFILTER1DEXT, glConvolutionFilter1DEXT );
    INIT_FUNCTION( nivenGLCONVOLUTIONFILTER2DEXT, glConvolutionFilter2DEXT );
    INIT_FUNCTION( nivenGLCONVOLUTIONPARAMETERFEXT, glConvolutionParameterfEXT );
    INIT_FUNCTION( nivenGLCONVOLUTIONPARAMETERFVEXT, glConvolutionParameterfvEXT );


    if (error == false)
      NIV_GL_EXT_convolution = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_EXT_pbuffer ()
  {
    bool error = false;

    if ( checked_WGL_EXT_pbuffer == true )
      return NIV_WGL_EXT_pbuffer;

    checked_WGL_EXT_pbuffer = true;
  
    if (strstr( WGLExtensionString, "WGL_EXT_pbuffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLCREATEPBUFFEREXT, wglCreatePbufferEXT );
    INIT_FUNCTION( nivenWGLQUERYPBUFFEREXT, wglQueryPbufferEXT );
    INIT_FUNCTION( nivenWGLRELEASEPBUFFERDCEXT, wglReleasePbufferDCEXT );
    INIT_FUNCTION( nivenWGLGETPBUFFERDCEXT, wglGetPbufferDCEXT );
    INIT_FUNCTION( nivenWGLDESTROYPBUFFEREXT, wglDestroyPbufferEXT );


    if (error == false)
      NIV_WGL_EXT_pbuffer = true;
    
    return !error;
  }
#endif

#ifdef _WIN32
  bool InitWGL_I3D_genlock ()
  {
    bool error = false;

    if ( checked_WGL_I3D_genlock == true )
      return NIV_WGL_I3D_genlock;

    checked_WGL_I3D_genlock = true;
  
    if (strstr( WGLExtensionString, "WGL_I3D_genlock" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLGENLOCKSOURCEEDGEI3D, wglGenlockSourceEdgeI3D );
    INIT_FUNCTION( nivenWGLGETGENLOCKSOURCEDELAYI3D, wglGetGenlockSourceDelayI3D );
    INIT_FUNCTION( nivenWGLGENLOCKSOURCEDELAYI3D, wglGenlockSourceDelayI3D );
    INIT_FUNCTION( nivenWGLGETGENLOCKSOURCEI3D, wglGetGenlockSourceI3D );
    INIT_FUNCTION( nivenWGLGENLOCKSAMPLERATEI3D, wglGenlockSampleRateI3D );
    INIT_FUNCTION( nivenWGLISENABLEDGENLOCKI3D, wglIsEnabledGenlockI3D );
    INIT_FUNCTION( nivenWGLDISABLEGENLOCKI3D, wglDisableGenlockI3D );
    INIT_FUNCTION( nivenWGLGETGENLOCKSAMPLERATEI3D, wglGetGenlockSampleRateI3D );
    INIT_FUNCTION( nivenWGLQUERYGENLOCKMAXSOURCEDELAYI3D, wglQueryGenlockMaxSourceDelayI3D );
    INIT_FUNCTION( nivenWGLGETGENLOCKSOURCEEDGEI3D, wglGetGenlockSourceEdgeI3D );
    INIT_FUNCTION( nivenWGLENABLEGENLOCKI3D, wglEnableGenlockI3D );
    INIT_FUNCTION( nivenWGLGENLOCKSOURCEI3D, wglGenlockSourceI3D );


    if (error == false)
      NIV_WGL_I3D_genlock = true;
    
    return !error;
  }
#endif

#ifdef _GLX
  bool InitGLX_ATI_pixel_format_float ()
  {
    bool error = false;

    if ( checked_GLX_ATI_pixel_format_float == true )
      return NIV_GLX_ATI_pixel_format_float;

    checked_GLX_ATI_pixel_format_float = true;
  
    if (strstr( GLXExtensionString, "GLX_ATI_pixel_format_float" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_ATI_pixel_format_float = true;
    
    return !error;
  }
#endif

#ifdef _GLX
  bool InitGLX_ARB_multisample ()
  {
    bool error = false;

    if ( checked_GLX_ARB_multisample == true )
      return NIV_GLX_ARB_multisample;

    checked_GLX_ARB_multisample = true;
  
    if (strstr( GLXExtensionString, "GLX_ARB_multisample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_ARB_multisample = true;
    
    return !error;
  }
#endif

#ifdef _WIN32
  bool InitWGL_ARB_pixel_format ()
  {
    bool error = false;

    if ( checked_WGL_ARB_pixel_format == true )
      return NIV_WGL_ARB_pixel_format;

    checked_WGL_ARB_pixel_format = true;
  
    if (strstr( WGLExtensionString, "WGL_ARB_pixel_format" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLGETPIXELFORMATATTRIBFVARB, wglGetPixelFormatAttribfvARB );
    INIT_FUNCTION( nivenWGLCHOOSEPIXELFORMATARB, wglChoosePixelFormatARB );
    INIT_FUNCTION( nivenWGLGETPIXELFORMATATTRIBIVARB, wglGetPixelFormatAttribivARB );


    if (error == false)
      NIV_WGL_ARB_pixel_format = true;
    
    return !error;
  }
#endif

#ifdef _WIN32
  bool InitWGL_3DFX_multisample ()
  {
    bool error = false;

    if ( checked_WGL_3DFX_multisample == true )
      return NIV_WGL_3DFX_multisample;

    checked_WGL_3DFX_multisample = true;
  
    if (strstr( WGLExtensionString, "WGL_3DFX_multisample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_WGL_3DFX_multisample = true;
    
    return !error;
  }
#endif

#ifdef _GLX
  bool InitGLX_SGIX_swap_group ()
  {
    bool error = false;

    if ( checked_GLX_SGIX_swap_group == true )
      return NIV_GLX_SGIX_swap_group;

    checked_GLX_SGIX_swap_group = true;
  
    if (strstr( GLXExtensionString, "GLX_SGIX_swap_group" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXJOINSWAPGROUPSGIX, glXJoinSwapGroupSGIX );


    if (error == false)
      NIV_GLX_SGIX_swap_group = true;
    
    return !error;
  }
#endif

  bool InitGL_EXT_vertex_shader ()
  {
    bool error = false;

    if ( checked_GL_EXT_vertex_shader == true )
      return NIV_GL_EXT_vertex_shader;

    checked_GL_EXT_vertex_shader = true;
  
    if (strstr( GLExtensionString, "GL_EXT_vertex_shader" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLVARIANTUBVEXT, glVariantubvEXT );
    INIT_FUNCTION( nivenGLSETINVARIANTEXT, glSetInvariantEXT );
    INIT_FUNCTION( nivenGLVARIANTSVEXT, glVariantsvEXT );
    INIT_FUNCTION( nivenGLGETLOCALCONSTANTINTEGERVEXT, glGetLocalConstantIntegervEXT );
    INIT_FUNCTION( nivenGLGETVARIANTINTEGERVEXT, glGetVariantIntegervEXT );
    INIT_FUNCTION( nivenGLVARIANTPOINTEREXT, glVariantPointerEXT );
    INIT_FUNCTION( nivenGLGENVERTEXSHADERSEXT, glGenVertexShadersEXT );
    INIT_FUNCTION( nivenGLENDVERTEXSHADEREXT, glEndVertexShaderEXT );
    INIT_FUNCTION( nivenGLBINDVERTEXSHADEREXT, glBindVertexShaderEXT );
    INIT_FUNCTION( nivenGLGETVARIANTFLOATVEXT, glGetVariantFloatvEXT );
    INIT_FUNCTION( nivenGLEXTRACTCOMPONENTEXT, glExtractComponentEXT );
    INIT_FUNCTION( nivenGLBEGINVERTEXSHADEREXT, glBeginVertexShaderEXT );
    INIT_FUNCTION( nivenGLDELETEVERTEXSHADEREXT, glDeleteVertexShaderEXT );
    INIT_FUNCTION( nivenGLVARIANTDVEXT, glVariantdvEXT );
    INIT_FUNCTION( nivenGLGETLOCALCONSTANTBOOLEANVEXT, glGetLocalConstantBooleanvEXT );
    INIT_FUNCTION( nivenGLISVARIANTENABLEDEXT, glIsVariantEnabledEXT );
    INIT_FUNCTION( nivenGLVARIANTUIVEXT, glVariantuivEXT );
    INIT_FUNCTION( nivenGLWRITEMASKEXT, glWriteMaskEXT );
    INIT_FUNCTION( nivenGLENABLEVARIANTCLIENTSTATEEXT, glEnableVariantClientStateEXT );
    INIT_FUNCTION( nivenGLVARIANTUSVEXT, glVariantusvEXT );
    INIT_FUNCTION( nivenGLGENSYMBOLSEXT, glGenSymbolsEXT );
    INIT_FUNCTION( nivenGLGETINVARIANTINTEGERVEXT, glGetInvariantIntegervEXT );
    INIT_FUNCTION( nivenGLSHADEROP2EXT, glShaderOp2EXT );
    INIT_FUNCTION( nivenGLBINDPARAMETEREXT, glBindParameterEXT );
    INIT_FUNCTION( nivenGLDISABLEVARIANTCLIENTSTATEEXT, glDisableVariantClientStateEXT );
    INIT_FUNCTION( nivenGLVARIANTIVEXT, glVariantivEXT );
    INIT_FUNCTION( nivenGLSWIZZLEEXT, glSwizzleEXT );
    INIT_FUNCTION( nivenGLGETINVARIANTBOOLEANVEXT, glGetInvariantBooleanvEXT );
    INIT_FUNCTION( nivenGLBINDTEXTUREUNITPARAMETEREXT, glBindTextureUnitParameterEXT );
    INIT_FUNCTION( nivenGLBINDTEXGENPARAMETEREXT, glBindTexGenParameterEXT );
    INIT_FUNCTION( nivenGLGETINVARIANTFLOATVEXT, glGetInvariantFloatvEXT );
    INIT_FUNCTION( nivenGLGETVARIANTBOOLEANVEXT, glGetVariantBooleanvEXT );
    INIT_FUNCTION( nivenGLGETVARIANTPOINTERVEXT, glGetVariantPointervEXT );
    INIT_FUNCTION( nivenGLBINDLIGHTPARAMETEREXT, glBindLightParameterEXT );
    INIT_FUNCTION( nivenGLSETLOCALCONSTANTEXT, glSetLocalConstantEXT );
    INIT_FUNCTION( nivenGLGETLOCALCONSTANTFLOATVEXT, glGetLocalConstantFloatvEXT );
    INIT_FUNCTION( nivenGLSHADEROP1EXT, glShaderOp1EXT );
    INIT_FUNCTION( nivenGLBINDMATERIALPARAMETEREXT, glBindMaterialParameterEXT );
    INIT_FUNCTION( nivenGLINSERTCOMPONENTEXT, glInsertComponentEXT );
    INIT_FUNCTION( nivenGLVARIANTFVEXT, glVariantfvEXT );
    INIT_FUNCTION( nivenGLSHADEROP3EXT, glShaderOp3EXT );
    INIT_FUNCTION( nivenGLVARIANTBVEXT, glVariantbvEXT );


    if (error == false)
      NIV_GL_EXT_vertex_shader = true;
    
    return !error;
  }

  bool InitGL_APPLE_pixel_buffer ()
  {
    bool error = false;

    if ( checked_GL_APPLE_pixel_buffer == true )
      return NIV_GL_APPLE_pixel_buffer;

    checked_GL_APPLE_pixel_buffer = true;
  
    if (strstr( GLExtensionString, "GL_APPLE_pixel_buffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_APPLE_pixel_buffer = true;
    
    return !error;
  }

  bool InitGL_EXT_misc_attribute ()
  {
    bool error = false;

    if ( checked_GL_EXT_misc_attribute == true )
      return NIV_GL_EXT_misc_attribute;

    checked_GL_EXT_misc_attribute = true;
  
    if (strstr( GLExtensionString, "GL_EXT_misc_attribute" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_misc_attribute = true;
    
    return !error;
  }

  bool InitGL_NV_texture_shader3 ()
  {
    bool error = false;

    if ( checked_GL_NV_texture_shader3 == true )
      return NIV_GL_NV_texture_shader3;

    checked_GL_NV_texture_shader3 = true;
  
    if (strstr( GLExtensionString, "GL_NV_texture_shader3" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_texture_shader3 = true;
    
    return !error;
  }

  bool InitGL_NV_texture_shader2 ()
  {
    bool error = false;

    if ( checked_GL_NV_texture_shader2 == true )
      return NIV_GL_NV_texture_shader2;

    checked_GL_NV_texture_shader2 = true;
  
    if (strstr( GLExtensionString, "GL_NV_texture_shader2" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_texture_shader2 = true;
    
    return !error;
  }

  bool InitGL_EXT_blend_func_separate ()
  {
    bool error = false;

    if ( checked_GL_EXT_blend_func_separate == true )
      return NIV_GL_EXT_blend_func_separate;

    checked_GL_EXT_blend_func_separate = true;
  
    if (strstr( GLExtensionString, "GL_EXT_blend_func_separate" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLBLENDFUNCSEPARATEEXT, glBlendFuncSeparateEXT );


    if (error == false)
      NIV_GL_EXT_blend_func_separate = true;
    
    return !error;
  }

  bool InitGL_SGIX_pixel_texture_bits ()
  {
    bool error = false;

    if ( checked_GL_SGIX_pixel_texture_bits == true )
      return NIV_GL_SGIX_pixel_texture_bits;

    checked_GL_SGIX_pixel_texture_bits = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_pixel_texture_bits" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_pixel_texture_bits = true;
    
    return !error;
  }

  bool InitGL_EXT_texture ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture == true )
      return NIV_GL_EXT_texture;

    checked_GL_EXT_texture = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture = true;
    
    return !error;
  }

  bool InitGL_APPLE_fence ()
  {
    bool error = false;

    if ( checked_GL_APPLE_fence == true )
      return NIV_GL_APPLE_fence;

    checked_GL_APPLE_fence = true;
  
    if (strstr( GLExtensionString, "GL_APPLE_fence" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLDELETEFENCESAPPLE, glDeleteFencesAPPLE );
    INIT_FUNCTION( nivenGLISFENCEAPPLE, glIsFenceAPPLE );
    INIT_FUNCTION( nivenGLFINISHOBJECTAPPLE, glFinishObjectAPPLE );
    INIT_FUNCTION( nivenGLTESTOBJECTAPPLE, glTestObjectAPPLE );
    INIT_FUNCTION( nivenGLTESTFENCEAPPLE, glTestFenceAPPLE );
    INIT_FUNCTION( nivenGLFINISHFENCEAPPLE, glFinishFenceAPPLE );
    INIT_FUNCTION( nivenGLGENFENCESAPPLE, glGenFencesAPPLE );
    INIT_FUNCTION( nivenGLSETFENCEAPPLE, glSetFenceAPPLE );


    if (error == false)
      NIV_GL_APPLE_fence = true;
    
    return !error;
  }

  bool InitGL_EXT_multisample ()
  {
    bool error = false;

    if ( checked_GL_EXT_multisample == true )
      return NIV_GL_EXT_multisample;

    checked_GL_EXT_multisample = true;
  
    if (strstr( GLExtensionString, "GL_EXT_multisample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLSAMPLEMASKEXT, glSampleMaskEXT );
    INIT_FUNCTION( nivenGLSAMPLEPATTERNEXT, glSamplePatternEXT );


    if (error == false)
      NIV_GL_EXT_multisample = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_cube_map ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_cube_map == true )
      return NIV_GL_EXT_texture_cube_map;

    checked_GL_EXT_texture_cube_map = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_cube_map" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_cube_map = true;
    
    return !error;
  }

  bool InitGL_ARB_occlusion_query ()
  {
    bool error = false;

    if ( checked_GL_ARB_occlusion_query == true )
      return NIV_GL_ARB_occlusion_query;

    checked_GL_ARB_occlusion_query = true;
  
    if (strstr( GLExtensionString, "GL_ARB_occlusion_query" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETQUERYOBJECTUIVARB, glGetQueryObjectuivARB );
    INIT_FUNCTION( nivenGLGETQUERYIVARB, glGetQueryivARB );
    INIT_FUNCTION( nivenGLGENQUERIESARB, glGenQueriesARB );
    INIT_FUNCTION( nivenGLGETQUERYOBJECTIVARB, glGetQueryObjectivARB );
    INIT_FUNCTION( nivenGLENDQUERYARB, glEndQueryARB );
    INIT_FUNCTION( nivenGLISQUERYARB, glIsQueryARB );
    INIT_FUNCTION( nivenGLBEGINQUERYARB, glBeginQueryARB );
    INIT_FUNCTION( nivenGLDELETEQUERIESARB, glDeleteQueriesARB );


    if (error == false)
      NIV_GL_ARB_occlusion_query = true;
    
    return !error;
  }

  bool InitGL_INGR_color_clamp ()
  {
    bool error = false;

    if ( checked_GL_INGR_color_clamp == true )
      return NIV_GL_INGR_color_clamp;

    checked_GL_INGR_color_clamp = true;
  
    if (strstr( GLExtensionString, "GL_INGR_color_clamp" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_INGR_color_clamp = true;
    
    return !error;
  }

  bool InitGL_EXT_422_pixels ()
  {
    bool error = false;

    if ( checked_GL_EXT_422_pixels == true )
      return NIV_GL_EXT_422_pixels;

    checked_GL_EXT_422_pixels = true;
  
    if (strstr( GLExtensionString, "GL_EXT_422_pixels" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_422_pixels = true;
    
    return !error;
  }

  bool InitGL_EXT_index_func ()
  {
    bool error = false;

    if ( checked_GL_EXT_index_func == true )
      return NIV_GL_EXT_index_func;

    checked_GL_EXT_index_func = true;
  
    if (strstr( GLExtensionString, "GL_EXT_index_func" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLINDEXFUNCEXT, glIndexFuncEXT );


    if (error == false)
      NIV_GL_EXT_index_func = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_MESA_set_3dfx_mode ()
  {
    bool error = false;

    if ( checked_GLX_MESA_set_3dfx_mode == true )
      return NIV_GLX_MESA_set_3dfx_mode;

    checked_GLX_MESA_set_3dfx_mode = true;
  
    if (strstr( GLXExtensionString, "GLX_MESA_set_3dfx_mode" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXSET3DFXMODEMESA, glXSet3DfxModeMESA );


    if (error == false)
      NIV_GLX_MESA_set_3dfx_mode = true;
    
    return !error;
  }
#endif

#ifdef _WIN32
  bool InitWGL_NV_float_buffer ()
  {
    bool error = false;

    if ( checked_WGL_NV_float_buffer == true )
      return NIV_WGL_NV_float_buffer;

    checked_WGL_NV_float_buffer = true;
  
    if (strstr( WGLExtensionString, "WGL_NV_float_buffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_WGL_NV_float_buffer = true;
    
    return !error;
  }
#endif

  bool InitGL_SUN_read_video_pixels ()
  {
    bool error = false;

    if ( checked_GL_SUN_read_video_pixels == true )
      return NIV_GL_SUN_read_video_pixels;

    checked_GL_SUN_read_video_pixels = true;
  
    if (strstr( GLExtensionString, "GL_SUN_read_video_pixels" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLREADVIDEOPIXELSSUN, glReadVideoPixelsSUN );


    if (error == false)
      NIV_GL_SUN_read_video_pixels = true;
    
    return !error;
  }

  bool InitGL_ARB_transpose_matrix ()
  {
    bool error = false;

    if ( checked_GL_ARB_transpose_matrix == true )
      return NIV_GL_ARB_transpose_matrix;

    checked_GL_ARB_transpose_matrix = true;
  
    if (strstr( GLExtensionString, "GL_ARB_transpose_matrix" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLMULTTRANSPOSEMATRIXDARB, glMultTransposeMatrixdARB );
    INIT_FUNCTION( nivenGLLOADTRANSPOSEMATRIXDARB, glLoadTransposeMatrixdARB );
    INIT_FUNCTION( nivenGLLOADTRANSPOSEMATRIXFARB, glLoadTransposeMatrixfARB );
    INIT_FUNCTION( nivenGLMULTTRANSPOSEMATRIXFARB, glMultTransposeMatrixfARB );


    if (error == false)
      NIV_GL_ARB_transpose_matrix = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_EXT_extensions_string ()
  {
    bool error = false;

    if ( checked_WGL_EXT_extensions_string == true )
      return NIV_WGL_EXT_extensions_string;

    checked_WGL_EXT_extensions_string = true;
  

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLGETEXTENSIONSSTRINGEXT, wglGetExtensionsStringEXT );


    if (error == false)
      NIV_WGL_EXT_extensions_string = true;
    
    return !error;
  }
#endif

#ifdef _WIN32
  bool InitWGL_ATI_pixel_format_float ()
  {
    bool error = false;

    if ( checked_WGL_ATI_pixel_format_float == true )
      return NIV_WGL_ATI_pixel_format_float;

    checked_WGL_ATI_pixel_format_float = true;
  
    if (strstr( WGLExtensionString, "WGL_ATI_pixel_format_float" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_WGL_ATI_pixel_format_float = true;
    
    return !error;
  }
#endif

#ifdef _WIN32
  bool InitWGL_I3D_image_buffer ()
  {
    bool error = false;

    if ( checked_WGL_I3D_image_buffer == true )
      return NIV_WGL_I3D_image_buffer;

    checked_WGL_I3D_image_buffer = true;
  
    if (strstr( WGLExtensionString, "WGL_I3D_image_buffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLASSOCIATEIMAGEBUFFEREVENTSI3D, wglAssociateImageBufferEventsI3D );
    INIT_FUNCTION( nivenWGLDESTROYIMAGEBUFFERI3D, wglDestroyImageBufferI3D );
    INIT_FUNCTION( nivenWGLRELEASEIMAGEBUFFEREVENTSI3D, wglReleaseImageBufferEventsI3D );
    INIT_FUNCTION( nivenWGLCREATEIMAGEBUFFERI3D, wglCreateImageBufferI3D );


    if (error == false)
      NIV_WGL_I3D_image_buffer = true;
    
    return !error;
  }
#endif

  bool InitGL_NV_fence ()
  {
    bool error = false;

    if ( checked_GL_NV_fence == true )
      return NIV_GL_NV_fence;

    checked_GL_NV_fence = true;
  
    if (strstr( GLExtensionString, "GL_NV_fence" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLDELETEFENCESNV, glDeleteFencesNV );
    INIT_FUNCTION( nivenGLTESTFENCENV, glTestFenceNV );
    INIT_FUNCTION( nivenGLGENFENCESNV, glGenFencesNV );
    INIT_FUNCTION( nivenGLGETFENCEIVNV, glGetFenceivNV );
    INIT_FUNCTION( nivenGLFINISHFENCENV, glFinishFenceNV );
    INIT_FUNCTION( nivenGLSETFENCENV, glSetFenceNV );
    INIT_FUNCTION( nivenGLISFENCENV, glIsFenceNV );


    if (error == false)
      NIV_GL_NV_fence = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_ATI_render_texture_rectangle ()
  {
    bool error = false;

    if ( checked_WGL_ATI_render_texture_rectangle == true )
      return NIV_WGL_ATI_render_texture_rectangle;

    checked_WGL_ATI_render_texture_rectangle = true;
  
    if (strstr( WGLExtensionString, "WGL_ATI_render_texture_rectangle" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_WGL_ATI_render_texture_rectangle = true;
    
    return !error;
  }
#endif

  bool InitGL_ARB_texture_border_clamp ()
  {
    bool error = false;

    if ( checked_GL_ARB_texture_border_clamp == true )
      return NIV_GL_ARB_texture_border_clamp;

    checked_GL_ARB_texture_border_clamp = true;
  
    if (strstr( GLExtensionString, "GL_ARB_texture_border_clamp" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_texture_border_clamp = true;
    
    return !error;
  }

  bool InitGL_EXT_fog_coord ()
  {
    bool error = false;

    if ( checked_GL_EXT_fog_coord == true )
      return NIV_GL_EXT_fog_coord;

    checked_GL_EXT_fog_coord = true;
  
    if (strstr( GLExtensionString, "GL_EXT_fog_coord" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLFOGCOORDDEXT, glFogCoorddEXT );
    INIT_FUNCTION( nivenGLFOGCOORDPOINTEREXT, glFogCoordPointerEXT );
    INIT_FUNCTION( nivenGLFOGCOORDFVEXT, glFogCoordfvEXT );
    INIT_FUNCTION( nivenGLFOGCOORDDVEXT, glFogCoorddvEXT );
    INIT_FUNCTION( nivenGLFOGCOORDFEXT, glFogCoordfEXT );


    if (error == false)
      NIV_GL_EXT_fog_coord = true;
    
    return !error;
  }

  bool InitGL_NV_depth_clamp ()
  {
    bool error = false;

    if ( checked_GL_NV_depth_clamp == true )
      return NIV_GL_NV_depth_clamp;

    checked_GL_NV_depth_clamp = true;
  
    if (strstr( GLExtensionString, "GL_NV_depth_clamp" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_depth_clamp = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_I3D_digital_video_control ()
  {
    bool error = false;

    if ( checked_WGL_I3D_digital_video_control == true )
      return NIV_WGL_I3D_digital_video_control;

    checked_WGL_I3D_digital_video_control = true;
  
    if (strstr( WGLExtensionString, "WGL_I3D_digital_video_control" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLSETDIGITALVIDEOPARAMETERSI3D, wglSetDigitalVideoParametersI3D );
    INIT_FUNCTION( nivenWGLGETDIGITALVIDEOPARAMETERSI3D, wglGetDigitalVideoParametersI3D );


    if (error == false)
      NIV_WGL_I3D_digital_video_control = true;
    
    return !error;
  }
#endif

  bool InitGL_ARB_texture_cube_map ()
  {
    bool error = false;

    if ( checked_GL_ARB_texture_cube_map == true )
      return NIV_GL_ARB_texture_cube_map;

    checked_GL_ARB_texture_cube_map = true;
  
    if (strstr( GLExtensionString, "GL_ARB_texture_cube_map" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_texture_cube_map = true;
    
    return !error;
  }

  bool InitGL_EXT_color_subtable ()
  {
    bool error = false;

    if ( checked_GL_EXT_color_subtable == true )
      return NIV_GL_EXT_color_subtable;

    checked_GL_EXT_color_subtable = true;
  
    if (strstr( GLExtensionString, "GL_EXT_color_subtable" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLCOPYCOLORSUBTABLEEXT, glCopyColorSubTableEXT );
    INIT_FUNCTION( nivenGLCOLORSUBTABLEEXT, glColorSubTableEXT );


    if (error == false)
      NIV_GL_EXT_color_subtable = true;
    
    return !error;
  }

  bool InitGL_EXT_blend_equation_separate ()
  {
    bool error = false;

    if ( checked_GL_EXT_blend_equation_separate == true )
      return NIV_GL_EXT_blend_equation_separate;

    checked_GL_EXT_blend_equation_separate = true;
  
    if (strstr( GLExtensionString, "GL_EXT_blend_equation_separate" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLBLENDEQUATIONSEPARATEEXT, glBlendEquationSeparateEXT );


    if (error == false)
      NIV_GL_EXT_blend_equation_separate = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_I3D_swap_frame_lock ()
  {
    bool error = false;

    if ( checked_WGL_I3D_swap_frame_lock == true )
      return NIV_WGL_I3D_swap_frame_lock;

    checked_WGL_I3D_swap_frame_lock = true;
  
    if (strstr( WGLExtensionString, "WGL_I3D_swap_frame_lock" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLENABLEFRAMELOCKI3D, wglEnableFrameLockI3D );
    INIT_FUNCTION( nivenWGLQUERYFRAMELOCKMASTERI3D, wglQueryFrameLockMasterI3D );
    INIT_FUNCTION( nivenWGLDISABLEFRAMELOCKI3D, wglDisableFrameLockI3D );
    INIT_FUNCTION( nivenWGLISENABLEDFRAMELOCKI3D, wglIsEnabledFrameLockI3D );


    if (error == false)
      NIV_WGL_I3D_swap_frame_lock = true;
    
    return !error;
  }
#endif

  bool InitGL_SUN_mesh_array ()
  {
    bool error = false;

    if ( checked_GL_SUN_mesh_array == true )
      return NIV_GL_SUN_mesh_array;

    checked_GL_SUN_mesh_array = true;
  
    if (strstr( GLExtensionString, "GL_SUN_mesh_array" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SUN_mesh_array = true;
    
    return !error;
  }

  bool InitGL_SUNX_constant_data ()
  {
    bool error = false;

    if ( checked_GL_SUNX_constant_data == true )
      return NIV_GL_SUNX_constant_data;

    checked_GL_SUNX_constant_data = true;
  
    if (strstr( GLExtensionString, "GL_SUNX_constant_data" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLFINISHTEXTURESUNX, glFinishTextureSUNX );


    if (error == false)
      NIV_GL_SUNX_constant_data = true;
    
    return !error;
  }

  bool InitGL_ARB_point_parameters ()
  {
    bool error = false;

    if ( checked_GL_ARB_point_parameters == true )
      return NIV_GL_ARB_point_parameters;

    checked_GL_ARB_point_parameters = true;
  
    if (strstr( GLExtensionString, "GL_ARB_point_parameters" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLPOINTPARAMETERFARB, glPointParameterfARB );
    INIT_FUNCTION( nivenGLPOINTPARAMETERFVARB, glPointParameterfvARB );


    if (error == false)
      NIV_GL_ARB_point_parameters = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_env_dot3 ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_env_dot3 == true )
      return NIV_GL_EXT_texture_env_dot3;

    checked_GL_EXT_texture_env_dot3 = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_env_dot3" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_env_dot3 = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_ARB_buffer_region ()
  {
    bool error = false;

    if ( checked_WGL_ARB_buffer_region == true )
      return NIV_WGL_ARB_buffer_region;

    checked_WGL_ARB_buffer_region = true;
  
    if (strstr( WGLExtensionString, "WGL_ARB_buffer_region" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLSAVEBUFFERREGIONARB, wglSaveBufferRegionARB );
    INIT_FUNCTION( nivenWGLCREATEBUFFERREGIONARB, wglCreateBufferRegionARB );
    INIT_FUNCTION( nivenWGLDELETEBUFFERREGIONARB, wglDeleteBufferRegionARB );
    INIT_FUNCTION( nivenWGLRESTOREBUFFERREGIONARB, wglRestoreBufferRegionARB );


    if (error == false)
      NIV_WGL_ARB_buffer_region = true;
    
    return !error;
  }
#endif

  bool InitGL_ATI_texture_env_combine3 ()
  {
    bool error = false;

    if ( checked_GL_ATI_texture_env_combine3 == true )
      return NIV_GL_ATI_texture_env_combine3;

    checked_GL_ATI_texture_env_combine3 = true;
  
    if (strstr( GLExtensionString, "GL_ATI_texture_env_combine3" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ATI_texture_env_combine3 = true;
    
    return !error;
  }

  bool InitGL_SGIX_shadow_ambient ()
  {
    bool error = false;

    if ( checked_GL_SGIX_shadow_ambient == true )
      return NIV_GL_SGIX_shadow_ambient;

    checked_GL_SGIX_shadow_ambient = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_shadow_ambient" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_shadow_ambient = true;
    
    return !error;
  }

  bool InitGL_EXT_multi_draw_arrays ()
  {
    bool error = false;

    if ( checked_GL_EXT_multi_draw_arrays == true )
      return NIV_GL_EXT_multi_draw_arrays;

    checked_GL_EXT_multi_draw_arrays = true;
  
    if (strstr( GLExtensionString, "GL_EXT_multi_draw_arrays" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLMULTIDRAWELEMENTSEXT, glMultiDrawElementsEXT );
    INIT_FUNCTION( nivenGLMULTIDRAWARRAYSEXT, glMultiDrawArraysEXT );


    if (error == false)
      NIV_GL_EXT_multi_draw_arrays = true;
    
    return !error;
  }

  bool InitGL_SGIX_depth_texture ()
  {
    bool error = false;

    if ( checked_GL_SGIX_depth_texture == true )
      return NIV_GL_SGIX_depth_texture;

    checked_GL_SGIX_depth_texture = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_depth_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_depth_texture = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_compression_dxt1 ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_compression_dxt1 == true )
      return NIV_GL_EXT_texture_compression_dxt1;

    checked_GL_EXT_texture_compression_dxt1 = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_compression_dxt1" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_compression_dxt1 = true;
    
    return !error;
  }

  bool InitGL_NV_texgen_emboss ()
  {
    bool error = false;

    if ( checked_GL_NV_texgen_emboss == true )
      return NIV_GL_NV_texgen_emboss;

    checked_GL_NV_texgen_emboss = true;
  
    if (strstr( GLExtensionString, "GL_NV_texgen_emboss" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_texgen_emboss = true;
    
    return !error;
  }

  bool InitGL_HP_occlusion_test ()
  {
    bool error = false;

    if ( checked_GL_HP_occlusion_test == true )
      return NIV_GL_HP_occlusion_test;

    checked_GL_HP_occlusion_test = true;
  
    if (strstr( GLExtensionString, "GL_HP_occlusion_test" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_HP_occlusion_test = true;
    
    return !error;
  }

  bool InitGL_WIN_phong_shading ()
  {
    bool error = false;

    if ( checked_GL_WIN_phong_shading == true )
      return NIV_GL_WIN_phong_shading;

    checked_GL_WIN_phong_shading = true;
  
    if (strstr( GLExtensionString, "GL_WIN_phong_shading" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_WIN_phong_shading = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGIS_shared_multisample ()
  {
    bool error = false;

    if ( checked_GLX_SGIS_shared_multisample == true )
      return NIV_GLX_SGIS_shared_multisample;

    checked_GLX_SGIS_shared_multisample = true;
  
    if (strstr( GLXExtensionString, "GLX_SGIS_shared_multisample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_SGIS_shared_multisample = true;
    
    return !error;
  }
#endif

  bool InitGL_ATIX_texture_env_combine3 ()
  {
    bool error = false;

    if ( checked_GL_ATIX_texture_env_combine3 == true )
      return NIV_GL_ATIX_texture_env_combine3;

    checked_GL_ATIX_texture_env_combine3 = true;
  
    if (strstr( GLExtensionString, "GL_ATIX_texture_env_combine3" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ATIX_texture_env_combine3 = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_filter_anisotropic ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_filter_anisotropic == true )
      return NIV_GL_EXT_texture_filter_anisotropic;

    checked_GL_EXT_texture_filter_anisotropic = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_filter_anisotropic" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_filter_anisotropic = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_perturb_normal ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_perturb_normal == true )
      return NIV_GL_EXT_texture_perturb_normal;

    checked_GL_EXT_texture_perturb_normal = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_perturb_normal" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTEXTURENORMALEXT, glTextureNormalEXT );


    if (error == false)
      NIV_GL_EXT_texture_perturb_normal = true;
    
    return !error;
  }

  bool InitGL_NV_fog_distance ()
  {
    bool error = false;

    if ( checked_GL_NV_fog_distance == true )
      return NIV_GL_NV_fog_distance;

    checked_GL_NV_fog_distance = true;
  
    if (strstr( GLExtensionString, "GL_NV_fog_distance" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_fog_distance = true;
    
    return !error;
  }

  bool InitGL_ATIX_vertex_shader_output_point_size ()
  {
    bool error = false;

    if ( checked_GL_ATIX_vertex_shader_output_point_size == true )
      return NIV_GL_ATIX_vertex_shader_output_point_size;

    checked_GL_ATIX_vertex_shader_output_point_size = true;
  
    if (strstr( GLExtensionString, "GL_ATIX_vertex_shader_output_point_size" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ATIX_vertex_shader_output_point_size = true;
    
    return !error;
  }

  bool InitGL_SUN_global_alpha ()
  {
    bool error = false;

    if ( checked_GL_SUN_global_alpha == true )
      return NIV_GL_SUN_global_alpha;

    checked_GL_SUN_global_alpha = true;
  
    if (strstr( GLExtensionString, "GL_SUN_global_alpha" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGLOBALALPHAFACTORDSUN, glGlobalAlphaFactordSUN );
    INIT_FUNCTION( nivenGLGLOBALALPHAFACTORSSUN, glGlobalAlphaFactorsSUN );
    INIT_FUNCTION( nivenGLGLOBALALPHAFACTORISUN, glGlobalAlphaFactoriSUN );
    INIT_FUNCTION( nivenGLGLOBALALPHAFACTORUSSUN, glGlobalAlphaFactorusSUN );
    INIT_FUNCTION( nivenGLGLOBALALPHAFACTORFSUN, glGlobalAlphaFactorfSUN );
    INIT_FUNCTION( nivenGLGLOBALALPHAFACTORBSUN, glGlobalAlphaFactorbSUN );
    INIT_FUNCTION( nivenGLGLOBALALPHAFACTORUISUN, glGlobalAlphaFactoruiSUN );
    INIT_FUNCTION( nivenGLGLOBALALPHAFACTORUBSUN, glGlobalAlphaFactorubSUN );


    if (error == false)
      NIV_GL_SUN_global_alpha = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_EXT_pixel_format ()
  {
    bool error = false;

    if ( checked_WGL_EXT_pixel_format == true )
      return NIV_WGL_EXT_pixel_format;

    checked_WGL_EXT_pixel_format = true;
  
    if (strstr( WGLExtensionString, "WGL_EXT_pixel_format" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLGETPIXELFORMATATTRIBFVEXT, wglGetPixelFormatAttribfvEXT );
    INIT_FUNCTION( nivenWGLCHOOSEPIXELFORMATEXT, wglChoosePixelFormatEXT );
    INIT_FUNCTION( nivenWGLGETPIXELFORMATATTRIBIVEXT, wglGetPixelFormatAttribivEXT );


    if (error == false)
      NIV_WGL_EXT_pixel_format = true;
    
    return !error;
  }
#endif

  bool InitGL_SGIX_async_histogram ()
  {
    bool error = false;

    if ( checked_GL_SGIX_async_histogram == true )
      return NIV_GL_SGIX_async_histogram;

    checked_GL_SGIX_async_histogram = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_async_histogram" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_async_histogram = true;
    
    return !error;
  }

  bool InitGL_ARB_vertex_program ()
  {
    bool error = false;

    if ( checked_GL_ARB_vertex_program == true )
      return NIV_GL_ARB_vertex_program;

    checked_GL_ARB_vertex_program = true;
  
    if (strstr( GLExtensionString, "GL_ARB_vertex_program" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLVERTEXATTRIB4UBVARB, glVertexAttrib4ubvARB );
    INIT_FUNCTION( nivenGLDISABLEVERTEXATTRIBARRAYARB, glDisableVertexAttribArrayARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4NSVARB, glVertexAttrib4NsvARB );
    INIT_FUNCTION( nivenGLGETPROGRAMLOCALPARAMETERFVARB, glGetProgramLocalParameterfvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2DVARB, glVertexAttrib2dvARB );
    INIT_FUNCTION( nivenGLPROGRAMENVPARAMETER4FVARB, glProgramEnvParameter4fvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4NIVARB, glVertexAttrib4NivARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1SARB, glVertexAttrib1sARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4UIVARB, glVertexAttrib4uivARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4NUBARB, glVertexAttrib4NubARB );
    INIT_FUNCTION( nivenGLPROGRAMLOCALPARAMETER4DARB, glProgramLocalParameter4dARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3FVARB, glVertexAttrib3fvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1FVARB, glVertexAttrib1fvARB );
    INIT_FUNCTION( nivenGLGETPROGRAMSTRINGARB, glGetProgramStringARB );
    INIT_FUNCTION( nivenGLGETPROGRAMLOCALPARAMETERDVARB, glGetProgramLocalParameterdvARB );
    INIT_FUNCTION( nivenGLENABLEVERTEXATTRIBARRAYARB, glEnableVertexAttribArrayARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2FVARB, glVertexAttrib2fvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3DVARB, glVertexAttrib3dvARB );
    INIT_FUNCTION( nivenGLPROGRAMENVPARAMETER4FARB, glProgramEnvParameter4fARB );
    INIT_FUNCTION( nivenGLGETVERTEXATTRIBIVARB, glGetVertexAttribivARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4SVARB, glVertexAttrib4svARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4FARB, glVertexAttrib4fARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3DARB, glVertexAttrib3dARB );
    INIT_FUNCTION( nivenGLISPROGRAMARB, glIsProgramARB );
    INIT_FUNCTION( nivenGLPROGRAMLOCALPARAMETER4DVARB, glProgramLocalParameter4dvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2SVARB, glVertexAttrib2svARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1DARB, glVertexAttrib1dARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1FARB, glVertexAttrib1fARB );
    INIT_FUNCTION( nivenGLPROGRAMLOCALPARAMETER4FVARB, glProgramLocalParameter4fvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2FARB, glVertexAttrib2fARB );
    INIT_FUNCTION( nivenGLPROGRAMENVPARAMETER4DARB, glProgramEnvParameter4dARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2DARB, glVertexAttrib2dARB );
    INIT_FUNCTION( nivenGLGETVERTEXATTRIBFVARB, glGetVertexAttribfvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4NUSVARB, glVertexAttrib4NusvARB );
    INIT_FUNCTION( nivenGLGETVERTEXATTRIBPOINTERVARB, glGetVertexAttribPointervARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3FARB, glVertexAttrib3fARB );
    INIT_FUNCTION( nivenGLGETPROGRAMENVPARAMETERDVARB, glGetProgramEnvParameterdvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4NUBVARB, glVertexAttrib4NubvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3SARB, glVertexAttrib3sARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4IVARB, glVertexAttrib4ivARB );
    INIT_FUNCTION( nivenGLDELETEPROGRAMSARB, glDeleteProgramsARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4NBVARB, glVertexAttrib4NbvARB );
    INIT_FUNCTION( nivenGLGETPROGRAMIVARB, glGetProgramivARB );
    INIT_FUNCTION( nivenGLPROGRAMENVPARAMETER4DVARB, glProgramEnvParameter4dvARB );
    INIT_FUNCTION( nivenGLGETVERTEXATTRIBDVARB, glGetVertexAttribdvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4USVARB, glVertexAttrib4usvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1SVARB, glVertexAttrib1svARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4SARB, glVertexAttrib4sARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4DVARB, glVertexAttrib4dvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4BVARB, glVertexAttrib4bvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIBPOINTERARB, glVertexAttribPointerARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3SVARB, glVertexAttrib3svARB );
    INIT_FUNCTION( nivenGLBINDPROGRAMARB, glBindProgramARB );
    INIT_FUNCTION( nivenGLPROGRAMSTRINGARB, glProgramStringARB );
    INIT_FUNCTION( nivenGLPROGRAMLOCALPARAMETER4FARB, glProgramLocalParameter4fARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4FVARB, glVertexAttrib4fvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4DARB, glVertexAttrib4dARB );
    INIT_FUNCTION( nivenGLGETPROGRAMENVPARAMETERFVARB, glGetProgramEnvParameterfvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1DVARB, glVertexAttrib1dvARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2SARB, glVertexAttrib2sARB );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4NUIVARB, glVertexAttrib4NuivARB );
    INIT_FUNCTION( nivenGLGENPROGRAMSARB, glGenProgramsARB );


    if (error == false)
      NIV_GL_ARB_vertex_program = true;
    
    return !error;
  }

  bool InitGL_MESA_resize_buffers ()
  {
    bool error = false;

    if ( checked_GL_MESA_resize_buffers == true )
      return NIV_GL_MESA_resize_buffers;

    checked_GL_MESA_resize_buffers = true;
  
    if (strstr( GLExtensionString, "GL_MESA_resize_buffers" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLRESIZEBUFFERSMESA, glResizeBuffersMESA );


    if (error == false)
      NIV_GL_MESA_resize_buffers = true;
    
    return !error;
  }

  bool InitGL_3DFX_multisample ()
  {
    bool error = false;

    if ( checked_GL_3DFX_multisample == true )
      return NIV_GL_3DFX_multisample;

    checked_GL_3DFX_multisample = true;
  
    if (strstr( GLExtensionString, "GL_3DFX_multisample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_3DFX_multisample = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_NV_render_texture_rectangle ()
  {
    bool error = false;

    if ( checked_WGL_NV_render_texture_rectangle == true )
      return NIV_WGL_NV_render_texture_rectangle;

    checked_WGL_NV_render_texture_rectangle = true;
  
    if (strstr( WGLExtensionString, "WGL_NV_render_texture_rectangle" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_WGL_NV_render_texture_rectangle = true;
    
    return !error;
  }
#endif

  bool InitGL_ARB_texture_env_dot3 ()
  {
    bool error = false;

    if ( checked_GL_ARB_texture_env_dot3 == true )
      return NIV_GL_ARB_texture_env_dot3;

    checked_GL_ARB_texture_env_dot3 = true;
  
    if (strstr( GLExtensionString, "GL_ARB_texture_env_dot3" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_texture_env_dot3 = true;
    
    return !error;
  }

  bool InitGL_EXT_bgra ()
  {
    bool error = false;

    if ( checked_GL_EXT_bgra == true )
      return NIV_GL_EXT_bgra;

    checked_GL_EXT_bgra = true;
  
    if (strstr( GLExtensionString, "GL_EXT_bgra" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_bgra = true;
    
    return !error;
  }

  bool InitGL_NV_float_buffer ()
  {
    bool error = false;

    if ( checked_GL_NV_float_buffer == true )
      return NIV_GL_NV_float_buffer;

    checked_GL_NV_float_buffer = true;
  
    if (strstr( GLExtensionString, "GL_NV_float_buffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_float_buffer = true;
    
    return !error;
  }

  bool InitGL_INGR_interlace_read ()
  {
    bool error = false;

    if ( checked_GL_INGR_interlace_read == true )
      return NIV_GL_INGR_interlace_read;

    checked_GL_INGR_interlace_read = true;
  
    if (strstr( GLExtensionString, "GL_INGR_interlace_read" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_INGR_interlace_read = true;
    
    return !error;
  }

  bool InitGL_NV_texture_env_combine4 ()
  {
    bool error = false;

    if ( checked_GL_NV_texture_env_combine4 == true )
      return NIV_GL_NV_texture_env_combine4;

    checked_GL_NV_texture_env_combine4 = true;
  
    if (strstr( GLExtensionString, "GL_NV_texture_env_combine4" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_texture_env_combine4 = true;
    
    return !error;
  }

  bool InitGL_OML_interlace ()
  {
    bool error = false;

    if ( checked_GL_OML_interlace == true )
      return NIV_GL_OML_interlace;

    checked_GL_OML_interlace = true;
  
    if (strstr( GLExtensionString, "GL_OML_interlace" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_OML_interlace = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGI_swap_control ()
  {
    bool error = false;

    if ( checked_GLX_SGI_swap_control == true )
      return NIV_GLX_SGI_swap_control;

    checked_GLX_SGI_swap_control = true;
  
    if (strstr( GLXExtensionString, "GLX_SGI_swap_control" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXSWAPINTERVALSGI, glXSwapIntervalSGI );


    if (error == false)
      NIV_GLX_SGI_swap_control = true;
    
    return !error;
  }
#endif

#ifdef _WIN32
  bool InitWGL_EXT_depth_float ()
  {
    bool error = false;

    if ( checked_WGL_EXT_depth_float == true )
      return NIV_WGL_EXT_depth_float;

    checked_WGL_EXT_depth_float = true;
  
    if (strstr( WGLExtensionString, "WGL_EXT_depth_float" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_WGL_EXT_depth_float = true;
    
    return !error;
  }
#endif

#ifdef _WIN32
  bool InitWGL_ARB_multisample ()
  {
    bool error = false;

    if ( checked_WGL_ARB_multisample == true )
      return NIV_WGL_ARB_multisample;

    checked_WGL_ARB_multisample = true;
  
    if (strstr( WGLExtensionString, "WGL_ARB_multisample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_WGL_ARB_multisample = true;
    
    return !error;
  }
#endif

  bool InitGL_ATI_fragment_shader ()
  {
    bool error = false;

    if ( checked_GL_ATI_fragment_shader == true )
      return NIV_GL_ATI_fragment_shader;

    checked_GL_ATI_fragment_shader = true;
  
    if (strstr( GLExtensionString, "GL_ATI_fragment_shader" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLBEGINFRAGMENTSHADERATI, glBeginFragmentShaderATI );
    INIT_FUNCTION( nivenGLALPHAFRAGMENTOP3ATI, glAlphaFragmentOp3ATI );
    INIT_FUNCTION( nivenGLCOLORFRAGMENTOP3ATI, glColorFragmentOp3ATI );
    INIT_FUNCTION( nivenGLDELETEFRAGMENTSHADERATI, glDeleteFragmentShaderATI );
    INIT_FUNCTION( nivenGLSAMPLEMAPATI, glSampleMapATI );
    INIT_FUNCTION( nivenGLGENFRAGMENTSHADERSATI, glGenFragmentShadersATI );
    INIT_FUNCTION( nivenGLSETFRAGMENTSHADERCONSTANTATI, glSetFragmentShaderConstantATI );
    INIT_FUNCTION( nivenGLCOLORFRAGMENTOP2ATI, glColorFragmentOp2ATI );
    INIT_FUNCTION( nivenGLCOLORFRAGMENTOP1ATI, glColorFragmentOp1ATI );
    INIT_FUNCTION( nivenGLALPHAFRAGMENTOP1ATI, glAlphaFragmentOp1ATI );
    INIT_FUNCTION( nivenGLALPHAFRAGMENTOP2ATI, glAlphaFragmentOp2ATI );
    INIT_FUNCTION( nivenGLBINDFRAGMENTSHADERATI, glBindFragmentShaderATI );
    INIT_FUNCTION( nivenGLENDFRAGMENTSHADERATI, glEndFragmentShaderATI );
    INIT_FUNCTION( nivenGLPASSTEXCOORDATI, glPassTexCoordATI );


    if (error == false)
      NIV_GL_ATI_fragment_shader = true;
    
    return !error;
  }

  bool InitGL_ARB_texture_env_combine ()
  {
    bool error = false;

    if ( checked_GL_ARB_texture_env_combine == true )
      return NIV_GL_ARB_texture_env_combine;

    checked_GL_ARB_texture_env_combine = true;
  
    if (strstr( GLExtensionString, "GL_ARB_texture_env_combine" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_texture_env_combine = true;
    
    return !error;
  }

  bool InitGL_ARB_vertex_buffer_object ()
  {
    bool error = false;

    if ( checked_GL_ARB_vertex_buffer_object == true )
      return NIV_GL_ARB_vertex_buffer_object;

    checked_GL_ARB_vertex_buffer_object = true;
  
    if (strstr( GLExtensionString, "GL_ARB_vertex_buffer_object" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGENBUFFERSARB, glGenBuffersARB );
    INIT_FUNCTION( nivenGLBUFFERSUBDATAARB, glBufferSubDataARB );
    INIT_FUNCTION( nivenGLDELETEBUFFERSARB, glDeleteBuffersARB );
    INIT_FUNCTION( nivenGLUNMAPBUFFERARB, glUnmapBufferARB );
    INIT_FUNCTION( nivenGLBINDBUFFERARB, glBindBufferARB );
    INIT_FUNCTION( nivenGLGETBUFFERPARAMETERIVARB, glGetBufferParameterivARB );
    INIT_FUNCTION( nivenGLGETBUFFERPOINTERVARB, glGetBufferPointervARB );
    INIT_FUNCTION( nivenGLGETBUFFERSUBDATAARB, glGetBufferSubDataARB );
    INIT_FUNCTION( nivenGLMAPBUFFERARB, glMapBufferARB );
    INIT_FUNCTION( nivenGLBUFFERDATAARB, glBufferDataARB );
    INIT_FUNCTION( nivenGLISBUFFERARB, glIsBufferARB );


    if (error == false)
      NIV_GL_ARB_vertex_buffer_object = true;
    
    return !error;
  }

  bool InitGL_SUN_triangle_list ()
  {
    bool error = false;

    if ( checked_GL_SUN_triangle_list == true )
      return NIV_GL_SUN_triangle_list;

    checked_GL_SUN_triangle_list = true;
  
    if (strstr( GLExtensionString, "GL_SUN_triangle_list" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLREPLACEMENTCODEUBVSUN, glReplacementCodeubvSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUISUN, glReplacementCodeuiSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUIVSUN, glReplacementCodeuivSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEPOINTERSUN, glReplacementCodePointerSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUSVSUN, glReplacementCodeusvSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUSSUN, glReplacementCodeusSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUBSUN, glReplacementCodeubSUN );


    if (error == false)
      NIV_GL_SUN_triangle_list = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_EXT_swap_control ()
  {
    bool error = false;

    if ( checked_WGL_EXT_swap_control == true )
      return NIV_WGL_EXT_swap_control;

    checked_WGL_EXT_swap_control = true;
  
    if (strstr( WGLExtensionString, "WGL_EXT_swap_control" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLGETSWAPINTERVALEXT, wglGetSwapIntervalEXT );
    INIT_FUNCTION( nivenWGLSWAPINTERVALEXT, wglSwapIntervalEXT );


    if (error == false)
      NIV_WGL_EXT_swap_control = true;
    
    return !error;
  }
#endif

#ifdef _GLX
  bool InitGLX_EXT_scene_marker ()
  {
    bool error = false;

    if ( checked_GLX_EXT_scene_marker == true )
      return NIV_GLX_EXT_scene_marker;

    checked_GLX_EXT_scene_marker = true;
  
    if (strstr( GLXExtensionString, "GLX_EXT_scene_marker" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_EXT_scene_marker = true;
    
    return !error;
  }
#endif

  bool InitGL_ATI_text_fragment_shader ()
  {
    bool error = false;

    if ( checked_GL_ATI_text_fragment_shader == true )
      return NIV_GL_ATI_text_fragment_shader;

    checked_GL_ATI_text_fragment_shader = true;
  
    if (strstr( GLExtensionString, "GL_ATI_text_fragment_shader" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ATI_text_fragment_shader = true;
    
    return !error;
  }

  bool InitGL_EXT_histogram ()
  {
    bool error = false;

    if ( checked_GL_EXT_histogram == true )
      return NIV_GL_EXT_histogram;

    checked_GL_EXT_histogram = true;
  
    if (strstr( GLExtensionString, "GL_EXT_histogram" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETMINMAXPARAMETERFVEXT, glGetMinmaxParameterfvEXT );
    INIT_FUNCTION( nivenGLMINMAXEXT, glMinmaxEXT );
    INIT_FUNCTION( nivenGLGETHISTOGRAMPARAMETERIVEXT, glGetHistogramParameterivEXT );
    INIT_FUNCTION( nivenGLGETMINMAXPARAMETERIVEXT, glGetMinmaxParameterivEXT );
    INIT_FUNCTION( nivenGLRESETHISTOGRAMEXT, glResetHistogramEXT );
    INIT_FUNCTION( nivenGLRESETMINMAXEXT, glResetMinmaxEXT );
    INIT_FUNCTION( nivenGLGETMINMAXEXT, glGetMinmaxEXT );
    INIT_FUNCTION( nivenGLGETHISTOGRAMEXT, glGetHistogramEXT );
    INIT_FUNCTION( nivenGLHISTOGRAMEXT, glHistogramEXT );
    INIT_FUNCTION( nivenGLGETHISTOGRAMPARAMETERFVEXT, glGetHistogramParameterfvEXT );


    if (error == false)
      NIV_GL_EXT_histogram = true;
    
    return !error;
  }

  bool InitGL_NV_vertex_program3 ()
  {
    bool error = false;

    if ( checked_GL_NV_vertex_program3 == true )
      return NIV_GL_NV_vertex_program3;

    checked_GL_NV_vertex_program3 = true;
  
    if (strstr( GLExtensionString, "GL_NV_vertex_program3" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_vertex_program3 = true;
    
    return !error;
  }

  bool InitGL_NV_vertex_array_range ()
  {
    bool error = false;

    if ( checked_GL_NV_vertex_array_range == true )
      return NIV_GL_NV_vertex_array_range;

    checked_GL_NV_vertex_array_range = true;
  
    if (strstr( GLExtensionString, "GL_NV_vertex_array_range" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLFLUSHVERTEXARRAYRANGENV, glFlushVertexArrayRangeNV );
    INIT_FUNCTION( nivenGLVERTEXARRAYRANGENV, glVertexArrayRangeNV );


    if (error == false)
      NIV_GL_NV_vertex_array_range = true;
    
    return !error;
  }

  bool InitGL_HP_texture_lighting ()
  {
    bool error = false;

    if ( checked_GL_HP_texture_lighting == true )
      return NIV_GL_HP_texture_lighting;

    checked_GL_HP_texture_lighting = true;
  
    if (strstr( GLExtensionString, "GL_HP_texture_lighting" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_HP_texture_lighting = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_EXT_display_color_table ()
  {
    bool error = false;

    if ( checked_WGL_EXT_display_color_table == true )
      return NIV_WGL_EXT_display_color_table;

    checked_WGL_EXT_display_color_table = true;
  
    if (strstr( WGLExtensionString, "WGL_EXT_display_color_table" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLDESTROYDISPLAYCOLORTABLEEXT, wglDestroyDisplayColorTableEXT );
    INIT_FUNCTION( nivenWGLCREATEDISPLAYCOLORTABLEEXT, wglCreateDisplayColorTableEXT );
    INIT_FUNCTION( nivenWGLBINDDISPLAYCOLORTABLEEXT, wglBindDisplayColorTableEXT );
    INIT_FUNCTION( nivenWGLLOADDISPLAYCOLORTABLEEXT, wglLoadDisplayColorTableEXT );


    if (error == false)
      NIV_WGL_EXT_display_color_table = true;
    
    return !error;
  }
#endif

  bool InitGL_NV_texture_expand_normal ()
  {
    bool error = false;

    if ( checked_GL_NV_texture_expand_normal == true )
      return NIV_GL_NV_texture_expand_normal;

    checked_GL_NV_texture_expand_normal = true;
  
    if (strstr( GLExtensionString, "GL_NV_texture_expand_normal" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_texture_expand_normal = true;
    
    return !error;
  }

  bool InitGL_EXT_separate_specular_color ()
  {
    bool error = false;

    if ( checked_GL_EXT_separate_specular_color == true )
      return NIV_GL_EXT_separate_specular_color;

    checked_GL_EXT_separate_specular_color = true;
  
    if (strstr( GLExtensionString, "GL_EXT_separate_specular_color" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_separate_specular_color = true;
    
    return !error;
  }

  bool InitGL_EXT_paletted_texture ()
  {
    bool error = false;

    if ( checked_GL_EXT_paletted_texture == true )
      return NIV_GL_EXT_paletted_texture;

    checked_GL_EXT_paletted_texture = true;
  
    if (strstr( GLExtensionString, "GL_EXT_paletted_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLCOLORTABLEEXT, glColorTableEXT );
    INIT_FUNCTION( nivenGLGETCOLORTABLEPARAMETERFVEXT, glGetColorTableParameterfvEXT );
    INIT_FUNCTION( nivenGLGETCOLORTABLEPARAMETERIVEXT, glGetColorTableParameterivEXT );
    INIT_FUNCTION( nivenGLGETCOLORTABLEEXT, glGetColorTableEXT );


    if (error == false)
      NIV_GL_EXT_paletted_texture = true;
    
    return !error;
  }

  bool InitGL_ATI_texture_float ()
  {
    bool error = false;

    if ( checked_GL_ATI_texture_float == true )
      return NIV_GL_ATI_texture_float;

    checked_GL_ATI_texture_float = true;
  
    if (strstr( GLExtensionString, "GL_ATI_texture_float" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ATI_texture_float = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_env_add ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_env_add == true )
      return NIV_GL_EXT_texture_env_add;

    checked_GL_EXT_texture_env_add = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_env_add" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_env_add = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_mirror_clamp ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_mirror_clamp == true )
      return NIV_GL_EXT_texture_mirror_clamp;

    checked_GL_EXT_texture_mirror_clamp = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_mirror_clamp" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_mirror_clamp = true;
    
    return !error;
  }

  bool InitGL_ATI_pn_triangles ()
  {
    bool error = false;

    if ( checked_GL_ATI_pn_triangles == true )
      return NIV_GL_ATI_pn_triangles;

    checked_GL_ATI_pn_triangles = true;
  
    if (strstr( GLExtensionString, "GL_ATI_pn_triangles" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLPNTRIANGLESFATI, glPNTrianglesfATI );
    INIT_FUNCTION( nivenGLPNTRIANGLESIATI, glPNTrianglesiATI );


    if (error == false)
      NIV_GL_ATI_pn_triangles = true;
    
    return !error;
  }

  bool InitGL_NV_texture_rectangle ()
  {
    bool error = false;

    if ( checked_GL_NV_texture_rectangle == true )
      return NIV_GL_NV_texture_rectangle;

    checked_GL_NV_texture_rectangle = true;
  
    if (strstr( GLExtensionString, "GL_NV_texture_rectangle" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_texture_rectangle = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_OML_sync_control ()
  {
    bool error = false;

    if ( checked_WGL_OML_sync_control == true )
      return NIV_WGL_OML_sync_control;

    checked_WGL_OML_sync_control = true;
  
    if (strstr( WGLExtensionString, "WGL_OML_sync_control" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLGETSYNCVALUESOML, wglGetSyncValuesOML );
    INIT_FUNCTION( nivenWGLGETMSCRATEOML, wglGetMscRateOML );
    INIT_FUNCTION( nivenWGLSWAPBUFFERSMSCOML, wglSwapBuffersMscOML );
    INIT_FUNCTION( nivenWGLSWAPLAYERBUFFERSMSCOML, wglSwapLayerBuffersMscOML );
    INIT_FUNCTION( nivenWGLWAITFORSBCOML, wglWaitForSbcOML );
    INIT_FUNCTION( nivenWGLWAITFORMSCOML, wglWaitForMscOML );


    if (error == false)
      NIV_WGL_OML_sync_control = true;
    
    return !error;
  }
#endif

  bool InitGL_NV_multisample_filter_hint ()
  {
    bool error = false;

    if ( checked_GL_NV_multisample_filter_hint == true )
      return NIV_GL_NV_multisample_filter_hint;

    checked_GL_NV_multisample_filter_hint = true;
  
    if (strstr( GLExtensionString, "GL_NV_multisample_filter_hint" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_multisample_filter_hint = true;
    
    return !error;
  }

  bool InitGL_APPLE_float_pixels ()
  {
    bool error = false;

    if ( checked_GL_APPLE_float_pixels == true )
      return NIV_GL_APPLE_float_pixels;

    checked_GL_APPLE_float_pixels = true;
  
    if (strstr( GLExtensionString, "GL_APPLE_float_pixels" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_APPLE_float_pixels = true;
    
    return !error;
  }

  bool InitGL_SGIS_texture_border_clamp ()
  {
    bool error = false;

    if ( checked_GL_SGIS_texture_border_clamp == true )
      return NIV_GL_SGIS_texture_border_clamp;

    checked_GL_SGIS_texture_border_clamp = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_texture_border_clamp" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIS_texture_border_clamp = true;
    
    return !error;
  }

  bool InitGL_ATI_vertex_attrib_array_object ()
  {
    bool error = false;

    if ( checked_GL_ATI_vertex_attrib_array_object == true )
      return NIV_GL_ATI_vertex_attrib_array_object;

    checked_GL_ATI_vertex_attrib_array_object = true;
  
    if (strstr( GLExtensionString, "GL_ATI_vertex_attrib_array_object" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETVERTEXATTRIBARRAYOBJECTIVATI, glGetVertexAttribArrayObjectivATI );
    INIT_FUNCTION( nivenGLGETVERTEXATTRIBARRAYOBJECTFVATI, glGetVertexAttribArrayObjectfvATI );
    INIT_FUNCTION( nivenGLVERTEXATTRIBARRAYOBJECTATI, glVertexAttribArrayObjectATI );


    if (error == false)
      NIV_GL_ATI_vertex_attrib_array_object = true;
    
    return !error;
  }

  bool InitGL_SGIX_clipmap ()
  {
    bool error = false;

    if ( checked_GL_SGIX_clipmap == true )
      return NIV_GL_SGIX_clipmap;

    checked_GL_SGIX_clipmap = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_clipmap" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_clipmap = true;
    
    return !error;
  }

  bool InitGL_HP_image_transform ()
  {
    bool error = false;

    if ( checked_GL_HP_image_transform == true )
      return NIV_GL_HP_image_transform;

    checked_GL_HP_image_transform = true;
  
    if (strstr( GLExtensionString, "GL_HP_image_transform" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLIMAGETRANSFORMPARAMETERFHP, glImageTransformParameterfHP );
    INIT_FUNCTION( nivenGLGETIMAGETRANSFORMPARAMETERIVHP, glGetImageTransformParameterivHP );
    INIT_FUNCTION( nivenGLIMAGETRANSFORMPARAMETERIVHP, glImageTransformParameterivHP );
    INIT_FUNCTION( nivenGLGETIMAGETRANSFORMPARAMETERFVHP, glGetImageTransformParameterfvHP );
    INIT_FUNCTION( nivenGLIMAGETRANSFORMPARAMETERFVHP, glImageTransformParameterfvHP );
    INIT_FUNCTION( nivenGLIMAGETRANSFORMPARAMETERIHP, glImageTransformParameteriHP );


    if (error == false)
      NIV_GL_HP_image_transform = true;
    
    return !error;
  }

  bool InitGL_SGIX_flush_raster ()
  {
    bool error = false;

    if ( checked_GL_SGIX_flush_raster == true )
      return NIV_GL_SGIX_flush_raster;

    checked_GL_SGIX_flush_raster = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_flush_raster" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLFLUSHRASTERSGIX, glFlushRasterSGIX );


    if (error == false)
      NIV_GL_SGIX_flush_raster = true;
    
    return !error;
  }

  bool InitGL_EXT_light_texture ()
  {
    bool error = false;

    if ( checked_GL_EXT_light_texture == true )
      return NIV_GL_EXT_light_texture;

    checked_GL_EXT_light_texture = true;
  
    if (strstr( GLExtensionString, "GL_EXT_light_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTEXTUREMATERIALEXT, glTextureMaterialEXT );
    INIT_FUNCTION( nivenGLAPPLYTEXTUREEXT, glApplyTextureEXT );
    INIT_FUNCTION( nivenGLTEXTURELIGHTEXT, glTextureLightEXT );


    if (error == false)
      NIV_GL_EXT_light_texture = true;
    
    return !error;
  }

  bool InitGL_ARB_point_sprite ()
  {
    bool error = false;

    if ( checked_GL_ARB_point_sprite == true )
      return NIV_GL_ARB_point_sprite;

    checked_GL_ARB_point_sprite = true;
  
    if (strstr( GLExtensionString, "GL_ARB_point_sprite" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_point_sprite = true;
    
    return !error;
  }

  bool InitGL_MESA_ycbcr_texture ()
  {
    bool error = false;

    if ( checked_GL_MESA_ycbcr_texture == true )
      return NIV_GL_MESA_ycbcr_texture;

    checked_GL_MESA_ycbcr_texture = true;
  
    if (strstr( GLExtensionString, "GL_MESA_ycbcr_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_MESA_ycbcr_texture = true;
    
    return !error;
  }

  bool InitGL_ARB_shading_language_100 ()
  {
    bool error = false;

    if ( checked_GL_ARB_shading_language_100 == true )
      return NIV_GL_ARB_shading_language_100;

    checked_GL_ARB_shading_language_100 = true;
  
    if (strstr( GLExtensionString, "GL_ARB_shading_language_100" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_shading_language_100 = true;
    
    return !error;
  }

  bool InitGL_SGIS_texture_select ()
  {
    bool error = false;

    if ( checked_GL_SGIS_texture_select == true )
      return NIV_GL_SGIS_texture_select;

    checked_GL_SGIS_texture_select = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_texture_select" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIS_texture_select = true;
    
    return !error;
  }

  bool InitGL_NV_vertex_program2 ()
  {
    bool error = false;

    if ( checked_GL_NV_vertex_program2 == true )
      return NIV_GL_NV_vertex_program2;

    checked_GL_NV_vertex_program2 = true;
  
    if (strstr( GLExtensionString, "GL_NV_vertex_program2" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_vertex_program2 = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGI_make_current_read ()
  {
    bool error = false;

    if ( checked_GLX_SGI_make_current_read == true )
      return NIV_GLX_SGI_make_current_read;

    checked_GLX_SGI_make_current_read = true;
  
    if (strstr( GLXExtensionString, "GLX_SGI_make_current_read" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXGETCURRENTREADDRAWABLESGI, glXGetCurrentReadDrawableSGI );
    INIT_FUNCTION( nivenGLXMAKECURRENTREADSGI, glXMakeCurrentReadSGI );


    if (error == false)
      NIV_GLX_SGI_make_current_read = true;
    
    return !error;
  }
#endif

  bool InitGL_ARB_half_float_pixel ()
  {
    bool error = false;

    if ( checked_GL_ARB_half_float_pixel == true )
      return NIV_GL_ARB_half_float_pixel;

    checked_GL_ARB_half_float_pixel = true;
  
    if (strstr( GLExtensionString, "GL_ARB_half_float_pixel" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_half_float_pixel = true;
    
    return !error;
  }

  bool InitGL_KTX_buffer_region ()
  {
    bool error = false;

    if ( checked_GL_KTX_buffer_region == true )
      return NIV_GL_KTX_buffer_region;

    checked_GL_KTX_buffer_region = true;
  
    if (strstr( GLExtensionString, "GL_KTX_buffer_region" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLDELETEBUFFERREGIONEXT, glDeleteBufferRegionEXT );
    INIT_FUNCTION( nivenGLREADBUFFERREGIONEXT, glReadBufferRegionEXT );
    INIT_FUNCTION( nivenGLBUFFERREGIONENABLEDEXT, glBufferRegionEnabledEXT );
    INIT_FUNCTION( nivenGLNEWBUFFERREGIONEXT, glNewBufferRegionEXT );
    INIT_FUNCTION( nivenGLDRAWBUFFERREGIONEXT, glDrawBufferRegionEXT );


    if (error == false)
      NIV_GL_KTX_buffer_region = true;
    
    return !error;
  }

  bool InitGL_EXT_vertex_weighting ()
  {
    bool error = false;

    if ( checked_GL_EXT_vertex_weighting == true )
      return NIV_GL_EXT_vertex_weighting;

    checked_GL_EXT_vertex_weighting = true;
  
    if (strstr( GLExtensionString, "GL_EXT_vertex_weighting" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLVERTEXWEIGHTFVEXT, glVertexWeightfvEXT );
    INIT_FUNCTION( nivenGLVERTEXWEIGHTFEXT, glVertexWeightfEXT );
    INIT_FUNCTION( nivenGLVERTEXWEIGHTPOINTEREXT, glVertexWeightPointerEXT );


    if (error == false)
      NIV_GL_EXT_vertex_weighting = true;
    
    return !error;
  }

  bool InitGL_ATIX_point_sprites ()
  {
    bool error = false;

    if ( checked_GL_ATIX_point_sprites == true )
      return NIV_GL_ATIX_point_sprites;

    checked_GL_ATIX_point_sprites = true;
  
    if (strstr( GLExtensionString, "GL_ATIX_point_sprites" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ATIX_point_sprites = true;
    
    return !error;
  }

  bool InitGL_APPLE_vertex_array_range ()
  {
    bool error = false;

    if ( checked_GL_APPLE_vertex_array_range == true )
      return NIV_GL_APPLE_vertex_array_range;

    checked_GL_APPLE_vertex_array_range = true;
  
    if (strstr( GLExtensionString, "GL_APPLE_vertex_array_range" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLVERTEXARRAYRANGEAPPLE, glVertexArrayRangeAPPLE );
    INIT_FUNCTION( nivenGLFLUSHVERTEXARRAYRANGEAPPLE, glFlushVertexArrayRangeAPPLE );
    INIT_FUNCTION( nivenGLVERTEXARRAYPARAMETERIAPPLE, glVertexArrayParameteriAPPLE );


    if (error == false)
      NIV_GL_APPLE_vertex_array_range = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_NV_float_buffer ()
  {
    bool error = false;

    if ( checked_GLX_NV_float_buffer == true )
      return NIV_GLX_NV_float_buffer;

    checked_GLX_NV_float_buffer = true;
  
    if (strstr( GLXExtensionString, "GLX_NV_float_buffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_NV_float_buffer = true;
    
    return !error;
  }
#endif

  bool InitGL_SGIS_detail_texture ()
  {
    bool error = false;

    if ( checked_GL_SGIS_detail_texture == true )
      return NIV_GL_SGIS_detail_texture;

    checked_GL_SGIS_detail_texture = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_detail_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLDETAILTEXFUNCSGIS, glDetailTexFuncSGIS );
    INIT_FUNCTION( nivenGLGETDETAILTEXFUNCSGIS, glGetDetailTexFuncSGIS );


    if (error == false)
      NIV_GL_SGIS_detail_texture = true;
    
    return !error;
  }

  bool InitGL_SGIX_sprite ()
  {
    bool error = false;

    if ( checked_GL_SGIX_sprite == true )
      return NIV_GL_SGIX_sprite;

    checked_GL_SGIX_sprite = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_sprite" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLSPRITEPARAMETERFSGIX, glSpriteParameterfSGIX );
    INIT_FUNCTION( nivenGLSPRITEPARAMETERISGIX, glSpriteParameteriSGIX );
    INIT_FUNCTION( nivenGLSPRITEPARAMETERIVSGIX, glSpriteParameterivSGIX );
    INIT_FUNCTION( nivenGLSPRITEPARAMETERFVSGIX, glSpriteParameterfvSGIX );


    if (error == false)
      NIV_GL_SGIX_sprite = true;
    
    return !error;
  }

  bool InitGL_NV_register_combiners ()
  {
    bool error = false;

    if ( checked_GL_NV_register_combiners == true )
      return NIV_GL_NV_register_combiners;

    checked_GL_NV_register_combiners = true;
  
    if (strstr( GLExtensionString, "GL_NV_register_combiners" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLCOMBINERPARAMETERFVNV, glCombinerParameterfvNV );
    INIT_FUNCTION( nivenGLCOMBINERPARAMETERIVNV, glCombinerParameterivNV );
    INIT_FUNCTION( nivenGLGETFINALCOMBINERINPUTPARAMETERIVNV, glGetFinalCombinerInputParameterivNV );
    INIT_FUNCTION( nivenGLCOMBINERPARAMETERINV, glCombinerParameteriNV );
    INIT_FUNCTION( nivenGLCOMBINERINPUTNV, glCombinerInputNV );
    INIT_FUNCTION( nivenGLCOMBINEROUTPUTNV, glCombinerOutputNV );
    INIT_FUNCTION( nivenGLGETCOMBINEROUTPUTPARAMETERFVNV, glGetCombinerOutputParameterfvNV );
    INIT_FUNCTION( nivenGLCOMBINERPARAMETERFNV, glCombinerParameterfNV );
    INIT_FUNCTION( nivenGLFINALCOMBINERINPUTNV, glFinalCombinerInputNV );
    INIT_FUNCTION( nivenGLGETFINALCOMBINERINPUTPARAMETERFVNV, glGetFinalCombinerInputParameterfvNV );
    INIT_FUNCTION( nivenGLGETCOMBINERINPUTPARAMETERFVNV, glGetCombinerInputParameterfvNV );
    INIT_FUNCTION( nivenGLGETCOMBINERINPUTPARAMETERIVNV, glGetCombinerInputParameterivNV );
    INIT_FUNCTION( nivenGLGETCOMBINEROUTPUTPARAMETERIVNV, glGetCombinerOutputParameterivNV );


    if (error == false)
      NIV_GL_NV_register_combiners = true;
    
    return !error;
  }

  bool InitGL_ARB_draw_buffers ()
  {
    bool error = false;

    if ( checked_GL_ARB_draw_buffers == true )
      return NIV_GL_ARB_draw_buffers;

    checked_GL_ARB_draw_buffers = true;
  
    if (strstr( GLExtensionString, "GL_ARB_draw_buffers" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLDRAWBUFFERSARB, glDrawBuffersARB );


    if (error == false)
      NIV_GL_ARB_draw_buffers = true;
    
    return !error;
  }

  bool InitGL_ARB_fragment_program_shadow ()
  {
    bool error = false;

    if ( checked_GL_ARB_fragment_program_shadow == true )
      return NIV_GL_ARB_fragment_program_shadow;

    checked_GL_ARB_fragment_program_shadow = true;
  
    if (strstr( GLExtensionString, "GL_ARB_fragment_program_shadow" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_fragment_program_shadow = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_EXT_make_current_read ()
  {
    bool error = false;

    if ( checked_WGL_EXT_make_current_read == true )
      return NIV_WGL_EXT_make_current_read;

    checked_WGL_EXT_make_current_read = true;
  
    if (strstr( WGLExtensionString, "WGL_EXT_make_current_read" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLGETCURRENTREADDCEXT, wglGetCurrentReadDCEXT );
    INIT_FUNCTION( nivenWGLMAKECONTEXTCURRENTEXT, wglMakeContextCurrentEXT );


    if (error == false)
      NIV_WGL_EXT_make_current_read = true;
    
    return !error;
  }
#endif

  bool InitGL_EXT_shared_texture_palette ()
  {
    bool error = false;

    if ( checked_GL_EXT_shared_texture_palette == true )
      return NIV_GL_EXT_shared_texture_palette;

    checked_GL_EXT_shared_texture_palette = true;
  
    if (strstr( GLExtensionString, "GL_EXT_shared_texture_palette" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_shared_texture_palette = true;
    
    return !error;
  }

  bool InitGL_ATI_element_array ()
  {
    bool error = false;

    if ( checked_GL_ATI_element_array == true )
      return NIV_GL_ATI_element_array;

    checked_GL_ATI_element_array = true;
  
    if (strstr( GLExtensionString, "GL_ATI_element_array" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLDRAWELEMENTARRAYATI, glDrawElementArrayATI );
    INIT_FUNCTION( nivenGLELEMENTPOINTERATI, glElementPointerATI );
    INIT_FUNCTION( nivenGLDRAWRANGEELEMENTARRAYATI, glDrawRangeElementArrayATI );


    if (error == false)
      NIV_GL_ATI_element_array = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_ARB_get_proc_address ()
  {
    bool error = false;

    if ( checked_GLX_ARB_get_proc_address == true )
      return NIV_GLX_ARB_get_proc_address;

    checked_GLX_ARB_get_proc_address = true;
  
    if (strstr( GLXExtensionString, "GLX_ARB_get_proc_address" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_ARB_get_proc_address = true;
    
    return !error;
  }
#endif

  bool InitGL_OML_resample ()
  {
    bool error = false;

    if ( checked_GL_OML_resample == true )
      return NIV_GL_OML_resample;

    checked_GL_OML_resample = true;
  
    if (strstr( GLExtensionString, "GL_OML_resample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_OML_resample = true;
    
    return !error;
  }

  bool InitGL_EXT_coordinate_frame ()
  {
    bool error = false;

    if ( checked_GL_EXT_coordinate_frame == true )
      return NIV_GL_EXT_coordinate_frame;

    checked_GL_EXT_coordinate_frame = true;
  
    if (strstr( GLExtensionString, "GL_EXT_coordinate_frame" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTANGENTPOINTEREXT, glTangentPointerEXT );
    INIT_FUNCTION( nivenGLBINORMALPOINTEREXT, glBinormalPointerEXT );


    if (error == false)
      NIV_GL_EXT_coordinate_frame = true;
    
    return !error;
  }

  bool InitGL_ATI_texture_mirror_once ()
  {
    bool error = false;

    if ( checked_GL_ATI_texture_mirror_once == true )
      return NIV_GL_ATI_texture_mirror_once;

    checked_GL_ATI_texture_mirror_once = true;
  
    if (strstr( GLExtensionString, "GL_ATI_texture_mirror_once" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ATI_texture_mirror_once = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_ARB_pbuffer ()
  {
    bool error = false;

    if ( checked_WGL_ARB_pbuffer == true )
      return NIV_WGL_ARB_pbuffer;

    checked_WGL_ARB_pbuffer = true;
  
    if (strstr( WGLExtensionString, "WGL_ARB_pbuffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLRELEASEPBUFFERDCARB, wglReleasePbufferDCARB );
    INIT_FUNCTION( nivenWGLCREATEPBUFFERARB, wglCreatePbufferARB );
    INIT_FUNCTION( nivenWGLQUERYPBUFFERARB, wglQueryPbufferARB );
    INIT_FUNCTION( nivenWGLGETPBUFFERDCARB, wglGetPbufferDCARB );
    INIT_FUNCTION( nivenWGLDESTROYPBUFFERARB, wglDestroyPbufferARB );


    if (error == false)
      NIV_WGL_ARB_pbuffer = true;
    
    return !error;
  }
#endif

  bool InitGL_EXT_cull_vertex ()
  {
    bool error = false;

    if ( checked_GL_EXT_cull_vertex == true )
      return NIV_GL_EXT_cull_vertex;

    checked_GL_EXT_cull_vertex = true;
  
    if (strstr( GLExtensionString, "GL_EXT_cull_vertex" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLCULLPARAMETERDVEXT, glCullParameterdvEXT );
    INIT_FUNCTION( nivenGLCULLPARAMETERFVEXT, glCullParameterfvEXT );


    if (error == false)
      NIV_GL_EXT_cull_vertex = true;
    
    return !error;
  }

  bool InitGL_IBM_rasterpos_clip ()
  {
    bool error = false;

    if ( checked_GL_IBM_rasterpos_clip == true )
      return NIV_GL_IBM_rasterpos_clip;

    checked_GL_IBM_rasterpos_clip = true;
  
    if (strstr( GLExtensionString, "GL_IBM_rasterpos_clip" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_IBM_rasterpos_clip = true;
    
    return !error;
  }

  bool InitGL_SGIX_reference_plane ()
  {
    bool error = false;

    if ( checked_GL_SGIX_reference_plane == true )
      return NIV_GL_SGIX_reference_plane;

    checked_GL_SGIX_reference_plane = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_reference_plane" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLREFERENCEPLANESGIX, glReferencePlaneSGIX );


    if (error == false)
      NIV_GL_SGIX_reference_plane = true;
    
    return !error;
  }

  bool InitGL_APPLE_texture_range ()
  {
    bool error = false;

    if ( checked_GL_APPLE_texture_range == true )
      return NIV_GL_APPLE_texture_range;

    checked_GL_APPLE_texture_range = true;
  
    if (strstr( GLExtensionString, "GL_APPLE_texture_range" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTEXTURERANGEAPPLE, glTextureRangeAPPLE );
    INIT_FUNCTION( nivenGLGETTEXPARAMETERPOINTERVAPPLE, glGetTexParameterPointervAPPLE );


    if (error == false)
      NIV_GL_APPLE_texture_range = true;
    
    return !error;
  }

  bool InitGL_SGIX_shadow ()
  {
    bool error = false;

    if ( checked_GL_SGIX_shadow == true )
      return NIV_GL_SGIX_shadow;

    checked_GL_SGIX_shadow = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_shadow" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_shadow = true;
    
    return !error;
  }

  bool InitGL_SGIX_texture_lod_bias ()
  {
    bool error = false;

    if ( checked_GL_SGIX_texture_lod_bias == true )
      return NIV_GL_SGIX_texture_lod_bias;

    checked_GL_SGIX_texture_lod_bias = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_texture_lod_bias" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_texture_lod_bias = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGIX_pbuffer ()
  {
    bool error = false;

    if ( checked_GLX_SGIX_pbuffer == true )
      return NIV_GLX_SGIX_pbuffer;

    checked_GLX_SGIX_pbuffer = true;
  
    if (strstr( GLXExtensionString, "GLX_SGIX_pbuffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXCREATEGLXPBUFFERSGIX, glXCreateGLXPbufferSGIX );
    INIT_FUNCTION( nivenGLXGETSELECTEDEVENTSGIX, glXGetSelectedEventSGIX );
    INIT_FUNCTION( nivenGLXDESTROYGLXPBUFFERSGIX, glXDestroyGLXPbufferSGIX );
    INIT_FUNCTION( nivenGLXSELECTEVENTSGIX, glXSelectEventSGIX );
    INIT_FUNCTION( nivenGLXQUERYGLXPBUFFERSGIX, glXQueryGLXPbufferSGIX );


    if (error == false)
      NIV_GLX_SGIX_pbuffer = true;
    
    return !error;
  }
#endif

  bool InitGL_NV_texgen_reflection ()
  {
    bool error = false;

    if ( checked_GL_NV_texgen_reflection == true )
      return NIV_GL_NV_texgen_reflection;

    checked_GL_NV_texgen_reflection = true;
  
    if (strstr( GLExtensionString, "GL_NV_texgen_reflection" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_texgen_reflection = true;
    
    return !error;
  }

  bool InitGL_SUN_slice_accum ()
  {
    bool error = false;

    if ( checked_GL_SUN_slice_accum == true )
      return NIV_GL_SUN_slice_accum;

    checked_GL_SUN_slice_accum = true;
  
    if (strstr( GLExtensionString, "GL_SUN_slice_accum" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SUN_slice_accum = true;
    
    return !error;
  }

  bool InitGL_IBM_multimode_draw_arrays ()
  {
    bool error = false;

    if ( checked_GL_IBM_multimode_draw_arrays == true )
      return NIV_GL_IBM_multimode_draw_arrays;

    checked_GL_IBM_multimode_draw_arrays = true;
  
    if (strstr( GLExtensionString, "GL_IBM_multimode_draw_arrays" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLMULTIMODEDRAWELEMENTSIBM, glMultiModeDrawElementsIBM );
    INIT_FUNCTION( nivenGLMULTIMODEDRAWARRAYSIBM, glMultiModeDrawArraysIBM );


    if (error == false)
      NIV_GL_IBM_multimode_draw_arrays = true;
    
    return !error;
  }

  bool InitGL_IBM_static_data ()
  {
    bool error = false;

    if ( checked_GL_IBM_static_data == true )
      return NIV_GL_IBM_static_data;

    checked_GL_IBM_static_data = true;
  
    if (strstr( GLExtensionString, "GL_IBM_static_data" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_IBM_static_data = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_EXT_visual_info ()
  {
    bool error = false;

    if ( checked_GLX_EXT_visual_info == true )
      return NIV_GLX_EXT_visual_info;

    checked_GLX_EXT_visual_info = true;
  
    if (strstr( GLXExtensionString, "GLX_EXT_visual_info" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_EXT_visual_info = true;
    
    return !error;
  }
#endif

  bool InitGL_EXT_clip_volume_hint ()
  {
    bool error = false;

    if ( checked_GL_EXT_clip_volume_hint == true )
      return NIV_GL_EXT_clip_volume_hint;

    checked_GL_EXT_clip_volume_hint = true;
  
    if (strstr( GLExtensionString, "GL_EXT_clip_volume_hint" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_clip_volume_hint = true;
    
    return !error;
  }

  bool InitGL_EXT_cmyka ()
  {
    bool error = false;

    if ( checked_GL_EXT_cmyka == true )
      return NIV_GL_EXT_cmyka;

    checked_GL_EXT_cmyka = true;
  
    if (strstr( GLExtensionString, "GL_EXT_cmyka" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_cmyka = true;
    
    return !error;
  }

  bool InitGL_EXT_compiled_vertex_array ()
  {
    bool error = false;

    if ( checked_GL_EXT_compiled_vertex_array == true )
      return NIV_GL_EXT_compiled_vertex_array;

    checked_GL_EXT_compiled_vertex_array = true;
  
    if (strstr( GLExtensionString, "GL_EXT_compiled_vertex_array" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLLOCKARRAYSEXT, glLockArraysEXT );
    INIT_FUNCTION( nivenGLUNLOCKARRAYSEXT, glUnlockArraysEXT );


    if (error == false)
      NIV_GL_EXT_compiled_vertex_array = true;
    
    return !error;
  }

  bool InitGL_3DFX_tbuffer ()
  {
    bool error = false;

    if ( checked_GL_3DFX_tbuffer == true )
      return NIV_GL_3DFX_tbuffer;

    checked_GL_3DFX_tbuffer = true;
  
    if (strstr( GLExtensionString, "GL_3DFX_tbuffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTBUFFERMASK3DFX, glTbufferMask3DFX );


    if (error == false)
      NIV_GL_3DFX_tbuffer = true;
    
    return !error;
  }

  bool InitGL_EXT_point_parameters ()
  {
    bool error = false;

    if ( checked_GL_EXT_point_parameters == true )
      return NIV_GL_EXT_point_parameters;

    checked_GL_EXT_point_parameters = true;
  
    if (strstr( GLExtensionString, "GL_EXT_point_parameters" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLPOINTPARAMETERFEXT, glPointParameterfEXT );
    INIT_FUNCTION( nivenGLPOINTPARAMETERFVEXT, glPointParameterfvEXT );


    if (error == false)
      NIV_GL_EXT_point_parameters = true;
    
    return !error;
  }

  bool InitGL_APPLE_vertex_array_object ()
  {
    bool error = false;

    if ( checked_GL_APPLE_vertex_array_object == true )
      return NIV_GL_APPLE_vertex_array_object;

    checked_GL_APPLE_vertex_array_object = true;
  
    if (strstr( GLExtensionString, "GL_APPLE_vertex_array_object" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGENVERTEXARRAYSAPPLE, glGenVertexArraysAPPLE );
    INIT_FUNCTION( nivenGLBINDVERTEXARRAYAPPLE, glBindVertexArrayAPPLE );
    INIT_FUNCTION( nivenGLISVERTEXARRAYAPPLE, glIsVertexArrayAPPLE );
    INIT_FUNCTION( nivenGLDELETEVERTEXARRAYSAPPLE, glDeleteVertexArraysAPPLE );


    if (error == false)
      NIV_GL_APPLE_vertex_array_object = true;
    
    return !error;
  }

  bool InitGL_3DFX_texture_compression_FXT1 ()
  {
    bool error = false;

    if ( checked_GL_3DFX_texture_compression_FXT1 == true )
      return NIV_GL_3DFX_texture_compression_FXT1;

    checked_GL_3DFX_texture_compression_FXT1 = true;
  
    if (strstr( GLExtensionString, "GL_3DFX_texture_compression_FXT1" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_3DFX_texture_compression_FXT1 = true;
    
    return !error;
  }

  bool InitGL_NV_occlusion_query ()
  {
    bool error = false;

    if ( checked_GL_NV_occlusion_query == true )
      return NIV_GL_NV_occlusion_query;

    checked_GL_NV_occlusion_query = true;
  
    if (strstr( GLExtensionString, "GL_NV_occlusion_query" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLENDOCCLUSIONQUERYNV, glEndOcclusionQueryNV );
    INIT_FUNCTION( nivenGLDELETEOCCLUSIONQUERIESNV, glDeleteOcclusionQueriesNV );
    INIT_FUNCTION( nivenGLGETOCCLUSIONQUERYUIVNV, glGetOcclusionQueryuivNV );
    INIT_FUNCTION( nivenGLGENOCCLUSIONQUERIESNV, glGenOcclusionQueriesNV );
    INIT_FUNCTION( nivenGLGETOCCLUSIONQUERYIVNV, glGetOcclusionQueryivNV );
    INIT_FUNCTION( nivenGLBEGINOCCLUSIONQUERYNV, glBeginOcclusionQueryNV );
    INIT_FUNCTION( nivenGLISOCCLUSIONQUERYNV, glIsOcclusionQueryNV );


    if (error == false)
      NIV_GL_NV_occlusion_query = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_OML_sync_control ()
  {
    bool error = false;

    if ( checked_GLX_OML_sync_control == true )
      return NIV_GLX_OML_sync_control;

    checked_GLX_OML_sync_control = true;
  
    if (strstr( GLXExtensionString, "GLX_OML_sync_control" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXGETSYNCVALUESOML, glXGetSyncValuesOML );
    INIT_FUNCTION( nivenGLXGETMSCRATEOML, glXGetMscRateOML );
    INIT_FUNCTION( nivenGLXWAITFORSBCOML, glXWaitForSbcOML );
    INIT_FUNCTION( nivenGLXWAITFORMSCOML, glXWaitForMscOML );
    INIT_FUNCTION( nivenGLXSWAPBUFFERSMSCOML, glXSwapBuffersMscOML );


    if (error == false)
      NIV_GLX_OML_sync_control = true;
    
    return !error;
  }
#endif

#ifdef _WIN32
  bool InitWGL_ARB_render_texture ()
  {
    bool error = false;

    if ( checked_WGL_ARB_render_texture == true )
      return NIV_WGL_ARB_render_texture;

    checked_WGL_ARB_render_texture = true;
  
    if (strstr( WGLExtensionString, "WGL_ARB_render_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLRELEASETEXIMAGEARB, wglReleaseTexImageARB );
    INIT_FUNCTION( nivenWGLBINDTEXIMAGEARB, wglBindTexImageARB );
    INIT_FUNCTION( nivenWGLSETPBUFFERATTRIBARB, wglSetPbufferAttribARB );


    if (error == false)
      NIV_WGL_ARB_render_texture = true;
    
    return !error;
  }
#endif

  bool InitGL_SGIS_multisample ()
  {
    bool error = false;

    if ( checked_GL_SGIS_multisample == true )
      return NIV_GL_SGIS_multisample;

    checked_GL_SGIS_multisample = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_multisample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLSAMPLEMASKSGIS, glSampleMaskSGIS );
    INIT_FUNCTION( nivenGLSAMPLEPATTERNSGIS, glSamplePatternSGIS );


    if (error == false)
      NIV_GL_SGIS_multisample = true;
    
    return !error;
  }

  bool InitGL_ARB_vertex_shader ()
  {
    bool error = false;

    if ( checked_GL_ARB_vertex_shader == true )
      return NIV_GL_ARB_vertex_shader;

    checked_GL_ARB_vertex_shader = true;
  
    if (strstr( GLExtensionString, "GL_ARB_vertex_shader" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETACTIVEATTRIBARB, glGetActiveAttribARB );
    INIT_FUNCTION( nivenGLBINDATTRIBLOCATIONARB, glBindAttribLocationARB );
    INIT_FUNCTION( nivenGLGETATTRIBLOCATIONARB, glGetAttribLocationARB );


    if (error == false)
      NIV_GL_ARB_vertex_shader = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_NV_render_depth_texture ()
  {
    bool error = false;

    if ( checked_WGL_NV_render_depth_texture == true )
      return NIV_WGL_NV_render_depth_texture;

    checked_WGL_NV_render_depth_texture = true;
  
    if (strstr( WGLExtensionString, "WGL_NV_render_depth_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_WGL_NV_render_depth_texture = true;
    
    return !error;
  }
#endif

  bool InitGL_EXT_texture_env ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_env == true )
      return NIV_GL_EXT_texture_env;

    checked_GL_EXT_texture_env = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_env" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_env = true;
    
    return !error;
  }

  bool InitGL_SGIX_fragment_specular_lighting ()
  {
    bool error = false;

    if ( checked_GL_SGIX_fragment_specular_lighting == true )
      return NIV_GL_SGIX_fragment_specular_lighting;

    checked_GL_SGIX_fragment_specular_lighting = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_fragment_specular_lighting" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETFRAGMENTLIGHTFVSGIX, glGetFragmentLightfvSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTMATERIALISGIX, glFragmentMaterialiSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTCOLORMATERIALSGIX, glFragmentColorMaterialSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTMATERIALFVSGIX, glFragmentMaterialfvSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTISGIX, glFragmentLightiSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTMODELIVSGIX, glFragmentLightModelivSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTFSGIX, glFragmentLightfSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTFVSGIX, glFragmentLightfvSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTMODELFSGIX, glFragmentLightModelfSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTIVSGIX, glFragmentLightivSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTMODELFVSGIX, glFragmentLightModelfvSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTMATERIALIVSGIX, glFragmentMaterialivSGIX );
    INIT_FUNCTION( nivenGLGETFRAGMENTMATERIALIVSGIX, glGetFragmentMaterialivSGIX );
    INIT_FUNCTION( nivenGLGETFRAGMENTMATERIALFVSGIX, glGetFragmentMaterialfvSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTMODELISGIX, glFragmentLightModeliSGIX );
    INIT_FUNCTION( nivenGLFRAGMENTMATERIALFSGIX, glFragmentMaterialfSGIX );
    INIT_FUNCTION( nivenGLGETFRAGMENTLIGHTIVSGIX, glGetFragmentLightivSGIX );


    if (error == false)
      NIV_GL_SGIX_fragment_specular_lighting = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_3DFX_multisample ()
  {
    bool error = false;

    if ( checked_GLX_3DFX_multisample == true )
      return NIV_GLX_3DFX_multisample;

    checked_GLX_3DFX_multisample = true;
  
    if (strstr( GLXExtensionString, "GLX_3DFX_multisample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_3DFX_multisample = true;
    
    return !error;
  }
#endif

  bool InitGL_ARB_fragment_shader ()
  {
    bool error = false;

    if ( checked_GL_ARB_fragment_shader == true )
      return NIV_GL_ARB_fragment_shader;

    checked_GL_ARB_fragment_shader = true;
  
    if (strstr( GLExtensionString, "GL_ARB_fragment_shader" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_fragment_shader = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGI_video_sync ()
  {
    bool error = false;

    if ( checked_GLX_SGI_video_sync == true )
      return NIV_GLX_SGI_video_sync;

    checked_GLX_SGI_video_sync = true;
  
    if (strstr( GLXExtensionString, "GLX_SGI_video_sync" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXWAITVIDEOSYNCSGI, glXWaitVideoSyncSGI );
    INIT_FUNCTION( nivenGLXGETVIDEOSYNCSGI, glXGetVideoSyncSGI );


    if (error == false)
      NIV_GLX_SGI_video_sync = true;
    
    return !error;
  }
#endif

  bool InitGL_NV_texture_shader ()
  {
    bool error = false;

    if ( checked_GL_NV_texture_shader == true )
      return NIV_GL_NV_texture_shader;

    checked_GL_NV_texture_shader = true;
  
    if (strstr( GLExtensionString, "GL_NV_texture_shader" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_texture_shader = true;
    
    return !error;
  }

  bool InitGL_NV_pixel_data_range ()
  {
    bool error = false;

    if ( checked_GL_NV_pixel_data_range == true )
      return NIV_GL_NV_pixel_data_range;

    checked_GL_NV_pixel_data_range = true;
  
    if (strstr( GLExtensionString, "GL_NV_pixel_data_range" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLPIXELDATARANGENV, glPixelDataRangeNV );
    INIT_FUNCTION( nivenGLFLUSHPIXELDATARANGENV, glFlushPixelDataRangeNV );


    if (error == false)
      NIV_GL_NV_pixel_data_range = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_EXT_multisample ()
  {
    bool error = false;

    if ( checked_WGL_EXT_multisample == true )
      return NIV_WGL_EXT_multisample;

    checked_WGL_EXT_multisample = true;
  
    if (strstr( WGLExtensionString, "WGL_EXT_multisample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_WGL_EXT_multisample = true;
    
    return !error;
  }
#endif

  bool InitGL_SGIS_texture_edge_clamp ()
  {
    bool error = false;

    if ( checked_GL_SGIS_texture_edge_clamp == true )
      return NIV_GL_SGIS_texture_edge_clamp;

    checked_GL_SGIS_texture_edge_clamp = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_texture_edge_clamp" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIS_texture_edge_clamp = true;
    
    return !error;
  }

  bool InitGL_ARB_imaging ()
  {
    bool error = false;

    if ( checked_GL_ARB_imaging == true )
      return NIV_GL_ARB_imaging;

    checked_GL_ARB_imaging = true;
  
    if (strstr( GLExtensionString, "GL_ARB_imaging" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLCONVOLUTIONPARAMETERI, glConvolutionParameteri );
    INIT_FUNCTION( nivenGLGETCONVOLUTIONPARAMETERIV, glGetConvolutionParameteriv );
    INIT_FUNCTION( nivenGLGETMINMAXPARAMETERFV, glGetMinmaxParameterfv );
    INIT_FUNCTION( nivenGLCONVOLUTIONPARAMETERF, glConvolutionParameterf );
    INIT_FUNCTION( nivenGLCOLORTABLEPARAMETERIV, glColorTableParameteriv );
    INIT_FUNCTION( nivenGLCOLORTABLE, glColorTable );
    INIT_FUNCTION( nivenGLCONVOLUTIONPARAMETERIV, glConvolutionParameteriv );
    INIT_FUNCTION( nivenGLGETMINMAX, glGetMinmax );
    INIT_FUNCTION( nivenGLMINMAX, glMinmax );
    INIT_FUNCTION( nivenGLCOPYCOLORSUBTABLE, glCopyColorSubTable );
    INIT_FUNCTION( nivenGLCONVOLUTIONFILTER2D, glConvolutionFilter2D );
    INIT_FUNCTION( nivenGLGETSEPARABLEFILTER, glGetSeparableFilter );
    INIT_FUNCTION( nivenGLGETCOLORTABLEPARAMETERIV, glGetColorTableParameteriv );
    INIT_FUNCTION( nivenGLCOPYCOLORTABLE, glCopyColorTable );
    INIT_FUNCTION( nivenGLSEPARABLEFILTER2D, glSeparableFilter2D );
    INIT_FUNCTION( nivenGLCOPYCONVOLUTIONFILTER1D, glCopyConvolutionFilter1D );
    INIT_FUNCTION( nivenGLCONVOLUTIONPARAMETERFV, glConvolutionParameterfv );
    INIT_FUNCTION( nivenGLGETCONVOLUTIONFILTER, glGetConvolutionFilter );
    INIT_FUNCTION( nivenGLCOLORTABLEPARAMETERFV, glColorTableParameterfv );
    INIT_FUNCTION( nivenGLRESETMINMAX, glResetMinmax );
    INIT_FUNCTION( nivenGLCOPYCONVOLUTIONFILTER2D, glCopyConvolutionFilter2D );
    INIT_FUNCTION( nivenGLHISTOGRAM, glHistogram );
    INIT_FUNCTION( nivenGLGETMINMAXPARAMETERIV, glGetMinmaxParameteriv );
    INIT_FUNCTION( nivenGLGETHISTOGRAMPARAMETERFV, glGetHistogramParameterfv );
    INIT_FUNCTION( nivenGLGETCOLORTABLE, glGetColorTable );
    INIT_FUNCTION( nivenGLGETCONVOLUTIONPARAMETERFV, glGetConvolutionParameterfv );
    INIT_FUNCTION( nivenGLRESETHISTOGRAM, glResetHistogram );
    INIT_FUNCTION( nivenGLCONVOLUTIONFILTER1D, glConvolutionFilter1D );
    INIT_FUNCTION( nivenGLGETCOLORTABLEPARAMETERFV, glGetColorTableParameterfv );
    INIT_FUNCTION( nivenGLGETHISTOGRAM, glGetHistogram );
    INIT_FUNCTION( nivenGLGETHISTOGRAMPARAMETERIV, glGetHistogramParameteriv );
    INIT_FUNCTION( nivenGLCOLORSUBTABLE, glColorSubTable );


    if (error == false)
      NIV_GL_ARB_imaging = true;
    
    return !error;
  }

  bool InitGL_WIN_specular_fog ()
  {
    bool error = false;

    if ( checked_GL_WIN_specular_fog == true )
      return NIV_GL_WIN_specular_fog;

    checked_GL_WIN_specular_fog = true;
  
    if (strstr( GLExtensionString, "GL_WIN_specular_fog" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_WIN_specular_fog = true;
    
    return !error;
  }

  bool InitGL_APPLE_client_storage ()
  {
    bool error = false;

    if ( checked_GL_APPLE_client_storage == true )
      return NIV_GL_APPLE_client_storage;

    checked_GL_APPLE_client_storage = true;
  
    if (strstr( GLExtensionString, "GL_APPLE_client_storage" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_APPLE_client_storage = true;
    
    return !error;
  }

  bool InitGL_IBM_vertex_array_lists ()
  {
    bool error = false;

    if ( checked_GL_IBM_vertex_array_lists == true )
      return NIV_GL_IBM_vertex_array_lists;

    checked_GL_IBM_vertex_array_lists = true;
  
    if (strstr( GLExtensionString, "GL_IBM_vertex_array_lists" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTEXCOORDPOINTERLISTIBM, glTexCoordPointerListIBM );
    INIT_FUNCTION( nivenGLEDGEFLAGPOINTERLISTIBM, glEdgeFlagPointerListIBM );
    INIT_FUNCTION( nivenGLNORMALPOINTERLISTIBM, glNormalPointerListIBM );
    INIT_FUNCTION( nivenGLSECONDARYCOLORPOINTERLISTIBM, glSecondaryColorPointerListIBM );
    INIT_FUNCTION( nivenGLINDEXPOINTERLISTIBM, glIndexPointerListIBM );
    INIT_FUNCTION( nivenGLCOLORPOINTERLISTIBM, glColorPointerListIBM );
    INIT_FUNCTION( nivenGLFOGCOORDPOINTERLISTIBM, glFogCoordPointerListIBM );
    INIT_FUNCTION( nivenGLVERTEXPOINTERLISTIBM, glVertexPointerListIBM );


    if (error == false)
      NIV_GL_IBM_vertex_array_lists = true;
    
    return !error;
  }

  bool InitGL_ARB_fragment_program ()
  {
    bool error = false;

    if ( checked_GL_ARB_fragment_program == true )
      return NIV_GL_ARB_fragment_program;

    checked_GL_ARB_fragment_program = true;
  
    if (strstr( GLExtensionString, "GL_ARB_fragment_program" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_fragment_program = true;
    
    return !error;
  }

  bool InitGL_ARB_shader_objects ()
  {
    bool error = false;

    if ( checked_GL_ARB_shader_objects == true )
      return NIV_GL_ARB_shader_objects;

    checked_GL_ARB_shader_objects = true;
  
    if (strstr( GLExtensionString, "GL_ARB_shader_objects" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETHANDLEARB, glGetHandleARB );
    INIT_FUNCTION( nivenGLUNIFORM3FVARB, glUniform3fvARB );
    INIT_FUNCTION( nivenGLUNIFORM4IARB, glUniform4iARB );
    INIT_FUNCTION( nivenGLUNIFORM2FARB, glUniform2fARB );
    INIT_FUNCTION( nivenGLUNIFORM3FARB, glUniform3fARB );
    INIT_FUNCTION( nivenGLUNIFORM1IARB, glUniform1iARB );
    INIT_FUNCTION( nivenGLUNIFORM1FVARB, glUniform1fvARB );
    INIT_FUNCTION( nivenGLVALIDATEPROGRAMARB, glValidateProgramARB );
    INIT_FUNCTION( nivenGLUNIFORM3IARB, glUniform3iARB );
    INIT_FUNCTION( nivenGLDELETEOBJECTARB, glDeleteObjectARB );
    INIT_FUNCTION( nivenGLCOMPILESHADERARB, glCompileShaderARB );
    INIT_FUNCTION( nivenGLGETOBJECTPARAMETERFVARB, glGetObjectParameterfvARB );
    INIT_FUNCTION( nivenGLGETUNIFORMLOCATIONARB, glGetUniformLocationARB );
    INIT_FUNCTION( nivenGLCREATEPROGRAMOBJECTARB, glCreateProgramObjectARB );
    INIT_FUNCTION( nivenGLGETSHADERSOURCEARB, glGetShaderSourceARB );
    INIT_FUNCTION( nivenGLUNIFORM2IVARB, glUniform2ivARB );
    INIT_FUNCTION( nivenGLUSEPROGRAMOBJECTARB, glUseProgramObjectARB );
    INIT_FUNCTION( nivenGLUNIFORMMATRIX2FVARB, glUniformMatrix2fvARB );
    INIT_FUNCTION( nivenGLLINKPROGRAMARB, glLinkProgramARB );
    INIT_FUNCTION( nivenGLGETUNIFORMFVARB, glGetUniformfvARB );
    INIT_FUNCTION( nivenGLUNIFORM1IVARB, glUniform1ivARB );
    INIT_FUNCTION( nivenGLUNIFORM2IARB, glUniform2iARB );
    INIT_FUNCTION( nivenGLATTACHOBJECTARB, glAttachObjectARB );
    INIT_FUNCTION( nivenGLUNIFORMMATRIX3FVARB, glUniformMatrix3fvARB );
    INIT_FUNCTION( nivenGLCREATESHADEROBJECTARB, glCreateShaderObjectARB );
    INIT_FUNCTION( nivenGLGETATTACHEDOBJECTSARB, glGetAttachedObjectsARB );
    INIT_FUNCTION( nivenGLUNIFORM4FARB, glUniform4fARB );
    INIT_FUNCTION( nivenGLUNIFORM4IVARB, glUniform4ivARB );
    INIT_FUNCTION( nivenGLUNIFORM3IVARB, glUniform3ivARB );
    INIT_FUNCTION( nivenGLGETUNIFORMIVARB, glGetUniformivARB );
    INIT_FUNCTION( nivenGLGETACTIVEUNIFORMARB, glGetActiveUniformARB );
    INIT_FUNCTION( nivenGLUNIFORMMATRIX4FVARB, glUniformMatrix4fvARB );
    INIT_FUNCTION( nivenGLGETOBJECTPARAMETERIVARB, glGetObjectParameterivARB );
    INIT_FUNCTION( nivenGLUNIFORM1FARB, glUniform1fARB );
    INIT_FUNCTION( nivenGLDETACHOBJECTARB, glDetachObjectARB );
    INIT_FUNCTION( nivenGLSHADERSOURCEARB, glShaderSourceARB );
    INIT_FUNCTION( nivenGLUNIFORM4FVARB, glUniform4fvARB );
    INIT_FUNCTION( nivenGLGETINFOLOGARB, glGetInfoLogARB );
    INIT_FUNCTION( nivenGLUNIFORM2FVARB, glUniform2fvARB );


    if (error == false)
      NIV_GL_ARB_shader_objects = true;
    
    return !error;
  }

  bool InitGL_EXT_framebuffer_object ()
  {
    bool error = false;

    if ( checked_GL_EXT_framebuffer_object == true )
      return NIV_GL_EXT_framebuffer_object;

    checked_GL_EXT_framebuffer_object = true;
  
    if (strstr( GLExtensionString, "GL_EXT_framebuffer_object" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLCHECKFRAMEBUFFERSTATUSEXT, glCheckFramebufferStatusEXT );
    INIT_FUNCTION( nivenGLDELETERENDERBUFFERSEXT, glDeleteRenderbuffersEXT );
    INIT_FUNCTION( nivenGLFRAMEBUFFERTEXTURE1DEXT, glFramebufferTexture1DEXT );
    INIT_FUNCTION( nivenGLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXT, glGetFramebufferAttachmentParameterivEXT );
    INIT_FUNCTION( nivenGLFRAMEBUFFERTEXTURE2DEXT, glFramebufferTexture2DEXT );
    INIT_FUNCTION( nivenGLGENRENDERBUFFERSEXT, glGenRenderbuffersEXT );
    INIT_FUNCTION( nivenGLGENFRAMEBUFFERSEXT, glGenFramebuffersEXT );
    INIT_FUNCTION( nivenGLDELETEFRAMEBUFFERSEXT, glDeleteFramebuffersEXT );
    INIT_FUNCTION( nivenGLISFRAMEBUFFEREXT, glIsFramebufferEXT );
    INIT_FUNCTION( nivenGLFRAMEBUFFERTEXTURE3DEXT, glFramebufferTexture3DEXT );
    INIT_FUNCTION( nivenGLISRENDERBUFFEREXT, glIsRenderbufferEXT );
    INIT_FUNCTION( nivenGLFRAMEBUFFERRENDERBUFFEREXT, glFramebufferRenderbufferEXT );
    INIT_FUNCTION( nivenGLGENERATEMIPMAPEXT, glGenerateMipmapEXT );
    INIT_FUNCTION( nivenGLBINDFRAMEBUFFEREXT, glBindFramebufferEXT );
    INIT_FUNCTION( nivenGLGETRENDERBUFFERPARAMETERIVEXT, glGetRenderbufferParameterivEXT );
    INIT_FUNCTION( nivenGLBINDRENDERBUFFEREXT, glBindRenderbufferEXT );
    INIT_FUNCTION( nivenGLRENDERBUFFERSTORAGEEXT, glRenderbufferStorageEXT );


    if (error == false)
      NIV_GL_EXT_framebuffer_object = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_I3D_gamma ()
  {
    bool error = false;

    if ( checked_WGL_I3D_gamma == true )
      return NIV_WGL_I3D_gamma;

    checked_WGL_I3D_gamma = true;
  
    if (strstr( WGLExtensionString, "WGL_I3D_gamma" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLGETGAMMATABLEPARAMETERSI3D, wglGetGammaTableParametersI3D );
    INIT_FUNCTION( nivenWGLGETGAMMATABLEI3D, wglGetGammaTableI3D );
    INIT_FUNCTION( nivenWGLSETGAMMATABLEPARAMETERSI3D, wglSetGammaTableParametersI3D );
    INIT_FUNCTION( nivenWGLSETGAMMATABLEI3D, wglSetGammaTableI3D );


    if (error == false)
      NIV_WGL_I3D_gamma = true;
    
    return !error;
  }
#endif

  bool InitGL_ATI_vertex_streams ()
  {
    bool error = false;

    if ( checked_GL_ATI_vertex_streams == true )
      return NIV_GL_ATI_vertex_streams;

    checked_GL_ATI_vertex_streams = true;
  
    if (strstr( GLExtensionString, "GL_ATI_vertex_streams" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLNORMALSTREAM3BVATI, glNormalStream3bvATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM2DATI, glVertexStream2dATI );
    INIT_FUNCTION( nivenGLNORMALSTREAM3SATI, glNormalStream3sATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM2IVATI, glVertexStream2ivATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM3DVATI, glVertexStream3dvATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM3SVATI, glVertexStream3svATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM3SATI, glVertexStream3sATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM4IATI, glVertexStream4iATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM3FATI, glVertexStream3fATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM2SVATI, glVertexStream2svATI );
    INIT_FUNCTION( nivenGLNORMALSTREAM3DVATI, glNormalStream3dvATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM2SATI, glVertexStream2sATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM4IVATI, glVertexStream4ivATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM3IVATI, glVertexStream3ivATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM3IATI, glVertexStream3iATI );
    INIT_FUNCTION( nivenGLNORMALSTREAM3BATI, glNormalStream3bATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM3FVATI, glVertexStream3fvATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM2DVATI, glVertexStream2dvATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM2FVATI, glVertexStream2fvATI );
    INIT_FUNCTION( nivenGLNORMALSTREAM3IATI, glNormalStream3iATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM3DATI, glVertexStream3dATI );
    INIT_FUNCTION( nivenGLNORMALSTREAM3FATI, glNormalStream3fATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM4FVATI, glVertexStream4fvATI );
    INIT_FUNCTION( nivenGLNORMALSTREAM3FVATI, glNormalStream3fvATI );
    INIT_FUNCTION( nivenGLVERTEXBLENDENVFATI, glVertexBlendEnvfATI );
    INIT_FUNCTION( nivenGLNORMALSTREAM3DATI, glNormalStream3dATI );
    INIT_FUNCTION( nivenGLNORMALSTREAM3IVATI, glNormalStream3ivATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM4FATI, glVertexStream4fATI );
    INIT_FUNCTION( nivenGLVERTEXBLENDENVIATI, glVertexBlendEnviATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM4DVATI, glVertexStream4dvATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM4SVATI, glVertexStream4svATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM2IATI, glVertexStream2iATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM2FATI, glVertexStream2fATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM4SATI, glVertexStream4sATI );
    INIT_FUNCTION( nivenGLNORMALSTREAM3SVATI, glNormalStream3svATI );
    INIT_FUNCTION( nivenGLVERTEXSTREAM4DATI, glVertexStream4dATI );
    INIT_FUNCTION( nivenGLCLIENTACTIVEVERTEXSTREAMATI, glClientActiveVertexStreamATI );


    if (error == false)
      NIV_GL_ATI_vertex_streams = true;
    
    return !error;
  }

  bool InitGL_APPLE_ycbcr_422 ()
  {
    bool error = false;

    if ( checked_GL_APPLE_ycbcr_422 == true )
      return NIV_GL_APPLE_ycbcr_422;

    checked_GL_APPLE_ycbcr_422 = true;
  
    if (strstr( GLExtensionString, "GL_APPLE_ycbcr_422" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_APPLE_ycbcr_422 = true;
    
    return !error;
  }

  bool InitGL_NV_blend_square ()
  {
    bool error = false;

    if ( checked_GL_NV_blend_square == true )
      return NIV_GL_NV_blend_square;

    checked_GL_NV_blend_square = true;
  
    if (strstr( GLExtensionString, "GL_NV_blend_square" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_blend_square = true;
    
    return !error;
  }

  bool InitGL_MESA_window_pos ()
  {
    bool error = false;

    if ( checked_GL_MESA_window_pos == true )
      return NIV_GL_MESA_window_pos;

    checked_GL_MESA_window_pos = true;
  
    if (strstr( GLExtensionString, "GL_MESA_window_pos" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLWINDOWPOS4IMESA, glWindowPos4iMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS3IMESA, glWindowPos3iMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS2IVMESA, glWindowPos2ivMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS2DMESA, glWindowPos2dMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS3DMESA, glWindowPos3dMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS3IVMESA, glWindowPos3ivMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS4DMESA, glWindowPos4dMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS3FVMESA, glWindowPos3fvMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS2FVMESA, glWindowPos2fvMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS3SMESA, glWindowPos3sMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS2SMESA, glWindowPos2sMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS3FMESA, glWindowPos3fMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS3SVMESA, glWindowPos3svMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS4IVMESA, glWindowPos4ivMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS4SVMESA, glWindowPos4svMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS3DVMESA, glWindowPos3dvMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS4FMESA, glWindowPos4fMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS4DVMESA, glWindowPos4dvMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS2FMESA, glWindowPos2fMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS4SMESA, glWindowPos4sMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS2SVMESA, glWindowPos2svMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS2IMESA, glWindowPos2iMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS4FVMESA, glWindowPos4fvMESA );
    INIT_FUNCTION( nivenGLWINDOWPOS2DVMESA, glWindowPos2dvMESA );


    if (error == false)
      NIV_GL_MESA_window_pos = true;
    
    return !error;
  }

  bool InitGL_ATI_envmap_bumpmap ()
  {
    bool error = false;

    if ( checked_GL_ATI_envmap_bumpmap == true )
      return NIV_GL_ATI_envmap_bumpmap;

    checked_GL_ATI_envmap_bumpmap = true;
  
    if (strstr( GLExtensionString, "GL_ATI_envmap_bumpmap" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTEXBUMPPARAMETERFVATI, glTexBumpParameterfvATI );
    INIT_FUNCTION( nivenGLTEXBUMPPARAMETERIVATI, glTexBumpParameterivATI );
    INIT_FUNCTION( nivenGLGETTEXBUMPPARAMETERIVATI, glGetTexBumpParameterivATI );
    INIT_FUNCTION( nivenGLGETTEXBUMPPARAMETERFVATI, glGetTexBumpParameterfvATI );


    if (error == false)
      NIV_GL_ATI_envmap_bumpmap = true;
    
    return !error;
  }

  bool InitGL_ARB_texture_non_power_of_two ()
  {
    bool error = false;

    if ( checked_GL_ARB_texture_non_power_of_two == true )
      return NIV_GL_ARB_texture_non_power_of_two;

    checked_GL_ARB_texture_non_power_of_two = true;
  
    if (strstr( GLExtensionString, "GL_ARB_texture_non_power_of_two" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_texture_non_power_of_two = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_env_combine ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_env_combine == true )
      return NIV_GL_EXT_texture_env_combine;

    checked_GL_EXT_texture_env_combine = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_env_combine" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_env_combine = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_object ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_object == true )
      return NIV_GL_EXT_texture_object;

    checked_GL_EXT_texture_object = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_object" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLBINDTEXTUREEXT, glBindTextureEXT );
    INIT_FUNCTION( nivenGLPRIORITIZETEXTURESEXT, glPrioritizeTexturesEXT );
    INIT_FUNCTION( nivenGLISTEXTUREEXT, glIsTextureEXT );
    INIT_FUNCTION( nivenGLDELETETEXTURESEXT, glDeleteTexturesEXT );
    INIT_FUNCTION( nivenGLGENTEXTURESEXT, glGenTexturesEXT );
    INIT_FUNCTION( nivenGLARETEXTURESRESIDENTEXT, glAreTexturesResidentEXT );


    if (error == false)
      NIV_GL_EXT_texture_object = true;
    
    return !error;
  }

  bool InitGL_ATI_texture_compression_3dc ()
  {
    bool error = false;

    if ( checked_GL_ATI_texture_compression_3dc == true )
      return NIV_GL_ATI_texture_compression_3dc;

    checked_GL_ATI_texture_compression_3dc = true;
  
    if (strstr( GLExtensionString, "GL_ATI_texture_compression_3dc" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ATI_texture_compression_3dc = true;
    
    return !error;
  }

  bool InitGL_OML_subsample ()
  {
    bool error = false;

    if ( checked_GL_OML_subsample == true )
      return NIV_GL_OML_subsample;

    checked_GL_OML_subsample = true;
  
    if (strstr( GLExtensionString, "GL_OML_subsample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_OML_subsample = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_lod_bias ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_lod_bias == true )
      return NIV_GL_EXT_texture_lod_bias;

    checked_GL_EXT_texture_lod_bias = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_lod_bias" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_lod_bias = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_ARB_pixel_format_float ()
  {
    bool error = false;

    if ( checked_WGL_ARB_pixel_format_float == true )
      return NIV_WGL_ARB_pixel_format_float;

    checked_WGL_ARB_pixel_format_float = true;
  
    if (strstr( WGLExtensionString, "WGL_ARB_pixel_format_float" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_WGL_ARB_pixel_format_float = true;
    
    return !error;
  }
#endif

  bool InitGL_EXT_scene_marker ()
  {
    bool error = false;

    if ( checked_GL_EXT_scene_marker == true )
      return NIV_GL_EXT_scene_marker;

    checked_GL_EXT_scene_marker = true;
  
    if (strstr( GLExtensionString, "GL_EXT_scene_marker" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLBEGINSCENEEXT, glBeginSceneEXT );
    INIT_FUNCTION( nivenGLENDSCENEEXT, glEndSceneEXT );


    if (error == false)
      NIV_GL_EXT_scene_marker = true;
    
    return !error;
  }

  bool InitGL_NV_primitive_restart ()
  {
    bool error = false;

    if ( checked_GL_NV_primitive_restart == true )
      return NIV_GL_NV_primitive_restart;

    checked_GL_NV_primitive_restart = true;
  
    if (strstr( GLExtensionString, "GL_NV_primitive_restart" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLPRIMITIVERESTARTINDEXNV, glPrimitiveRestartIndexNV );
    INIT_FUNCTION( nivenGLPRIMITIVERESTARTNV, glPrimitiveRestartNV );


    if (error == false)
      NIV_GL_NV_primitive_restart = true;
    
    return !error;
  }

  bool InitGL_ARB_shadow_ambient ()
  {
    bool error = false;

    if ( checked_GL_ARB_shadow_ambient == true )
      return NIV_GL_ARB_shadow_ambient;

    checked_GL_ARB_shadow_ambient = true;
  
    if (strstr( GLExtensionString, "GL_ARB_shadow_ambient" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_shadow_ambient = true;
    
    return !error;
  }

  bool InitGL_SGIX_vertex_preclip_hint ()
  {
    bool error = false;

    if ( checked_GL_SGIX_vertex_preclip_hint == true )
      return NIV_GL_SGIX_vertex_preclip_hint;

    checked_GL_SGIX_vertex_preclip_hint = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_vertex_preclip_hint" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_vertex_preclip_hint = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_MESA_pixmap_colormap ()
  {
    bool error = false;

    if ( checked_GLX_MESA_pixmap_colormap == true )
      return NIV_GLX_MESA_pixmap_colormap;

    checked_GLX_MESA_pixmap_colormap = true;
  
    if (strstr( GLXExtensionString, "GLX_MESA_pixmap_colormap" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXCREATEGLXPIXMAPMESA, glXCreateGLXPixmapMESA );


    if (error == false)
      NIV_GLX_MESA_pixmap_colormap = true;
    
    return !error;
  }
#endif

  bool InitGL_EXT_pixel_buffer_object ()
  {
    bool error = false;

    if ( checked_GL_EXT_pixel_buffer_object == true )
      return NIV_GL_EXT_pixel_buffer_object;

    checked_GL_EXT_pixel_buffer_object = true;
  
    if (strstr( GLExtensionString, "GL_EXT_pixel_buffer_object" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_pixel_buffer_object = true;
    
    return !error;
  }

  bool InitGL_EXT_abgr ()
  {
    bool error = false;

    if ( checked_GL_EXT_abgr == true )
      return NIV_GL_EXT_abgr;

    checked_GL_EXT_abgr = true;
  
    if (strstr( GLExtensionString, "GL_EXT_abgr" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_abgr = true;
    
    return !error;
  }

  bool InitGL_NV_vertex_program ()
  {
    bool error = false;

    if ( checked_GL_NV_vertex_program == true )
      return NIV_GL_NV_vertex_program;

    checked_GL_NV_vertex_program = true;
  
    if (strstr( GLExtensionString, "GL_NV_vertex_program" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLVERTEXATTRIBS2FVNV, glVertexAttribs2fvNV );
    INIT_FUNCTION( nivenGLTRACKMATRIXNV, glTrackMatrixNV );
    INIT_FUNCTION( nivenGLBINDPROGRAMNV, glBindProgramNV );
    INIT_FUNCTION( nivenGLGETVERTEXATTRIBFVNV, glGetVertexAttribfvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3SNV, glVertexAttrib3sNV );
    INIT_FUNCTION( nivenGLGETPROGRAMPARAMETERDVNV, glGetProgramParameterdvNV );
    INIT_FUNCTION( nivenGLGETTRACKMATRIXIVNV, glGetTrackMatrixivNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4FNV, glVertexAttrib4fNV );
    INIT_FUNCTION( nivenGLAREPROGRAMSRESIDENTNV, glAreProgramsResidentNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1DNV, glVertexAttrib1dNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS3DVNV, glVertexAttribs3dvNV );
    INIT_FUNCTION( nivenGLDELETEPROGRAMSNV, glDeleteProgramsNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBPOINTERNV, glVertexAttribPointerNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS1SVNV, glVertexAttribs1svNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2DNV, glVertexAttrib2dNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3DNV, glVertexAttrib3dNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1SVNV, glVertexAttrib1svNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS3SVNV, glVertexAttribs3svNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS1DVNV, glVertexAttribs1dvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS4FVNV, glVertexAttribs4fvNV );
    INIT_FUNCTION( nivenGLPROGRAMPARAMETER4FNV, glProgramParameter4fNV );
    INIT_FUNCTION( nivenGLPROGRAMPARAMETERS4DVNV, glProgramParameters4dvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4UBNV, glVertexAttrib4ubNV );
    INIT_FUNCTION( nivenGLGETPROGRAMIVNV, glGetProgramivNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4SVNV, glVertexAttrib4svNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4FVNV, glVertexAttrib4fvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS4SVNV, glVertexAttribs4svNV );
    INIT_FUNCTION( nivenGLLOADPROGRAMNV, glLoadProgramNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1FVNV, glVertexAttrib1fvNV );
    INIT_FUNCTION( nivenGLEXECUTEPROGRAMNV, glExecuteProgramNV );
    INIT_FUNCTION( nivenGLISPROGRAMNV, glIsProgramNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4DVNV, glVertexAttrib4dvNV );
    INIT_FUNCTION( nivenGLPROGRAMPARAMETER4DNV, glProgramParameter4dNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2FNV, glVertexAttrib2fNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3FNV, glVertexAttrib3fNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1DVNV, glVertexAttrib1dvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1FNV, glVertexAttrib1fNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2DVNV, glVertexAttrib2dvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS1FVNV, glVertexAttribs1fvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS2DVNV, glVertexAttribs2dvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS2SVNV, glVertexAttribs2svNV );
    INIT_FUNCTION( nivenGLGETPROGRAMPARAMETERFVNV, glGetProgramParameterfvNV );
    INIT_FUNCTION( nivenGLGETPROGRAMSTRINGNV, glGetProgramStringNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS3FVNV, glVertexAttribs3fvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4DNV, glVertexAttrib4dNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4UBVNV, glVertexAttrib4ubvNV );
    INIT_FUNCTION( nivenGLGENPROGRAMSNV, glGenProgramsNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB4SNV, glVertexAttrib4sNV );
    INIT_FUNCTION( nivenGLREQUESTRESIDENTPROGRAMSNV, glRequestResidentProgramsNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3FVNV, glVertexAttrib3fvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB1SNV, glVertexAttrib1sNV );
    INIT_FUNCTION( nivenGLGETVERTEXATTRIBIVNV, glGetVertexAttribivNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3SVNV, glVertexAttrib3svNV );
    INIT_FUNCTION( nivenGLPROGRAMPARAMETER4FVNV, glProgramParameter4fvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS4UBVNV, glVertexAttribs4ubvNV );
    INIT_FUNCTION( nivenGLGETVERTEXATTRIBDVNV, glGetVertexAttribdvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB3DVNV, glVertexAttrib3dvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2FVNV, glVertexAttrib2fvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2SNV, glVertexAttrib2sNV );
    INIT_FUNCTION( nivenGLPROGRAMPARAMETERS4FVNV, glProgramParameters4fvNV );
    INIT_FUNCTION( nivenGLGETVERTEXATTRIBPOINTERVNV, glGetVertexAttribPointervNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIBS4DVNV, glVertexAttribs4dvNV );
    INIT_FUNCTION( nivenGLVERTEXATTRIB2SVNV, glVertexAttrib2svNV );
    INIT_FUNCTION( nivenGLPROGRAMPARAMETER4DVNV, glProgramParameter4dvNV );


    if (error == false)
      NIV_GL_NV_vertex_program = true;
    
    return !error;
  }

  bool InitGL_SGIX_texture_multi_buffer ()
  {
    bool error = false;

    if ( checked_GL_SGIX_texture_multi_buffer == true )
      return NIV_GL_SGIX_texture_multi_buffer;

    checked_GL_SGIX_texture_multi_buffer = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_texture_multi_buffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_texture_multi_buffer = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGIS_blended_overlay ()
  {
    bool error = false;

    if ( checked_GLX_SGIS_blended_overlay == true )
      return NIV_GLX_SGIS_blended_overlay;

    checked_GLX_SGIS_blended_overlay = true;
  
    if (strstr( GLXExtensionString, "GLX_SGIS_blended_overlay" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_SGIS_blended_overlay = true;
    
    return !error;
  }
#endif

  bool InitGL_ARB_texture_rectangle ()
  {
    bool error = false;

    if ( checked_GL_ARB_texture_rectangle == true )
      return NIV_GL_ARB_texture_rectangle;

    checked_GL_ARB_texture_rectangle = true;
  
    if (strstr( GLExtensionString, "GL_ARB_texture_rectangle" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_texture_rectangle = true;
    
    return !error;
  }

  bool InitGL_SGI_texture_color_table ()
  {
    bool error = false;

    if ( checked_GL_SGI_texture_color_table == true )
      return NIV_GL_SGI_texture_color_table;

    checked_GL_SGI_texture_color_table = true;
  
    if (strstr( GLExtensionString, "GL_SGI_texture_color_table" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGI_texture_color_table = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGIX_visual_select_group ()
  {
    bool error = false;

    if ( checked_GLX_SGIX_visual_select_group == true )
      return NIV_GLX_SGIX_visual_select_group;

    checked_GLX_SGIX_visual_select_group = true;
  
    if (strstr( GLXExtensionString, "GLX_SGIX_visual_select_group" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_SGIX_visual_select_group = true;
    
    return !error;
  }
#endif

  bool InitGL_SGIS_pixel_texture ()
  {
    bool error = false;

    if ( checked_GL_SGIS_pixel_texture == true )
      return NIV_GL_SGIS_pixel_texture;

    checked_GL_SGIS_pixel_texture = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_pixel_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIS_pixel_texture = true;
    
    return !error;
  }

  bool InitGL_ARB_multisample ()
  {
    bool error = false;

    if ( checked_GL_ARB_multisample == true )
      return NIV_GL_ARB_multisample;

    checked_GL_ARB_multisample = true;
  
    if (strstr( GLExtensionString, "GL_ARB_multisample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLSAMPLECOVERAGEARB, glSampleCoverageARB );


    if (error == false)
      NIV_GL_ARB_multisample = true;
    
    return !error;
  }

  bool InitGL_SGIS_generate_mipmap ()
  {
    bool error = false;

    if ( checked_GL_SGIS_generate_mipmap == true )
      return NIV_GL_SGIS_generate_mipmap;

    checked_GL_SGIS_generate_mipmap = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_generate_mipmap" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIS_generate_mipmap = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_EXT_visual_rating ()
  {
    bool error = false;

    if ( checked_GLX_EXT_visual_rating == true )
      return NIV_GLX_EXT_visual_rating;

    checked_GLX_EXT_visual_rating = true;
  
    if (strstr( GLXExtensionString, "GLX_EXT_visual_rating" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_EXT_visual_rating = true;
    
    return !error;
  }
#endif

  bool InitGL_ATI_map_object_buffer ()
  {
    bool error = false;

    if ( checked_GL_ATI_map_object_buffer == true )
      return NIV_GL_ATI_map_object_buffer;

    checked_GL_ATI_map_object_buffer = true;
  
    if (strstr( GLExtensionString, "GL_ATI_map_object_buffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLMAPOBJECTBUFFERATI, glMapObjectBufferATI );
    INIT_FUNCTION( nivenGLUNMAPOBJECTBUFFERATI, glUnmapObjectBufferATI );


    if (error == false)
      NIV_GL_ATI_map_object_buffer = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_edge_clamp ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_edge_clamp == true )
      return NIV_GL_EXT_texture_edge_clamp;

    checked_GL_EXT_texture_edge_clamp = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_edge_clamp" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_edge_clamp = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_MESA_agp_offset ()
  {
    bool error = false;

    if ( checked_GLX_MESA_agp_offset == true )
      return NIV_GLX_MESA_agp_offset;

    checked_GLX_MESA_agp_offset = true;
  
    if (strstr( GLXExtensionString, "GLX_MESA_agp_offset" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXGETAGPOFFSETMESA, glXGetAGPOffsetMESA );


    if (error == false)
      NIV_GLX_MESA_agp_offset = true;
    
    return !error;
  }
#endif

  bool InitGL_NV_light_max_exponent ()
  {
    bool error = false;

    if ( checked_GL_NV_light_max_exponent == true )
      return NIV_GL_NV_light_max_exponent;

    checked_GL_NV_light_max_exponent = true;
  
    if (strstr( GLExtensionString, "GL_NV_light_max_exponent" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_light_max_exponent = true;
    
    return !error;
  }

  bool InitGL_EXT_blend_minmax ()
  {
    bool error = false;

    if ( checked_GL_EXT_blend_minmax == true )
      return NIV_GL_EXT_blend_minmax;

    checked_GL_EXT_blend_minmax = true;
  
    if (strstr( GLExtensionString, "GL_EXT_blend_minmax" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLBLENDEQUATIONEXT, glBlendEquationEXT );


    if (error == false)
      NIV_GL_EXT_blend_minmax = true;
    
    return !error;
  }

  bool InitGL_ARB_texture_float ()
  {
    bool error = false;

    if ( checked_GL_ARB_texture_float == true )
      return NIV_GL_ARB_texture_float;

    checked_GL_ARB_texture_float = true;
  
    if (strstr( GLExtensionString, "GL_ARB_texture_float" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_texture_float = true;
    
    return !error;
  }

  bool InitGL_SUN_vertex ()
  {
    bool error = false;

    if ( checked_GL_SUN_vertex == true )
      return NIV_GL_SUN_vertex;

    checked_GL_SUN_vertex = true;
  
    if (strstr( GLExtensionString, "GL_SUN_vertex" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLCOLOR3FVERTEX3FVSUN, glColor3fVertex3fvSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUN, glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUIVERTEX3FSUN, glReplacementCodeuiVertex3fSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FVSUN, glReplacementCodeuiColor4fNormal3fVertex3fvSUN );
    INIT_FUNCTION( nivenGLTEXCOORD4FVERTEX4FVSUN, glTexCoord4fVertex4fvSUN );
    INIT_FUNCTION( nivenGLTEXCOORD2FCOLOR3FVERTEX3FSUN, glTexCoord2fColor3fVertex3fSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FSUN, glReplacementCodeuiColor4fNormal3fVertex3fSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUINORMAL3FVERTEX3FSUN, glReplacementCodeuiNormal3fVertex3fSUN );
    INIT_FUNCTION( nivenGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUN, glTexCoord2fColor4fNormal3fVertex3fvSUN );
    INIT_FUNCTION( nivenGLTEXCOORD2FNORMAL3FVERTEX3FSUN, glTexCoord2fNormal3fVertex3fSUN );
    INIT_FUNCTION( nivenGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FSUN, glTexCoord4fColor4fNormal3fVertex4fSUN );
    INIT_FUNCTION( nivenGLTEXCOORD2FCOLOR3FVERTEX3FVSUN, glTexCoord2fColor3fVertex3fvSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FSUN, glReplacementCodeuiTexCoord2fVertex3fSUN );
    INIT_FUNCTION( nivenGLNORMAL3FVERTEX3FVSUN, glNormal3fVertex3fvSUN );
    INIT_FUNCTION( nivenGLCOLOR4FNORMAL3FVERTEX3FSUN, glColor4fNormal3fVertex3fSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUICOLOR3FVERTEX3FSUN, glReplacementCodeuiColor3fVertex3fSUN );
    INIT_FUNCTION( nivenGLNORMAL3FVERTEX3FSUN, glNormal3fVertex3fSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUICOLOR4UBVERTEX3FSUN, glReplacementCodeuiColor4ubVertex3fSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUICOLOR4UBVERTEX3FVSUN, glReplacementCodeuiColor4ubVertex3fvSUN );
    INIT_FUNCTION( nivenGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FVSUN, glTexCoord4fColor4fNormal3fVertex4fvSUN );
    INIT_FUNCTION( nivenGLTEXCOORD2FCOLOR4UBVERTEX3FVSUN, glTexCoord2fColor4ubVertex3fvSUN );
    INIT_FUNCTION( nivenGLTEXCOORD2FCOLOR4UBVERTEX3FSUN, glTexCoord2fColor4ubVertex3fSUN );
    INIT_FUNCTION( nivenGLTEXCOORD4FVERTEX4FSUN, glTexCoord4fVertex4fSUN );
    INIT_FUNCTION( nivenGLCOLOR4UBVERTEX2FSUN, glColor4ubVertex2fSUN );
    INIT_FUNCTION( nivenGLCOLOR3FVERTEX3FSUN, glColor3fVertex3fSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUIVERTEX3FVSUN, glReplacementCodeuiVertex3fvSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FSUN, glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FVSUN, glReplacementCodeuiTexCoord2fVertex3fvSUN );
    INIT_FUNCTION( nivenGLTEXCOORD2FVERTEX3FVSUN, glTexCoord2fVertex3fvSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUINORMAL3FVERTEX3FVSUN, glReplacementCodeuiNormal3fVertex3fvSUN );
    INIT_FUNCTION( nivenGLCOLOR4UBVERTEX2FVSUN, glColor4ubVertex2fvSUN );
    INIT_FUNCTION( nivenGLCOLOR4UBVERTEX3FVSUN, glColor4ubVertex3fvSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUN, glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN );
    INIT_FUNCTION( nivenGLTEXCOORD2FNORMAL3FVERTEX3FVSUN, glTexCoord2fNormal3fVertex3fvSUN );
    INIT_FUNCTION( nivenGLCOLOR4FNORMAL3FVERTEX3FVSUN, glColor4fNormal3fVertex3fvSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FVSUN, glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN );
    INIT_FUNCTION( nivenGLREPLACEMENTCODEUICOLOR3FVERTEX3FVSUN, glReplacementCodeuiColor3fVertex3fvSUN );
    INIT_FUNCTION( nivenGLCOLOR4UBVERTEX3FSUN, glColor4ubVertex3fSUN );
    INIT_FUNCTION( nivenGLTEXCOORD2FVERTEX3FSUN, glTexCoord2fVertex3fSUN );
    INIT_FUNCTION( nivenGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUN, glTexCoord2fColor4fNormal3fVertex3fSUN );


    if (error == false)
      NIV_GL_SUN_vertex = true;
    
    return !error;
  }

  bool InitGL_ARB_texture_env_crossbar ()
  {
    bool error = false;

    if ( checked_GL_ARB_texture_env_crossbar == true )
      return NIV_GL_ARB_texture_env_crossbar;

    checked_GL_ARB_texture_env_crossbar = true;
  
    if (strstr( GLExtensionString, "GL_ARB_texture_env_crossbar" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_texture_env_crossbar = true;
    
    return !error;
  }

  bool InitGL_SGIS_texture_lod ()
  {
    bool error = false;

    if ( checked_GL_SGIS_texture_lod == true )
      return NIV_GL_SGIS_texture_lod;

    checked_GL_SGIS_texture_lod = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_texture_lod" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIS_texture_lod = true;
    
    return !error;
  }

  bool InitGL_MESA_pack_invert ()
  {
    bool error = false;

    if ( checked_GL_MESA_pack_invert == true )
      return NIV_GL_MESA_pack_invert;

    checked_GL_MESA_pack_invert = true;
  
    if (strstr( GLExtensionString, "GL_MESA_pack_invert" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_MESA_pack_invert = true;
    
    return !error;
  }

  bool InitGL_ATIX_texture_env_route ()
  {
    bool error = false;

    if ( checked_GL_ATIX_texture_env_route == true )
      return NIV_GL_ATIX_texture_env_route;

    checked_GL_ATIX_texture_env_route = true;
  
    if (strstr( GLExtensionString, "GL_ATIX_texture_env_route" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ATIX_texture_env_route = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_MESA_release_buffers ()
  {
    bool error = false;

    if ( checked_GLX_MESA_release_buffers == true )
      return NIV_GLX_MESA_release_buffers;

    checked_GLX_MESA_release_buffers = true;
  
    if (strstr( GLXExtensionString, "GLX_MESA_release_buffers" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXRELEASEBUFFERSMESA, glXReleaseBuffersMESA );


    if (error == false)
      NIV_GLX_MESA_release_buffers = true;
    
    return !error;
  }
#endif

  bool InitGL_SGIS_sharpen_texture ()
  {
    bool error = false;

    if ( checked_GL_SGIS_sharpen_texture == true )
      return NIV_GL_SGIS_sharpen_texture;

    checked_GL_SGIS_sharpen_texture = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_sharpen_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETSHARPENTEXFUNCSGIS, glGetSharpenTexFuncSGIS );
    INIT_FUNCTION( nivenGLSHARPENTEXFUNCSGIS, glSharpenTexFuncSGIS );


    if (error == false)
      NIV_GL_SGIS_sharpen_texture = true;
    
    return !error;
  }

  bool InitGL_SGIX_texture_range ()
  {
    bool error = false;

    if ( checked_GL_SGIX_texture_range == true )
      return NIV_GL_SGIX_texture_range;

    checked_GL_SGIX_texture_range = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_texture_range" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_texture_range = true;
    
    return !error;
  }

  bool InitGL_EXT_texture_rectangle ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture_rectangle == true )
      return NIV_GL_EXT_texture_rectangle;

    checked_GL_EXT_texture_rectangle = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture_rectangle" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_texture_rectangle = true;
    
    return !error;
  }

  bool InitGL_EXT_blend_logic_op ()
  {
    bool error = false;

    if ( checked_GL_EXT_blend_logic_op == true )
      return NIV_GL_EXT_blend_logic_op;

    checked_GL_EXT_blend_logic_op = true;
  
    if (strstr( GLExtensionString, "GL_EXT_blend_logic_op" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_blend_logic_op = true;
    
    return !error;
  }

  bool InitGL_SGIS_fog_function ()
  {
    bool error = false;

    if ( checked_GL_SGIS_fog_function == true )
      return NIV_GL_SGIS_fog_function;

    checked_GL_SGIS_fog_function = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_fog_function" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETFOGFUNCSGIS, glGetFogFuncSGIS );
    INIT_FUNCTION( nivenGLFOGFUNCSGIS, glFogFuncSGIS );


    if (error == false)
      NIV_GL_SGIS_fog_function = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SUN_video_resize ()
  {
    bool error = false;

    if ( checked_GLX_SUN_video_resize == true )
      return NIV_GLX_SUN_video_resize;

    checked_GLX_SUN_video_resize = true;
  
    if (strstr( GLXExtensionString, "GLX_SUN_video_resize" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXGETVIDEORESIZESUN, glXGetVideoResizeSUN );
    INIT_FUNCTION( nivenGLXVIDEORESIZESUN, glXVideoResizeSUN );


    if (error == false)
      NIV_GLX_SUN_video_resize = true;
    
    return !error;
  }
#endif

  bool InitGL_IBM_cull_vertex ()
  {
    bool error = false;

    if ( checked_GL_IBM_cull_vertex == true )
      return NIV_GL_IBM_cull_vertex;

    checked_GL_IBM_cull_vertex = true;
  
    if (strstr( GLExtensionString, "GL_IBM_cull_vertex" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_IBM_cull_vertex = true;
    
    return !error;
  }

  bool InitGL_PGI_vertex_hints ()
  {
    bool error = false;

    if ( checked_GL_PGI_vertex_hints == true )
      return NIV_GL_PGI_vertex_hints;

    checked_GL_PGI_vertex_hints = true;
  
    if (strstr( GLExtensionString, "GL_PGI_vertex_hints" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_PGI_vertex_hints = true;
    
    return !error;
  }

  bool InitGL_GREMEDY_string_marker ()
  {
    bool error = false;

    if ( checked_GL_GREMEDY_string_marker == true )
      return NIV_GL_GREMEDY_string_marker;

    checked_GL_GREMEDY_string_marker = true;
  
    if (strstr( GLExtensionString, "GL_GREMEDY_string_marker" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLSTRINGMARKERGREMEDY, glStringMarkerGREMEDY );


    if (error == false)
      NIV_GL_GREMEDY_string_marker = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGIS_color_range ()
  {
    bool error = false;

    if ( checked_GLX_SGIS_color_range == true )
      return NIV_GLX_SGIS_color_range;

    checked_GLX_SGIS_color_range = true;
  
    if (strstr( GLXExtensionString, "GLX_SGIS_color_range" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_SGIS_color_range = true;
    
    return !error;
  }
#endif

  bool InitGL_EXT_subtexture ()
  {
    bool error = false;

    if ( checked_GL_EXT_subtexture == true )
      return NIV_GL_EXT_subtexture;

    checked_GL_EXT_subtexture = true;
  
    if (strstr( GLExtensionString, "GL_EXT_subtexture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTEXSUBIMAGE1DEXT, glTexSubImage1DEXT );
    INIT_FUNCTION( nivenGLTEXSUBIMAGE2DEXT, glTexSubImage2DEXT );
    INIT_FUNCTION( nivenGLTEXSUBIMAGE3DEXT, glTexSubImage3DEXT );


    if (error == false)
      NIV_GL_EXT_subtexture = true;
    
    return !error;
  }

  bool InitGL_WIN_swap_hint ()
  {
    bool error = false;

    if ( checked_GL_WIN_swap_hint == true )
      return NIV_GL_WIN_swap_hint;

    checked_GL_WIN_swap_hint = true;
  
    if (strstr( GLExtensionString, "GL_WIN_swap_hint" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLADDSWAPHINTRECTWIN, glAddSwapHintRectWIN );


    if (error == false)
      NIV_GL_WIN_swap_hint = true;
    
    return !error;
  }

  bool InitGL_ARB_color_buffer_float ()
  {
    bool error = false;

    if ( checked_GL_ARB_color_buffer_float == true )
      return NIV_GL_ARB_color_buffer_float;

    checked_GL_ARB_color_buffer_float = true;
  
    if (strstr( GLExtensionString, "GL_ARB_color_buffer_float" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLCLAMPCOLORARB, glClampColorARB );


    if (error == false)
      NIV_GL_ARB_color_buffer_float = true;
    
    return !error;
  }

  bool InitGL_EXT_pixel_transform_color_table ()
  {
    bool error = false;

    if ( checked_GL_EXT_pixel_transform_color_table == true )
      return NIV_GL_EXT_pixel_transform_color_table;

    checked_GL_EXT_pixel_transform_color_table = true;
  
    if (strstr( GLExtensionString, "GL_EXT_pixel_transform_color_table" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_pixel_transform_color_table = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_ARB_fbconfig_float ()
  {
    bool error = false;

    if ( checked_GLX_ARB_fbconfig_float == true )
      return NIV_GLX_ARB_fbconfig_float;

    checked_GLX_ARB_fbconfig_float = true;
  
    if (strstr( GLXExtensionString, "GLX_ARB_fbconfig_float" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_ARB_fbconfig_float = true;
    
    return !error;
  }
#endif

  bool InitGL_ARB_window_pos ()
  {
    bool error = false;

    if ( checked_GL_ARB_window_pos == true )
      return NIV_GL_ARB_window_pos;

    checked_GL_ARB_window_pos = true;
  
    if (strstr( GLExtensionString, "GL_ARB_window_pos" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLWINDOWPOS2SARB, glWindowPos2sARB );
    INIT_FUNCTION( nivenGLWINDOWPOS2SVARB, glWindowPos2svARB );
    INIT_FUNCTION( nivenGLWINDOWPOS3FARB, glWindowPos3fARB );
    INIT_FUNCTION( nivenGLWINDOWPOS2FVARB, glWindowPos2fvARB );
    INIT_FUNCTION( nivenGLWINDOWPOS2DARB, glWindowPos2dARB );
    INIT_FUNCTION( nivenGLWINDOWPOS2FARB, glWindowPos2fARB );
    INIT_FUNCTION( nivenGLWINDOWPOS3DARB, glWindowPos3dARB );
    INIT_FUNCTION( nivenGLWINDOWPOS3SARB, glWindowPos3sARB );
    INIT_FUNCTION( nivenGLWINDOWPOS3SVARB, glWindowPos3svARB );
    INIT_FUNCTION( nivenGLWINDOWPOS2IARB, glWindowPos2iARB );
    INIT_FUNCTION( nivenGLWINDOWPOS2IVARB, glWindowPos2ivARB );
    INIT_FUNCTION( nivenGLWINDOWPOS3IVARB, glWindowPos3ivARB );
    INIT_FUNCTION( nivenGLWINDOWPOS3IARB, glWindowPos3iARB );
    INIT_FUNCTION( nivenGLWINDOWPOS3FVARB, glWindowPos3fvARB );
    INIT_FUNCTION( nivenGLWINDOWPOS2DVARB, glWindowPos2dvARB );
    INIT_FUNCTION( nivenGLWINDOWPOS3DVARB, glWindowPos3dvARB );


    if (error == false)
      NIV_GL_ARB_window_pos = true;
    
    return !error;
  }

  bool InitGL_NV_fragment_program2 ()
  {
    bool error = false;

    if ( checked_GL_NV_fragment_program2 == true )
      return NIV_GL_NV_fragment_program2;

    checked_GL_NV_fragment_program2 = true;
  
    if (strstr( GLExtensionString, "GL_NV_fragment_program2" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_fragment_program2 = true;
    
    return !error;
  }

  bool InitGL_ARB_shadow ()
  {
    bool error = false;

    if ( checked_GL_ARB_shadow == true )
      return NIV_GL_ARB_shadow;

    checked_GL_ARB_shadow = true;
  
    if (strstr( GLExtensionString, "GL_ARB_shadow" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_shadow = true;
    
    return !error;
  }

  bool InitGL_ARB_texture_mirrored_repeat ()
  {
    bool error = false;

    if ( checked_GL_ARB_texture_mirrored_repeat == true )
      return NIV_GL_ARB_texture_mirrored_repeat;

    checked_GL_ARB_texture_mirrored_repeat = true;
  
    if (strstr( GLExtensionString, "GL_ARB_texture_mirrored_repeat" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_texture_mirrored_repeat = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGIX_video_resize ()
  {
    bool error = false;

    if ( checked_GLX_SGIX_video_resize == true )
      return NIV_GLX_SGIX_video_resize;

    checked_GLX_SGIX_video_resize = true;
  
    if (strstr( GLXExtensionString, "GLX_SGIX_video_resize" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXCHANNELRECTSGIX, glXChannelRectSGIX );
    INIT_FUNCTION( nivenGLXQUERYCHANNELRECTSGIX, glXQueryChannelRectSGIX );
    INIT_FUNCTION( nivenGLXBINDCHANNELTOWINDOWSGIX, glXBindChannelToWindowSGIX );
    INIT_FUNCTION( nivenGLXCHANNELRECTSYNCSGIX, glXChannelRectSyncSGIX );
    INIT_FUNCTION( nivenGLXQUERYCHANNELDELTASSGIX, glXQueryChannelDeltasSGIX );


    if (error == false)
      NIV_GLX_SGIX_video_resize = true;
    
    return !error;
  }
#endif

#ifdef _WIN32
  bool InitWGL_I3D_swap_frame_usage ()
  {
    bool error = false;

    if ( checked_WGL_I3D_swap_frame_usage == true )
      return NIV_WGL_I3D_swap_frame_usage;

    checked_WGL_I3D_swap_frame_usage = true;
  
    if (strstr( WGLExtensionString, "WGL_I3D_swap_frame_usage" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLGETFRAMEUSAGEI3D, wglGetFrameUsageI3D );
    INIT_FUNCTION( nivenWGLENDFRAMETRACKINGI3D, wglEndFrameTrackingI3D );
    INIT_FUNCTION( nivenWGLBEGINFRAMETRACKINGI3D, wglBeginFrameTrackingI3D );
    INIT_FUNCTION( nivenWGLQUERYFRAMETRACKINGI3D, wglQueryFrameTrackingI3D );


    if (error == false)
      NIV_WGL_I3D_swap_frame_usage = true;
    
    return !error;
  }
#endif

  bool InitGL_PGI_misc_hints ()
  {
    bool error = false;

    if ( checked_GL_PGI_misc_hints == true )
      return NIV_GL_PGI_misc_hints;

    checked_GL_PGI_misc_hints = true;
  
    if (strstr( GLExtensionString, "GL_PGI_misc_hints" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_PGI_misc_hints = true;
    
    return !error;
  }

  bool InitGL_NV_evaluators ()
  {
    bool error = false;

    if ( checked_GL_NV_evaluators == true )
      return NIV_GL_NV_evaluators;

    checked_GL_NV_evaluators = true;
  
    if (strstr( GLExtensionString, "GL_NV_evaluators" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETMAPPARAMETERIVNV, glGetMapParameterivNV );
    INIT_FUNCTION( nivenGLMAPCONTROLPOINTSNV, glMapControlPointsNV );
    INIT_FUNCTION( nivenGLGETMAPATTRIBPARAMETERIVNV, glGetMapAttribParameterivNV );
    INIT_FUNCTION( nivenGLGETMAPCONTROLPOINTSNV, glGetMapControlPointsNV );
    INIT_FUNCTION( nivenGLGETMAPPARAMETERFVNV, glGetMapParameterfvNV );
    INIT_FUNCTION( nivenGLEVALMAPSNV, glEvalMapsNV );
    INIT_FUNCTION( nivenGLMAPPARAMETERFVNV, glMapParameterfvNV );
    INIT_FUNCTION( nivenGLGETMAPATTRIBPARAMETERFVNV, glGetMapAttribParameterfvNV );
    INIT_FUNCTION( nivenGLMAPPARAMETERIVNV, glMapParameterivNV );


    if (error == false)
      NIV_GL_NV_evaluators = true;
    
    return !error;
  }

  bool InitGL_INTEL_texture_scissor ()
  {
    bool error = false;

    if ( checked_GL_INTEL_texture_scissor == true )
      return NIV_GL_INTEL_texture_scissor;

    checked_GL_INTEL_texture_scissor = true;
  
    if (strstr( GLExtensionString, "GL_INTEL_texture_scissor" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTEXSCISSORFUNCINTEL, glTexScissorFuncINTEL );
    INIT_FUNCTION( nivenGLTEXSCISSORINTEL, glTexScissorINTEL );


    if (error == false)
      NIV_GL_INTEL_texture_scissor = true;
    
    return !error;
  }

  bool InitGL_NV_texture_compression_vtc ()
  {
    bool error = false;

    if ( checked_GL_NV_texture_compression_vtc == true )
      return NIV_GL_NV_texture_compression_vtc;

    checked_GL_NV_texture_compression_vtc = true;
  
    if (strstr( GLExtensionString, "GL_NV_texture_compression_vtc" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_texture_compression_vtc = true;
    
    return !error;
  }

  bool InitGL_SGIS_texture_filter4 ()
  {
    bool error = false;

    if ( checked_GL_SGIS_texture_filter4 == true )
      return NIV_GL_SGIS_texture_filter4;

    checked_GL_SGIS_texture_filter4 = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_texture_filter4" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTEXFILTERFUNCSGIS, glTexFilterFuncSGIS );
    INIT_FUNCTION( nivenGLGETTEXFILTERFUNCSGIS, glGetTexFilterFuncSGIS );


    if (error == false)
      NIV_GL_SGIS_texture_filter4 = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_OML_swap_method ()
  {
    bool error = false;

    if ( checked_GLX_OML_swap_method == true )
      return NIV_GLX_OML_swap_method;

    checked_GLX_OML_swap_method = true;
  
    if (strstr( GLXExtensionString, "GLX_OML_swap_method" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GLX_OML_swap_method = true;
    
    return !error;
  }
#endif

  bool InitGL_EXT_copy_texture ()
  {
    bool error = false;

    if ( checked_GL_EXT_copy_texture == true )
      return NIV_GL_EXT_copy_texture;

    checked_GL_EXT_copy_texture = true;
  
    if (strstr( GLExtensionString, "GL_EXT_copy_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLCOPYTEXIMAGE2DEXT, glCopyTexImage2DEXT );
    INIT_FUNCTION( nivenGLCOPYTEXSUBIMAGE2DEXT, glCopyTexSubImage2DEXT );
    INIT_FUNCTION( nivenGLCOPYTEXSUBIMAGE1DEXT, glCopyTexSubImage1DEXT );
    INIT_FUNCTION( nivenGLCOPYTEXIMAGE1DEXT, glCopyTexImage1DEXT );
    INIT_FUNCTION( nivenGLCOPYTEXSUBIMAGE3DEXT, glCopyTexSubImage3DEXT );


    if (error == false)
      NIV_GL_EXT_copy_texture = true;
    
    return !error;
  }

  bool InitGL_NV_register_combiners2 ()
  {
    bool error = false;

    if ( checked_GL_NV_register_combiners2 == true )
      return NIV_GL_NV_register_combiners2;

    checked_GL_NV_register_combiners2 = true;
  
    if (strstr( GLExtensionString, "GL_NV_register_combiners2" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETCOMBINERSTAGEPARAMETERFVNV, glGetCombinerStageParameterfvNV );
    INIT_FUNCTION( nivenGLCOMBINERSTAGEPARAMETERFVNV, glCombinerStageParameterfvNV );


    if (error == false)
      NIV_GL_NV_register_combiners2 = true;
    
    return !error;
  }

  bool InitGL_EXT_fragment_lighting ()
  {
    bool error = false;

    if ( checked_GL_EXT_fragment_lighting == true )
      return NIV_GL_EXT_fragment_lighting;

    checked_GL_EXT_fragment_lighting = true;
  
    if (strstr( GLExtensionString, "GL_EXT_fragment_lighting" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLFRAGMENTLIGHTFVEXT, glFragmentLightfvEXT );
    INIT_FUNCTION( nivenGLGETFRAGMENTLIGHTFVEXT, glGetFragmentLightfvEXT );
    INIT_FUNCTION( nivenGLGETFRAGMENTLIGHTIVEXT, glGetFragmentLightivEXT );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTFEXT, glFragmentLightfEXT );
    INIT_FUNCTION( nivenGLLIGHTENVIEXT, glLightEnviEXT );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTIEXT, glFragmentLightiEXT );
    INIT_FUNCTION( nivenGLFRAGMENTMATERIALFVEXT, glFragmentMaterialfvEXT );
    INIT_FUNCTION( nivenGLFRAGMENTMATERIALFEXT, glFragmentMaterialfEXT );
    INIT_FUNCTION( nivenGLFRAGMENTCOLORMATERIALEXT, glFragmentColorMaterialEXT );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTMODELFVEXT, glFragmentLightModelfvEXT );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTMODELIVEXT, glFragmentLightModelivEXT );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTIVEXT, glFragmentLightivEXT );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTMODELIEXT, glFragmentLightModeliEXT );
    INIT_FUNCTION( nivenGLFRAGMENTMATERIALIVEXT, glFragmentMaterialivEXT );
    INIT_FUNCTION( nivenGLGETFRAGMENTMATERIALIVEXT, glGetFragmentMaterialivEXT );
    INIT_FUNCTION( nivenGLFRAGMENTLIGHTMODELFEXT, glFragmentLightModelfEXT );
    INIT_FUNCTION( nivenGLFRAGMENTMATERIALIEXT, glFragmentMaterialiEXT );
    INIT_FUNCTION( nivenGLGETFRAGMENTMATERIALFVEXT, glGetFragmentMaterialfvEXT );


    if (error == false)
      NIV_GL_EXT_fragment_lighting = true;
    
    return !error;
  }

  bool InitGL_SGIX_interlace ()
  {
    bool error = false;

    if ( checked_GL_SGIX_interlace == true )
      return NIV_GL_SGIX_interlace;

    checked_GL_SGIX_interlace = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_interlace" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_interlace = true;
    
    return !error;
  }

  bool InitGL_NV_vertex_program1_1 ()
  {
    bool error = false;

    if ( checked_GL_NV_vertex_program1_1 == true )
      return NIV_GL_NV_vertex_program1_1;

    checked_GL_NV_vertex_program1_1 = true;
  
    if (strstr( GLExtensionString, "GL_NV_vertex_program1_1" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_vertex_program1_1 = true;
    
    return !error;
  }

  bool InitGL_EXT_rescale_normal ()
  {
    bool error = false;

    if ( checked_GL_EXT_rescale_normal == true )
      return NIV_GL_EXT_rescale_normal;

    checked_GL_EXT_rescale_normal = true;
  
    if (strstr( GLExtensionString, "GL_EXT_rescale_normal" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_rescale_normal = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_ATI_render_texture ()
  {
    bool error = false;

    if ( checked_GLX_ATI_render_texture == true )
      return NIV_GLX_ATI_render_texture;

    checked_GLX_ATI_render_texture = true;
  
    if (strstr( GLXExtensionString, "GLX_ATI_render_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXBINDTEXIMAGEATI, glXBindTexImageATI );
    INIT_FUNCTION( nivenGLXRELEASETEXIMAGEATI, glXReleaseTexImageATI );
    INIT_FUNCTION( nivenGLXDRAWABLEATTRIBATI, glXDrawableAttribATI );


    if (error == false)
      NIV_GLX_ATI_render_texture = true;
    
    return !error;
  }
#endif

  bool InitGL_HP_convolution_border_modes ()
  {
    bool error = false;

    if ( checked_GL_HP_convolution_border_modes == true )
      return NIV_GL_HP_convolution_border_modes;

    checked_GL_HP_convolution_border_modes = true;
  
    if (strstr( GLExtensionString, "GL_HP_convolution_border_modes" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_HP_convolution_border_modes = true;
    
    return !error;
  }

  bool InitGL_SGI_color_table ()
  {
    bool error = false;

    if ( checked_GL_SGI_color_table == true )
      return NIV_GL_SGI_color_table;

    checked_GL_SGI_color_table = true;
  
    if (strstr( GLExtensionString, "GL_SGI_color_table" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLCOLORTABLEPARAMETERFVSGI, glColorTableParameterfvSGI );
    INIT_FUNCTION( nivenGLCOPYCOLORTABLESGI, glCopyColorTableSGI );
    INIT_FUNCTION( nivenGLGETCOLORTABLEPARAMETERIVSGI, glGetColorTableParameterivSGI );
    INIT_FUNCTION( nivenGLGETCOLORTABLESGI, glGetColorTableSGI );
    INIT_FUNCTION( nivenGLCOLORTABLESGI, glColorTableSGI );
    INIT_FUNCTION( nivenGLGETCOLORTABLEPARAMETERFVSGI, glGetColorTableParameterfvSGI );
    INIT_FUNCTION( nivenGLCOLORTABLEPARAMETERIVSGI, glColorTableParameterivSGI );


    if (error == false)
      NIV_GL_SGI_color_table = true;
    
    return !error;
  }

  bool InitGL_SGIX_resample ()
  {
    bool error = false;

    if ( checked_GL_SGIX_resample == true )
      return NIV_GL_SGIX_resample;

    checked_GL_SGIX_resample = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_resample" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_resample = true;
    
    return !error;
  }

  bool InitGL_SGIX_ir_instrument1 ()
  {
    bool error = false;

    if ( checked_GL_SGIX_ir_instrument1 == true )
      return NIV_GL_SGIX_ir_instrument1;

    checked_GL_SGIX_ir_instrument1 = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_ir_instrument1" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_ir_instrument1 = true;
    
    return !error;
  }

  bool InitGL_SGIX_list_priority ()
  {
    bool error = false;

    if ( checked_GL_SGIX_list_priority == true )
      return NIV_GL_SGIX_list_priority;

    checked_GL_SGIX_list_priority = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_list_priority" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_list_priority = true;
    
    return !error;
  }

  bool InitGL_SGIX_framezoom ()
  {
    bool error = false;

    if ( checked_GL_SGIX_framezoom == true )
      return NIV_GL_SGIX_framezoom;

    checked_GL_SGIX_framezoom = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_framezoom" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLFRAMEZOOMSGIX, glFrameZoomSGIX );


    if (error == false)
      NIV_GL_SGIX_framezoom = true;
    
    return !error;
  }

  bool InitGL_EXT_index_material ()
  {
    bool error = false;

    if ( checked_GL_EXT_index_material == true )
      return NIV_GL_EXT_index_material;

    checked_GL_EXT_index_material = true;
  
    if (strstr( GLExtensionString, "GL_EXT_index_material" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLINDEXMATERIALEXT, glIndexMaterialEXT );


    if (error == false)
      NIV_GL_EXT_index_material = true;
    
    return !error;
  }

  bool InitGL_SGIS_texture4D ()
  {
    bool error = false;

    if ( checked_GL_SGIS_texture4D == true )
      return NIV_GL_SGIS_texture4D;

    checked_GL_SGIS_texture4D = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_texture4D" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTEXSUBIMAGE4DSGIS, glTexSubImage4DSGIS );
    INIT_FUNCTION( nivenGLTEXIMAGE4DSGIS, glTexImage4DSGIS );


    if (error == false)
      NIV_GL_SGIS_texture4D = true;
    
    return !error;
  }

  bool InitGL_EXT_texture3D ()
  {
    bool error = false;

    if ( checked_GL_EXT_texture3D == true )
      return NIV_GL_EXT_texture3D;

    checked_GL_EXT_texture3D = true;
  
    if (strstr( GLExtensionString, "GL_EXT_texture3D" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTEXIMAGE3DEXT, glTexImage3DEXT );


    if (error == false)
      NIV_GL_EXT_texture3D = true;
    
    return !error;
  }

  bool InitGL_REND_screen_coordinates ()
  {
    bool error = false;

    if ( checked_GL_REND_screen_coordinates == true )
      return NIV_GL_REND_screen_coordinates;

    checked_GL_REND_screen_coordinates = true;
  
    if (strstr( GLExtensionString, "GL_REND_screen_coordinates" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_REND_screen_coordinates = true;
    
    return !error;
  }

  bool InitGL_ARB_multitexture ()
  {
    bool error = false;

    if ( checked_GL_ARB_multitexture == true )
      return NIV_GL_ARB_multitexture;

    checked_GL_ARB_multitexture = true;
  
    if (strstr( GLExtensionString, "GL_ARB_multitexture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLMULTITEXCOORD2SVARB, glMultiTexCoord2svARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD1IVARB, glMultiTexCoord1ivARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD4FARB, glMultiTexCoord4fARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD4FVARB, glMultiTexCoord4fvARB );
    INIT_FUNCTION( nivenGLCLIENTACTIVETEXTUREARB, glClientActiveTextureARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD3SVARB, glMultiTexCoord3svARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD4SARB, glMultiTexCoord4sARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD4DVARB, glMultiTexCoord4dvARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD1FARB, glMultiTexCoord1fARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD2FVARB, glMultiTexCoord2fvARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD3IARB, glMultiTexCoord3iARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD1DVARB, glMultiTexCoord1dvARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD3DARB, glMultiTexCoord3dARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD4SVARB, glMultiTexCoord4svARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD2SARB, glMultiTexCoord2sARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD3SARB, glMultiTexCoord3sARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD2DVARB, glMultiTexCoord2dvARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD3IVARB, glMultiTexCoord3ivARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD1FVARB, glMultiTexCoord1fvARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD1SARB, glMultiTexCoord1sARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD1SVARB, glMultiTexCoord1svARB );
    INIT_FUNCTION( nivenGLACTIVETEXTUREARB, glActiveTextureARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD4IVARB, glMultiTexCoord4ivARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD2FARB, glMultiTexCoord2fARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD2IARB, glMultiTexCoord2iARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD3FARB, glMultiTexCoord3fARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD4DARB, glMultiTexCoord4dARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD3DVARB, glMultiTexCoord3dvARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD1IARB, glMultiTexCoord1iARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD2IVARB, glMultiTexCoord2ivARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD4IARB, glMultiTexCoord4iARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD3FVARB, glMultiTexCoord3fvARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD1DARB, glMultiTexCoord1dARB );
    INIT_FUNCTION( nivenGLMULTITEXCOORD2DARB, glMultiTexCoord2dARB );


    if (error == false)
      NIV_GL_ARB_multitexture = true;
    
    return !error;
  }

  bool InitGL_EXT_secondary_color ()
  {
    bool error = false;

    if ( checked_GL_EXT_secondary_color == true )
      return NIV_GL_EXT_secondary_color;

    checked_GL_EXT_secondary_color = true;
  
    if (strstr( GLExtensionString, "GL_EXT_secondary_color" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLSECONDARYCOLOR3USEXT, glSecondaryColor3usEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3DVEXT, glSecondaryColor3dvEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3BEXT, glSecondaryColor3bEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3BVEXT, glSecondaryColor3bvEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3DEXT, glSecondaryColor3dEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3SEXT, glSecondaryColor3sEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3SVEXT, glSecondaryColor3svEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3UBEXT, glSecondaryColor3ubEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3UIEXT, glSecondaryColor3uiEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3IEXT, glSecondaryColor3iEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3FEXT, glSecondaryColor3fEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3FVEXT, glSecondaryColor3fvEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3UBVEXT, glSecondaryColor3ubvEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3IVEXT, glSecondaryColor3ivEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLORPOINTEREXT, glSecondaryColorPointerEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3UIVEXT, glSecondaryColor3uivEXT );
    INIT_FUNCTION( nivenGLSECONDARYCOLOR3USVEXT, glSecondaryColor3usvEXT );


    if (error == false)
      NIV_GL_EXT_secondary_color = true;
    
    return !error;
  }

  bool InitGL_SGIS_color_range ()
  {
    bool error = false;

    if ( checked_GL_SGIS_color_range == true )
      return NIV_GL_SGIS_color_range;

    checked_GL_SGIS_color_range = true;
  
    if (strstr( GLExtensionString, "GL_SGIS_color_range" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIS_color_range = true;
    
    return !error;
  }

  bool InitGL_SGIX_fog_offset ()
  {
    bool error = false;

    if ( checked_GL_SGIX_fog_offset == true )
      return NIV_GL_SGIX_fog_offset;

    checked_GL_SGIX_fog_offset = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_fog_offset" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_fog_offset = true;
    
    return !error;
  }

#ifdef _WIN32
  bool InitWGL_ARB_make_current_read ()
  {
    bool error = false;

    if ( checked_WGL_ARB_make_current_read == true )
      return NIV_WGL_ARB_make_current_read;

    checked_WGL_ARB_make_current_read = true;
  
    if (strstr( WGLExtensionString, "WGL_ARB_make_current_read" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenWGLGETCURRENTREADDCARB, wglGetCurrentReadDCARB );
    INIT_FUNCTION( nivenWGLMAKECONTEXTCURRENTARB, wglMakeContextCurrentARB );


    if (error == false)
      NIV_WGL_ARB_make_current_read = true;
    
    return !error;
  }
#endif

  bool InitGL_NV_copy_depth_to_color ()
  {
    bool error = false;

    if ( checked_GL_NV_copy_depth_to_color == true )
      return NIV_GL_NV_copy_depth_to_color;

    checked_GL_NV_copy_depth_to_color = true;
  
    if (strstr( GLExtensionString, "GL_NV_copy_depth_to_color" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_NV_copy_depth_to_color = true;
    
    return !error;
  }

  bool InitGL_EXT_vertex_array ()
  {
    bool error = false;

    if ( checked_GL_EXT_vertex_array == true )
      return NIV_GL_EXT_vertex_array;

    checked_GL_EXT_vertex_array = true;
  
    if (strstr( GLExtensionString, "GL_EXT_vertex_array" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLVERTEXPOINTEREXT, glVertexPointerEXT );
    INIT_FUNCTION( nivenGLCOLORPOINTEREXT, glColorPointerEXT );
    INIT_FUNCTION( nivenGLGETPOINTERVEXT, glGetPointervEXT );
    INIT_FUNCTION( nivenGLNORMALPOINTEREXT, glNormalPointerEXT );
    INIT_FUNCTION( nivenGLINDEXPOINTEREXT, glIndexPointerEXT );
    INIT_FUNCTION( nivenGLEDGEFLAGPOINTEREXT, glEdgeFlagPointerEXT );
    INIT_FUNCTION( nivenGLDRAWARRAYSEXT, glDrawArraysEXT );
    INIT_FUNCTION( nivenGLARRAYELEMENTEXT, glArrayElementEXT );
    INIT_FUNCTION( nivenGLTEXCOORDPOINTEREXT, glTexCoordPointerEXT );


    if (error == false)
      NIV_GL_EXT_vertex_array = true;
    
    return !error;
  }

  bool InitGL_INTEL_parallel_arrays ()
  {
    bool error = false;

    if ( checked_GL_INTEL_parallel_arrays == true )
      return NIV_GL_INTEL_parallel_arrays;

    checked_GL_INTEL_parallel_arrays = true;
  
    if (strstr( GLExtensionString, "GL_INTEL_parallel_arrays" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLVERTEXPOINTERVINTEL, glVertexPointervINTEL );
    INIT_FUNCTION( nivenGLTEXCOORDPOINTERVINTEL, glTexCoordPointervINTEL );
    INIT_FUNCTION( nivenGLNORMALPOINTERVINTEL, glNormalPointervINTEL );
    INIT_FUNCTION( nivenGLCOLORPOINTERVINTEL, glColorPointervINTEL );


    if (error == false)
      NIV_GL_INTEL_parallel_arrays = true;
    
    return !error;
  }

  bool InitGL_ATI_draw_buffers ()
  {
    bool error = false;

    if ( checked_GL_ATI_draw_buffers == true )
      return NIV_GL_ATI_draw_buffers;

    checked_GL_ATI_draw_buffers = true;
  
    if (strstr( GLExtensionString, "GL_ATI_draw_buffers" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLDRAWBUFFERSATI, glDrawBuffersATI );


    if (error == false)
      NIV_GL_ATI_draw_buffers = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGIX_fbconfig ()
  {
    bool error = false;

    if ( checked_GLX_SGIX_fbconfig == true )
      return NIV_GLX_SGIX_fbconfig;

    checked_GLX_SGIX_fbconfig = true;
  
    if (strstr( GLXExtensionString, "GLX_SGIX_fbconfig" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXCREATECONTEXTWITHCONFIGSGIX, glXCreateContextWithConfigSGIX );
    INIT_FUNCTION( nivenGLXGETFBCONFIGFROMVISUALSGIX, glXGetFBConfigFromVisualSGIX );
    INIT_FUNCTION( nivenGLXCREATEGLXPIXMAPWITHCONFIGSGIX, glXCreateGLXPixmapWithConfigSGIX );
    INIT_FUNCTION( nivenGLXCHOOSEFBCONFIGSGIX, glXChooseFBConfigSGIX );
    INIT_FUNCTION( nivenGLXGETFBCONFIGATTRIBSGIX, glXGetFBConfigAttribSGIX );
    INIT_FUNCTION( nivenGLXGETVISUALFROMFBCONFIGSGIX, glXGetVisualFromFBConfigSGIX );


    if (error == false)
      NIV_GLX_SGIX_fbconfig = true;
    
    return !error;
  }
#endif

  bool InitGL_SGIX_async ()
  {
    bool error = false;

    if ( checked_GL_SGIX_async == true )
      return NIV_GL_SGIX_async;

    checked_GL_SGIX_async = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_async" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLPOLLASYNCSGIX, glPollAsyncSGIX );
    INIT_FUNCTION( nivenGLGENASYNCMARKERSSGIX, glGenAsyncMarkersSGIX );
    INIT_FUNCTION( nivenGLDELETEASYNCMARKERSSGIX, glDeleteAsyncMarkersSGIX );
    INIT_FUNCTION( nivenGLFINISHASYNCSGIX, glFinishAsyncSGIX );
    INIT_FUNCTION( nivenGLASYNCMARKERSGIX, glAsyncMarkerSGIX );
    INIT_FUNCTION( nivenGLISASYNCMARKERSGIX, glIsAsyncMarkerSGIX );


    if (error == false)
      NIV_GL_SGIX_async = true;
    
    return !error;
  }

  bool InitGL_EXT_depth_bounds_test ()
  {
    bool error = false;

    if ( checked_GL_EXT_depth_bounds_test == true )
      return NIV_GL_EXT_depth_bounds_test;

    checked_GL_EXT_depth_bounds_test = true;
  
    if (strstr( GLExtensionString, "GL_EXT_depth_bounds_test" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLDEPTHBOUNDSEXT, glDepthBoundsEXT );


    if (error == false)
      NIV_GL_EXT_depth_bounds_test = true;
    
    return !error;
  }

  bool InitGL_ATI_vertex_array_object ()
  {
    bool error = false;

    if ( checked_GL_ATI_vertex_array_object == true )
      return NIV_GL_ATI_vertex_array_object;

    checked_GL_ATI_vertex_array_object = true;
  
    if (strstr( GLExtensionString, "GL_ATI_vertex_array_object" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLNEWOBJECTBUFFERATI, glNewObjectBufferATI );
    INIT_FUNCTION( nivenGLGETVARIANTARRAYOBJECTIVATI, glGetVariantArrayObjectivATI );
    INIT_FUNCTION( nivenGLISOBJECTBUFFERATI, glIsObjectBufferATI );
    INIT_FUNCTION( nivenGLGETOBJECTBUFFERFVATI, glGetObjectBufferfvATI );
    INIT_FUNCTION( nivenGLUPDATEOBJECTBUFFERATI, glUpdateObjectBufferATI );
    INIT_FUNCTION( nivenGLGETARRAYOBJECTIVATI, glGetArrayObjectivATI );
    INIT_FUNCTION( nivenGLFREEOBJECTBUFFERATI, glFreeObjectBufferATI );
    INIT_FUNCTION( nivenGLVARIANTARRAYOBJECTATI, glVariantArrayObjectATI );
    INIT_FUNCTION( nivenGLGETVARIANTARRAYOBJECTFVATI, glGetVariantArrayObjectfvATI );
    INIT_FUNCTION( nivenGLGETOBJECTBUFFERIVATI, glGetObjectBufferivATI );
    INIT_FUNCTION( nivenGLARRAYOBJECTATI, glArrayObjectATI );
    INIT_FUNCTION( nivenGLGETARRAYOBJECTFVATI, glGetArrayObjectfvATI );


    if (error == false)
      NIV_GL_ATI_vertex_array_object = true;
    
    return !error;
  }

  bool InitGL_SUN_convolution_border_modes ()
  {
    bool error = false;

    if ( checked_GL_SUN_convolution_border_modes == true )
      return NIV_GL_SUN_convolution_border_modes;

    checked_GL_SUN_convolution_border_modes = true;
  
    if (strstr( GLExtensionString, "GL_SUN_convolution_border_modes" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SUN_convolution_border_modes = true;
    
    return !error;
  }

  bool InitGL_SGIX_fog_texture ()
  {
    bool error = false;

    if ( checked_GL_SGIX_fog_texture == true )
      return NIV_GL_SGIX_fog_texture;

    checked_GL_SGIX_fog_texture = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_fog_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLTEXTUREFOGSGIX, glTextureFogSGIX );


    if (error == false)
      NIV_GL_SGIX_fog_texture = true;
    
    return !error;
  }

  bool InitGL_SGIX_pixel_texture ()
  {
    bool error = false;

    if ( checked_GL_SGIX_pixel_texture == true )
      return NIV_GL_SGIX_pixel_texture;

    checked_GL_SGIX_pixel_texture = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_pixel_texture" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLPIXELTEXGENSGIX, glPixelTexGenSGIX );


    if (error == false)
      NIV_GL_SGIX_pixel_texture = true;
    
    return !error;
  }

  bool InitGL_APPLE_specular_vector ()
  {
    bool error = false;

    if ( checked_GL_APPLE_specular_vector == true )
      return NIV_GL_APPLE_specular_vector;

    checked_GL_APPLE_specular_vector = true;
  
    if (strstr( GLExtensionString, "GL_APPLE_specular_vector" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_APPLE_specular_vector = true;
    
    return !error;
  }

  bool InitGL_ARB_texture_env_add ()
  {
    bool error = false;

    if ( checked_GL_ARB_texture_env_add == true )
      return NIV_GL_ARB_texture_env_add;

    checked_GL_ARB_texture_env_add = true;
  
    if (strstr( GLExtensionString, "GL_ARB_texture_env_add" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_texture_env_add = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGIX_swap_barrier ()
  {
    bool error = false;

    if ( checked_GLX_SGIX_swap_barrier == true )
      return NIV_GLX_SGIX_swap_barrier;

    checked_GLX_SGIX_swap_barrier = true;
  
    if (strstr( GLXExtensionString, "GLX_SGIX_swap_barrier" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXQUERYMAXSWAPBARRIERSSGIX, glXQueryMaxSwapBarriersSGIX );
    INIT_FUNCTION( nivenGLXBINDSWAPBARRIERSGIX, glXBindSwapBarrierSGIX );


    if (error == false)
      NIV_GLX_SGIX_swap_barrier = true;
    
    return !error;
  }
#endif

  bool InitGL_NV_fragment_program ()
  {
    bool error = false;

    if ( checked_GL_NV_fragment_program == true )
      return NIV_GL_NV_fragment_program;

    checked_GL_NV_fragment_program = true;
  
    if (strstr( GLExtensionString, "GL_NV_fragment_program" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLGETPROGRAMNAMEDPARAMETERFVNV, glGetProgramNamedParameterfvNV );
    INIT_FUNCTION( nivenGLPROGRAMNAMEDPARAMETER4FNV, glProgramNamedParameter4fNV );
    INIT_FUNCTION( nivenGLPROGRAMNAMEDPARAMETER4DVNV, glProgramNamedParameter4dvNV );
    INIT_FUNCTION( nivenGLPROGRAMNAMEDPARAMETER4DNV, glProgramNamedParameter4dNV );
    INIT_FUNCTION( nivenGLPROGRAMNAMEDPARAMETER4FVNV, glProgramNamedParameter4fvNV );
    INIT_FUNCTION( nivenGLGETPROGRAMNAMEDPARAMETERDVNV, glGetProgramNamedParameterdvNV );


    if (error == false)
      NIV_GL_NV_fragment_program = true;
    
    return !error;
  }

  bool InitGL_SGIX_texture_coordinate_clamp ()
  {
    bool error = false;

    if ( checked_GL_SGIX_texture_coordinate_clamp == true )
      return NIV_GL_SGIX_texture_coordinate_clamp;

    checked_GL_SGIX_texture_coordinate_clamp = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_texture_coordinate_clamp" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_texture_coordinate_clamp = true;
    
    return !error;
  }

  bool InitGL_EXT_pixel_transform ()
  {
    bool error = false;

    if ( checked_GL_EXT_pixel_transform == true )
      return NIV_GL_EXT_pixel_transform;

    checked_GL_EXT_pixel_transform = true;
  
    if (strstr( GLExtensionString, "GL_EXT_pixel_transform" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLPIXELTRANSFORMPARAMETERFEXT, glPixelTransformParameterfEXT );
    INIT_FUNCTION( nivenGLGETPIXELTRANSFORMPARAMETERFVEXT, glGetPixelTransformParameterfvEXT );
    INIT_FUNCTION( nivenGLPIXELTRANSFORMPARAMETERIEXT, glPixelTransformParameteriEXT );
    INIT_FUNCTION( nivenGLGETPIXELTRANSFORMPARAMETERIVEXT, glGetPixelTransformParameterivEXT );
    INIT_FUNCTION( nivenGLPIXELTRANSFORMPARAMETERFVEXT, glPixelTransformParameterfvEXT );
    INIT_FUNCTION( nivenGLPIXELTRANSFORMPARAMETERIVEXT, glPixelTransformParameterivEXT );


    if (error == false)
      NIV_GL_EXT_pixel_transform = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_MESA_copy_sub_buffer ()
  {
    bool error = false;

    if ( checked_GLX_MESA_copy_sub_buffer == true )
      return NIV_GLX_MESA_copy_sub_buffer;

    checked_GLX_MESA_copy_sub_buffer = true;
  
    if (strstr( GLXExtensionString, "GLX_MESA_copy_sub_buffer" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXCOPYSUBBUFFERMESA, glXCopySubBufferMESA );


    if (error == false)
      NIV_GLX_MESA_copy_sub_buffer = true;
    
    return !error;
  }
#endif

  bool InitGL_SGIX_texture_add_env ()
  {
    bool error = false;

    if ( checked_GL_SGIX_texture_add_env == true )
      return NIV_GL_SGIX_texture_add_env;

    checked_GL_SGIX_texture_add_env = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_texture_add_env" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_texture_add_env = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SGI_cushion ()
  {
    bool error = false;

    if ( checked_GLX_SGI_cushion == true )
      return NIV_GLX_SGI_cushion;

    checked_GLX_SGI_cushion = true;
  
    if (strstr( GLXExtensionString, "GLX_SGI_cushion" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXCUSHIONSGI, glXCushionSGI );


    if (error == false)
      NIV_GLX_SGI_cushion = true;
    
    return !error;
  }
#endif

  bool InitGL_ARB_matrix_palette ()
  {
    bool error = false;

    if ( checked_GL_ARB_matrix_palette == true )
      return NIV_GL_ARB_matrix_palette;

    checked_GL_ARB_matrix_palette = true;
  
    if (strstr( GLExtensionString, "GL_ARB_matrix_palette" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLMATRIXINDEXPOINTERARB, glMatrixIndexPointerARB );
    INIT_FUNCTION( nivenGLMATRIXINDEXUIVARB, glMatrixIndexuivARB );
    INIT_FUNCTION( nivenGLMATRIXINDEXUSVARB, glMatrixIndexusvARB );
    INIT_FUNCTION( nivenGLCURRENTPALETTEMATRIXARB, glCurrentPaletteMatrixARB );
    INIT_FUNCTION( nivenGLMATRIXINDEXUBVARB, glMatrixIndexubvARB );


    if (error == false)
      NIV_GL_ARB_matrix_palette = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_SUN_get_transparent_index ()
  {
    bool error = false;

    if ( checked_GLX_SUN_get_transparent_index == true )
      return NIV_GLX_SUN_get_transparent_index;

    checked_GLX_SUN_get_transparent_index = true;
  
    if (strstr( GLXExtensionString, "GLX_SUN_get_transparent_index" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXGETTRANSPARENTINDEXSUN, glXGetTransparentIndexSUN );


    if (error == false)
      NIV_GLX_SUN_get_transparent_index = true;
    
    return !error;
  }
#endif

  bool InitGL_SGI_color_matrix ()
  {
    bool error = false;

    if ( checked_GL_SGI_color_matrix == true )
      return NIV_GL_SGI_color_matrix;

    checked_GL_SGI_color_matrix = true;
  
    if (strstr( GLExtensionString, "GL_SGI_color_matrix" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGI_color_matrix = true;
    
    return !error;
  }

  bool InitGL_EXT_packed_pixels ()
  {
    bool error = false;

    if ( checked_GL_EXT_packed_pixels == true )
      return NIV_GL_EXT_packed_pixels;

    checked_GL_EXT_packed_pixels = true;
  
    if (strstr( GLExtensionString, "GL_EXT_packed_pixels" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_EXT_packed_pixels = true;
    
    return !error;
  }

  bool InitGL_EXT_draw_range_elements ()
  {
    bool error = false;

    if ( checked_GL_EXT_draw_range_elements == true )
      return NIV_GL_EXT_draw_range_elements;

    checked_GL_EXT_draw_range_elements = true;
  
    if (strstr( GLExtensionString, "GL_EXT_draw_range_elements" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLDRAWRANGEELEMENTSEXT, glDrawRangeElementsEXT );


    if (error == false)
      NIV_GL_EXT_draw_range_elements = true;
    
    return !error;
  }

  bool InitGL_ARB_pixel_buffer_object ()
  {
    bool error = false;

    if ( checked_GL_ARB_pixel_buffer_object == true )
      return NIV_GL_ARB_pixel_buffer_object;

    checked_GL_ARB_pixel_buffer_object = true;
  
    if (strstr( GLExtensionString, "GL_ARB_pixel_buffer_object" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_ARB_pixel_buffer_object = true;
    
    return !error;
  }

  bool InitGL_S3_s3tc ()
  {
    bool error = false;

    if ( checked_GL_S3_s3tc == true )
      return NIV_GL_S3_s3tc;

    checked_GL_S3_s3tc = true;
  
    if (strstr( GLExtensionString, "GL_S3_s3tc" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_S3_s3tc = true;
    
    return !error;
  }

#ifdef _GLX
  bool InitGLX_NV_vertex_array_range ()
  {
    bool error = false;

    if ( checked_GLX_NV_vertex_array_range == true )
      return NIV_GLX_NV_vertex_array_range;

    checked_GLX_NV_vertex_array_range = true;
  
    if (strstr( GLXExtensionString, "GLX_NV_vertex_array_range" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }

    INIT_FUNCTION( nivenGLXALLOCATEMEMORYNV, glXAllocateMemoryNV );
    INIT_FUNCTION( nivenGLXFREEMEMORYNV, glXFreeMemoryNV );


    if (error == false)
      NIV_GLX_NV_vertex_array_range = true;
    
    return !error;
  }
#endif

  bool InitGL_SGIX_blend_alpha_minmax ()
  {
    bool error = false;

    if ( checked_GL_SGIX_blend_alpha_minmax == true )
      return NIV_GL_SGIX_blend_alpha_minmax;

    checked_GL_SGIX_blend_alpha_minmax = true;
  
    if (strstr( GLExtensionString, "GL_SGIX_blend_alpha_minmax" )==NULL)
      error = true;
    else
      error = false;

    
    if (error == true)
    {
      return false;	// Early out if extension string not found
    }



    if (error == false)
      NIV_GL_SGIX_blend_alpha_minmax = true;
    
    return !error;
  }


};